/*
 * In a generated replay, this file is partially common, boilerplate code
 * included in every replay, and partially generated replay code. The following
 * header applies to the boilerplate code. A comment indicating "Auto-generated
 * below this comment" marks the separation between these two parts.
 *
 * Copyright (C) 2011 Purdue University
 * Written by Gregor Richards
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

(function() {
    // global eval alias
    var geval = eval;

    // FIXME: gmail workaround, this can be handled more cleanly
    Function.prototype.bind = null;

    // detect if we're in a browser or not
    var inbrowser = false;
    var inharness = false;
    if (typeof window !== "undefined" && "document" in window) {
        inbrowser = true;
        if (window.parent && "JSBNG_handleResult" in window.parent) {
            inharness = true;
        }
    } else if (typeof global !== "undefined") {
        window = global;
        window.top = window;
    } else {
        window = (function() { return this; })();
        window.top = window;
    }

    var callpath = [];

    // global state
    var JSBNG_Replay = window.top.JSBNG_Replay = {
        push: function(arr, fun) {
            arr.push(fun);
            return fun;
        },

        path: function(str) {
            verifyPath(str);
        }
    };

    // the actual replay runner
    function onload() {
        try {
            delete window.onload;
        } catch (ex) {}

        var jr = JSBNG_Replay$;
        var cb = function() {
            var end = new Date().getTime();

            var msg = "Time: " + (end - st) + "ms";
    
            if (inharness) {
                window.parent.JSBNG_handleResult({error:false, time:(end - st)});
            } else if (inbrowser) {
                var res = document.createElement("div");
    
                res.style.position = "fixed";
                res.style.left = "1em";
                res.style.top = "1em";
                res.style.width = "35em";
                res.style.height = "5em";
                res.style.padding = "1em";
                res.style.backgroundColor = "white";
                res.style.color = "black";
                res.appendChild(document.createTextNode(msg));
    
                document.body.appendChild(res);
            } else if (typeof console !== "undefined") {
                console.log(msg);
            } else if (typeof print !== "undefined") {
                // hopefully not the browser print() function :)
                print(msg);
            }
        };

        // force it to JIT
        jr(false);

        // then time it
        var st = new Date().getTime();
        while (jr !== null) {
            jr = jr(true, cb);
        }
    }

    // add a frame at replay time
    function iframe(pageid) {
        var iw;
        if (inbrowser) {
            // represent the iframe as an iframe (of course)
            var iframe = document.createElement("iframe");
            iframe.style.display = "none";
            document.body.appendChild(iframe);
            iw = iframe.contentWindow;
            iw.document.write("<script type=\"text/javascript\">Function.prototype.bind = null; var JSBNG_Replay_geval = eval;</script>");
            iw.document.close();
        } else {
            // no general way, just lie and do horrible things
            var topwin = window;
            (function() {
                var window = {};
                window.window = window;
                window.top = topwin;
                window.JSBNG_Replay_geval = function(str) {
                    eval(str);
                }
                iw = window;
            })();
        }
        return iw;
    }

    // called at the end of the replay stuff
    function finalize() {
        if (inbrowser) {
            setTimeout(onload, 0);
        } else {
            onload();
        }
    }

    // verify this recorded value and this replayed value are close enough
    function verify(rep, rec) {
        if (rec !== rep &&
            (rep === rep || rec === rec) /* NaN test */) {
            if (typeof rec !== "object" || rec === null ||
                !(("__JSBNG_unknown_" + typeof(rep)) in rec)) {
                return false;
            }
        }
        return true;
    }

    // general message
    var firstMessage = true;
    function replayMessage(msg) {
        if (inbrowser) {
            if (firstMessage)
                document.open();
            firstMessage = false;
            document.write(msg);
        } else {
            console.log(msg);
        }
    }

    // complain when there's an error
    function verificationError(msg) {
        if (inharness) {
            window.parent.JSBNG_handleResult({error:true, msg: msg});
        } else replayMessage(msg);
        throw new Error();
    }

    // to verify a set
    function verifySet(objstr, obj, prop, gvalstr, gval) {
        if (/^on/.test(prop)) {
            // these aren't instrumented compatibly
            return;
        }

        if (!verify(obj[prop], gval)) {
            var bval = obj[prop];
            var msg = "Verification failure! " + objstr + "." + prop + " is not " + gvalstr + ", it's " + bval + "!";
            verificationError(msg);
        }
    }

    // to verify a call or new
    function verifyCall(iscall, func, cthis, cargs) {
        var ok = true;
        var callArgs = func.callArgs[func.inst];
        iscall = iscall ? 1 : 0;
        if (cargs.length !== callArgs.length - 1) {
            ok = false;
        } else {
            if (iscall && !verify(cthis, callArgs[0])) ok = false;
            for (var i = 0; i < cargs.length; i++) {
                if (!verify(cargs[i], callArgs[i+1])) ok = false;
            }
        }
        if (!ok) {
            var msg = "Call verification failure!";
            verificationError(msg);
        }

        return func.returns[func.inst++];
    }

    // to verify the callpath
    function verifyPath(func) {
        var real = callpath.shift();
        if (real !== func) {
            var msg = "Call path verification failure! Expected " + real + ", found " + func;
            verificationError(msg);
        }
    }

    // figure out how to define getters
    var defineGetter;
    if (Object.defineProperty) {
        var odp = Object.defineProperty;
        defineGetter = function(obj, prop, getter) {
            odp(obj, prop, {"enumerable": true, "get": getter, "set": function(){}});
        };
    } else if (Object.prototype.__defineGetter__) {
        var opdg = Object.prototype.__defineGetter__;
        var opds = Object.prototype.__defineSetter__;
        defineGetter = function(obj, prop, getter) {
            opdg.call(obj, prop, getter);
            opds.call(obj, prop, function(){});
        };
    } else {
        defineGetter = function() {
            verificationError("This replay requires getters for correct behavior, and your JS engine appears to be incapable of defining getters. Sorry!");
        };
    }

    // for calling events
    var fpc = Function.prototype.call;

// resist the urge, don't put a })(); here!
/******************************************************************************
 * Auto-generated below this comment
 *****************************************************************************/
var ow925563445 = window;
var f925563445_0;
var o0;
var o1;
var f925563445_4;
var f925563445_7;
var f925563445_12;
var f925563445_13;
var f925563445_14;
var f925563445_15;
var o2;
var o3;
var o4;
var f925563445_74;
var f925563445_75;
var f925563445_163;
var f925563445_280;
var f925563445_426;
var o5;
var fo925563445_427_className;
var o6;
var f925563445_430;
var fo925563445_1_cookie;
var f925563445_432;
var f925563445_433;
var f925563445_435;
var f925563445_436;
var f925563445_438;
var o7;
var f925563445_441;
var o8;
var o9;
var o10;
var o11;
var f925563445_457;
var f925563445_461;
var f925563445_465;
var f925563445_467;
var f925563445_468;
var o12;
var o13;
var f925563445_487;
var o14;
var o15;
var fo925563445_486_firstChild;
var o16;
var o17;
var o18;
var o19;
var o20;
var o21;
var o22;
var o23;
var o24;
var f925563445_550;
var f925563445_551;
var f925563445_552;
var o25;
var fo925563445_564___FB_TOKEN;
var o26;
var fo925563445_562___FB_TOKEN;
var o27;
var f925563445_577;
var o28;
var o29;
var o30;
var o31;
var o32;
var o33;
var o34;
var o35;
var fo925563445_574___FB_TOKEN;
var fo925563445_573___FB_TOKEN;
var fo925563445_427___FB_TOKEN;
var f925563445_596;
var f925563445_597;
var fo925563445_598___FB_TOKEN;
var o36;
var o37;
var o38;
var fo925563445_616___FB_TOKEN;
var fo925563445_618___FB_TOKEN;
var f925563445_621;
var f925563445_625;
var f925563445_626;
var f925563445_627;
var fo925563445_631___FB_TOKEN;
var fo925563445_636___FB_TOKEN;
var fo925563445_641___FB_TOKEN;
var fo925563445_646___FB_TOKEN;
var fo925563445_651___FB_TOKEN;
var fo925563445_656___FB_TOKEN;
var fo925563445_661___FB_TOKEN;
var fo925563445_666___FB_TOKEN;
var fo925563445_671___FB_TOKEN;
var fo925563445_676___FB_TOKEN;
var fo925563445_678_className;
var fo925563445_680___FB_TOKEN;
var fo925563445_686___FB_TOKEN;
var fo925563445_693___FB_TOKEN;
var fo925563445_694___FB_TOKEN;
var fo925563445_705___FB_TOKEN;
var fo925563445_706___FB_TOKEN;
var fo925563445_717___FB_TOKEN;
var fo925563445_719___FB_TOKEN;
var o39;
var o40;
var o41;
var o42;
var o43;
var o44;
var o45;
var o46;
var o47;
var o48;
var o49;
var o50;
var o51;
var o52;
var o53;
var o54;
var o55;
var o56;
var o57;
var o58;
var o59;
var o60;
var o61;
var o62;
var o63;
var o64;
var o65;
var o66;
var o67;
var o68;
var o69;
var o70;
var fo925563445_729_className;
var fo925563445_737_className;
var fo925563445_747_className;
var fo925563445_757_className;
var fo925563445_773___FB_TOKEN;
var fo925563445_780___FB_TOKEN;
var fo925563445_787___FB_TOKEN;
var fo925563445_788___FB_TOKEN;
var fo925563445_789___FB_TOKEN;
var fo925563445_790___FB_TOKEN;
var fo925563445_791___FB_TOKEN;
var fo925563445_814___FB_TOKEN;
var fo925563445_821___FB_TOKEN;
var fo925563445_823___FB_TOKEN;
var o71;
var o72;
var o73;
var o74;
var o75;
var o76;
var o77;
var o78;
var o79;
var fo925563445_831_className;
var fo925563445_839_className;
var fo925563445_847_className;
var fo925563445_863_className;
var fo925563445_871_className;
var fo925563445_887___FB_TOKEN;
var fo925563445_889___FB_TOKEN;
var fo925563445_894_className;
var fo925563445_904___FB_TOKEN;
var fo925563445_917___FB_TOKEN;
var fo925563445_925___FB_TOKEN;
var fo925563445_927___FB_TOKEN;
var fo925563445_935_className;
var fo925563445_943_className;
var fo925563445_624_readyState;
var fo925563445_622_className;
var fo925563445_959_readyState;
var fo925563445_962___FB_TOKEN;
var f925563445_1001;
var fo925563445_1___FB_TOKEN;
var fo925563445_983___FB_TOKEN;
var fo925563445_982___FB_TOKEN;
var fo925563445_988___FB_TOKEN;
var fo925563445_978___FB_TOKEN;
var fo925563445_1011___FB_TOKEN;
var fo925563445_1031___FB_TOKEN;
var f925563445_1035;
var f925563445_1037;
var fo925563445_1030_firstChild;
var f925563445_1055;
var fo925563445_977_className;
var fo925563445_989___FB_TOKEN;
var fo925563445_1065_className;
var fo925563445_1065___FB_TOKEN;
var fo925563445_1082_options;
var fo925563445_1098_className;
var fo925563445_1099_className;
var fo925563445_1098___FB_TOKEN;
var fo925563445_1099___FB_TOKEN;
var fo925563445_1106_className;
var fo925563445_1108_className;
var f925563445_1113;
var fo925563445_1116___FB_TOKEN;
var fo925563445_1018___FB_TOKEN;
var fo925563445_1154_options;
var fo925563445_1117___FB_TOKEN;
var f925563445_1171;
var f925563445_1175;
var fo925563445_1179_readyState;
var f925563445_1182;
var fo925563445_1180_readyState;
var fo925563445_1201_readyState;
var fo925563445_1252_readyState;
var o80;
var o81;
var o82;
var o83;
var o84;
var o85;
var o86;
var o87;
var o88;
var o89;
var o90;
var o91;
var o92;
var o93;
var o94;
var o95;
var o96;
var o97;
var o98;
var o99;
var o100;
var o101;
var o102;
var o103;
var o104;
var o105;
var o106;
var o107;
var o108;
var o109;
var o110;
var o111;
var o112;
var o113;
var o114;
var o115;
var o116;
var o117;
var o118;
var o119;
var o120;
var o121;
var o122;
var o123;
var o124;
var o125;
var o126;
var o127;
var o128;
var o129;
var o130;
var o131;
var o132;
var o133;
var o134;
var o135;
var o136;
var o137;
var o138;
var o139;
var o140;
var o141;
var o142;
var o143;
var o144;
var o145;
var o146;
var o147;
var o148;
var o149;
var o150;
var o151;
var o152;
var o153;
var o154;
var o155;
var o156;
var o157;
var o158;
var o159;
var o160;
var o161;
var o162;
var o163;
var o164;
var o165;
var o166;
var o167;
var o168;
var o169;
var o170;
var o171;
var o172;
var o173;
var o174;
var o175;
var o176;
var o177;
var o178;
var o179;
var o180;
var o181;
var o182;
var o183;
var o184;
var o185;
var o186;
var o187;
var o188;
var o189;
var o190;
var o191;
var o192;
var o193;
var o194;
var o195;
var o196;
var o197;
var o198;
var o199;
var o200;
var o201;
var o202;
var o203;
var o204;
var o205;
var o206;
var o207;
var o208;
var o209;
var o210;
var o211;
var o212;
var o213;
var o214;
var o215;
var o216;
var o217;
var o218;
var o219;
var o220;
var o221;
var o222;
var o223;
var o224;
var o225;
var o226;
var o227;
var o228;
var o229;
var o230;
var o231;
var o232;
var o233;
var o234;
var o235;
var o236;
var o237;
var o238;
var o239;
var o240;
var o241;
var o242;
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_154 = [];
JSBNG_Replay.sfb70ab12eee911300ccf01d20dbb588c58164ec7_2 = [];
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32 = [];
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28 = [];
JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_505 = [];
JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11 = [];
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_157 = [];
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88 = [];
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_158 = [];
// 1
// 2
f925563445_0 = function() { return f925563445_0.returns[f925563445_0.inst++]; };
f925563445_0.returns = [];
f925563445_0.inst = 0;
// 3
ow925563445.JSBNG__Date = f925563445_0;
// 4
o0 = {};
// 5
ow925563445.JSBNG__document = o0;
// 6
o1 = {};
// 7
ow925563445.JSBNG__sessionStorage = o1;
// 10
f925563445_4 = function() { return f925563445_4.returns[f925563445_4.inst++]; };
f925563445_4.returns = [];
f925563445_4.inst = 0;
// 11
ow925563445.JSBNG__getComputedStyle = f925563445_4;
// 16
f925563445_7 = function() { return f925563445_7.returns[f925563445_7.inst++]; };
f925563445_7.returns = [];
f925563445_7.inst = 0;
// 17
ow925563445.JSBNG__addEventListener = f925563445_7;
// 18
ow925563445.JSBNG__top = ow925563445;
// 23
ow925563445.JSBNG__scrollX = 0;
// 24
ow925563445.JSBNG__scrollY = 0;
// 29
f925563445_12 = function() { return f925563445_12.returns[f925563445_12.inst++]; };
f925563445_12.returns = [];
f925563445_12.inst = 0;
// 30
ow925563445.JSBNG__setTimeout = f925563445_12;
// 31
f925563445_13 = function() { return f925563445_13.returns[f925563445_13.inst++]; };
f925563445_13.returns = [];
f925563445_13.inst = 0;
// 32
ow925563445.JSBNG__setInterval = f925563445_13;
// 33
f925563445_14 = function() { return f925563445_14.returns[f925563445_14.inst++]; };
f925563445_14.returns = [];
f925563445_14.inst = 0;
// 34
ow925563445.JSBNG__clearTimeout = f925563445_14;
// 35
f925563445_15 = function() { return f925563445_15.returns[f925563445_15.inst++]; };
f925563445_15.returns = [];
f925563445_15.inst = 0;
// 36
ow925563445.JSBNG__clearInterval = f925563445_15;
// 41
ow925563445.JSBNG__frames = ow925563445;
// 44
ow925563445.JSBNG__self = ow925563445;
// 45
o2 = {};
// 46
ow925563445.JSBNG__navigator = o2;
// 49
o3 = {};
// 50
ow925563445.JSBNG__history = o3;
// 61
ow925563445.JSBNG__closed = false;
// 64
ow925563445.JSBNG__opener = null;
// 65
ow925563445.JSBNG__defaultStatus = "";
// 66
o4 = {};
// 67
ow925563445.JSBNG__location = o4;
// 68
ow925563445.JSBNG__innerWidth = 1280;
// 69
ow925563445.JSBNG__innerHeight = 709;
// 70
ow925563445.JSBNG__outerWidth = 1280;
// 71
ow925563445.JSBNG__outerHeight = 771;
// 72
ow925563445.JSBNG__screenX = 0;
// 73
ow925563445.JSBNG__screenY = 0;
// 74
ow925563445.JSBNG__pageXOffset = 0;
// 75
ow925563445.JSBNG__pageYOffset = 0;
// 100
ow925563445.JSBNG__frameElement = undefined;
// 131
ow925563445.JSBNG__screenLeft = 0;
// 136
ow925563445.JSBNG__clientInformation = o2;
// 139
ow925563445.JSBNG__defaultstatus = "";
// 152
ow925563445.JSBNG__event = undefined;
// 153
ow925563445.JSBNG__devicePixelRatio = 1;
// 158
ow925563445.JSBNG__offscreenBuffering = true;
// 159
ow925563445.JSBNG__screenTop = 0;
// 174
f925563445_74 = function() { return f925563445_74.returns[f925563445_74.inst++]; };
f925563445_74.returns = [];
f925563445_74.inst = 0;
// 175
ow925563445.JSBNG__XMLHttpRequest = f925563445_74;
// 176
f925563445_75 = function() { return f925563445_75.returns[f925563445_75.inst++]; };
f925563445_75.returns = [];
f925563445_75.inst = 0;
// 177
ow925563445.JSBNG__Image = f925563445_75;
// 178
ow925563445.JSBNG__name = "";
// 185
ow925563445.JSBNG__status = "";
// 354
f925563445_163 = function() { return f925563445_163.returns[f925563445_163.inst++]; };
f925563445_163.returns = [];
f925563445_163.inst = 0;
// 355
ow925563445.JSBNG__Document = f925563445_163;
// 588
f925563445_280 = function() { return f925563445_280.returns[f925563445_280.inst++]; };
f925563445_280.returns = [];
f925563445_280.inst = 0;
// 589
ow925563445.JSBNG__Event = f925563445_280;
// 634
ow925563445.JSBNG__XMLDocument = f925563445_163;
// 855
ow925563445.JSBNG__TEMPORARY = 0;
// 856
ow925563445.JSBNG__PERSISTENT = 1;
// 883
f925563445_426 = function() { return f925563445_426.returns[f925563445_426.inst++]; };
f925563445_426.returns = [];
f925563445_426.inst = 0;
// 884
ow925563445.Math.JSBNG__random = f925563445_426;
// 885
// 888
o2.userAgent = "Mozilla/5.0 (X11; Linux i686 (x86_64)) AppleWebKit/535.3 (KHTML, like Gecko) Chrome/16.0.877.0 Safari/535.3";
// 889
o0.domain = "www.facebook.com";
// 891
o4.hostname = "www.facebook.com";
// 892
// 893
// 894
o5 = {};
// 895
o0.documentElement = o5;
// undefined
fo925563445_427_className = function() { return fo925563445_427_className.returns[fo925563445_427_className.inst++]; };
fo925563445_427_className.returns = [];
fo925563445_427_className.inst = 0;
defineGetter(o5, "className", fo925563445_427_className);
// undefined
fo925563445_427_className.returns.push("no_js");
// 899
// 900
// 902
o6 = {};
// 903
f925563445_0.returns.push(o6);
// undefined
o6 = null;
// 904
o6 = {};
// 905
f925563445_0.returns.push(o6);
// 906
f925563445_430 = function() { return f925563445_430.returns[f925563445_430.inst++]; };
f925563445_430.returns = [];
f925563445_430.inst = 0;
// 907
o6.toGMTString = f925563445_430;
// undefined
o6 = null;
// 908
f925563445_430.returns.push("Invalid Date");
// undefined
fo925563445_1_cookie = function() { return fo925563445_1_cookie.returns[fo925563445_1_cookie.inst++]; };
fo925563445_1_cookie.returns = [];
fo925563445_1_cookie.inst = 0;
defineGetter(o0, "cookie", fo925563445_1_cookie);
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199");
// 911
o6 = {};
// 912
f925563445_0.returns.push(o6);
// undefined
o6 = null;
// 913
// 914
// 915
// 916
f925563445_432 = function() { return f925563445_432.returns[f925563445_432.inst++]; };
f925563445_432.returns = [];
f925563445_432.inst = 0;
// 917
o1.getItem = f925563445_432;
// 918
f925563445_432.returns.push(null);
// 919
// 920
// 921
// 922
// 923
// 924
// 925
// 926
// 927
// 928
// 929
// 930
// 931
// 932
// 933
// 934
// 936
// 938
// 939
// 940
// 941
// 942
// 943
// 944
// 945
// 946
// 947
// 948
// 949
// 950
// 951
// 952
f925563445_433 = function() { return f925563445_433.returns[f925563445_433.inst++]; };
f925563445_433.returns = [];
f925563445_433.inst = 0;
// 953
o0.JSBNG__addEventListener = f925563445_433;
// 954
// 955
// 958
f925563445_433.returns.push(undefined);
// 959
// 960
// 961
// 962
// 963
// 964
// 965
// 966
// 967
// 968
// 969
// 970
// 971
// 972
// 973
// 974
// 975
// 976
// 977
// 978
// 979
// 980
// 981
// 982
// 983
o4.href = "http://www.facebook.com/";
// undefined
o4 = null;
// 984
// 985
// 987
o5.JSBNG__addEventListener = f925563445_433;
// 989
f925563445_433.returns.push(undefined);
// 991
f925563445_433.returns.push(undefined);
// 993
// 995
// 996
// 997
// 998
// 999
// 1000
// 1001
// 1002
// 1003
// 1004
// 1005
// 1006
// 1007
// 1008
// 1009
// 1010
// 1013
// 1014
o5.clientWidth = 1280;
// undefined
fo925563445_427_className.returns.push("");
// 1017
// 1018
ow925563445.JSBNG__attachEvent = undefined;
// 1019
f925563445_7.returns.push(undefined);
// 1020
f925563445_12.returns.push(4);
// 1030
o4 = {};
// 1031
f925563445_0.returns.push(o4);
// 1032
f925563445_435 = function() { return f925563445_435.returns[f925563445_435.inst++]; };
f925563445_435.returns = [];
f925563445_435.inst = 0;
// 1033
o4.getTime = f925563445_435;
// undefined
o4 = null;
// 1034
f925563445_435.returns.push(1318265693322);
// 1036
// 1037
// 1038
// 1039
// 1040
// 1041
// 1042
// 1043
// 1044
// 1045
// 1046
// 1047
// 1048
// 1049
// 1051
// 1052
// 1053
// 1054
// 1055
// 1056
// 1057
f925563445_436 = function() { return f925563445_436.returns[f925563445_436.inst++]; };
f925563445_436.returns = [];
f925563445_436.inst = 0;
// 1058
o0.createElement = f925563445_436;
// 1059
o4 = {};
// 1060
f925563445_436.returns.push(o4);
// 1061
// 1062
// 1063
f925563445_438 = function() { return f925563445_438.returns[f925563445_438.inst++]; };
f925563445_438.returns = [];
f925563445_438.inst = 0;
// 1064
o0.getElementsByTagName = f925563445_438;
// 1065
o6 = {};
// 1066
f925563445_438.returns.push(o6);
// 1067
o6.length = 1;
// 1068
o7 = {};
// 1069
o6["0"] = o7;
// undefined
o6 = null;
// 1070
f925563445_441 = function() { return f925563445_441.returns[f925563445_441.inst++]; };
f925563445_441.returns = [];
f925563445_441.inst = 0;
// 1071
o7.appendChild = f925563445_441;
// 1072
f925563445_441.returns.push(o4);
// 1073
o6 = {};
// 1074
f925563445_0.returns.push(o6);
// undefined
o6 = null;
// 1075
// 1076
f925563445_13.returns.push(5);
// 1077
// 1078
// 1079
// 1080
// 1082
o6 = {};
// 1083
f925563445_436.returns.push(o6);
// 1084
// 1085
// 1087
f925563445_441.returns.push(o6);
// 1088
o8 = {};
// 1089
f925563445_0.returns.push(o8);
// undefined
o8 = null;
// 1090
// 1091
// 1092
// 1093
// 1094
// 1096
o8 = {};
// 1097
f925563445_436.returns.push(o8);
// 1098
// 1099
// 1101
f925563445_441.returns.push(o8);
// 1102
o9 = {};
// 1103
f925563445_0.returns.push(o9);
// undefined
o9 = null;
// 1104
// 1105
// 1106
// 1107
// 1108
// 1110
o9 = {};
// 1111
f925563445_436.returns.push(o9);
// 1112
// 1113
// 1115
f925563445_441.returns.push(o9);
// 1116
o10 = {};
// 1117
f925563445_0.returns.push(o10);
// undefined
o10 = null;
// 1118
// 1120
o10 = {};
// 1121
f925563445_438.returns.push(o10);
// 1122
o10.length = 6;
// 1123
o11 = {};
// 1124
o10["0"] = o11;
// 1125
o11.rel = "alternate";
// undefined
o11 = null;
// 1127
o11 = {};
// 1128
o10["1"] = o11;
// 1129
o11.rel = "stylesheet";
// 1131
o11.href = "http://static.ak.fbcdn.net/rsrc.php/v1/yO/r/0lyilyZ95tg.css";
// undefined
o11 = null;
// 1134
o11 = {};
// 1135
o10["2"] = o11;
// 1136
o11.rel = "stylesheet";
// 1138
o11.href = "http://static.ak.fbcdn.net/rsrc.php/v1/yi/r/ErOKEBv7otW.css";
// undefined
o11 = null;
// 1141
o11 = {};
// 1142
o10["3"] = o11;
// 1143
o11.rel = "stylesheet";
// 1145
o11.href = "http://static.ak.fbcdn.net/rsrc.php/v1/yk/r/W3vdX4klem6.css";
// undefined
o11 = null;
// 1148
o11 = {};
// 1149
o10["4"] = o11;
// 1150
o11.rel = "stylesheet";
// 1152
o11.href = "http://static.ak.fbcdn.net/rsrc.php/v1/yR/r/ITJh_KJve0v.css";
// undefined
o11 = null;
// 1155
o11 = {};
// 1156
o10["5"] = o11;
// undefined
o10 = null;
// 1157
o11.rel = "shortcut icon";
// undefined
o11 = null;
// 1159
// 1160
// 1161
// 1162
// 1163
// 1164
// 1165
// 1166
// 1167
// 1168
// 1169
// 1170
// 1171
// 1172
// 1173
// 1174
// 1175
// 1176
// 1177
// 1178
// 1179
// 1180
// 1181
// 1182
// 1183
// 1184
// 1185
// 1186
// 1187
// 1188
// 1189
// 1190
// 1191
// 1192
// 1193
// 1194
// 1195
// 1196
// 1197
// 1198
// 1199
// 1200
// 1201
// 1202
// 1203
// 1204
// 1205
// 1206
// 1207
// 1208
// 1209
// 1211
// 1212
// 1213
// 1214
// 1215
// 1216
// 1217
// 1218
// 1219
// 1220
// 1221
// 1222
// 1223
// 1224
// 1225
// 1226
// 1227
// 1228
// 1229
// 1230
// 1232
// 1233
// 1234
// 1235
// 1236
// 1237
// 1238
// 1239
// 1240
// 1241
// 1242
// 1243
// 1244
// 1245
// 1246
// 1247
// 1248
// 1249
// 1250
// 1251
// 1252
// 1253
// 1254
// 1255
// 1256
// 1257
// 1258
// 1259
// 1260
// 1261
// 1262
// 1263
// 1264
// 1265
// 1266
// 1267
// 1268
// 1269
// 1270
// 1271
// 1272
// 1273
// 1274
// 1275
// 1276
// 1277
// 1278
// 1279
// 1280
// 1281
// 1282
// 1283
// 1284
// 1285
// 1286
// 1287
// 1288
// 1289
// 1290
// 1291
// 1292
// 1293
// 1294
// 1295
// 1296
// 1297
// 1298
// 1299
// 1300
// 1301
// 1302
// 1303
// 1304
// 1305
// 1306
// 1307
// 1308
// 1309
// 1310
// 1311
// 1312
// 1313
// 1314
// 1315
// 1316
// 1317
// 1318
// 1319
// 1320
// 1321
// 1322
// 1323
// 1324
// 1325
// 1326
// 1328
// 1329
// 1330
// 1331
// 1332
// 1333
// 1334
// 1335
// 1336
// 1337
// 1338
// 1339
// 1340
// 1341
// 1342
// 1343
// 1344
// 1345
// 1346
// 1347
// 1348
// 1349
// 1350
// 1351
// 1352
// 1353
// 1354
// 1355
// 1356
// 1357
// 1358
// 1359
// 1360
// 1361
// 1362
// 1363
// 1364
// 1365
// 1366
// 1367
// 1368
// 1369
// 1370
// 1371
// 1372
// 1373
// 1374
// 1376
// 1377
// 1378
// 1379
// 1380
// 1381
// 1382
// 1383
// 1384
// 1385
// 1386
// 1387
// 1388
// 1389
// 1390
// 1391
// 1392
// 1393
// 1394
// 1395
// 1396
// 1397
// 1398
// 1399
// 1400
// 1401
// 1402
// 1403
// 1404
// 1405
// 1406
// 1407
// 1408
// 1409
// 1410
// 1411
// 1412
// 1413
// 1414
// 1415
// 1416
// 1417
// 1419
// 1420
// 1421
// 1422
// 1423
// 1424
// 1425
// 1426
// 1427
// 1428
// 1429
// 1430
// 1431
// 1432
// 1433
// 1434
// 1435
// 1436
// 1437
// 1438
// 1439
// 1440
// 1441
// 1442
// 1443
// 1444
// 1445
// 1446
// 1447
// 1448
// 1449
// 1450
// 1451
// 1452
// 1453
// 1454
// 1455
// 1456
// 1457
// 1459
// 1460
// 1461
// 1462
// 1463
// 1464
// 1465
// 1466
// 1467
// 1468
// 1469
// 1470
// 1471
// 1472
// 1473
// 1474
// 1475
// 1476
// 1477
// 1478
// 1479
// 1480
// 1481
// 1482
// 1483
// 1484
// 1485
// 1486
// 1487
// 1488
// 1489
// 1490
// 1491
// 1492
// 1493
// 1494
// 1495
// 1496
// 1497
// 1498
// 1499
// 1500
// 1501
// 1502
// 1503
// 1505
// 1506
// 1507
// 1508
// 1509
// 1510
// 1511
// 1512
// 1513
// 1514
// 1515
// 1516
// 1517
// 1518
// 1519
// 1520
// 1521
// 1522
// 1523
// 1524
// 1525
// 1526
// 1527
// 1528
// 1529
// 1530
// 1531
// 1532
// 1533
// 1534
// 1535
// 1536
// 1537
// 1538
// 1539
// 1540
// 1541
// 1542
// 1543
// 1544
// 1545
// 1546
// 1547
// 1548
// 1549
// 1550
// 1551
// 1553
// 1554
// 1555
// 1556
// 1557
// 1558
// 1559
// 1560
// 1561
// 1562
// 1563
// 1564
// 1565
// 1566
// 1567
// 1568
// 1569
// 1570
// 1571
// 1572
// 1573
// 1574
// 1575
// 1576
// 1577
// 1578
// 1579
// 1580
// 1581
// 1582
// 1583
// 1584
// 1585
// 1586
// 1587
// 1588
// 1589
// 1590
// 1591
// 1592
// 1593
// 1594
// 1595
// 1596
// 1597
// 1599
// 1600
// 1601
// 1602
// 1603
// 1604
// 1605
// 1606
// 1607
// 1608
// 1609
// 1610
// 1611
// 1612
// 1613
// 1614
// 1615
// 1616
// 1617
// 1618
// 1619
// 1620
// 1621
// 1622
// 1623
// 1624
// 1625
// 1626
// 1627
// 1628
// 1629
// 1630
// 1631
// 1632
// 1633
// 1634
// 1635
// 1636
// 1637
// 1638
// 1639
// 1640
// 1641
// 1642
// 1643
// 1644
// 1645
// 1646
// 1647
// 1648
// 1649
// 1650
// 1651
// 1652
// 1653
// 1654
// 1656
// 1657
// 1658
// 1659
// 1660
// 1661
// 1662
// 1663
// 1664
// 1665
// 1666
// 1667
// 1668
// 1669
// 1670
// 1671
// 1672
// 1673
// 1674
// 1675
// 1676
// 1677
// 1678
// 1679
// 1680
// 1681
// 1682
// 1683
// 1684
// 1685
// 1686
// 1687
// 1688
// 1689
// 1690
// 1691
// 1692
// 1693
// 1694
// 1695
// 1696
// 1697
// 1698
// 1699
// 1700
// 1701
// 1702
// 1703
// 1704
// 1705
// 1707
// 1708
// 1709
// 1710
// 1711
// 1712
// 1713
// 1714
// 1715
// 1716
// 1717
// 1718
// 1719
// 1720
// 1721
// 1722
// 1723
// 1724
// 1725
// 1726
// 1727
// 1728
// 1729
// 1730
// 1731
// 1732
// 1733
// 1734
// 1735
// 1736
// 1737
// 1738
// 1739
// 1740
// 1741
// 1742
// 1743
// 1744
// 1745
// 1747
// 1748
// 1749
// 1750
// 1751
// 1752
// 1753
// 1754
// 1755
// 1756
// 1757
// 1758
// 1759
// 1760
// 1761
// 1762
// 1763
// 1764
// 1765
// 1766
// 1767
// 1768
// 1769
// 1770
// 1771
// 1772
// 1773
// 1774
// 1775
// 1776
// 1777
// 1778
// 1779
// 1780
// 1781
// 1782
// 1783
// 1784
// 1785
// 1786
// 1787
// 1788
// 1789
// 1791
// 1792
// 1793
// 1794
// 1795
// 1796
// 1797
// 1798
// 1799
// 1800
// 1801
// 1802
// 1803
// 1804
// 1805
// 1806
// 1807
// 1808
// 1809
// 1810
// 1811
// 1812
// 1813
// 1814
// 1815
// 1816
// 1817
// 1818
// 1819
// 1820
// 1821
// 1822
// 1823
// 1824
// 1825
// 1826
// 1827
// 1828
// 1829
// 1830
// 1831
// 1832
// 1833
// 1834
// 1835
// 1836
o10 = {};
// 1838
// 1839
// 1840
// 1841
// 1842
// 1843
// 1844
// 1846
// 1847
f925563445_457 = function() { return f925563445_457.returns[f925563445_457.inst++]; };
f925563445_457.returns = [];
f925563445_457.inst = 0;
// 1848
o0.getElementById = f925563445_457;
// 1849
o11 = {};
// 1850
f925563445_457.returns.push(o11);
// undefined
o11 = null;
// 1852
// 1853
// 1854
o11 = {};
// 1855
f925563445_0.returns.push(o11);
// 1856
o11.getTime = f925563445_435;
// undefined
o11 = null;
// 1857
f925563445_435.returns.push(1318265693425);
// 1858
o4.offsetHeight = 0;
// 1859
o4.currentStyle = null;
// 1860
o0.defaultView = ow925563445;
// 1861
o11 = {};
// 1862
f925563445_4.returns.push(o11);
// 1863
f925563445_461 = function() { return f925563445_461.returns[f925563445_461.inst++]; };
f925563445_461.returns = [];
f925563445_461.inst = 0;
// 1864
o11.getPropertyValue = f925563445_461;
// undefined
o11 = null;
// 1865
f925563445_461.returns.push("42px");
// 1866
o6.offsetHeight = 0;
// 1867
o6.currentStyle = null;
// 1869
o11 = {};
// 1870
f925563445_4.returns.push(o11);
// 1871
o11.getPropertyValue = f925563445_461;
// undefined
o11 = null;
// 1872
f925563445_461.returns.push("42px");
// 1873
o8.offsetHeight = 0;
// 1874
o8.currentStyle = null;
// 1876
o11 = {};
// 1877
f925563445_4.returns.push(o11);
// 1878
o11.getPropertyValue = f925563445_461;
// undefined
o11 = null;
// 1879
f925563445_461.returns.push("42px");
// 1880
o9.offsetHeight = 0;
// 1881
o9.currentStyle = null;
// 1883
o11 = {};
// 1884
f925563445_4.returns.push(o11);
// 1885
o11.getPropertyValue = f925563445_461;
// undefined
o11 = null;
// 1886
f925563445_461.returns.push("42px");
// 1887
// 1888
o4.parentNode = o7;
// 1889
f925563445_465 = function() { return f925563445_465.returns[f925563445_465.inst++]; };
f925563445_465.returns = [];
f925563445_465.inst = 0;
// 1890
o7.removeChild = f925563445_465;
// 1891
f925563445_465.returns.push(o4);
// undefined
o4 = null;
// 1892
o6.parentNode = o7;
// 1894
f925563445_465.returns.push(o6);
// undefined
o6 = null;
// 1895
o8.parentNode = o7;
// 1897
f925563445_465.returns.push(o8);
// undefined
o8 = null;
// 1898
o9.parentNode = o7;
// 1900
f925563445_465.returns.push(o9);
// undefined
o9 = null;
// 1901
// 1902
// 1903
// 1904
// 1905
// 1906
// 1907
// 1908
// 1909
// 1910
// 1911
// 1912
// 1913
// 1914
// 1915
// 1916
// 1917
// 1918
// 1919
// 1920
// 1921
// 1922
// 1923
// 1924
// 1925
// 1926
// 1927
// 1928
// 1929
// 1930
// 1931
// 1932
// 1933
// 1934
// 1935
// 1936
// 1937
// 1938
// 1939
// 1940
// 1941
// 1942
// 1943
// 1944
// 1945
// 1946
// 1947
// 1948
// 1949
// 1950
// 1951
// 1952
// 1953
// 1954
// 1955
// 1956
// 1957
// 1958
// 1959
// 1960
// 1961
// 1962
// 1963
// 1964
// 1965
// 1966
// 1967
// 1968
// 1969
// 1970
// 1971
// 1972
// 1973
// 1974
// 1975
// 1977
o4 = {};
// 1978
f925563445_457.returns.push(o4);
// 1979
// 1980
// 1981
// 1982
f925563445_467 = function() { return f925563445_467.returns[f925563445_467.inst++]; };
f925563445_467.returns = [];
f925563445_467.inst = 0;
// 1983
o4.setAttribute = f925563445_467;
// 1984
f925563445_468 = function() { return f925563445_468.returns[f925563445_468.inst++]; };
f925563445_468.returns = [];
f925563445_468.inst = 0;
// 1985
o4.getAttribute = f925563445_468;
// undefined
o4 = null;
// 1986
f925563445_468.returns.push("pagelet_welcome_box");
// 1987
f925563445_467.returns.push(undefined);
// 1988
// 1989
// 1990
// 1991
// 1992
// 1993
// 1994
// 1995
// 1996
// 1997
// 1998
// 1999
// 2000
// 2001
// 2002
// 2003
// 2004
// 2005
// 2006
// 2007
// 2008
// 2009
// 2010
// 2011
// 2012
// 2013
// 2014
// 2015
// 2016
// 2017
// 2018
// 2019
// 2020
// 2021
// 2022
// 2023
// 2024
// 2025
// 2026
// 2027
// 2028
// 2029
// 2031
o4 = {};
// 2032
f925563445_457.returns.push(o4);
// 2033
// 2034
// 2035
// 2036
o4.setAttribute = f925563445_467;
// 2037
o4.getAttribute = f925563445_468;
// undefined
o4 = null;
// 2038
f925563445_468.returns.push("pagelet_navigation");
// 2039
f925563445_467.returns.push(undefined);
// 2040
// 2041
// 2042
// 2043
// 2044
// 2045
// 2046
// 2047
// 2048
// 2049
// 2050
// 2051
// 2052
// 2053
// 2054
// 2055
// 2056
// 2057
// 2058
// 2059
// 2060
// 2061
// 2062
// 2063
// 2064
// 2065
// 2066
// 2067
// 2068
// 2069
// 2070
// 2071
// 2072
// 2073
// 2074
// 2075
// 2076
// 2077
// 2078
// 2079
// 2080
// 2081
// 2082
// 2083
// 2084
// 2085
// 2086
// 2087
// 2088
// 2089
// 2090
// 2091
// 2092
// 2093
// 2094
// 2095
// 2096
// 2097
// 2098
// 2099
// 2100
// 2101
// 2102
// 2103
// 2104
// 2105
// 2106
// 2107
// 2108
// 2109
// 2110
// 2111
// 2112
// 2113
o0.createStyleSheet = null;
// 2115
o4 = {};
// 2116
f925563445_436.returns.push(o4);
// 2117
// 2118
// 2119
// 2120
// 2122
f925563445_441.returns.push(o4);
// undefined
o4 = null;
// 2123
// 2125
o4 = {};
// 2126
f925563445_436.returns.push(o4);
// 2127
// 2128
// 2130
f925563445_441.returns.push(o4);
// 2131
o6 = {};
// 2132
f925563445_0.returns.push(o6);
// undefined
o6 = null;
// 2133
// 2134
f925563445_13.returns.push(6);
// 2135
// 2136
// 2139
o6 = {};
// 2140
f925563445_436.returns.push(o6);
// 2141
// 2142
// 2143
// 2144
// 2146
f925563445_441.returns.push(o6);
// undefined
o6 = null;
// 2147
// 2149
o6 = {};
// 2150
f925563445_436.returns.push(o6);
// 2151
// 2152
// 2154
f925563445_441.returns.push(o6);
// 2155
o8 = {};
// 2156
f925563445_0.returns.push(o8);
// undefined
o8 = null;
// 2157
// 2158
// 2159
// 2162
o8 = {};
// 2163
f925563445_436.returns.push(o8);
// 2164
// 2165
// 2166
// 2167
// 2169
f925563445_441.returns.push(o8);
// undefined
o8 = null;
// 2170
// 2172
o8 = {};
// 2173
f925563445_436.returns.push(o8);
// 2174
// 2175
// 2177
f925563445_441.returns.push(o8);
// 2178
o9 = {};
// 2179
f925563445_0.returns.push(o9);
// undefined
o9 = null;
// 2180
// 2181
// 2182
// 2185
o9 = {};
// 2186
f925563445_436.returns.push(o9);
// 2187
// 2188
// 2189
// 2190
// 2192
f925563445_441.returns.push(o9);
// undefined
o9 = null;
// 2193
// 2195
o9 = {};
// 2196
f925563445_436.returns.push(o9);
// 2197
// 2198
// 2200
f925563445_441.returns.push(o9);
// 2201
o11 = {};
// 2202
f925563445_0.returns.push(o11);
// undefined
o11 = null;
// 2203
// 2204
// 2205
// 2208
o11 = {};
// 2209
f925563445_436.returns.push(o11);
// 2210
// 2211
// 2212
// 2213
// 2215
f925563445_441.returns.push(o11);
// undefined
o11 = null;
// 2216
// 2218
o11 = {};
// 2219
f925563445_436.returns.push(o11);
// 2220
// 2221
// 2223
f925563445_441.returns.push(o11);
// 2224
o12 = {};
// 2225
f925563445_0.returns.push(o12);
// undefined
o12 = null;
// 2226
// 2227
// 2228
// 2229
// 2230
// 2231
// 2232
// 2233
// 2234
// 2235
// 2236
// 2237
// 2238
// 2239
// 2240
// 2241
// 2242
// 2243
// 2244
// 2245
// 2246
// 2247
// 2248
// 2249
// 2250
// 2251
// 2252
// 2253
// 2254
// 2255
// 2256
// 2257
// 2258
// 2259
// 2260
// 2261
// 2262
// 2263
// 2264
// 2265
// 2266
// 2267
// 2268
// 2269
// 2270
// 2271
// 2272
// 2273
// 2274
// 2275
// 2276
// 2278
o12 = {};
// 2279
f925563445_457.returns.push(o12);
// 2280
// 2282
o13 = {};
// 2283
f925563445_436.returns.push(o13);
// 2284
// 2285
// 2286
// 2287
f925563445_487 = function() { return f925563445_487.returns[f925563445_487.inst++]; };
f925563445_487.returns = [];
f925563445_487.inst = 0;
// 2288
o0.createDocumentFragment = f925563445_487;
// 2289
o14 = {};
// 2290
f925563445_487.returns.push(o14);
// 2291
o15 = {};
// undefined
fo925563445_486_firstChild = function() { return fo925563445_486_firstChild.returns[fo925563445_486_firstChild.inst++]; };
fo925563445_486_firstChild.returns = [];
fo925563445_486_firstChild.inst = 0;
defineGetter(o13, "firstChild", fo925563445_486_firstChild);
// undefined
o13 = null;
// undefined
fo925563445_486_firstChild.returns.push(o15);
// 2293
o14.appendChild = f925563445_441;
// undefined
fo925563445_486_firstChild.returns.push(o15);
// 2295
f925563445_441.returns.push(o15);
// undefined
o15 = null;
// undefined
fo925563445_486_firstChild.returns.push(null);
// 2297
o12.appendChild = f925563445_441;
// 2298
f925563445_441.returns.push(o14);
// undefined
o14 = null;
// 2299
o12.setAttribute = f925563445_467;
// 2300
o12.getAttribute = f925563445_468;
// 2301
f925563445_468.returns.push(null);
// 2302
f925563445_467.returns.push(undefined);
// 2303
// 2304
// 2305
// 2306
// 2307
// 2308
// 2309
// 2310
// 2311
// 2312
// 2313
// 2314
// 2315
// 2316
// 2317
// 2318
// 2319
// 2320
// 2321
// 2322
// 2323
// 2324
// 2325
// 2326
// 2327
// 2329
// 2330
// 2331
o13 = {};
// 2332
f925563445_0.returns.push(o13);
// 2333
o13.getTime = f925563445_435;
// undefined
o13 = null;
// 2334
f925563445_435.returns.push(1318265693465);
// 2335
o4.offsetHeight = 0;
// 2336
o4.currentStyle = null;
// 2338
o13 = {};
// 2339
f925563445_4.returns.push(o13);
// 2340
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2341
f925563445_461.returns.push("auto");
// 2342
o6.offsetHeight = 0;
// 2343
o6.currentStyle = null;
// 2345
o13 = {};
// 2346
f925563445_4.returns.push(o13);
// 2347
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2348
f925563445_461.returns.push("auto");
// 2349
o8.offsetHeight = 0;
// 2350
o8.currentStyle = null;
// 2352
o13 = {};
// 2353
f925563445_4.returns.push(o13);
// 2354
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2355
f925563445_461.returns.push("auto");
// 2356
o9.offsetHeight = 0;
// 2357
o9.currentStyle = null;
// 2359
o13 = {};
// 2360
f925563445_4.returns.push(o13);
// 2361
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2362
f925563445_461.returns.push("auto");
// 2363
o11.offsetHeight = 0;
// 2364
o11.currentStyle = null;
// 2366
o13 = {};
// 2367
f925563445_4.returns.push(o13);
// 2368
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2369
f925563445_461.returns.push("auto");
// 2370
// 2371
// 2373
// 2374
// 2375
o13 = {};
// 2376
f925563445_0.returns.push(o13);
// 2377
o13.getTime = f925563445_435;
// undefined
o13 = null;
// 2378
f925563445_435.returns.push(1318265693490);
// 2382
o13 = {};
// 2383
f925563445_4.returns.push(o13);
// 2384
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2385
f925563445_461.returns.push("auto");
// 2389
o13 = {};
// 2390
f925563445_4.returns.push(o13);
// 2391
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2392
f925563445_461.returns.push("auto");
// 2396
o13 = {};
// 2397
f925563445_4.returns.push(o13);
// 2398
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2399
f925563445_461.returns.push("auto");
// 2403
o13 = {};
// 2404
f925563445_4.returns.push(o13);
// 2405
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2406
f925563445_461.returns.push("auto");
// 2410
o13 = {};
// 2411
f925563445_4.returns.push(o13);
// 2412
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2413
f925563445_461.returns.push("auto");
// 2414
// 2415
// 2417
// 2418
// 2419
o13 = {};
// 2420
f925563445_0.returns.push(o13);
// 2421
o13.getTime = f925563445_435;
// undefined
o13 = null;
// 2422
f925563445_435.returns.push(1318265693514);
// 2426
o13 = {};
// 2427
f925563445_4.returns.push(o13);
// 2428
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2429
f925563445_461.returns.push("42px");
// 2433
o13 = {};
// 2434
f925563445_4.returns.push(o13);
// 2435
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2436
f925563445_461.returns.push("42px");
// 2440
o13 = {};
// 2441
f925563445_4.returns.push(o13);
// 2442
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2443
f925563445_461.returns.push("42px");
// 2447
o13 = {};
// 2448
f925563445_4.returns.push(o13);
// 2449
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2450
f925563445_461.returns.push("42px");
// 2454
o13 = {};
// 2455
f925563445_4.returns.push(o13);
// 2456
o13.getPropertyValue = f925563445_461;
// undefined
o13 = null;
// 2457
f925563445_461.returns.push("42px");
// 2458
// 2459
o4.parentNode = o7;
// 2461
f925563445_465.returns.push(o4);
// undefined
o4 = null;
// 2462
o6.parentNode = o7;
// 2464
f925563445_465.returns.push(o6);
// undefined
o6 = null;
// 2465
o8.parentNode = o7;
// 2467
f925563445_465.returns.push(o8);
// undefined
o8 = null;
// 2468
o9.parentNode = o7;
// 2470
f925563445_465.returns.push(o9);
// undefined
o9 = null;
// 2471
o11.parentNode = o7;
// 2473
f925563445_465.returns.push(o11);
// undefined
o11 = null;
// 2474
// 2475
// 2476
// 2477
// 2478
// 2479
// 2480
// 2481
// 2482
// 2483
// 2484
// 2485
// 2486
// 2487
// 2488
// 2489
// 2490
// 2491
// 2492
// 2493
// 2494
// 2495
// 2496
// 2497
// 2498
// 2499
// 2500
// 2501
// 2502
// 2503
// 2504
// 2505
// 2506
// 2507
// 2508
// 2509
// 2510
// 2511
// 2512
// 2513
// 2514
// 2515
// 2516
// 2517
// 2519
o4 = {};
// 2520
f925563445_457.returns.push(o4);
// 2521
// 2522
// 2523
// 2524
o4.setAttribute = f925563445_467;
// 2525
o4.getAttribute = f925563445_468;
// undefined
o4 = null;
// 2526
f925563445_468.returns.push("pagelet_welcome");
// 2527
f925563445_467.returns.push(undefined);
// 2528
// 2529
// 2530
// 2531
// 2532
// 2533
// 2534
// 2535
// 2536
// 2537
// 2538
// 2539
// 2540
// 2541
// 2542
// 2543
// 2544
// 2545
// 2546
// 2547
// 2548
// 2549
// 2550
// 2551
// 2552
// 2553
// 2554
// 2555
// 2556
// 2557
// 2558
// 2559
// 2560
// 2561
// 2562
// 2563
// 2564
// 2565
// 2566
// 2567
// 2568
// 2569
// 2570
// 2571
// 2572
// 2573
// 2574
// 2575
// 2576
// 2577
// 2578
// 2579
// 2580
// 2582
f925563445_457.returns.push(o12);
// 2583
// 2584
// 2585
// undefined
o12 = null;
// 2588
f925563445_468.returns.push("pagelet_pinned_nav");
// 2589
f925563445_467.returns.push(undefined);
// 2590
// 2591
// 2592
// 2593
// 2594
// 2595
// 2596
// 2597
// 2598
// 2599
// 2600
// 2601
// 2602
// 2603
// 2604
// 2605
// 2606
// 2607
// 2608
// 2609
// 2610
// 2611
// 2612
// 2613
// 2614
// 2615
// 2616
// 2617
// 2618
// 2619
// 2620
// 2621
// 2622
// 2623
// 2624
// 2625
// 2626
// 2627
// 2628
// 2629
// 2630
// 2631
// 2632
// 2633
// 2634
// 2635
// 2636
// 2637
// 2638
// 2639
// 2640
// 2642
o4 = {};
// 2643
f925563445_457.returns.push(o4);
// 2644
// 2645
// 2646
// 2647
o4.setAttribute = f925563445_467;
// 2648
o4.getAttribute = f925563445_468;
// undefined
o4 = null;
// 2649
f925563445_468.returns.push(null);
// 2650
f925563445_467.returns.push(undefined);
// 2651
// 2652
// 2653
// 2654
// 2655
// 2656
// 2657
// 2658
// 2659
// 2660
// 2661
// 2662
// 2663
// 2664
// 2665
// 2666
// 2667
// 2668
// 2669
// 2670
// 2671
// 2672
// 2673
// 2674
// 2675
// 2676
// 2677
// 2678
// 2679
// 2680
// 2681
// 2682
// 2683
// 2684
// 2685
// 2686
// 2687
// 2688
// 2689
// 2690
// 2691
// 2692
// 2693
// 2694
// 2695
// 2696
// 2697
// 2698
// 2699
// 2700
// 2703
o4 = {};
// 2704
f925563445_436.returns.push(o4);
// 2705
// 2706
// 2707
// 2708
// 2710
f925563445_441.returns.push(o4);
// undefined
o4 = null;
// 2711
// 2713
o4 = {};
// 2714
f925563445_436.returns.push(o4);
// 2715
// 2716
// 2718
f925563445_441.returns.push(o4);
// 2719
o6 = {};
// 2720
f925563445_0.returns.push(o6);
// undefined
o6 = null;
// 2721
// 2722
f925563445_13.returns.push(7);
// 2723
// 2724
// 2727
o6 = {};
// 2728
f925563445_436.returns.push(o6);
// 2729
// 2730
// 2731
// 2732
// 2734
f925563445_441.returns.push(o6);
// undefined
o6 = null;
// 2735
// 2737
o6 = {};
// 2738
f925563445_436.returns.push(o6);
// 2739
// 2740
// 2742
f925563445_441.returns.push(o6);
// 2743
o8 = {};
// 2744
f925563445_0.returns.push(o8);
// undefined
o8 = null;
// 2745
// 2746
// 2747
// 2748
// 2749
// 2750
// 2751
// 2752
// 2753
// 2754
// 2755
// 2756
// 2757
// 2758
// 2759
// 2760
// 2761
// 2762
// 2763
// 2764
// 2765
// 2766
// 2767
// 2768
// 2769
// 2770
// 2771
// 2772
// 2773
// 2774
// 2775
// 2776
// 2777
// 2778
// 2779
// 2780
// 2781
// 2782
// 2783
// 2785
// 2786
// 2787
o8 = {};
// 2788
f925563445_0.returns.push(o8);
// 2789
o8.getTime = f925563445_435;
// undefined
o8 = null;
// 2790
f925563445_435.returns.push(1318265693558);
// 2791
o4.offsetHeight = 0;
// 2792
o4.currentStyle = null;
// 2794
o8 = {};
// 2795
f925563445_4.returns.push(o8);
// 2796
o8.getPropertyValue = f925563445_461;
// undefined
o8 = null;
// 2797
f925563445_461.returns.push("auto");
// 2798
o6.offsetHeight = 0;
// 2799
o6.currentStyle = null;
// 2801
o8 = {};
// 2802
f925563445_4.returns.push(o8);
// 2803
o8.getPropertyValue = f925563445_461;
// undefined
o8 = null;
// 2804
f925563445_461.returns.push("auto");
// 2805
// 2806
// 2808
// 2809
// 2810
o8 = {};
// 2811
f925563445_0.returns.push(o8);
// 2812
o8.getTime = f925563445_435;
// undefined
o8 = null;
// 2813
f925563445_435.returns.push(1318265693607);
// 2817
o8 = {};
// 2818
f925563445_4.returns.push(o8);
// 2819
o8.getPropertyValue = f925563445_461;
// undefined
o8 = null;
// 2820
f925563445_461.returns.push("42px");
// 2824
o8 = {};
// 2825
f925563445_4.returns.push(o8);
// 2826
o8.getPropertyValue = f925563445_461;
// undefined
o8 = null;
// 2827
f925563445_461.returns.push("42px");
// 2828
// 2829
o4.parentNode = o7;
// 2831
f925563445_465.returns.push(o4);
// undefined
o4 = null;
// 2832
o6.parentNode = o7;
// undefined
o7 = null;
// 2834
f925563445_465.returns.push(o6);
// undefined
o6 = null;
// 2835
// 2836
// 2837
// 2838
// 2839
// 2840
// 2841
// 2842
// 2843
// 2844
// 2845
// 2846
// 2847
// 2848
// 2849
// 2850
// 2851
// 2852
// 2853
// 2854
// 2855
// 2856
// 2857
// 2858
// 2859
// 2860
// 2862
o4 = {};
// 2863
f925563445_457.returns.push(o4);
// 2864
// 2865
// 2866
// 2867
o4.setAttribute = f925563445_467;
// 2868
o4.getAttribute = f925563445_468;
// undefined
o4 = null;
// 2869
f925563445_468.returns.push("pagelet_sidebar");
// 2870
f925563445_467.returns.push(undefined);
// 2871
// 2872
// 2873
// 2874
// 2875
// 2876
// 2877
// 2878
// 2879
// 2880
// 2881
// 2882
// 2883
// 2884
// 2885
// 2886
// 2887
// 2888
// 2889
// 2890
// 2891
// 2892
// 2893
// 2894
// 2895
// 2896
// 2897
// 2898
// 2899
// 2900
// 2901
// 2902
// 2903
// 2904
// 2905
// 2906
// 2907
// 2908
// 2909
// 2910
// 2911
// 2912
// 2913
// 2914
// 2915
// 2916
// 2917
// 2919
o4 = {};
// 2920
f925563445_457.returns.push(o4);
// 2921
// 2922
// 2923
// 2924
o4.setAttribute = f925563445_467;
// 2925
o4.getAttribute = f925563445_468;
// undefined
o4 = null;
// 2926
f925563445_468.returns.push("pagelet_friends_online");
// 2927
f925563445_467.returns.push(undefined);
// 2928
// 2929
// 2930
// 2931
// 2932
// 2933
// 2934
// 2935
// 2936
// 2937
// 2938
// 2939
// 2940
// 2941
// 2942
// 2943
// 2944
// 2945
// 2946
// 2947
// 2948
// 2949
// 2950
// 2951
// 2952
// 2953
// 2954
// 2955
// 2956
// 2957
// 2958
// 2959
// 2960
// 2961
// 2962
// 2963
// 2964
// 2965
// 2966
// 2967
// 2968
// 2969
// 2970
// 2971
// 2972
// 2973
// 2974
// 2975
// 2976
// 2978
o4 = {};
// 2979
f925563445_457.returns.push(o4);
// 2980
// 2981
// 2982
// 2983
o4.setAttribute = f925563445_467;
// 2984
o4.getAttribute = f925563445_468;
// 2985
f925563445_468.returns.push(null);
// 2986
f925563445_467.returns.push(undefined);
// 2987
// 2988
// 2989
// 2990
// 2991
// 2992
// 2993
// 2994
// 2995
// 2996
// 2997
// 2998
// 2999
// 3000
// 3001
// 3002
// 3003
// 3004
// 3005
// 3006
// 3007
// 3008
// 3009
// 3010
// 3011
// 3012
// 3013
// 3014
// 3015
// 3016
// 3017
// 3018
// 3019
// 3020
// 3021
// 3022
// 3023
// 3024
// 3025
// 3026
// 3027
// 3028
// 3029
// 3030
// 3031
// 3032
// 3033
// 3034
// 3036
o6 = {};
// 3037
f925563445_457.returns.push(o6);
// 3038
// 3039
// 3040
// 3041
// 3042
// 3043
// 3044
// 3045
// 3046
// 3047
// 3048
// 3049
// 3050
o6.setAttribute = f925563445_467;
// 3051
o6.getAttribute = f925563445_468;
// undefined
o6 = null;
// 3052
f925563445_468.returns.push("pagelet_presence");
// 3053
f925563445_467.returns.push(undefined);
// 3054
// 3055
// 3056
// 3057
// 3058
// 3059
// 3060
// 3061
// 3062
// 3063
// 3064
// 3065
// 3066
// 3067
// 3068
// 3069
// 3070
// 3071
// 3072
// 3073
// 3074
// 3075
// 3076
// 3077
// 3078
// 3079
// 3080
// 3081
// 3082
// 3083
// 3084
// 3085
// 3086
// 3087
// 3088
// 3089
// 3090
// 3091
// 3092
// 3093
// 3094
// 3095
// 3096
// 3097
// 3098
// 3099
// 3100
// 3101
// 3102
// 3103
// 3104
// 3105
// 3106
// 3107
// 3108
// 3109
// 3110
// 3111
// 3112
// 3113
// 3114
// 3115
// 3116
// 3117
// 3118
// 3119
// 3120
// 3121
// 3122
// 3123
// 3124
// 3125
// 3126
// 3127
// 3128
// 3129
// 3130
// 3131
// 3132
// 3133
// 3134
// 3135
// 3136
// 3137
// 3138
// 3139
// 3140
// 3141
// 3142
// 3143
// 3144
// 3145
// 3146
// 3147
// 3148
// 3149
// 3150
// 3151
// 3152
// 3153
// 3154
// 3155
// 3156
// 3157
// 3158
// 3159
// 3160
// 3161
// 3162
// 3163
// 3164
// 3165
// 3166
// 3167
// 3168
// 3169
// 3170
// 3171
// 3172
// 3173
// 3174
// 3175
// 3176
// 3177
// 3178
// 3179
// 3180
// 3181
// 3182
// 3183
// 3184
// 3186
o6 = {};
// 3187
f925563445_436.returns.push(o6);
// 3188
// 3189
// 3190
// 3191
// 3192
// 3193
// 3195
f925563445_441.returns.push(o6);
// 3196
// 3197
// 3199
o7 = {};
// 3200
f925563445_436.returns.push(o7);
// 3201
// 3202
// 3203
// 3204
// 3205
// 3206
// 3208
f925563445_441.returns.push(o7);
// 3209
// 3210
// 3212
o8 = {};
// 3213
f925563445_436.returns.push(o8);
// 3214
// 3215
// 3216
// 3217
// 3218
// 3219
// 3221
f925563445_441.returns.push(o8);
// 3222
// 3223
// 3225
o9 = {};
// 3226
f925563445_436.returns.push(o9);
// 3227
// 3228
// 3229
// 3230
// 3231
// 3232
// 3234
f925563445_441.returns.push(o9);
// 3235
// 3236
// 3238
o11 = {};
// 3239
f925563445_436.returns.push(o11);
// 3240
// 3241
// 3242
// 3243
// 3244
// 3245
// 3247
f925563445_441.returns.push(o11);
// 3248
// 3249
// 3251
o12 = {};
// 3252
f925563445_436.returns.push(o12);
// 3253
// 3254
// 3255
// 3256
// 3257
// 3258
// 3260
f925563445_441.returns.push(o12);
// 3261
// 3262
// 3263
// 3264
// 3265
// 3266
// 3267
// 3268
// 3269
// 3270
// 3271
// 3272
// 3273
// 3274
// 3275
// 3276
// 3277
// 3278
// 3279
// 3280
// 3281
// 3282
// 3283
// 3284
// 3285
// 3286
// 3287
// 3288
// 3289
// 3290
// 3291
// 3292
// 3293
// 3294
// 3295
// 3296
// 3297
// 3298
// 3299
// 3300
// 3301
// 3302
// 3303
// 3304
// 3305
// 3306
// 3307
// 3308
// 3309
// 3310
// 3311
// 3312
// 3313
// 3314
// 3315
// 3316
// 3317
// 3318
// 3319
// 3320
// 3321
// 3322
// 3323
// 3324
// 3325
// 3326
// 3327
// 3328
// 3329
// 3330
// 3331
// 3332
// 3333
// 3334
// 3335
// 3336
// 3337
// 3338
// 3339
// 3340
// 3341
// 3342
// 3343
// 3344
// 3345
// 3346
// 3347
// 3348
// 3349
// 3350
// 3351
// 3352
// 3353
// 3354
// 3355
// 3356
// 3357
// 3358
// 3359
// 3360
// 3361
// 3362
// 3363
// 3364
// 3365
// 3366
// 3367
// 3368
// 3369
// 3370
// 3371
// 3372
// 3373
// 3374
// 3375
// 3376
// 3377
// 3378
// 3379
// 3380
// 3381
// 3382
// 3383
// 3384
// 3385
// 3386
// 3387
// 3388
// 3389
// 3390
// 3391
// 3392
// 3393
// 3394
// 3395
// 3396
// 3397
// 3398
// 3399
// 3400
// 3401
// 3402
// 3403
// 3404
// 3406
o13 = {};
// 3407
f925563445_436.returns.push(o13);
// 3408
// 3409
// 3410
// 3411
// 3412
// 3413
// 3415
f925563445_441.returns.push(o13);
// 3416
// 3417
// 3419
o14 = {};
// 3420
f925563445_436.returns.push(o14);
// 3421
// 3422
// 3423
// 3424
// 3425
// 3426
// 3428
f925563445_441.returns.push(o14);
// 3429
// 3430
// 3432
o15 = {};
// 3433
f925563445_436.returns.push(o15);
// 3434
// 3435
// 3436
// 3437
// 3438
// 3439
// 3441
f925563445_441.returns.push(o15);
// 3442
// 3443
// 3445
o16 = {};
// 3446
f925563445_436.returns.push(o16);
// 3447
// 3448
// 3449
// 3450
// 3451
// 3452
// 3454
f925563445_441.returns.push(o16);
// 3455
// 3456
// 3457
// 3458
// 3459
// 3460
// 3461
// 3462
// 3463
// 3464
// 3465
// 3466
// 3467
// 3468
// 3469
// 3470
// 3471
// 3472
// 3473
// 3474
// 3475
// 3476
// 3477
// 3478
// 3479
// 3480
// 3481
// 3482
// 3483
// 3484
// 3485
// 3486
// 3487
// 3488
// 3489
// 3490
// 3491
// 3492
// 3493
// 3494
// 3495
// 3496
// 3497
// 3498
// 3499
// 3500
// 3501
// 3502
// 3503
// 3504
// 3505
// 3506
// 3507
// 3508
// 3509
// 3510
// 3511
// 3512
// 3513
// 3514
// 3515
// 3516
// 3517
// 3518
// 3519
// 3520
// 3521
// 3522
// 3524
o17 = {};
// 3525
f925563445_436.returns.push(o17);
// 3526
// 3527
// 3528
// 3529
// 3530
// 3531
// 3533
f925563445_441.returns.push(o17);
// 3534
// 3535
// 3536
// 3537
// 3538
// 3539
// 3540
// 3541
// 3542
// 3543
// 3544
// 3545
// 3546
// 3547
// 3548
// 3549
// 3550
// 3551
// 3552
// 3553
// 3554
// 3555
// 3556
// 3557
// 3558
// 3559
// 3560
// 3561
// 3562
// 3563
// 3564
// 3565
// 3566
// 3567
// 3568
// 3569
// 3570
// 3571
// 3572
// 3573
// 3574
// 3575
// 3576
// 3577
// 3578
// 3579
// 3580
// 3581
// 3582
// 3583
// 3584
// 3585
// 3586
// 3587
// 3588
// 3589
// 3590
// 3591
// 3592
// 3593
// 3594
// 3595
// 3596
// 3597
// 3598
// 3599
// 3600
// 3601
// 3602
// 3603
// 3604
// 3605
// 3606
// 3607
// 3608
// 3609
// 3610
// 3611
// 3612
// 3613
// 3614
// 3616
o18 = {};
// 3617
f925563445_436.returns.push(o18);
// 3618
// 3619
// 3620
// 3621
// 3622
// 3623
// 3625
f925563445_441.returns.push(o18);
// 3626
// 3627
// 3629
o19 = {};
// 3630
f925563445_436.returns.push(o19);
// 3631
// 3632
// 3633
// 3634
// 3635
// 3636
// 3638
f925563445_441.returns.push(o19);
// 3639
// 3640
// 3642
o20 = {};
// 3643
f925563445_436.returns.push(o20);
// 3644
// 3645
// 3646
// 3647
// 3648
// 3649
// 3651
f925563445_441.returns.push(o20);
// 3652
// 3653
// 3654
// 3655
// 3656
// 3657
// 3658
// 3659
// 3660
// 3661
// 3662
// 3663
// 3664
// 3665
// 3666
// 3667
// 3668
// 3669
// 3670
// 3671
// 3672
// 3673
// 3674
// 3675
// 3676
// 3677
// 3678
// 3679
// 3680
// 3681
// 3682
// 3683
// 3684
// 3685
// 3686
// 3687
// 3688
// 3689
// 3690
// 3691
// 3692
// 3693
// 3694
// 3695
// 3696
// 3697
// 3698
// 3699
// 3700
// 3701
// 3702
// 3703
// 3704
// 3705
// 3706
// 3707
// 3708
// 3709
// 3710
// 3711
// 3712
// 3713
// 3714
// 3715
// 3716
// 3717
// 3718
// 3719
// 3720
// 3721
// 3722
// 3723
// 3724
// 3725
// 3726
// 3727
// 3728
// 3729
// 3730
// 3731
// 3732
// 3733
// 3734
// 3735
// 3736
// 3737
// 3738
// 3739
// 3740
// 3741
// 3742
// 3743
// 3744
// 3745
// 3746
// 3747
// 3748
// 3749
// 3750
// 3751
// 3752
// 3753
// 3754
// 3755
// 3757
o21 = {};
// 3758
f925563445_436.returns.push(o21);
// 3759
// 3760
// 3761
// 3762
// 3763
// 3764
// 3766
f925563445_441.returns.push(o21);
// 3767
// 3768
// 3769
// 3770
// 3771
// 3772
// 3773
// 3774
// 3775
// 3776
// 3777
// 3778
// 3779
// 3780
// 3781
// 3782
// 3783
// 3784
// 3785
// 3786
// 3787
// 3788
// 3789
// 3790
// 3791
// 3792
// 3793
// 3794
// 3795
// 3796
// 3797
// 3798
// 3799
// 3800
// 3801
// 3802
// 3803
// 3804
// 3805
// 3806
// 3807
// 3808
// 3809
// 3810
// 3811
// 3812
// 3813
// 3814
// 3815
// 3816
// 3817
// 3818
// 3819
// 3820
// 3821
// 3822
// 3823
// 3824
// 3825
// 3826
// 3827
// 3828
// 3829
// 3830
// 3831
// 3832
// 3833
// 3834
f925563445_15.returns.push(undefined);
// 3836
// 3837
// 3838
o22 = {};
// 3839
f925563445_0.returns.push(o22);
// 3840
o22.getTime = f925563445_435;
// undefined
o22 = null;
// 3841
f925563445_435.returns.push(1318265693686);
// 3842
// 3843
// 3844
f925563445_15.returns.push(undefined);
// 3846
// 3847
// 3848
o22 = {};
// 3849
f925563445_0.returns.push(o22);
// 3850
o22.getTime = f925563445_435;
// undefined
o22 = null;
// 3851
f925563445_435.returns.push(1318265693687);
// 3852
// 3853
// 3854
f925563445_15.returns.push(undefined);
// 3856
// 3857
// 3858
// 3859
// 3860
// 3861
// 3862
// 3863
// 3864
// 3865
// 3866
// 3867
// 3868
// 3869
// 3870
// 3871
// 3872
// 3873
// 3874
// 3875
// 3876
// 3877
// 3878
// 3879
// 3880
// 3881
// 3882
// 3883
// 3884
// 3885
// 3886
// 3887
// 3888
// 3889
// 3890
// 3892
// 3893
o22 = {};
// 3894
f925563445_436.returns.push(o22);
// 3895
o22.textContent = "";
// undefined
o22 = null;
// 3896
// 3897
// 3898
// 3899
// 3900
// 3901
// 3902
// 3903
// 3904
// 3905
// 3906
o22 = {};
// 3907
f925563445_280.prototype = o22;
// 3908
// 3910
// 3911
// 3912
// 3913
// 3914
// 3915
// 3916
// 3917
// 3918
// 3919
// 3920
// 3921
// 3922
// 3923
// 3924
// 3925
// 3926
// 3928
// 3929
// 3930
// 3931
// 3932
// 3933
// 3934
// 3935
// 3936
// 3937
// 3938
// 3939
// 3940
// 3941
// 3942
// 3943
// 3944
// 3945
// 3946
// 3948
// 3949
o23 = {};
// 3950
f925563445_436.returns.push(o23);
// 3951
o24 = {};
// 3952
o23.style = o24;
// undefined
o23 = null;
// 3953
o24["null"] = null;
// 3955
o24.borderRadius = "";
// undefined
o24 = null;
// 3956
// 3957
// 3958
// 3959
// 3960
// 3961
// 3962
// 3963
// 3964
// 3965
// 3966
// 3967
// 3968
// 3969
// 3970
// 3971
// 3972
// 3973
// 3974
// 3975
// 3976
// 3977
// 3978
// 3979
// 3980
// 3981
// 3982
// 3983
// 3984
// 3985
// 3986
// 3987
// 3988
// 3989
// 3990
// 3991
// 3992
// 3993
// 3994
// 3995
// 3996
// 3997
// 3998
// 3999
// 4000
// 4001
// 4002
// 4003
// 4004
// 4005
// 4006
// 4007
// 4008
// 4009
// 4010
// 4011
// 4012
// 4013
// 4014
// 4015
// 4017
// 4018
// 4019
// 4020
// 4021
// 4022
// 4023
// 4024
// 4025
// 4026
// 4027
// 4028
// 4029
// 4030
// 4031
// 4032
// 4033
// 4034
// 4035
// 4036
// 4037
// 4038
// 4039
// 4040
// 4041
// 4042
// 4043
// 4044
// 4045
// 4046
// 4047
// 4048
// 4049
// 4050
// 4051
// 4052
// 4053
// 4054
// 4055
// 4056
// 4057
// 4058
// 4059
// 4060
// 4061
// 4062
// 4063
// 4064
// 4065
// 4066
// 4067
// 4068
// 4069
// 4070
// 4071
// 4072
// 4073
// 4074
// 4076
// 4077
// 4078
// 4079
// 4080
// 4081
// 4082
// 4083
// 4084
// 4085
// 4086
// 4087
// 4088
// 4089
// 4090
// 4091
// 4092
// 4093
// 4094
// 4095
// 4096
// 4097
// 4098
// 4099
// 4100
// 4101
// 4102
// 4103
// 4104
// 4105
// 4106
// 4107
// 4108
// 4109
// 4110
// 4111
// 4112
// 4113
// 4114
// 4115
// 4116
// 4117
// 4118
// 4119
// 4120
// 4121
// 4122
// 4123
// 4125
// 4126
// 4127
// 4128
// 4129
// 4130
// 4131
// 4132
// 4133
// 4134
// 4135
// 4136
// 4137
// 4138
// 4139
// 4140
// 4141
// 4142
// 4143
// 4144
// 4145
// 4146
// 4147
// 4148
// 4149
// 4150
// 4153
// 4154
// 4155
// 4156
// 4157
// 4158
// 4159
// 4160
// 4161
// 4162
// 4163
// 4164
// 4165
// 4166
// 4167
// 4168
// 4169
// 4170
// 4171
// 4172
// 4173
// 4174
// 4175
// 4176
// 4177
// 4178
// 4180
// 4181
// 4183
// 4184
// 4185
// 4186
// 4187
// 4188
// 4189
// 4190
// 4191
// 4192
// 4193
// 4194
// 4195
// 4196
// 4197
// 4198
// 4199
// 4200
// 4201
// 4202
// 4203
// 4204
// 4205
// 4206
// 4207
// 4208
// 4210
// 4211
// 4212
// 4214
// 4215
// 4216
// 4217
// 4218
// 4219
// 4220
// 4221
// 4222
// 4223
// 4224
// 4225
// 4226
// 4227
// 4228
// 4229
// 4230
// 4231
// 4232
// 4233
// 4234
// 4235
// 4236
// 4237
// 4238
// 4239
// 4241
// 4242
// 4243
// 4244
// 4245
// 4246
// 4247
// 4248
// 4249
// 4250
// 4251
// 4252
// 4253
// 4254
// 4255
// 4256
// 4257
// 4258
// 4259
// 4260
// 4261
// 4262
// 4263
// 4264
// 4265
// 4266
// 4267
// 4268
// 4269
// 4270
// 4271
// 4272
// 4273
// 4274
// 4275
// 4276
// 4277
// 4278
// 4279
// 4280
// 4281
// 4282
// 4283
// 4284
// 4285
// 4286
// 4287
// 4288
// 4289
// 4290
// 4291
// 4292
// 4293
// 4294
// 4295
// 4296
// 4297
// 4298
// 4299
// 4300
// 4301
// 4302
// 4303
// 4304
// 4305
// 4306
// 4307
// 4308
// 4309
// 4310
// 4311
// 4312
// 4313
// 4314
// 4315
// 4316
// 4317
// 4318
// 4319
// 4320
// 4321
// 4322
// 4323
// 4324
// 4325
// 4326
// 4327
// 4328
// 4329
// 4330
// 4331
// 4332
// 4333
// 4334
// 4335
// 4336
// 4337
// 4338
// 4339
// 4340
// 4341
// 4342
// 4343
// 4344
// 4345
// 4346
// 4347
// 4348
// 4349
// 4350
// 4351
// 4352
// 4353
// 4354
// 4355
// 4356
// 4357
// 4358
// 4359
// 4360
// 4361
// 4362
// 4363
// 4364
// 4365
// 4366
// 4367
// 4368
// 4369
// 4370
// 4371
// 4372
// 4373
// 4375
// 4376
// 4377
// 4378
// 4379
// 4380
// 4381
// 4382
// 4383
// 4384
// 4385
// 4386
// 4387
// 4388
// 4389
// 4390
// 4391
// 4392
// 4393
// 4394
// 4395
// 4396
// 4397
// 4398
// 4399
// 4400
// 4401
// 4402
// 4403
// 4404
// 4405
// 4406
// 4407
// 4408
// 4409
// 4410
// 4411
// 4412
// 4413
// 4414
// 4415
// 4416
// 4417
// 4418
// 4419
// 4420
// 4421
// 4422
// 4423
// 4424
// 4425
// 4426
// 4427
// 4428
// 4430
// 4431
// 4432
// 4433
// 4434
// 4435
// 4436
// 4437
// 4438
// 4439
// 4440
// 4441
// 4442
// 4443
// 4444
// 4445
// 4446
// 4447
// 4448
// 4449
// 4450
// 4451
// 4452
// 4453
// 4454
// 4455
// 4456
// 4457
// 4458
// 4459
// 4460
// 4461
// 4462
// 4463
// 4464
// 4465
// 4466
// 4467
// 4468
// 4469
// 4470
// 4471
// 4472
// 4473
// 4474
// 4475
// 4476
// 4477
// 4478
// 4479
// 4480
// 4481
// 4482
// 4483
// 4484
// 4485
// 4486
// 4487
// 4488
// 4489
// 4490
// 4491
// 4492
// 4493
// 4494
// 4495
// 4496
// 4497
// 4498
// 4499
// 4500
// 4501
// 4502
// 4503
// 4504
// 4505
// 4506
// 4507
// 4508
// 4509
// 4510
// 4511
// 4512
// 4513
// 4514
// 4515
// 4516
// 4517
// 4518
// 4519
// 4520
// 4521
// 4522
// 4523
// 4524
// 4525
// 4526
// 4528
// 4529
// 4530
// 4531
// 4532
// 4533
// 4534
// 4535
// 4536
// 4537
// 4538
// 4539
// 4540
// 4541
// 4542
// 4543
// 4544
// 4545
// 4546
// 4547
// 4548
// 4549
// 4550
// 4551
// 4552
// 4553
// 4554
// 4555
// 4556
// 4557
// 4558
// 4559
// 4560
// 4561
// 4562
// 4563
// 4564
// 4565
// 4566
// 4567
// 4568
// 4569
// 4570
// 4571
// 4572
// 4573
// 4574
// 4575
// 4576
// 4577
// 4578
// 4579
// 4580
// 4581
// 4582
// 4583
// 4584
// 4585
// 4586
// 4587
// 4588
// 4589
// 4590
// 4591
// 4592
// 4593
// 4594
// 4595
// 4596
// 4597
// 4598
// 4599
// 4600
// 4601
// 4602
// 4603
// 4604
// 4605
// 4606
// 4607
// 4608
// 4609
// 4610
// 4611
// 4612
// 4613
// 4614
// 4615
// 4616
// 4617
// 4618
// 4619
// 4620
// 4621
// 4622
// 4623
// 4624
// 4625
// 4626
// 4627
// 4628
// 4631
// 4632
// 4633
// 4634
// 4635
// 4636
// 4637
// 4638
// 4639
// 4640
// 4641
// 4642
// 4643
// 4644
// 4645
// 4646
// 4647
// 4648
// 4649
// 4650
// 4651
// 4652
// 4653
// 4654
// 4655
// 4656
// 4658
// 4659
// 4660
// 4661
// 4662
// 4663
// 4664
// 4665
// 4666
// 4667
// 4668
// 4669
// 4670
// 4671
// 4672
// 4673
// 4674
// 4675
// 4676
// 4677
// 4678
// 4679
// 4680
// 4681
// 4682
// 4683
// 4684
// 4685
// 4686
// 4687
// 4688
// 4689
// 4690
// 4691
// 4692
// 4693
// 4694
// 4695
// 4696
// 4697
// 4698
// 4699
// 4700
// 4702
// 4703
// 4704
// 4705
// 4706
// 4707
// 4708
// 4709
// 4710
// 4711
// 4712
// 4713
// 4714
// 4715
// 4716
// 4717
// 4718
// 4719
// 4720
// 4721
// 4722
// 4723
// 4724
// 4725
// 4726
// 4727
// 4729
// 4730
// 4731
// 4732
// 4733
// 4734
// 4735
// 4736
// 4737
// 4738
// 4739
// 4740
// 4741
// 4742
// 4743
// 4744
// 4746
// 4747
// 4748
// 4749
// 4750
// 4751
// 4752
// 4753
// 4754
// 4755
// 4756
// 4757
// 4758
// 4759
// 4760
// 4761
// 4762
// 4763
// 4764
// 4765
// 4766
// 4767
// 4768
// 4769
// 4770
// 4771
// 4772
// 4773
// 4774
// 4775
// 4776
// 4777
// 4778
// 4779
// 4780
// 4781
// 4782
// 4783
// 4784
// 4785
// 4787
// 4788
// 4789
// 4790
// 4791
// 4792
o23 = {};
// 4793
f925563445_0.returns.push(o23);
// undefined
o23 = null;
// 4794
// 4795
f925563445_426.returns.push(0.09623256628401577);
// 4796
// 4797
// 4798
// 4799
// 4800
// 4801
// 4802
// 4803
// 4804
// 4805
// 4806
// 4807
// 4808
// 4809
// 4810
// 4811
// 4812
// 4813
// 4814
// 4815
// 4816
// 4817
// 4818
// 4819
// 4820
// 4821
// 4822
// 4823
// 4824
// 4825
// 4826
// 4827
// 4828
// 4829
// 4830
// 4831
// 4832
// 4833
// 4834
// 4835
// 4836
// 4837
// 4838
// 4839
// 4840
// 4841
// 4842
// 4843
// 4844
// 4845
// 4846
// 4847
// 4848
// 4849
// 4850
// 4851
// 4852
// 4853
// 4854
// 4855
// 4856
// 4857
// 4858
o0.title = "Facebook";
// 4859
// 4860
// 4861
// 4862
// 4863
// 4864
o23 = {};
// 4865
f925563445_0.returns.push(o23);
// undefined
o23 = null;
// 4866
// 4867
// 4868
// 4869
// 4870
// 4871
// 4872
// 4873
// 4874
// 4875
// 4876
// 4877
// 4878
// 4879
// 4880
// 4881
// 4882
// 4883
// 4884
// 4885
// 4886
// 4887
// 4888
// 4889
// 4890
// 4891
// 4892
// 4893
// 4894
// 4895
// 4896
// 4897
// 4898
// 4899
// 4900
// 4901
// 4902
// 4903
// 4904
// 4905
// 4906
// 4907
// 4908
// 4909
// 4910
// 4911
// 4912
// 4913
// 4914
// 4915
// 4916
// 4917
// 4918
// 4919
// 4920
// 4921
// 4922
// 4923
// 4924
// 4925
// 4926
// 4927
// 4928
// 4929
// 4930
// 4931
// 4932
// 4933
// 4934
// 4935
// 4936
// 4937
// 4938
// 4939
// 4940
// 4941
// 4942
// 4944
// 4945
// 4946
// 4947
// 4948
// 4949
// 4950
// 4951
// 4952
// 4953
// 4954
// 4955
// 4956
// 4957
// 4958
// 4959
// 4960
// 4961
// 4962
// 4963
// 4964
// 4965
// 4966
// 4967
// 4968
// 4969
// 4970
// 4971
// 4972
// 4973
// 4974
// 4975
// 4976
// 4977
// 4978
// 4979
// 4980
// 4981
// 4982
// 4983
// 4984
// 4985
// 4986
// 4987
// 4988
// 4989
// 4990
// 4991
// 4992
// 4993
// 4994
// 4995
// 4996
// 4997
// 4998
// 4999
// 5000
// 5001
// 5002
// 5003
// 5004
// 5005
// 5006
// 5007
// 5008
// 5009
// 5010
// 5011
// 5012
// 5013
// 5014
// 5015
// 5016
// 5017
// 5018
// 5019
// 5020
// 5021
// 5022
// 5023
// 5024
// 5025
// 5026
// 5027
// 5028
// 5029
// 5030
// 5031
// 5032
// 5033
// 5034
// 5035
// 5036
// 5037
// 5038
// 5039
// 5040
// 5041
// 5042
// 5043
// 5044
// 5045
// 5046
// 5047
// 5048
// 5049
// 5050
// 5051
// 5052
// 5053
// 5054
// 5056
// 5057
// 5058
// 5059
// 5060
// 5061
// 5062
// 5063
// 5064
// 5065
// 5066
// 5067
// 5068
// 5069
// 5070
// 5071
// 5072
// 5073
// 5074
// 5075
// 5076
// 5077
// 5078
// 5079
// 5080
// 5081
// 5082
// 5083
// 5084
// 5085
// 5086
// 5087
// 5088
// 5089
// 5090
// 5091
// 5092
// 5093
// 5094
// 5095
// 5096
// 5097
// 5098
// 5099
// 5100
// 5101
// 5102
// 5103
// 5104
// 5105
// 5106
// 5107
// 5108
// 5109
// 5110
// 5111
// 5112
// 5113
// 5114
// 5115
// 5116
// 5117
// 5118
// 5119
// 5120
// 5121
// 5122
// 5123
// 5124
// 5125
// 5126
// 5127
// 5128
// 5129
// 5130
// 5131
// 5132
// 5133
// 5134
// 5135
// 5136
// 5137
// 5138
// 5139
// 5140
// 5141
// 5142
// 5143
// 5144
// 5145
// 5146
// 5147
// 5148
// 5149
// 5150
// 5151
// 5152
// 5153
// 5154
// 5155
// 5156
// 5157
// 5158
// 5159
// 5160
// 5161
// 5162
// 5163
// 5164
// 5165
// 5166
// 5167
// 5168
// 5169
// 5170
// 5171
// 5172
// 5173
// 5174
// 5175
// 5176
// 5177
// 5178
// 5179
// 5180
// 5181
// 5182
// 5183
// 5184
// 5185
// 5186
// 5187
// 5188
// 5189
// 5190
// 5191
// 5192
// 5193
// 5194
// 5195
// 5196
// 5197
// 5198
// 5199
// 5200
// 5201
// 5202
// 5203
// 5204
// 5205
// 5206
// 5207
// 5208
// 5209
// 5210
// 5211
// 5212
// 5213
// 5214
// 5215
// 5216
// 5217
// 5218
// 5219
// 5220
// 5221
// 5222
// 5223
// 5224
// 5225
// 5226
// 5227
// 5228
// 5229
// 5230
// 5231
// 5232
// 5233
// 5234
// 5235
// 5236
// 5237
// 5238
// 5239
// 5240
// 5241
// 5242
// 5243
// 5244
// 5245
// 5246
// 5247
// 5248
// 5249
// 5250
// 5251
// 5252
// 5253
// 5254
// 5255
// 5256
// 5257
// 5258
// 5259
// 5260
// 5261
// 5262
// 5263
// 5264
// 5265
// 5266
// 5267
// 5268
// 5269
// 5270
// 5271
// 5272
// 5273
// 5274
// 5275
// 5277
// 5278
// 5279
// 5280
// 5281
// 5282
// 5283
// 5284
// 5285
// 5286
// 5287
// 5288
// 5289
// 5290
// 5291
// 5292
// 5293
// 5294
// 5295
// 5296
// 5297
// 5298
// 5299
// 5300
// 5301
// 5302
// 5303
// 5304
// 5306
// 5307
// 5308
// 5309
// 5310
// 5311
// 5313
// 5314
// 5315
// 5316
// 5317
// 5318
// 5319
o23 = {};
// 5320
f925563445_0.returns.push(o23);
// 5321
o23.getTime = f925563445_435;
// undefined
o23 = null;
// 5322
// 5323
f925563445_435.returns.push(1318265707872);
// 5324
// 5325
// 5326
// 5327
// 5328
// 5329
// 5330
f925563445_550 = function() { return f925563445_550.returns[f925563445_550.inst++]; };
f925563445_550.returns = [];
f925563445_550.inst = 0;
// 5331
o3.pushState = f925563445_550;
// 5332
o0.JSBNG__URL = "http://www.facebook.com/";
// 5333
f925563445_551 = function() { return f925563445_551.returns[f925563445_551.inst++]; };
f925563445_551.returns = [];
f925563445_551.inst = 0;
// 5334
o3.replaceState = f925563445_551;
// undefined
o3 = null;
// 5335
// 5336
f925563445_551.returns.push(undefined);
// 5337
f925563445_552 = function() { return f925563445_552.returns[f925563445_552.inst++]; };
f925563445_552.returns = [];
f925563445_552.inst = 0;
// 5338
f925563445_280.listen = f925563445_552;
// 5339
// 5340
// 5341
// 5342
// 5343
// 5344
// 5345
// 5346
o3 = {};
// 5347
f925563445_280.Priority = o3;
// 5348
o3.NORMAL = 0;
// 5349
// 5350
// 5351
// 5352
// 5353
// 5354
// 5355
// 5356
// 5357
// 5358
// 5359
// 5360
f925563445_7.returns.push(undefined);
// 5361
// 5362
// 5363
// 5364
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 5365
// 5366
// 5367
// 5368
// 5369
// 5370
// 5371
// 5372
// 5373
// 5374
// 5375
// 5376
// 5377
// 5378
// 5379
// 5380
// 5381
// 5382
// 5383
// 5384
// 5385
// 5386
// 5387
// 5388
// 5389
// 5390
// 5391
// 5392
// 5393
// 5394
// 5395
// 5396
// 5397
// 5398
// 5399
// 5400
// 5401
// 5402
// 5404
// 5405
// 5408
// 5409
// 5410
// 5411
// 5412
// 5413
// 5414
// 5415
// 5416
// 5417
// 5418
// 5419
f925563445_7.returns.push(undefined);
// 5420
// 5421
// 5422
// 5423
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 5424
// 5425
// 5426
// 5427
// 5428
// 5429
// 5430
// 5431
// 5432
// 5433
// 5434
// 5435
// 5436
// 5437
// 5438
// 5439
// 5440
// 5441
// 5443
// 5444
o23 = {};
// 5445
f925563445_457.returns.push(o23);
// 5446
// 5448
// 5449
o24 = {};
// 5450
f925563445_457.returns.push(o24);
// 5451
// 5453
// 5454
o25 = {};
// 5455
f925563445_457.returns.push(o25);
// 5456
// 5457
o23.id = "contentArea";
// undefined
o23 = null;
// 5458
o24.id = "rightCol";
// undefined
o24 = null;
// 5459
o25.id = "toolbarContainer";
// undefined
o25 = null;
// 5460
// 5461
// 5462
// 5463
// 5464
// 5465
// 5466
// 5467
// 5468
// 5469
// 5470
// 5471
// 5472
// 5473
// 5474
// 5475
// 5476
// 5477
// 5478
// 5479
// 5480
// 5481
// 5482
// 5483
// 5484
// 5485
// 5486
// 5487
// 5488
// 5489
// 5490
// 5491
// 5492
// 5493
// 5494
// 5495
// 5496
// 5497
// 5498
// 5499
// 5500
// 5501
// 5502
// 5503
// 5504
// 5505
// 5506
// 5507
// 5508
// 5509
// 5510
// 5511
// 5512
// 5513
// 5514
// 5515
// 5516
// 5517
// 5518
// 5519
// 5520
// 5521
// 5522
// 5523
// 5524
// 5525
// 5526
// 5527
// 5528
// 5529
// 5530
// 5531
// 5532
// 5533
// 5534
// 5535
// 5536
// 5537
// 5538
// 5539
// 5540
// 5541
// 5542
// 5543
// 5544
// 5545
// 5546
// 5547
// 5548
// 5549
// 5550
// 5551
// 5552
// 5553
// 5554
// 5555
// 5556
// 5557
// 5558
// 5559
// 5560
// 5561
// 5562
// 5563
// 5564
// 5565
// 5566
// 5567
// 5568
// 5569
// 5570
// 5571
// 5572
// 5573
// 5574
// 5575
// 5576
// 5577
// 5578
// 5579
// 5581
// 5582
o23 = {};
// 5583
f925563445_457.returns.push(o23);
// 5584
// 5585
// 5586
// 5587
o23.__FB_TOKEN = null;
// 5588
// undefined
o23 = null;
// 5589
// 5590
// 5591
// 5592
// 5593
// 5594
// 5595
// 5596
// 5597
// 5598
// 5599
// 5600
// 5601
// 5603
// 5604
// 5606
// 5607
// 5608
// 5609
// 5610
// 5611
// 5612
// 5615
// 5616
// 5617
// 5618
// 5619
// 5620
// 5621
// 5622
// 5623
// 5624
// 5625
// 5626
f925563445_7.returns.push(undefined);
// 5627
// 5628
// 5629
// 5630
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 5631
// 5632
// 5633
// 5634
o23 = {};
// 5635
f925563445_0.returns.push(o23);
// undefined
o23 = null;
// 5636
// 5637
// 5638
// 5639
// 5640
// 5641
// 5642
// 5643
// 5644
// 5645
// 5646
// 5647
// 5648
// 5649
// 5650
// 5651
// 5653
// 5654
o23 = {};
// 5655
f925563445_457.returns.push(o23);
// 5656
// 5658
// 5659
o24 = {};
// 5660
f925563445_457.returns.push(o24);
// undefined
o24 = null;
// 5661
// 5662
// 5663
// 5664
// 5665
// 5666
// 5667
o24 = {};
// 5668
o23.firstChild = o24;
// undefined
o23 = null;
// 5669
o24.nodeValue = "0";
// undefined
o24 = null;
// 5670
// 5672
// 5673
o23 = {};
// 5674
f925563445_457.returns.push(o23);
// 5675
// 5676
// 5677
// 5678
// 5679
// 5680
// 5681
// 5682
// 5683
// 5684
// 5685
// 5686
// 5687
// 5688
// 5689
// 5690
// 5691
// 5692
// 5693
// 5695
// 5696
o24 = {};
// 5697
f925563445_457.returns.push(o24);
// 5698
// 5700
// 5701
o25 = {};
// 5702
f925563445_457.returns.push(o25);
// 5703
// 5705
// 5706
f925563445_457.returns.push(null);
// 5707
// 5709
// 5710
f925563445_457.returns.push(null);
// 5711
// 5712
// 5713
// 5714
// 5715
// 5716
// 5717
// 5718
// 5719
// 5720
// 5721
// 5722
// 5723
// 5724
// 5725
// 5726
// 5727
// 5728
// 5729
// 5730
// 5731
// 5732
// 5733
// 5734
// 5735
// 5736
// 5737
// 5738
// 5739
// 5740
// 5741
// 5742
// 5743
// 5744
// 5745
// 5746
// 5747
// 5748
// 5749
// 5750
// 5751
// 5752
// 5753
// 5754
// 5755
// 5756
// 5757
// 5758
// 5759
// 5760
// 5761
// 5762
// 5763
// 5764
// 5765
// 5766
// 5767
// 5768
// 5769
// 5770
// 5771
// 5772
// 5773
// 5774
// 5775
// 5776
// 5777
// 5778
// 5779
// 5780
// 5781
// 5782
// 5783
// 5784
// 5785
// 5786
// 5787
// 5788
// 5789
// 5790
// 5791
// 5792
// 5793
// 5794
// 5795
// 5796
// 5797
// 5798
// 5799
// 5800
// 5801
// 5802
// 5804
// 5805
// 5806
// 5807
// 5808
// 5809
// 5810
// 5813
o25.nodeName = "DIV";
// 5814
// 5815
// undefined
fo925563445_564___FB_TOKEN = function() { return fo925563445_564___FB_TOKEN.returns[fo925563445_564___FB_TOKEN.inst++]; };
fo925563445_564___FB_TOKEN.returns = [];
fo925563445_564___FB_TOKEN.inst = 0;
defineGetter(o25, "__FB_TOKEN", fo925563445_564___FB_TOKEN);
// undefined
fo925563445_564___FB_TOKEN.returns.push(null);
// 5818
o25.getAttribute = f925563445_468;
// 5820
// 5821
f925563445_468.returns.push(null);
// 5822
// 5823
// 5824
// 5825
// 5826
// 5827
// 5828
// 5829
// 5830
o26 = {};
// undefined
fo925563445_564___FB_TOKEN.returns.push(o26);
// 5832
o26["0"] = 3;
// 5833
o25.JSBNG__addEventListener = f925563445_433;
// 5835
// 5836
f925563445_433.returns.push(undefined);
// 5837
// 5838
// undefined
fo925563445_564___FB_TOKEN.returns.push(o26);
// undefined
o26 = null;
// 5841
o25.onsubmit = null;
// 5843
// 5844
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 5845
// 5846
// 5847
// 5848
// 5850
// 5851
o26 = {};
// 5852
f925563445_457.returns.push(o26);
// undefined
o26 = null;
// 5853
// 5854
// 5855
// 5856
// 5857
// 5858
// 5859
// 5860
// 5861
// 5862
// 5863
// 5864
// 5865
// 5866
// 5867
// 5868
// 5869
// 5870
// 5871
// 5872
// 5873
// 5874
// 5875
// 5876
// 5877
// 5878
// 5879
// 5880
// 5881
// 5882
// 5883
// 5884
// 5885
// 5886
// 5887
// 5888
// 5889
// 5890
// 5891
// 5892
// 5893
// 5894
// 5895
// 5896
// 5898
// 5899
// 5902
// 5903
// 5904
// 5905
// 5906
// 5907
// 5908
// 5909
// 5910
// 5911
// 5912
// 5913
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 5914
// 5915
// 5916
// 5917
// 5918
// 5919
// 5920
// 5921
// 5923
// 5924
f925563445_457.returns.push(o24);
// undefined
o24 = null;
// 5925
// 5927
// 5928
o24 = {};
// 5929
f925563445_457.returns.push(o24);
// undefined
o24 = null;
// 5930
// 5932
// 5933
f925563445_457.returns.push(null);
// 5934
// 5936
// 5937
f925563445_457.returns.push(null);
// 5938
// 5939
// 5940
// 5941
// 5942
// 5943
// 5944
// 5945
// 5946
// 5947
// 5948
// 5949
// 5950
// 5951
// 5952
// 5953
// 5954
// 5955
// 5956
// 5957
// 5958
// 5959
// 5960
// 5961
// 5962
// 5963
// 5964
// 5965
// 5966
// 5967
// 5968
// 5969
// 5970
// 5971
// 5972
// 5973
// 5974
// 5975
// 5976
// 5977
// 5978
// 5979
// 5980
// 5981
// 5982
// 5983
// 5984
// 5985
// 5986
// 5987
// 5988
// 5989
// 5990
// 5991
// 5992
// 5993
// 5994
// 5995
// 5996
// 5997
// 5998
// 6000
// 6001
o24 = {};
// 6002
f925563445_457.returns.push(o24);
// 6003
// 6005
// 6006
o26 = {};
// 6007
f925563445_457.returns.push(o26);
// undefined
o26 = null;
// 6008
// 6009
// 6010
// 6011
// 6012
// 6013
// 6014
o26 = {};
// 6015
o24.firstChild = o26;
// undefined
o24 = null;
// 6016
o26.nodeValue = "0";
// undefined
o26 = null;
// 6017
// 6019
// 6020
o24 = {};
// 6021
f925563445_457.returns.push(o24);
// 6022
// 6023
// 6024
// 6025
// 6026
// 6027
// 6028
// 6029
// 6030
// 6031
// 6032
// 6033
// 6034
// 6035
// 6036
// 6038
// 6039
f925563445_457.returns.push(o24);
// 6040
// 6041
// 6042
// 6043
// 6044
// 6045
// 6046
// 6047
// 6048
// 6049
// 6050
// 6051
// 6052
// 6053
// 6054
// 6055
// 6056
// 6057
// 6058
// 6059
// 6060
// 6061
// 6062
// 6063
// 6064
// 6065
// 6066
// 6067
// 6068
// 6069
// 6070
// 6071
// 6072
// 6073
// 6074
// 6075
// 6076
// 6078
// 6079
f925563445_457.returns.push(o23);
// 6080
// 6081
// 6082
// 6083
// 6084
// 6085
// 6086
// 6087
// 6088
// 6089
// 6090
// 6091
// 6092
// 6093
// 6094
// 6095
// 6096
// 6097
// 6098
// 6099
// 6100
// 6101
// 6102
// 6103
// 6105
// 6106
f925563445_457.returns.push(o23);
// 6107
// 6108
// 6109
// 6110
// 6111
// 6112
// 6113
// 6114
// 6115
// 6116
// 6117
// 6119
// 6120
f925563445_457.returns.push(o24);
// undefined
o24 = null;
// 6121
// 6122
// 6123
// 6124
// 6125
// 6126
// 6127
// 6128
// 6129
// 6130
// 6131
// 6132
// 6133
// 6134
// 6135
// 6136
// 6137
// 6138
// 6139
// 6140
// 6141
// 6142
// 6143
// 6144
// 6145
// 6146
// 6147
// 6148
// 6149
// 6150
// 6151
// 6153
// 6154
// 6158
// 6159
// 6160
o23.nodeName = "UL";
// 6161
// 6162
// undefined
fo925563445_562___FB_TOKEN = function() { return fo925563445_562___FB_TOKEN.returns[fo925563445_562___FB_TOKEN.inst++]; };
fo925563445_562___FB_TOKEN.returns = [];
fo925563445_562___FB_TOKEN.inst = 0;
defineGetter(o23, "__FB_TOKEN", fo925563445_562___FB_TOKEN);
// undefined
fo925563445_562___FB_TOKEN.returns.push(null);
// 6165
o23.getAttribute = f925563445_468;
// 6167
// 6168
f925563445_468.returns.push(null);
// 6169
// 6170
// 6171
// 6172
// 6173
// 6174
// 6175
// 6176
// 6177
o24 = {};
// undefined
fo925563445_562___FB_TOKEN.returns.push(o24);
// 6179
o24["0"] = 4;
// 6180
o23.JSBNG__addEventListener = f925563445_433;
// 6182
// 6183
f925563445_433.returns.push(undefined);
// 6184
// 6185
// undefined
fo925563445_562___FB_TOKEN.returns.push(o24);
// 6188
o23.onmouseover = null;
// 6190
// 6191
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6193
// 6194
// 6196
// 6197
// undefined
fo925563445_562___FB_TOKEN.returns.push(o24);
// 6200
// 6201
// 6202
// 6203
// 6204
// 6205
// 6206
// 6207
// undefined
fo925563445_562___FB_TOKEN.returns.push(o24);
// 6212
// 6213
f925563445_433.returns.push(undefined);
// 6214
// 6215
// undefined
fo925563445_562___FB_TOKEN.returns.push(o24);
// undefined
o24 = null;
// 6218
o23.onmouseout = null;
// 6220
// 6221
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6222
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6223
// 6224
// 6225
// 6227
// 6228
f925563445_457.returns.push(o23);
// undefined
o23 = null;
// 6229
// 6230
// 6231
// 6232
// 6233
// 6234
// 6235
// 6236
// 6237
// 6238
// 6239
// 6240
// 6241
// 6242
// 6243
// 6244
// 6245
// 6246
// 6247
// 6248
// 6249
// 6250
// 6251
// 6252
// 6253
// 6254
// 6255
// 6256
// 6257
// 6258
// 6259
// 6260
// 6261
// 6262
// 6263
// 6264
// 6265
// 6266
// 6267
// 6268
// 6269
// 6270
// 6271
// 6272
// 6273
// 6274
// 6275
// 6276
// 6277
// 6278
// 6279
// 6280
// 6281
// 6282
// 6283
// 6284
// 6285
// 6286
// 6287
// 6288
// 6289
// 6290
// 6291
// 6292
// 6293
// 6294
// 6295
// 6296
// 6297
// 6298
// 6299
// 6300
// 6301
// 6302
// 6303
// 6304
// 6305
// 6306
// 6307
// 6308
// 6309
// 6310
// 6312
// 6313
o23 = {};
// 6314
f925563445_457.returns.push(o23);
// 6315
// 6317
// 6318
o24 = {};
// 6319
f925563445_457.returns.push(o24);
// 6320
// 6322
// 6323
o26 = {};
// 6324
f925563445_457.returns.push(o26);
// 6325
// 6327
// 6328
o27 = {};
// 6329
f925563445_457.returns.push(o27);
// 6330
// 6331
// 6332
// 6333
// 6334
// 6335
// 6336
// 6337
// 6338
// 6339
// 6340
// 6341
// 6342
// 6343
// 6344
// 6345
// 6346
// 6347
// 6348
// 6349
// 6350
// 6351
// 6352
// 6353
// 6354
// 6355
// 6356
// 6357
// 6358
// 6359
// 6360
// 6361
// 6362
// 6363
// 6364
// 6365
// 6366
// 6367
// 6368
// 6369
// 6370
// 6371
// 6372
// 6373
// 6374
// 6375
// 6376
// 6377
// 6378
// 6379
// 6380
f925563445_577 = function() { return f925563445_577.returns[f925563445_577.inst++]; };
f925563445_577.returns = [];
f925563445_577.inst = 0;
// 6381
o26.getElementsByTagName = f925563445_577;
// undefined
o26 = null;
// 6382
// 6383
// 6384
o26 = {};
// 6385
f925563445_577.returns.push(o26);
// 6386
o26.length = 10;
// 6387
o28 = {};
// 6388
o26["0"] = o28;
// 6389
o29 = {};
// 6390
o26["1"] = o29;
// 6391
o30 = {};
// 6392
o26["2"] = o30;
// 6393
o31 = {};
// 6394
o26["3"] = o31;
// 6395
o26["4"] = o24;
// 6396
o26["5"] = o27;
// 6397
o32 = {};
// 6398
o26["6"] = o32;
// 6399
o33 = {};
// 6400
o26["7"] = o33;
// 6401
o34 = {};
// 6402
o26["8"] = o34;
// 6403
o35 = {};
// 6404
o26["9"] = o35;
// undefined
o26 = null;
// 6405
// 6406
// 6407
o28.className = "uiHeader uiHeaderBottomBorder jewelHeader";
// undefined
o28 = null;
// 6408
// 6409
// 6410
o29.className = "clearfix uiHeaderTop";
// undefined
o29 = null;
// 6411
// 6412
// 6413
o30.className = "";
// undefined
o30 = null;
// 6414
// 6415
// 6416
o31.className = "uiHeaderTitle";
// undefined
o31 = null;
// 6417
// 6418
// 6419
o24.className = "jewelItemList jewelHighlight";
// 6420
// 6421
// 6422
o27.className = "";
// 6423
// 6424
// 6425
o32.className = "jewelLoading img";
// 6426
// 6427
// 6428
o33.className = "jewelFooter";
// undefined
o33 = null;
// 6429
// 6430
// 6431
o34.className = "seeMore";
// undefined
o34 = null;
// 6432
// 6433
// 6434
o35.className = "";
// undefined
o35 = null;
// 6435
// 6437
// 6438
f925563445_457.returns.push(o24);
// 6439
// 6440
// 6441
// 6442
o24.getElementsByTagName = f925563445_577;
// 6443
// 6444
// 6445
o26 = {};
// 6446
f925563445_577.returns.push(o26);
// 6447
o26.length = 2;
// 6448
o26["0"] = o27;
// 6449
o26["1"] = o32;
// undefined
o26 = null;
// undefined
o32 = null;
// 6450
// 6451
// 6453
// 6454
// 6456
// 6457
// 6458
// 6459
// 6460
// 6461
// 6462
// 6463
// 6464
// 6465
// 6466
// 6467
// 6468
// 6469
// 6470
// 6471
// 6472
// 6473
// 6474
// 6475
// 6476
// 6477
// 6478
// 6479
// 6480
// 6481
// 6482
// 6483
// 6484
// 6485
// 6486
// 6487
// 6488
// 6489
// 6490
// 6491
// 6492
// 6493
// 6494
// 6495
// 6496
// 6497
// 6498
// 6499
// 6500
// 6501
// 6502
// 6503
// 6504
// 6505
// 6506
// 6507
// 6508
// 6509
// 6510
// 6511
// 6512
// 6513
// 6514
// 6515
// 6516
// 6517
// 6518
// 6519
// 6520
// 6521
// 6522
// 6523
// 6524
// 6525
// 6526
// 6527
// 6528
// 6529
// 6530
// 6531
// 6532
// 6533
// 6534
// 6535
f925563445_12.returns.push(8);
// 6536
// 6537
// 6538
// 6539
// 6540
// 6541
// 6542
// 6543
o23.getElementsByTagName = f925563445_577;
// 6544
// 6545
// 6546
o26 = {};
// 6547
f925563445_577.returns.push(o26);
// 6548
o26.length = 2;
// 6549
o28 = {};
// 6550
o26["0"] = o28;
// 6551
o29 = {};
// 6552
o26["1"] = o29;
// undefined
o26 = null;
// 6553
// 6554
// 6555
o28.className = "jewelCount";
// 6556
// 6557
// 6558
o29.className = "";
// 6559
// 6560
o28.getElementsByTagName = f925563445_577;
// undefined
o28 = null;
// 6561
// 6562
// 6563
o26 = {};
// 6564
f925563445_577.returns.push(o26);
// 6565
o26.length = 1;
// 6566
o26["0"] = o29;
// undefined
o26 = null;
// undefined
o29 = null;
// 6567
// 6568
// 6570
// 6571
// 6575
// 6576
// 6577
o24.nodeName = "UL";
// 6578
// 6579
// undefined
fo925563445_574___FB_TOKEN = function() { return fo925563445_574___FB_TOKEN.returns[fo925563445_574___FB_TOKEN.inst++]; };
fo925563445_574___FB_TOKEN.returns = [];
fo925563445_574___FB_TOKEN.inst = 0;
defineGetter(o24, "__FB_TOKEN", fo925563445_574___FB_TOKEN);
// undefined
fo925563445_574___FB_TOKEN.returns.push(null);
// 6582
o24.getAttribute = f925563445_468;
// 6584
// 6585
f925563445_468.returns.push(null);
// 6586
// 6587
// 6588
// 6589
// 6590
// 6591
// 6592
// 6593
// 6594
o26 = {};
// undefined
fo925563445_574___FB_TOKEN.returns.push(o26);
// 6596
o26["0"] = 5;
// 6597
o24.JSBNG__addEventListener = f925563445_433;
// 6599
// 6600
f925563445_433.returns.push(undefined);
// 6601
// 6602
// undefined
fo925563445_574___FB_TOKEN.returns.push(o26);
// 6605
o24.onmouseover = null;
// 6607
// 6608
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6610
// 6611
// 6613
// 6614
// undefined
fo925563445_574___FB_TOKEN.returns.push(o26);
// 6617
// 6618
// 6619
// 6620
// 6621
// 6622
// 6623
// 6624
// undefined
fo925563445_574___FB_TOKEN.returns.push(o26);
// 6629
// 6630
f925563445_433.returns.push(undefined);
// 6631
// 6632
// undefined
fo925563445_574___FB_TOKEN.returns.push(o26);
// undefined
o26 = null;
// 6635
o24.onmouseout = null;
// undefined
o24 = null;
// 6637
// 6638
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6639
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6641
// 6642
// 6643
// 6644
// 6645
// 6646
// 6647
// 6650
o23.nodeName = "DIV";
// 6651
// 6652
// undefined
fo925563445_573___FB_TOKEN = function() { return fo925563445_573___FB_TOKEN.returns[fo925563445_573___FB_TOKEN.inst++]; };
fo925563445_573___FB_TOKEN.returns = [];
fo925563445_573___FB_TOKEN.inst = 0;
defineGetter(o23, "__FB_TOKEN", fo925563445_573___FB_TOKEN);
// undefined
fo925563445_573___FB_TOKEN.returns.push(null);
// 6655
o23.getAttribute = f925563445_468;
// 6657
// 6658
f925563445_468.returns.push(null);
// 6659
// 6660
// 6661
// 6662
// 6663
// 6664
// 6665
// 6666
// 6667
o24 = {};
// undefined
fo925563445_573___FB_TOKEN.returns.push(o24);
// 6669
o24["0"] = 6;
// 6670
o23.JSBNG__addEventListener = f925563445_433;
// 6672
// 6673
f925563445_433.returns.push(undefined);
// 6674
// 6675
// undefined
fo925563445_573___FB_TOKEN.returns.push(o24);
// 6678
o23.onmouseover = null;
// 6680
// 6681
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6682
// 6683
// 6684
// 6685
// 6686
// 6687
// 6688
// 6689
// 6690
// 6691
// 6692
// 6693
// 6694
// 6695
// 6696
// 6697
// 6698
// 6699
// 6700
// 6701
// 6702
// 6703
// 6704
// 6705
// 6706
// 6707
// 6708
// 6709
// 6710
// 6711
// 6712
// 6713
// 6714
// 6715
// 6716
// 6717
// 6718
// 6719
// 6720
// 6721
// 6722
// 6723
// 6724
// 6725
// 6726
// 6727
// 6728
// 6729
// 6730
// 6731
// 6732
// 6733
// 6734
// 6735
// 6736
// 6737
// 6739
// 6740
// 6741
o26 = {};
// 6742
f925563445_577.returns.push(o26);
// 6743
o26.length = 1;
// 6744
o26["0"] = o27;
// undefined
o26 = null;
// undefined
o27 = null;
// 6745
// 6746
// 6748
// 6749
// 6750
// 6751
// 6752
// 6753
// 6754
// 6755
// 6756
// 6757
// 6758
// 6759
// 6760
// 6761
// 6762
// 6763
// 6764
// 6765
// 6766
// 6767
// 6768
// 6769
// 6770
// 6771
// 6772
// 6773
// 6774
// 6775
// 6776
// 6777
// 6778
// 6779
// 6780
// 6781
// 6782
// 6783
// 6784
// 6785
// 6787
// 6788
f925563445_457.returns.push(o23);
// undefined
o23 = null;
// 6789
// 6790
// 6791
// 6792
// 6793
// 6794
// 6795
// 6796
// 6797
// 6798
// 6799
// 6800
// 6801
// 6802
// 6803
// 6804
// 6805
// 6806
// 6807
// 6808
// 6809
// 6810
// 6811
// 6812
// 6813
// 6814
// 6815
// 6816
// 6817
// 6818
// 6819
// 6820
// 6821
// 6822
// 6823
// 6824
// 6825
// 6826
f925563445_12.returns.push(9);
// 6827
// 6828
// 6829
// 6830
// 6831
// 6833
// 6834
// 6837
// 6838
// 6839
// 6840
// 6841
// 6842
// 6843
// 6844
// 6845
// 6846
// 6847
// 6848
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6849
// 6850
// 6852
// 6853
// 6856
// 6857
// 6858
// 6859
// 6860
// 6861
// 6862
// 6863
// 6864
// 6865
// 6866
// 6867
f925563445_7.returns.push(undefined);
// 6868
// 6869
// 6870
// 6871
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6872
// 6873
// 6876
// 6877
// 6880
o5.nodeName = "HTML";
// 6881
// 6882
// undefined
fo925563445_427___FB_TOKEN = function() { return fo925563445_427___FB_TOKEN.returns[fo925563445_427___FB_TOKEN.inst++]; };
fo925563445_427___FB_TOKEN.returns = [];
fo925563445_427___FB_TOKEN.inst = 0;
defineGetter(o5, "__FB_TOKEN", fo925563445_427___FB_TOKEN);
// undefined
fo925563445_427___FB_TOKEN.returns.push(null);
// 6885
o5.getAttribute = f925563445_468;
// 6887
// 6888
f925563445_468.returns.push(null);
// 6889
// 6890
// 6891
// 6892
// 6893
// 6894
// 6895
// 6896
// 6897
o23 = {};
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 6899
o23["0"] = 7;
// 6902
// 6903
f925563445_433.returns.push(undefined);
// 6904
// 6905
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 6908
o5.onkeyup = null;
// 6910
// 6911
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6912
// 6913
// 6916
// 6917
// 6921
// 6922
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 6925
// 6926
// 6927
// 6928
// 6929
// 6930
// 6931
// 6932
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 6937
// 6938
f925563445_433.returns.push(undefined);
// 6939
// 6940
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 6943
f925563445_596 = function() { return f925563445_596.returns[f925563445_596.inst++]; };
f925563445_596.returns = [];
f925563445_596.inst = 0;
// 6944
o5.onsubmit = f925563445_596;
// 6947
o3._BUBBLE = 1000;
// 6949
// 6951
// 6952
// 6954
// 6955
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 6958
// 6959
// 6960
// 6961
// 6962
// 6963
// 6964
// 6965
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 6968
// 6969
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6971
// 6972
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6973
// 6974
// 6975
// 6976
// 6978
// 6979
// 6981
// 6982
// 6985
// 6986
// 6987
// 6988
// 6989
// 6990
// 6991
// 6992
// 6993
// 6994
// 6995
// 6996
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 6997
// 6998
// 6999
f925563445_14.returns.push(undefined);
// 7000
// 7001
// 7002
// 7003
f925563445_12.returns.push(10);
// 7004
// 7005
// 7006
// 7007
// 7008
// 7009
// 7010
// 7011
// 7012
// 7013
// 7014
// 7015
// 7016
// 7017
// 7018
// 7019
// 7020
// 7021
// 7024
// 7025
// 7026
// 7027
// 7031
// 7032
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7035
// 7036
// 7037
// 7038
// 7039
// 7040
// 7041
// 7042
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7047
// 7048
f925563445_433.returns.push(undefined);
// 7049
// 7050
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7053
o5.onmousewheel = null;
// 7055
// 7056
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7057
// 7058
// 7059
// 7060
// 7061
// 7062
// 7063
// 7064
// 7065
// 7066
// 7067
// 7068
// 7069
// 7070
// 7071
// 7072
// 7073
// 7074
// 7075
// 7076
// 7077
// 7078
// 7079
// 7080
// 7081
// 7082
// 7083
// 7084
// 7085
// 7086
// 7087
// 7088
// 7089
// 7090
// 7091
// 7092
// 7093
// 7094
// 7095
// 7096
// 7097
// 7098
// 7099
// 7100
// 7101
// 7102
// 7103
// 7104
// 7105
// 7106
// 7107
// 7108
// 7109
// 7110
// 7111
// 7112
// 7113
// 7114
// 7115
// 7116
// 7117
// 7118
// 7119
// 7120
// 7121
// 7122
// 7123
// 7124
// 7125
// 7126
// 7130
o3.URGENT = -20;
// undefined
o3 = null;
// 7131
// 7132
// 7134
// 7135
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7138
// 7139
// 7140
// 7141
// 7142
// 7143
// 7144
// 7145
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7148
// 7149
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7150
// 7151
// 7154
// 7155
// 7159
// 7160
// 7162
// 7163
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7166
// 7167
// 7168
// 7169
// 7170
// 7171
// 7172
// 7173
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7178
// 7179
f925563445_433.returns.push(undefined);
// 7180
// 7181
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7184
f925563445_597 = function() { return f925563445_597.returns[f925563445_597.inst++]; };
f925563445_597.returns = [];
f925563445_597.inst = 0;
// 7185
o5.onkeydown = f925563445_597;
// 7190
// 7192
// 7193
// 7195
// 7196
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7199
// 7200
// 7201
// 7202
// 7203
// 7204
// 7205
// 7206
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7209
// 7210
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7212
// 7213
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7215
// 7216
// 7218
// 7219
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7222
// 7223
// 7224
// 7225
// 7226
// 7227
// 7228
// 7229
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7234
// 7235
f925563445_433.returns.push(undefined);
// 7236
// 7237
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7240
o5.onpaste = null;
// 7242
// 7243
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7244
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7245
// 7246
// 7247
// 7248
// 7249
// 7250
// 7251
// 7254
// 7255
// 7256
// 7257
// 7258
// 7259
// 7260
// 7264
// 7265
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7268
// 7269
// 7270
// 7271
// 7272
// 7273
// 7274
// 7275
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7280
// 7281
f925563445_433.returns.push(undefined);
// 7282
// 7283
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7286
o5.onmouseover = null;
// 7288
// 7289
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7290
// 7291
// 7293
o3 = {};
// 7294
o0.body = o3;
// 7295
// 7296
// 7299
o3.nodeName = "BODY";
// 7300
// 7301
// undefined
fo925563445_598___FB_TOKEN = function() { return fo925563445_598___FB_TOKEN.returns[fo925563445_598___FB_TOKEN.inst++]; };
fo925563445_598___FB_TOKEN.returns = [];
fo925563445_598___FB_TOKEN.inst = 0;
defineGetter(o3, "__FB_TOKEN", fo925563445_598___FB_TOKEN);
// undefined
fo925563445_598___FB_TOKEN.returns.push(null);
// 7304
o3.getAttribute = f925563445_468;
// 7306
// 7307
f925563445_468.returns.push(null);
// 7308
// 7309
// 7310
// 7311
// 7312
// 7313
// 7314
// 7315
// 7316
o26 = {};
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7318
o26["0"] = 8;
// 7319
o3.JSBNG__addEventListener = f925563445_433;
// 7321
// 7322
f925563445_433.returns.push(undefined);
// 7323
// 7324
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7327
o3.onmouseover = null;
// 7329
// 7330
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7333
// 7334
// 7338
// 7339
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7342
// 7343
// 7344
// 7345
// 7346
// 7347
// 7348
// 7349
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7354
// 7355
f925563445_433.returns.push(undefined);
// 7356
// 7357
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7360
o3.onkeydown = null;
// 7362
// 7363
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7366
// 7367
// 7371
// 7372
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7375
// 7376
// 7377
// 7378
// 7379
// 7380
// 7381
// 7382
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7387
// 7388
f925563445_433.returns.push(undefined);
// 7389
// 7390
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7393
o3.onclick = null;
// 7395
// 7396
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7397
// 7398
// 7401
// 7402
// 7406
// 7407
// 7409
// 7410
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7413
// 7414
// 7415
// 7416
// 7417
// 7418
// 7419
// 7420
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7423
// 7424
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7426
// 7427
// 7429
// 7430
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7433
// 7434
// 7435
// 7436
// 7437
// 7438
// 7439
// 7440
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7443
// 7444
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7445
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7446
// 7447
// 7450
// 7451
// 7455
// 7456
// 7458
// 7459
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7462
// 7463
// 7464
// 7465
// 7466
// 7467
// 7468
// 7469
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7472
// 7473
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7475
// 7476
// 7478
// 7479
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7482
// 7483
// 7484
// 7485
// 7486
// 7487
// 7488
// 7489
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7494
// 7495
f925563445_433.returns.push(undefined);
// 7496
// 7497
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 7500
o3.onkeyup = null;
// 7502
// 7503
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7504
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7505
// 7506
// 7507
// 7508
// 7509
// 7510
// 7511
// 7512
// 7513
// 7514
// 7515
// 7516
// 7517
// 7518
// 7519
// 7520
// 7521
// 7522
// 7523
// 7524
// 7525
// 7526
// 7527
// 7528
// 7529
// 7530
// 7531
// 7532
// 7533
// 7534
// 7535
// 7536
// 7537
// 7538
// 7539
// 7540
// 7541
// 7542
// 7543
// 7544
// 7545
// 7546
// 7547
// 7548
// 7549
// 7552
// 7553
// 7554
// 7555
// 7556
// 7557
// 7558
// 7562
// 7563
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7566
// 7567
// 7568
// 7569
// 7570
// 7571
// 7572
// 7573
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7578
// 7579
f925563445_433.returns.push(undefined);
// 7580
// 7581
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7584
o5.onmousedown = null;
// 7586
// 7587
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7590
// 7591
// 7592
// 7593
// 7594
// 7595
// 7596
// 7600
// 7601
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7604
// 7605
// 7606
// 7607
// 7608
// 7609
// 7610
// 7611
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7614
// 7615
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7616
// 7617
// 7618
// 7619
// 7620
// 7623
// 7624
// 7625
// 7626
// 7627
// 7628
// 7629
// 7633
// 7634
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7637
// 7638
// 7639
// 7640
// 7641
// 7642
// 7643
// 7644
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 7647
// 7648
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 7649
// 7650
// 7651
// 7652
// 7653
// 7654
// 7655
// 7656
// 7657
// 7658
// 7659
// 7660
// 7661
// 7662
// 7663
// 7664
// 7665
// 7666
// 7667
// 7668
// 7669
// 7670
// 7671
// 7672
// 7673
// 7674
// 7675
// 7676
// 7677
// 7678
// 7679
// 7680
// 7681
// 7682
// 7683
// 7684
// 7685
// 7686
// 7687
// 7688
// 7689
o25.getElementsByTagName = f925563445_577;
// undefined
o25 = null;
// 7690
// 7691
// 7692
o25 = {};
// 7693
f925563445_577.returns.push(o25);
// 7694
o25.length = 13;
// 7695
o27 = {};
// 7696
o25["0"] = o27;
// 7697
o28 = {};
// 7698
o25["1"] = o28;
// 7699
o29 = {};
// 7700
o25["2"] = o29;
// 7701
o30 = {};
// 7702
o25["3"] = o30;
// 7703
o31 = {};
// 7704
o25["4"] = o31;
// 7705
o25["5"] = o4;
// 7706
o32 = {};
// 7707
o25["6"] = o32;
// 7708
o33 = {};
// 7709
o25["7"] = o33;
// 7710
o34 = {};
// 7711
o25["8"] = o34;
// 7712
o35 = {};
// 7713
o25["9"] = o35;
// 7714
o36 = {};
// 7715
o25["10"] = o36;
// 7716
o37 = {};
// 7717
o25["11"] = o37;
// 7718
o38 = {};
// 7719
o25["12"] = o38;
// undefined
o25 = null;
// 7720
// 7721
// 7722
o27.className = "uiHeader uiHeaderBottomBorder jewelHeader";
// undefined
o27 = null;
// 7723
// 7724
// 7725
o28.className = "clearfix uiHeaderTop";
// undefined
o28 = null;
// 7726
// 7727
// 7728
o29.className = "uiHeaderActions rfloat";
// undefined
o29 = null;
// 7729
// 7730
// 7731
o30.className = "";
// undefined
o30 = null;
// 7732
// 7733
// 7734
o31.className = "uiHeaderTitle";
// undefined
o31 = null;
// 7735
// 7736
// 7737
o4.className = "jewelItemList";
// 7738
// 7739
// 7740
o32.className = "";
// undefined
o32 = null;
// 7741
// 7742
// 7743
o33.className = "fbRequestList";
// undefined
o33 = null;
// 7744
// 7745
// 7746
o34.className = "uiList pbm";
// undefined
o34 = null;
// 7747
// 7748
// 7749
o35.className = "empty  uiListItem uiListLight uiListVerticalItemBorder";
// 7750
// 7751
// 7752
o36.className = "jewelFooter";
// undefined
o36 = null;
// 7753
// 7754
// 7755
o37.className = "seeMore";
// undefined
o37 = null;
// 7756
// 7757
// 7758
o38.className = "";
// undefined
o38 = null;
// 7759
// 7760
o4.getElementsByTagName = f925563445_577;
// undefined
o4 = null;
// 7761
// 7762
// 7763
o4 = {};
// 7764
f925563445_577.returns.push(o4);
// 7765
o4.length = 1;
// 7766
o4["0"] = o35;
// undefined
o4 = null;
// 7767
// 7768
// 7770
// 7771
// 7772
// 7773
// 7774
// 7775
// 7776
// 7777
// 7778
// 7779
// 7780
// 7782
// 7783
// 7784
o4 = {};
// 7785
f925563445_577.returns.push(o4);
// 7786
o4.length = 1;
// 7787
o4["0"] = o35;
// undefined
o4 = null;
// undefined
o35 = null;
// 7788
// 7789
// 7791
// 7792
// 7793
// 7794
// 7795
// 7796
// 7797
// 7798
// 7799
// 7800
// 7801
// 7802
// 7803
// 7804
// 7805
// 7806
// 7807
// 7809
// 7810
// 7811
// 7812
// 7813
// 7814
// 7815
// 7816
// 7817
// 7818
// 7819
// 7820
// 7821
// 7822
// 7823
// 7824
// 7825
// 7826
// 7827
// 7828
// 7829
// 7830
// 7831
// 7832
// 7833
// 7834
// 7835
// 7836
// 7837
// 7838
// 7839
// 7840
// 7841
// 7842
// 7843
// 7844
// 7845
// 7846
// 7847
// 7848
// 7849
// 7850
// 7851
// 7852
// 7853
// 7854
// 7855
// 7856
// 7857
// 7858
// 7859
// 7860
// 7861
// 7862
// 7863
// 7864
// 7865
// 7866
// 7867
// 7868
// 7869
// 7870
// 7871
// 7872
// 7873
// 7874
// 7875
// 7876
// 7877
// 7878
// 7879
// 7880
// 7881
// 7882
// 7883
// 7884
// 7885
// 7886
// 7887
// 7888
// 7889
// 7890
// 7891
// 7892
// 7893
// 7894
// 7895
// 7896
// 7897
// 7898
// 7899
// 7900
// 7901
// 7902
// 7903
// 7904
// 7905
// 7906
// 7907
// 7908
// 7909
// 7910
// 7911
// 7912
// 7913
// 7914
// 7915
// 7916
// 7917
// 7918
// 7919
// 7920
// 7921
// 7922
// 7923
// 7924
// 7925
// 7926
// 7927
// 7928
// 7929
// 7930
// 7931
// 7932
// 7933
// 7934
// 7935
// 7936
// 7937
// 7938
// 7939
// 7940
// 7941
// 7942
// 7943
// 7944
// 7945
// 7946
// 7947
// 7948
// 7949
// 7950
// 7951
// 7952
// 7953
// 7954
// 7955
// 7956
// 7957
// 7958
// 7959
// 7960
// 7961
// 7962
// 7963
// 7964
// 7965
// 7966
// 7967
// 7968
// 7969
// 7970
// 7971
// 7972
// 7973
// 7974
// 7975
// 7976
// 7977
// 7978
// 7980
// 7981
o4 = {};
// 7982
f925563445_457.returns.push(o4);
// 7983
// 7984
// 7985
// 7986
// 7987
// 7988
// 7989
// 7990
// 7991
// 7992
// 7993
// 7994
// 7995
// 7996
// 7997
// 7998
// 7999
// 8000
// 8001
// 8002
// 8004
// 8005
// 8006
// 8007
// 8008
// 8009
// 8010
// 8011
// 8012
// 8013
// 8014
// 8015
// 8016
// 8017
// 8018
// 8019
// 8020
// 8021
// 8022
// 8023
// 8024
// 8025
// 8026
// 8027
// 8028
// 8029
// 8030
// 8031
// 8032
// 8033
// 8034
// 8035
// 8036
// 8037
// 8038
// 8039
// 8040
// 8041
// 8042
// 8043
// 8044
// 8045
// 8046
// 8047
// 8048
// 8049
// 8050
// 8051
// 8052
// 8053
// 8054
// 8055
// 8056
// 8057
// 8058
// 8059
// 8060
// 8061
// 8062
// 8063
// 8064
// 8065
// 8066
// 8067
// 8068
// 8069
// 8070
// 8071
// 8072
// 8074
// 8075
// 8076
// 8077
// 8078
// 8079
// 8080
// 8083
// 8084
// 8085
// 8086
// 8087
// 8088
// 8089
// 8090
// 8091
// 8092
// 8093
// 8094
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8095
// 8096
// 8097
// 8098
// 8099
// 8100
// 8101
// 8102
// 8103
// 8104
// 8105
o4.className = "uiFutureSideNav";
// 8107
// undefined
o4 = null;
// 8108
// 8109
// 8110
// 8111
// 8112
// 8113
// 8114
// 8115
// 8116
// 8117
// 8118
// 8119
// 8120
// 8121
// 8122
// 8123
// 8124
// 8125
// 8126
// 8127
// 8128
// 8129
// 8130
// 8131
// 8132
// 8133
// 8134
// 8135
// 8136
// 8137
// 8138
// 8139
// 8140
// 8141
// 8142
// 8143
// 8144
// 8145
// 8146
// 8147
// 8148
// 8149
// 8150
// 8151
// 8152
// 8153
// 8154
// 8155
// 8156
// 8157
// 8158
// 8159
// 8160
// 8161
// 8162
// 8163
// 8164
// 8165
// 8166
// 8167
// 8168
// 8169
// 8170
// 8171
// 8172
// 8173
// 8174
// 8175
// 8176
// 8177
// 8178
// 8179
// 8180
// 8181
// 8182
// 8183
// 8184
// 8185
// 8186
// 8187
// 8188
// 8189
// 8190
// 8191
// 8192
// 8193
// 8194
// 8195
// 8196
// 8197
// 8198
// 8199
// 8200
// 8201
// 8202
// 8203
// 8204
// 8205
// 8206
// 8207
// 8208
// 8209
// 8210
// 8211
// 8212
// 8213
// 8214
// 8215
// 8216
// 8217
// 8218
// 8219
// 8220
// 8221
// 8222
// 8223
// 8224
// 8225
// 8226
// 8227
// 8228
// 8229
// 8230
// 8231
// 8232
// 8233
// 8234
// 8235
// 8236
// 8237
// 8238
// 8239
// 8240
// 8241
// 8242
// 8243
// 8244
// 8245
// 8246
// 8247
// 8248
// 8249
// 8250
// 8251
// 8252
// 8253
// 8254
// 8255
// 8256
// 8257
// 8258
// 8259
// 8260
// 8261
// 8262
// 8263
// 8264
// 8265
// 8266
// 8267
// 8268
// 8269
// 8270
// 8271
// 8272
// 8273
// 8275
// 8276
o4 = {};
// 8277
f925563445_457.returns.push(o4);
// 8278
// 8279
// 8280
// 8281
// 8282
// 8284
// 8285
// 8288
o4.nodeName = "DIV";
// 8289
// 8290
// undefined
fo925563445_616___FB_TOKEN = function() { return fo925563445_616___FB_TOKEN.returns[fo925563445_616___FB_TOKEN.inst++]; };
fo925563445_616___FB_TOKEN.returns = [];
fo925563445_616___FB_TOKEN.inst = 0;
defineGetter(o4, "__FB_TOKEN", fo925563445_616___FB_TOKEN);
// undefined
fo925563445_616___FB_TOKEN.returns.push(null);
// 8293
o4.getAttribute = f925563445_468;
// 8295
// 8296
f925563445_468.returns.push(null);
// 8297
// 8298
// 8299
// 8300
// 8301
// 8302
// 8303
// 8304
// 8305
o25 = {};
// undefined
fo925563445_616___FB_TOKEN.returns.push(o25);
// 8307
o25["0"] = 9;
// 8308
o4.JSBNG__addEventListener = f925563445_433;
// 8310
// 8311
f925563445_433.returns.push(undefined);
// 8312
// 8313
// undefined
fo925563445_616___FB_TOKEN.returns.push(o25);
// undefined
o25 = null;
// 8316
o4.onmouseover = null;
// undefined
o4 = null;
// 8318
// 8319
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8320
// 8321
// 8322
// 8323
// 8324
// 8326
// 8327
o4 = {};
// 8328
f925563445_457.returns.push(o4);
// 8330
// 8331
// 8334
o4.nodeName = "INPUT";
// 8335
// 8336
// undefined
fo925563445_618___FB_TOKEN = function() { return fo925563445_618___FB_TOKEN.returns[fo925563445_618___FB_TOKEN.inst++]; };
fo925563445_618___FB_TOKEN.returns = [];
fo925563445_618___FB_TOKEN.inst = 0;
defineGetter(o4, "__FB_TOKEN", fo925563445_618___FB_TOKEN);
// undefined
fo925563445_618___FB_TOKEN.returns.push(null);
// 8339
o4.getAttribute = f925563445_468;
// 8341
// 8342
f925563445_468.returns.push(null);
// 8343
// 8344
// 8345
// 8346
// 8347
// 8348
// 8349
// 8350
// 8351
o25 = {};
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8353
o25["0"] = 10;
// 8354
o4.JSBNG__addEventListener = f925563445_433;
// 8356
// 8357
f925563445_433.returns.push(undefined);
// 8358
// 8359
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8362
o4.onjsbng__focus = null;
// 8364
// 8365
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8367
// 8368
// 8369
// 8370
// 8371
// 8372
// 8373
// 8377
// 8378
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8381
// 8382
// 8383
// 8384
// 8385
// 8386
// 8387
// 8388
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8393
// 8394
f925563445_433.returns.push(undefined);
// 8395
// 8396
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8399
o4.onchange = null;
// 8401
// 8402
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8404
// 8405
// 8406
// 8407
// 8408
// 8409
// 8410
// 8414
// 8415
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8418
// 8419
// 8420
// 8421
// 8422
// 8423
// 8424
// 8425
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8430
// 8431
f925563445_433.returns.push(undefined);
// 8432
// 8433
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8436
o4.onkeydown = null;
// undefined
o4 = null;
// 8438
// 8439
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8441
// 8442
// 8446
// 8447
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// 8450
// 8451
// 8452
// 8453
// 8454
// 8455
// 8456
// 8457
// undefined
fo925563445_618___FB_TOKEN.returns.push(o25);
// undefined
o25 = null;
// 8460
// 8461
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8462
// 8463
// 8464
// 8465
// 8466
// 8468
// 8469
o4 = {};
// 8470
f925563445_457.returns.push(o4);
// 8471
f925563445_621 = function() { return f925563445_621.returns[f925563445_621.inst++]; };
f925563445_621.returns = [];
f925563445_621.inst = 0;
// 8472
o4.onsubmit = f925563445_621;
// undefined
o4 = null;
// 8473
// 8474
// 8475
// 8476
// 8477
// 8479
// 8480
o4 = {};
// 8481
f925563445_457.returns.push(o4);
// 8482
// 8483
// 8484
// 8486
o3.scrollLeft = 0;
// 8488
o5.scrollLeft = 0;
// 8490
o3.scrollTop = 0;
// 8492
o5.scrollTop = 0;
// 8493
// 8494
// 8495
// 8496
// 8497
// 8498
// 8499
o25 = {};
// 8500
f925563445_0.returns.push(o25);
// undefined
o25 = null;
// 8501
// 8502
// 8503
// 8504
// 8505
// 8506
// 8507
// 8509
// 8510
// 8513
// 8514
// 8515
// 8516
// 8517
// 8518
// 8519
// 8520
// 8521
// 8522
// 8523
// 8524
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8526
// 8527
// 8530
// 8531
// 8532
// 8533
// 8534
// 8535
// 8536
// 8537
// 8538
// 8539
// 8540
// 8541
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8542
// 8543
// 8544
// 8545
// 8546
f925563445_12.returns.push(11);
// 8547
// 8548
// 8549
// 8550
// 8551
// 8552
// 8553
// 8554
// 8555
// 8556
// 8557
// 8558
// 8559
// 8560
// 8561
// 8562
// 8563
// 8564
// 8565
// 8566
// 8567
// 8568
// 8569
// 8570
// 8571
// 8572
// 8573
// 8574
// 8575
// 8576
// 8577
// 8578
// 8579
// 8580
// 8581
// 8582
// 8583
// 8584
// 8585
// 8586
// 8587
// 8588
// 8589
// 8590
// 8591
// 8592
// 8593
// 8594
// 8595
// 8596
// 8597
// 8598
// 8599
// 8600
// 8601
// 8602
// 8603
// 8604
// 8605
// 8606
// 8607
// 8608
// 8609
// 8610
// 8611
// 8613
// 8614
// 8615
// 8616
// 8617
// 8618
// 8619
// 8620
// 8621
// 8622
// 8623
// 8624
// 8625
// 8626
// 8627
// 8628
// 8629
// 8630
// 8631
// 8632
// 8633
// 8634
// 8635
// 8636
// 8637
// 8638
// 8639
// 8640
// 8641
// 8642
// 8643
// 8644
// 8645
// 8646
// 8647
// 8648
// 8649
// 8650
// 8651
// 8652
// 8653
// 8654
// 8655
// 8656
// 8657
// 8658
// 8659
// 8660
// 8661
// 8662
// 8663
// 8664
// 8665
// 8666
// 8667
// 8668
// 8669
// 8670
// 8671
// 8672
// 8673
// 8674
// 8675
// 8676
// 8677
// 8678
// 8679
// 8680
// 8681
// 8682
// 8683
// 8684
o25 = {};
// 8685
f925563445_74.returns.push(o25);
// 8686
// 8687
// 8688
// 8689
// 8690
// 8691
f925563445_625 = function() { return f925563445_625.returns[f925563445_625.inst++]; };
f925563445_625.returns = [];
f925563445_625.inst = 0;
// 8692
o25.open = f925563445_625;
// 8693
// 8694
// 8695
f925563445_625.returns.push(undefined);
// 8696
// 8697
f925563445_626 = function() { return f925563445_626.returns[f925563445_626.inst++]; };
f925563445_626.returns = [];
f925563445_626.inst = 0;
// 8698
o25.setRequestHeader = f925563445_626;
// 8699
// 8700
f925563445_626.returns.push(undefined);
// 8701
// 8702
// 8703
// 8704
f925563445_627 = function() { return f925563445_627.returns[f925563445_627.inst++]; };
f925563445_627.returns = [];
f925563445_627.inst = 0;
// 8705
o25.send = f925563445_627;
// 8706
// 8707
f925563445_627.returns.push(undefined);
// 8708
// 8711
// 8712
// 8716
// 8717
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 8720
// 8721
// 8722
// 8723
// 8724
// 8725
// 8726
// 8727
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 8730
// 8731
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8732
// 8733
// 8734
// 8735
// 8736
// 8737
// 8738
// 8739
// 8740
// 8742
// 8743
o27 = {};
// 8744
f925563445_457.returns.push(o27);
// 8745
// 8747
// 8748
o28 = {};
// 8749
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 8750
// 8752
// 8753
f925563445_457.returns.push(null);
// 8754
// 8756
// 8757
f925563445_457.returns.push(null);
// 8758
// 8759
// 8760
// 8761
// 8762
// 8764
// 8765
// 8768
o27.nodeName = "LABEL";
// 8769
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 8770
// 8771
// 8772
o27 = {};
// 8773
f925563445_577.returns.push(o27);
// 8774
o27.length = 1;
// 8775
o28 = {};
// 8776
o27["0"] = o28;
// undefined
o27 = null;
// 8777
// 8778
// undefined
fo925563445_631___FB_TOKEN = function() { return fo925563445_631___FB_TOKEN.returns[fo925563445_631___FB_TOKEN.inst++]; };
fo925563445_631___FB_TOKEN.returns = [];
fo925563445_631___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_631___FB_TOKEN);
// undefined
fo925563445_631___FB_TOKEN.returns.push(null);
// 8781
o28.getAttribute = f925563445_468;
// 8783
// 8784
f925563445_468.returns.push(null);
// 8785
// 8786
// 8787
// 8788
// 8789
// 8790
// 8791
// 8792
// 8793
o27 = {};
// undefined
fo925563445_631___FB_TOKEN.returns.push(o27);
// 8795
o27["0"] = 11;
// 8796
o28.JSBNG__addEventListener = f925563445_433;
// 8798
// 8799
f925563445_433.returns.push(undefined);
// 8800
// 8801
// undefined
fo925563445_631___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 8804
o28.onclick = null;
// 8805
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 8806
// 8807
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8808
// 8809
// 8810
// 8811
// 8812
// 8813
// 8814
// 8815
// 8816
// 8817
// 8818
// 8819
// 8820
// 8821
// 8822
// 8823
// 8824
// 8825
// 8826
// 8827
// 8829
// 8830
o27 = {};
// 8831
f925563445_457.returns.push(o27);
// 8832
// 8834
// 8835
o28 = {};
// 8836
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 8837
// 8839
// 8840
f925563445_457.returns.push(null);
// 8841
// 8843
// 8844
f925563445_457.returns.push(null);
// 8845
// 8846
// 8847
// 8848
// 8849
// 8851
// 8852
// 8855
o27.nodeName = "LABEL";
// 8856
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 8857
// 8858
// 8859
o27 = {};
// 8860
f925563445_577.returns.push(o27);
// 8861
o27.length = 1;
// 8862
o28 = {};
// 8863
o27["0"] = o28;
// undefined
o27 = null;
// 8864
// 8865
// undefined
fo925563445_636___FB_TOKEN = function() { return fo925563445_636___FB_TOKEN.returns[fo925563445_636___FB_TOKEN.inst++]; };
fo925563445_636___FB_TOKEN.returns = [];
fo925563445_636___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_636___FB_TOKEN);
// undefined
fo925563445_636___FB_TOKEN.returns.push(null);
// 8868
o28.getAttribute = f925563445_468;
// 8870
// 8871
f925563445_468.returns.push(null);
// 8872
// 8873
// 8874
// 8875
// 8876
// 8877
// 8878
// 8879
// 8880
o27 = {};
// undefined
fo925563445_636___FB_TOKEN.returns.push(o27);
// 8882
o27["0"] = 12;
// 8883
o28.JSBNG__addEventListener = f925563445_433;
// 8885
// 8886
f925563445_433.returns.push(undefined);
// 8887
// 8888
// undefined
fo925563445_636___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 8891
o28.onclick = null;
// 8892
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 8893
// 8894
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8895
// 8896
// 8897
// 8898
// 8899
// 8900
// 8901
// 8902
// 8903
// 8904
// 8905
// 8906
// 8907
// 8908
// 8909
// 8910
// 8911
// 8912
// 8913
// 8914
// 8916
// 8917
o27 = {};
// 8918
f925563445_457.returns.push(o27);
// 8919
// 8921
// 8922
o28 = {};
// 8923
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 8924
// 8926
// 8927
f925563445_457.returns.push(null);
// 8928
// 8930
// 8931
f925563445_457.returns.push(null);
// 8932
// 8933
// 8934
// 8935
// 8936
// 8938
// 8939
// 8942
o27.nodeName = "LABEL";
// 8943
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 8944
// 8945
// 8946
o27 = {};
// 8947
f925563445_577.returns.push(o27);
// 8948
o27.length = 1;
// 8949
o28 = {};
// 8950
o27["0"] = o28;
// undefined
o27 = null;
// 8951
// 8952
// undefined
fo925563445_641___FB_TOKEN = function() { return fo925563445_641___FB_TOKEN.returns[fo925563445_641___FB_TOKEN.inst++]; };
fo925563445_641___FB_TOKEN.returns = [];
fo925563445_641___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_641___FB_TOKEN);
// undefined
fo925563445_641___FB_TOKEN.returns.push(null);
// 8955
o28.getAttribute = f925563445_468;
// 8957
// 8958
f925563445_468.returns.push(null);
// 8959
// 8960
// 8961
// 8962
// 8963
// 8964
// 8965
// 8966
// 8967
o27 = {};
// undefined
fo925563445_641___FB_TOKEN.returns.push(o27);
// 8969
o27["0"] = 13;
// 8970
o28.JSBNG__addEventListener = f925563445_433;
// 8972
// 8973
f925563445_433.returns.push(undefined);
// 8974
// 8975
// undefined
fo925563445_641___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 8978
o28.onclick = null;
// 8979
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 8980
// 8981
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 8982
// 8983
// 8984
// 8985
// 8986
// 8987
// 8988
// 8989
// 8990
// 8991
// 8992
// 8993
// 8994
// 8995
// 8996
// 8997
// 8998
// 8999
// 9000
// 9001
// 9003
// 9004
o27 = {};
// 9005
f925563445_457.returns.push(o27);
// 9006
// 9008
// 9009
o28 = {};
// 9010
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 9011
// 9013
// 9014
f925563445_457.returns.push(null);
// 9015
// 9017
// 9018
f925563445_457.returns.push(null);
// 9019
// 9020
// 9021
// 9022
// 9023
// 9025
// 9026
// 9029
o27.nodeName = "LABEL";
// 9030
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9031
// 9032
// 9033
o27 = {};
// 9034
f925563445_577.returns.push(o27);
// 9035
o27.length = 1;
// 9036
o28 = {};
// 9037
o27["0"] = o28;
// undefined
o27 = null;
// 9038
// 9039
// undefined
fo925563445_646___FB_TOKEN = function() { return fo925563445_646___FB_TOKEN.returns[fo925563445_646___FB_TOKEN.inst++]; };
fo925563445_646___FB_TOKEN.returns = [];
fo925563445_646___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_646___FB_TOKEN);
// undefined
fo925563445_646___FB_TOKEN.returns.push(null);
// 9042
o28.getAttribute = f925563445_468;
// 9044
// 9045
f925563445_468.returns.push(null);
// 9046
// 9047
// 9048
// 9049
// 9050
// 9051
// 9052
// 9053
// 9054
o27 = {};
// undefined
fo925563445_646___FB_TOKEN.returns.push(o27);
// 9056
o27["0"] = 14;
// 9057
o28.JSBNG__addEventListener = f925563445_433;
// 9059
// 9060
f925563445_433.returns.push(undefined);
// 9061
// 9062
// undefined
fo925563445_646___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9065
o28.onclick = null;
// 9066
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 9067
// 9068
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9069
// 9070
// 9071
// 9072
// 9073
// 9074
// 9075
// 9076
// 9077
// 9078
// 9079
// 9080
// 9081
// 9082
// 9083
// 9084
// 9085
// 9086
// 9087
// 9088
// 9090
// 9091
o27 = {};
// 9092
f925563445_457.returns.push(o27);
// 9093
// 9095
// 9096
o28 = {};
// 9097
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 9098
// 9100
// 9101
f925563445_457.returns.push(null);
// 9102
// 9104
// 9105
f925563445_457.returns.push(null);
// 9106
// 9107
// 9108
// 9109
// 9110
// 9112
// 9113
// 9116
o27.nodeName = "LABEL";
// 9117
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9118
// 9119
// 9120
o27 = {};
// 9121
f925563445_577.returns.push(o27);
// 9122
o27.length = 1;
// 9123
o28 = {};
// 9124
o27["0"] = o28;
// undefined
o27 = null;
// 9125
// 9126
// undefined
fo925563445_651___FB_TOKEN = function() { return fo925563445_651___FB_TOKEN.returns[fo925563445_651___FB_TOKEN.inst++]; };
fo925563445_651___FB_TOKEN.returns = [];
fo925563445_651___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_651___FB_TOKEN);
// undefined
fo925563445_651___FB_TOKEN.returns.push(null);
// 9129
o28.getAttribute = f925563445_468;
// 9131
// 9132
f925563445_468.returns.push(null);
// 9133
// 9134
// 9135
// 9136
// 9137
// 9138
// 9139
// 9140
// 9141
o27 = {};
// undefined
fo925563445_651___FB_TOKEN.returns.push(o27);
// 9143
o27["0"] = 15;
// 9144
o28.JSBNG__addEventListener = f925563445_433;
// 9146
// 9147
f925563445_433.returns.push(undefined);
// 9148
// 9149
// undefined
fo925563445_651___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9152
o28.onclick = null;
// 9153
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 9154
// 9155
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9156
// 9157
// 9158
// 9159
// 9160
// 9161
// 9162
// 9163
// 9164
// 9165
// 9166
// 9167
// 9168
// 9169
// 9170
// 9171
// 9172
// 9173
// 9174
// 9175
// 9177
// 9178
o27 = {};
// 9179
f925563445_457.returns.push(o27);
// 9180
// 9182
// 9183
o28 = {};
// 9184
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 9185
// 9187
// 9188
f925563445_457.returns.push(null);
// 9189
// 9191
// 9192
f925563445_457.returns.push(null);
// 9193
// 9194
// 9195
// 9196
// 9197
// 9199
// 9200
// 9203
o27.nodeName = "LABEL";
// 9204
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9205
// 9206
// 9207
o27 = {};
// 9208
f925563445_577.returns.push(o27);
// 9209
o27.length = 1;
// 9210
o28 = {};
// 9211
o27["0"] = o28;
// undefined
o27 = null;
// 9212
// 9213
// undefined
fo925563445_656___FB_TOKEN = function() { return fo925563445_656___FB_TOKEN.returns[fo925563445_656___FB_TOKEN.inst++]; };
fo925563445_656___FB_TOKEN.returns = [];
fo925563445_656___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_656___FB_TOKEN);
// undefined
fo925563445_656___FB_TOKEN.returns.push(null);
// 9216
o28.getAttribute = f925563445_468;
// 9218
// 9219
f925563445_468.returns.push(null);
// 9220
// 9221
// 9222
// 9223
// 9224
// 9225
// 9226
// 9227
// 9228
o27 = {};
// undefined
fo925563445_656___FB_TOKEN.returns.push(o27);
// 9230
o27["0"] = 16;
// 9231
o28.JSBNG__addEventListener = f925563445_433;
// 9233
// 9234
f925563445_433.returns.push(undefined);
// 9235
// 9236
// undefined
fo925563445_656___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9239
o28.onclick = null;
// 9240
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 9241
// 9242
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9243
// 9244
// 9245
// 9246
// 9247
// 9248
// 9249
// 9250
// 9251
// 9252
// 9253
// 9254
// 9255
// 9256
// 9257
// 9258
// 9259
// 9260
// 9261
// 9262
// 9264
// 9265
o27 = {};
// 9266
f925563445_457.returns.push(o27);
// 9267
// 9269
// 9270
o28 = {};
// 9271
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 9272
// 9274
// 9275
f925563445_457.returns.push(null);
// 9276
// 9278
// 9279
f925563445_457.returns.push(null);
// 9280
// 9281
// 9282
// 9283
// 9284
// 9286
// 9287
// 9290
o27.nodeName = "LABEL";
// 9291
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9292
// 9293
// 9294
o27 = {};
// 9295
f925563445_577.returns.push(o27);
// 9296
o27.length = 1;
// 9297
o28 = {};
// 9298
o27["0"] = o28;
// undefined
o27 = null;
// 9299
// 9300
// undefined
fo925563445_661___FB_TOKEN = function() { return fo925563445_661___FB_TOKEN.returns[fo925563445_661___FB_TOKEN.inst++]; };
fo925563445_661___FB_TOKEN.returns = [];
fo925563445_661___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_661___FB_TOKEN);
// undefined
fo925563445_661___FB_TOKEN.returns.push(null);
// 9303
o28.getAttribute = f925563445_468;
// 9305
// 9306
f925563445_468.returns.push(null);
// 9307
// 9308
// 9309
// 9310
// 9311
// 9312
// 9313
// 9314
// 9315
o27 = {};
// undefined
fo925563445_661___FB_TOKEN.returns.push(o27);
// 9317
o27["0"] = 17;
// 9318
o28.JSBNG__addEventListener = f925563445_433;
// 9320
// 9321
f925563445_433.returns.push(undefined);
// 9322
// 9323
// undefined
fo925563445_661___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9326
o28.onclick = null;
// 9327
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 9328
// 9329
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9330
// 9331
// 9332
// 9333
// 9334
// 9335
// 9336
// 9337
// 9338
// 9339
// 9340
// 9341
// 9342
// 9343
// 9344
// 9345
// 9346
// 9347
// 9348
// 9349
// 9351
// 9352
o27 = {};
// 9353
f925563445_457.returns.push(o27);
// 9354
// 9356
// 9357
o28 = {};
// 9358
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 9359
// 9361
// 9362
f925563445_457.returns.push(null);
// 9363
// 9365
// 9366
f925563445_457.returns.push(null);
// 9367
// 9368
// 9369
// 9370
// 9371
// 9373
// 9374
// 9377
o27.nodeName = "LABEL";
// 9378
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9379
// 9380
// 9381
o27 = {};
// 9382
f925563445_577.returns.push(o27);
// 9383
o27.length = 1;
// 9384
o28 = {};
// 9385
o27["0"] = o28;
// undefined
o27 = null;
// 9386
// 9387
// undefined
fo925563445_666___FB_TOKEN = function() { return fo925563445_666___FB_TOKEN.returns[fo925563445_666___FB_TOKEN.inst++]; };
fo925563445_666___FB_TOKEN.returns = [];
fo925563445_666___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_666___FB_TOKEN);
// undefined
fo925563445_666___FB_TOKEN.returns.push(null);
// 9390
o28.getAttribute = f925563445_468;
// 9392
// 9393
f925563445_468.returns.push(null);
// 9394
// 9395
// 9396
// 9397
// 9398
// 9399
// 9400
// 9401
// 9402
o27 = {};
// undefined
fo925563445_666___FB_TOKEN.returns.push(o27);
// 9404
o27["0"] = 18;
// 9405
o28.JSBNG__addEventListener = f925563445_433;
// 9407
// 9408
f925563445_433.returns.push(undefined);
// 9409
// 9410
// undefined
fo925563445_666___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9413
o28.onclick = null;
// 9414
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 9415
// 9416
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9417
// 9418
// 9419
// 9420
// 9421
// 9422
// 9423
// 9424
// 9425
// 9426
// 9427
// 9428
// 9429
// 9430
// 9431
// 9432
// 9433
// 9434
// 9435
// 9436
// 9438
// 9439
o27 = {};
// 9440
f925563445_457.returns.push(o27);
// 9441
// 9443
// 9444
o28 = {};
// 9445
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 9446
// 9448
// 9449
f925563445_457.returns.push(null);
// 9450
// 9452
// 9453
f925563445_457.returns.push(null);
// 9454
// 9455
// 9456
// 9457
// 9458
// 9460
// 9461
// 9464
o27.nodeName = "LABEL";
// 9465
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9466
// 9467
// 9468
o27 = {};
// 9469
f925563445_577.returns.push(o27);
// 9470
o27.length = 1;
// 9471
o28 = {};
// 9472
o27["0"] = o28;
// undefined
o27 = null;
// 9473
// 9474
// undefined
fo925563445_671___FB_TOKEN = function() { return fo925563445_671___FB_TOKEN.returns[fo925563445_671___FB_TOKEN.inst++]; };
fo925563445_671___FB_TOKEN.returns = [];
fo925563445_671___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_671___FB_TOKEN);
// undefined
fo925563445_671___FB_TOKEN.returns.push(null);
// 9477
o28.getAttribute = f925563445_468;
// 9479
// 9480
f925563445_468.returns.push(null);
// 9481
// 9482
// 9483
// 9484
// 9485
// 9486
// 9487
// 9488
// 9489
o27 = {};
// undefined
fo925563445_671___FB_TOKEN.returns.push(o27);
// 9491
o27["0"] = 19;
// 9492
o28.JSBNG__addEventListener = f925563445_433;
// 9494
// 9495
f925563445_433.returns.push(undefined);
// 9496
// 9497
// undefined
fo925563445_671___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9500
o28.onclick = null;
// 9501
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 9502
// 9503
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9504
// 9505
// 9506
// 9507
// 9508
// 9509
// 9510
// 9511
// 9512
// 9513
// 9514
// 9515
// 9516
// 9517
// 9518
// 9519
// 9520
// 9521
// 9522
// 9523
// 9525
// 9526
o27 = {};
// 9527
f925563445_457.returns.push(o27);
// 9528
// 9530
// 9531
o28 = {};
// 9532
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 9533
// 9535
// 9536
f925563445_457.returns.push(null);
// 9537
// 9539
// 9540
f925563445_457.returns.push(null);
// 9541
// 9542
// 9543
// 9544
// 9545
// 9547
// 9548
// 9551
o27.nodeName = "LABEL";
// 9552
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9553
// 9554
// 9555
o27 = {};
// 9556
f925563445_577.returns.push(o27);
// 9557
o27.length = 1;
// 9558
o28 = {};
// 9559
o27["0"] = o28;
// undefined
o27 = null;
// 9560
// 9561
// undefined
fo925563445_676___FB_TOKEN = function() { return fo925563445_676___FB_TOKEN.returns[fo925563445_676___FB_TOKEN.inst++]; };
fo925563445_676___FB_TOKEN.returns = [];
fo925563445_676___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_676___FB_TOKEN);
// undefined
fo925563445_676___FB_TOKEN.returns.push(null);
// 9564
o28.getAttribute = f925563445_468;
// 9566
// 9567
f925563445_468.returns.push(null);
// 9568
// 9569
// 9570
// 9571
// 9572
// 9573
// 9574
// 9575
// 9576
o27 = {};
// undefined
fo925563445_676___FB_TOKEN.returns.push(o27);
// 9578
o27["0"] = 20;
// 9579
o28.JSBNG__addEventListener = f925563445_433;
// 9581
// 9582
f925563445_433.returns.push(undefined);
// 9583
// 9584
// undefined
fo925563445_676___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9587
o28.onclick = null;
// 9588
o28.nodeName = "INPUT";
// undefined
o28 = null;
// 9589
// 9590
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9591
// 9592
// 9593
// 9594
// 9595
// 9596
// 9597
// 9598
// 9599
// 9600
// 9601
// 9602
// 9603
// 9604
// 9605
// 9606
// 9607
// 9608
// 9609
// 9610
// 9611
// 9612
// 9613
// 9614
// 9615
// 9616
// 9617
// 9618
// 9619
// 9620
// 9621
// 9622
// 9623
// 9624
// 9625
// 9626
// 9627
// 9628
// 9629
// 9630
// 9631
// 9632
// 9633
// 9634
// 9635
// 9636
// 9637
// 9638
// 9639
// 9640
// 9641
// 9642
// 9643
// 9644
// 9645
// 9646
// 9647
// 9648
// 9649
// 9650
// 9651
// 9652
// 9653
// 9654
// 9655
// 9656
// 9657
// 9658
// 9659
// 9660
// 9661
// 9662
// 9663
// 9664
// 9665
// 9666
// 9667
// 9668
// 9669
// 9670
// 9671
// 9672
// 9673
// 9674
// 9675
// 9676
// 9677
// 9678
// 9679
// 9680
// 9681
// 9682
// 9683
// 9684
// 9685
// 9686
// 9687
// 9688
// 9689
// 9690
// 9691
// 9692
// 9693
// 9694
// 9695
// 9696
// 9697
// 9698
// 9699
// 9700
// 9702
// 9703
o27 = {};
// 9704
f925563445_457.returns.push(o27);
// 9705
// 9706
// 9707
// 9708
// 9709
// 9710
// 9711
// 9712
// 9713
// 9714
// 9715
// 9716
// 9717
// 9718
// 9719
// 9720
// 9721
// 9722
// 9723
// 9724
// 9725
// 9726
// 9727
// undefined
fo925563445_678_className = function() { return fo925563445_678_className.returns[fo925563445_678_className.inst++]; };
fo925563445_678_className.returns = [];
fo925563445_678_className.inst = 0;
defineGetter(o27, "className", fo925563445_678_className);
// undefined
fo925563445_678_className.returns.push("sideNavItem stat_elem selectedItem open");
// 9729
// 9730
// 9731
// 9732
// 9733
// 9734
// undefined
fo925563445_678_className.returns.push("sideNavItem stat_elem selectedItem open");
// undefined
fo925563445_678_className.returns.push("sideNavItem stat_elem selectedItem open");
// 9738
// 9739
// 9740
// 9741
// 9742
// 9743
// 9744
// 9745
// 9746
// 9747
// 9748
// 9749
// undefined
fo925563445_678_className.returns.push("sideNavItem stat_elem open");
// undefined
fo925563445_678_className.returns.push("sideNavItem stat_elem open");
// 9753
// 9754
// undefined
fo925563445_678_className.returns.push("sideNavItem stat_elem open selectedItem");
// 9756
// 9757
// 9758
// 9759
// 9760
// 9761
// 9762
// 9763
// 9764
// 9765
// undefined
fo925563445_678_className.returns.push("sideNavItem stat_elem open selectedItem");
// 9767
// 9768
// 9769
// 9770
// 9771
// 9772
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9773
// 9774
// 9775
o27 = {};
// 9776
f925563445_577.returns.push(o27);
// 9777
o27.length = 1;
// 9778
o28 = {};
// 9779
o27["0"] = o28;
// undefined
o27 = null;
// 9780
// 9781
// 9782
o28.className = "item clearfix";
// 9784
// 9785
// 9786
// 9787
// 9788
// 9789
// 9790
// 9793
o28.nodeName = "A";
// 9794
// 9795
// undefined
fo925563445_680___FB_TOKEN = function() { return fo925563445_680___FB_TOKEN.returns[fo925563445_680___FB_TOKEN.inst++]; };
fo925563445_680___FB_TOKEN.returns = [];
fo925563445_680___FB_TOKEN.inst = 0;
defineGetter(o28, "__FB_TOKEN", fo925563445_680___FB_TOKEN);
// undefined
fo925563445_680___FB_TOKEN.returns.push(null);
// 9798
o28.getAttribute = f925563445_468;
// 9800
// 9801
f925563445_468.returns.push(null);
// 9802
// 9803
// 9804
// 9805
// 9806
// 9807
// 9808
// 9809
// 9810
o27 = {};
// undefined
fo925563445_680___FB_TOKEN.returns.push(o27);
// 9812
o27["0"] = 21;
// 9813
o28.JSBNG__addEventListener = f925563445_433;
// 9815
// 9816
f925563445_433.returns.push(undefined);
// 9817
// 9818
// undefined
fo925563445_680___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9821
o28.onclick = null;
// undefined
o28 = null;
// 9823
// 9824
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9825
// 9826
// 9827
// 9828
// 9829
// 9830
// 9831
// 9832
// 9833
// 9834
// 9835
// 9836
// 9837
// 9838
// 9839
// 9840
// 9841
// 9842
// 9843
// 9845
// 9846
o27 = {};
// 9847
f925563445_457.returns.push(o27);
// 9848
// 9849
// 9850
// 9851
// 9852
// 9853
// 9854
// 9855
// 9856
// 9857
// 9858
// 9859
// 9860
// 9861
// 9862
// 9863
// 9864
// 9865
// 9866
// 9867
// 9868
// 9869
// 9870
// 9871
// 9872
// 9873
// 9874
// 9875
// 9876
// 9877
// 9878
o27.className = "sideNavItem stat_elem";
// 9879
// 9880
// 9881
// 9882
// 9883
// 9884
// 9886
// 9887
// 9888
// 9889
// 9890
// 9891
// 9892
// 9893
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 9894
// 9895
// 9896
o27 = {};
// 9897
f925563445_577.returns.push(o27);
// 9898
o27.length = 3;
// 9899
o28 = {};
// 9900
o27["0"] = o28;
// 9901
o29 = {};
// 9902
o27["1"] = o29;
// 9903
o30 = {};
// 9904
o27["2"] = o30;
// undefined
o27 = null;
// 9905
// 9906
// 9907
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 9908
// 9909
// 9910
o29.className = "itemAnchor";
// undefined
o29 = null;
// 9911
// 9912
// 9913
o30.className = "item clearfix";
// 9915
// 9916
// 9917
// 9918
// 9919
// 9920
// 9921
// 9924
o30.nodeName = "A";
// 9925
// 9926
// undefined
fo925563445_686___FB_TOKEN = function() { return fo925563445_686___FB_TOKEN.returns[fo925563445_686___FB_TOKEN.inst++]; };
fo925563445_686___FB_TOKEN.returns = [];
fo925563445_686___FB_TOKEN.inst = 0;
defineGetter(o30, "__FB_TOKEN", fo925563445_686___FB_TOKEN);
// undefined
fo925563445_686___FB_TOKEN.returns.push(null);
// 9929
o30.getAttribute = f925563445_468;
// 9931
// 9932
f925563445_468.returns.push(null);
// 9933
// 9934
// 9935
// 9936
// 9937
// 9938
// 9939
// 9940
// 9941
o27 = {};
// undefined
fo925563445_686___FB_TOKEN.returns.push(o27);
// 9943
o27["0"] = 22;
// 9944
o30.JSBNG__addEventListener = f925563445_433;
// 9946
// 9947
f925563445_433.returns.push(undefined);
// 9948
// 9949
// undefined
fo925563445_686___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 9952
o30.onclick = null;
// undefined
o30 = null;
// 9954
// 9955
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 9956
// 9957
// 9958
// 9959
// 9960
// 9961
// 9962
// 9963
// 9964
// 9965
// 9966
// 9967
// 9968
// 9969
// 9970
// 9971
// 9972
// 9973
// 9974
// 9976
// 9977
o27 = {};
// 9978
f925563445_457.returns.push(o27);
// 9979
// 9980
// 9981
// 9982
// 9983
// 9984
// 9985
// 9986
// 9987
// 9988
// 9989
// 9990
// 9991
// 9992
// 9993
// 9994
// 9995
// 9996
// 9997
// 9998
// 9999
// 10000
// 10001
// 10002
o27.className = "sideNavItem stat_elem";
// 10003
// 10004
// 10005
// 10006
// 10007
// 10008
// 10010
// 10011
// 10012
// 10013
// 10014
// 10015
// 10016
// 10017
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 10018
// 10019
// 10020
o27 = {};
// 10021
f925563445_577.returns.push(o27);
// 10022
o27.length = 5;
// 10023
o28 = {};
// 10024
o27["0"] = o28;
// 10025
o29 = {};
// 10026
o27["1"] = o29;
// 10027
o30 = {};
// 10028
o27["2"] = o30;
// 10029
o31 = {};
// 10030
o27["3"] = o31;
// 10031
o32 = {};
// 10032
o27["4"] = o32;
// undefined
o27 = null;
// 10033
// 10034
// 10035
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 10036
// 10037
// 10038
o29.className = "itemAnchor";
// undefined
o29 = null;
// 10039
// 10040
// 10041
o30.className = "itemAnchor";
// undefined
o30 = null;
// 10042
// 10043
// 10044
o31.className = "item clearfix sortableItem";
// 10045
// 10046
// 10047
o32.className = "subitem clearfix";
// 10049
// 10050
// 10051
// 10052
// 10053
// 10054
// 10055
// 10058
o31.nodeName = "A";
// 10059
// 10060
// undefined
fo925563445_693___FB_TOKEN = function() { return fo925563445_693___FB_TOKEN.returns[fo925563445_693___FB_TOKEN.inst++]; };
fo925563445_693___FB_TOKEN.returns = [];
fo925563445_693___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_693___FB_TOKEN);
// undefined
fo925563445_693___FB_TOKEN.returns.push(null);
// 10063
o31.getAttribute = f925563445_468;
// 10065
// 10066
f925563445_468.returns.push(null);
// 10067
// 10068
// 10069
// 10070
// 10071
// 10072
// 10073
// 10074
// 10075
o27 = {};
// undefined
fo925563445_693___FB_TOKEN.returns.push(o27);
// 10077
o27["0"] = 23;
// 10078
o31.JSBNG__addEventListener = f925563445_433;
// 10080
// 10081
f925563445_433.returns.push(undefined);
// 10082
// 10083
// undefined
fo925563445_693___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 10086
o31.onclick = null;
// undefined
o31 = null;
// 10088
// 10089
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 10090
// 10091
// 10092
// 10093
// 10094
// 10095
// 10096
// 10097
// 10098
// 10099
// 10100
// 10101
// 10102
// 10103
// 10104
// 10105
// 10106
// 10107
// 10108
// 10110
// 10111
o27 = {};
// 10112
f925563445_457.returns.push(o27);
// 10113
// 10114
// 10115
// 10116
// 10117
// 10118
// 10119
// 10120
// 10121
// 10122
// 10123
// 10124
// 10125
// 10126
// 10127
// 10128
// 10129
// 10130
// 10131
// 10132
// 10133
// 10134
// 10135
o27.className = "";
// 10136
// 10137
// 10138
// 10139
// 10140
// 10141
// 10143
// 10144
// 10145
// 10146
// 10147
// 10148
// 10149
// 10150
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 10151
// 10152
// 10153
o27 = {};
// 10154
f925563445_577.returns.push(o27);
// 10155
o27.length = 1;
// 10156
o27["0"] = o32;
// undefined
o27 = null;
// 10157
// 10158
// 10160
// 10161
// 10162
// 10164
// 10165
// 10166
o27 = {};
// 10167
f925563445_577.returns.push(o27);
// 10168
o27.length = 1;
// 10169
o27["0"] = o32;
// undefined
o27 = null;
// 10170
// 10171
// 10174
// 10175
// 10176
// 10177
// 10178
// 10179
// 10180
// 10183
o32.nodeName = "A";
// 10184
// 10185
// undefined
fo925563445_694___FB_TOKEN = function() { return fo925563445_694___FB_TOKEN.returns[fo925563445_694___FB_TOKEN.inst++]; };
fo925563445_694___FB_TOKEN.returns = [];
fo925563445_694___FB_TOKEN.inst = 0;
defineGetter(o32, "__FB_TOKEN", fo925563445_694___FB_TOKEN);
// undefined
fo925563445_694___FB_TOKEN.returns.push(null);
// 10188
o32.getAttribute = f925563445_468;
// 10190
// 10191
f925563445_468.returns.push(null);
// 10192
// 10193
// 10194
// 10195
// 10196
// 10197
// 10198
// 10199
// 10200
o27 = {};
// undefined
fo925563445_694___FB_TOKEN.returns.push(o27);
// 10202
o27["0"] = 24;
// 10203
o32.JSBNG__addEventListener = f925563445_433;
// 10205
// 10206
f925563445_433.returns.push(undefined);
// 10207
// 10208
// undefined
fo925563445_694___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 10211
o32.onclick = null;
// undefined
o32 = null;
// 10213
// 10214
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 10215
// 10216
// 10217
// 10218
// 10219
// 10220
// 10221
// 10222
// 10223
// 10224
// 10225
// 10226
// 10227
// 10228
// 10229
// 10230
// 10231
// 10232
// 10233
// 10235
// 10236
o27 = {};
// 10237
f925563445_457.returns.push(o27);
// 10238
// 10239
// 10240
// 10241
// 10242
// 10243
// 10244
// 10245
// 10246
// 10247
// 10248
// 10249
// 10250
// 10251
// 10252
// 10253
// 10254
// 10255
// 10256
// 10257
// 10258
// 10259
// 10260
// 10261
// 10262
// 10263
// 10264
// 10265
// 10266
o27.className = "sideNavItem stat_elem";
// 10267
// 10268
// 10269
// 10270
// 10271
// 10272
// 10274
// 10275
// 10276
// 10277
// 10278
// 10279
// 10280
// 10281
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 10282
// 10283
// 10284
o27 = {};
// 10285
f925563445_577.returns.push(o27);
// 10286
o27.length = 5;
// 10287
o28 = {};
// 10288
o27["0"] = o28;
// 10289
o29 = {};
// 10290
o27["1"] = o29;
// 10291
o30 = {};
// 10292
o27["2"] = o30;
// 10293
o31 = {};
// 10294
o27["3"] = o31;
// 10295
o32 = {};
// 10296
o27["4"] = o32;
// undefined
o27 = null;
// 10297
// 10298
// 10299
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 10300
// 10301
// 10302
o29.className = "itemAnchor";
// undefined
o29 = null;
// 10303
// 10304
// 10305
o30.className = "itemAnchor";
// undefined
o30 = null;
// 10306
// 10307
// 10308
o31.className = "item clearfix sortableItem";
// 10309
// 10310
// 10311
o32.className = "subitem clearfix";
// 10313
// 10314
// 10315
// 10316
// 10317
// 10318
// 10319
// 10322
o31.nodeName = "A";
// 10323
// 10324
// undefined
fo925563445_705___FB_TOKEN = function() { return fo925563445_705___FB_TOKEN.returns[fo925563445_705___FB_TOKEN.inst++]; };
fo925563445_705___FB_TOKEN.returns = [];
fo925563445_705___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_705___FB_TOKEN);
// undefined
fo925563445_705___FB_TOKEN.returns.push(null);
// 10327
o31.getAttribute = f925563445_468;
// 10329
// 10330
f925563445_468.returns.push(null);
// 10331
// 10332
// 10333
// 10334
// 10335
// 10336
// 10337
// 10338
// 10339
o27 = {};
// undefined
fo925563445_705___FB_TOKEN.returns.push(o27);
// 10341
o27["0"] = 25;
// 10342
o31.JSBNG__addEventListener = f925563445_433;
// 10344
// 10345
f925563445_433.returns.push(undefined);
// 10346
// 10347
// undefined
fo925563445_705___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 10350
o31.onclick = null;
// undefined
o31 = null;
// 10352
// 10353
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 10354
// 10355
// 10356
// 10357
// 10358
// 10359
// 10360
// 10361
// 10362
// 10363
// 10364
// 10365
// 10366
// 10367
// 10368
// 10369
// 10370
// 10371
// 10372
// 10374
// 10375
o27 = {};
// 10376
f925563445_457.returns.push(o27);
// 10377
// 10378
// 10379
// 10380
// 10381
// 10382
// 10383
// 10384
// 10385
// 10386
// 10387
// 10388
// 10389
// 10390
// 10391
// 10392
// 10393
// 10394
// 10395
// 10396
// 10397
// 10398
// 10399
o27.className = "";
// 10400
// 10401
// 10402
// 10403
// 10404
// 10405
// 10407
// 10408
// 10409
// 10410
// 10411
// 10412
// 10413
// 10414
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 10415
// 10416
// 10417
o27 = {};
// 10418
f925563445_577.returns.push(o27);
// 10419
o27.length = 1;
// 10420
o27["0"] = o32;
// undefined
o27 = null;
// 10421
// 10422
// 10424
// 10425
// 10426
// 10428
// 10429
// 10430
o27 = {};
// 10431
f925563445_577.returns.push(o27);
// 10432
o27.length = 1;
// 10433
o27["0"] = o32;
// undefined
o27 = null;
// 10434
// 10435
// 10438
// 10439
// 10440
// 10441
// 10442
// 10443
// 10444
// 10447
o32.nodeName = "A";
// 10448
// 10449
// undefined
fo925563445_706___FB_TOKEN = function() { return fo925563445_706___FB_TOKEN.returns[fo925563445_706___FB_TOKEN.inst++]; };
fo925563445_706___FB_TOKEN.returns = [];
fo925563445_706___FB_TOKEN.inst = 0;
defineGetter(o32, "__FB_TOKEN", fo925563445_706___FB_TOKEN);
// undefined
fo925563445_706___FB_TOKEN.returns.push(null);
// 10452
o32.getAttribute = f925563445_468;
// 10454
// 10455
f925563445_468.returns.push(null);
// 10456
// 10457
// 10458
// 10459
// 10460
// 10461
// 10462
// 10463
// 10464
o27 = {};
// undefined
fo925563445_706___FB_TOKEN.returns.push(o27);
// 10466
o27["0"] = 26;
// 10467
o32.JSBNG__addEventListener = f925563445_433;
// 10469
// 10470
f925563445_433.returns.push(undefined);
// 10471
// 10472
// undefined
fo925563445_706___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 10475
o32.onclick = null;
// undefined
o32 = null;
// 10477
// 10478
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 10479
// 10480
// 10481
// 10482
// 10483
// 10484
// 10485
// 10486
// 10487
// 10488
// 10489
// 10490
// 10491
// 10492
// 10493
// 10494
// 10495
// 10496
// 10497
// 10499
// 10500
o27 = {};
// 10501
f925563445_457.returns.push(o27);
// 10502
// 10503
// 10504
// 10505
// 10506
// 10507
// 10508
// 10509
// 10510
// 10511
// 10512
// 10513
// 10514
// 10515
// 10516
// 10517
// 10518
// 10519
// 10520
// 10521
// 10522
// 10523
// 10524
// 10525
o27.className = "sideNavItem stat_elem";
// 10526
// 10527
// 10528
// 10529
// 10530
// 10531
// 10533
// 10534
// 10535
// 10536
// 10537
// 10538
// 10539
// 10540
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 10541
// 10542
// 10543
o27 = {};
// 10544
f925563445_577.returns.push(o27);
// 10545
o27.length = 4;
// 10546
o28 = {};
// 10547
o27["0"] = o28;
// 10548
o29 = {};
// 10549
o27["1"] = o29;
// 10550
o30 = {};
// 10551
o27["2"] = o30;
// 10552
o31 = {};
// 10553
o27["3"] = o31;
// undefined
o27 = null;
// 10554
// 10555
// 10556
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 10557
// 10558
// 10559
o29.className = "itemAnchor";
// undefined
o29 = null;
// 10560
// 10561
// 10562
o30.className = "itemAnchor";
// undefined
o30 = null;
// 10563
// 10564
// 10565
o31.className = "item clearfix sortableItem";
// 10567
// 10568
// 10569
// 10570
// 10571
// 10572
// 10573
// 10576
o31.nodeName = "A";
// 10577
// 10578
// undefined
fo925563445_717___FB_TOKEN = function() { return fo925563445_717___FB_TOKEN.returns[fo925563445_717___FB_TOKEN.inst++]; };
fo925563445_717___FB_TOKEN.returns = [];
fo925563445_717___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_717___FB_TOKEN);
// undefined
fo925563445_717___FB_TOKEN.returns.push(null);
// 10581
o31.getAttribute = f925563445_468;
// 10583
// 10584
f925563445_468.returns.push(null);
// 10585
// 10586
// 10587
// 10588
// 10589
// 10590
// 10591
// 10592
// 10593
o27 = {};
// undefined
fo925563445_717___FB_TOKEN.returns.push(o27);
// 10595
o27["0"] = 27;
// 10596
o31.JSBNG__addEventListener = f925563445_433;
// 10598
// 10599
f925563445_433.returns.push(undefined);
// 10600
// 10601
// undefined
fo925563445_717___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 10604
o31.onclick = null;
// undefined
o31 = null;
// 10606
// 10607
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 10608
// 10609
// 10610
// 10611
// 10612
// 10613
// 10614
// 10615
// 10616
// 10617
// 10618
// 10619
// 10620
// 10621
// 10622
// 10623
// 10624
// 10625
// 10626
// 10627
// 10628
// 10629
// 10631
// 10632
o27 = {};
// 10633
f925563445_457.returns.push(o27);
// 10635
// 10636
// 10637
// 10638
// 10639
// 10640
// 10641
// 10644
o27.nodeName = "DIV";
// 10645
// 10646
// undefined
fo925563445_719___FB_TOKEN = function() { return fo925563445_719___FB_TOKEN.returns[fo925563445_719___FB_TOKEN.inst++]; };
fo925563445_719___FB_TOKEN.returns = [];
fo925563445_719___FB_TOKEN.inst = 0;
defineGetter(o27, "__FB_TOKEN", fo925563445_719___FB_TOKEN);
// undefined
fo925563445_719___FB_TOKEN.returns.push(null);
// 10649
o27.getAttribute = f925563445_468;
// 10651
// 10652
f925563445_468.returns.push(null);
// 10653
// 10654
// 10655
// 10656
// 10657
// 10658
// 10659
// 10660
// 10661
o28 = {};
// undefined
fo925563445_719___FB_TOKEN.returns.push(o28);
// 10663
o28["0"] = 28;
// 10664
o27.JSBNG__addEventListener = f925563445_433;
// 10666
// 10667
f925563445_433.returns.push(undefined);
// 10668
// 10669
// undefined
fo925563445_719___FB_TOKEN.returns.push(o28);
// undefined
o28 = null;
// 10672
o27.onclick = null;
// 10674
// 10675
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 10676
// 10677
// 10678
// 10679
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 10680
// 10681
// 10682
o27 = {};
// 10683
f925563445_577.returns.push(o27);
// 10684
o27.length = 43;
// 10685
o28 = {};
// 10686
o27["0"] = o28;
// 10687
o29 = {};
// 10688
o27["1"] = o29;
// 10689
o30 = {};
// 10690
o27["2"] = o30;
// 10691
o31 = {};
// 10692
o27["3"] = o31;
// 10693
o32 = {};
// 10694
o27["4"] = o32;
// 10695
o33 = {};
// 10696
o27["5"] = o33;
// 10697
o34 = {};
// 10698
o27["6"] = o34;
// 10699
o35 = {};
// 10700
o27["7"] = o35;
// 10701
o36 = {};
// 10702
o27["8"] = o36;
// 10703
o37 = {};
// 10704
o27["9"] = o37;
// 10705
o38 = {};
// 10706
o27["10"] = o38;
// 10707
o39 = {};
// 10708
o27["11"] = o39;
// 10709
o40 = {};
// 10710
o27["12"] = o40;
// 10711
o41 = {};
// 10712
o27["13"] = o41;
// 10713
o42 = {};
// 10714
o27["14"] = o42;
// 10715
o43 = {};
// 10716
o27["15"] = o43;
// 10717
o44 = {};
// 10718
o27["16"] = o44;
// 10719
o45 = {};
// 10720
o27["17"] = o45;
// 10721
o46 = {};
// 10722
o27["18"] = o46;
// 10723
o47 = {};
// 10724
o27["19"] = o47;
// 10725
o48 = {};
// 10726
o27["20"] = o48;
// 10727
o49 = {};
// 10728
o27["21"] = o49;
// 10729
o50 = {};
// 10730
o27["22"] = o50;
// 10731
o51 = {};
// 10732
o27["23"] = o51;
// 10733
o52 = {};
// 10734
o27["24"] = o52;
// 10735
o53 = {};
// 10736
o27["25"] = o53;
// 10737
o54 = {};
// 10738
o27["26"] = o54;
// 10739
o55 = {};
// 10740
o27["27"] = o55;
// 10741
o56 = {};
// 10742
o27["28"] = o56;
// 10743
o57 = {};
// 10744
o27["29"] = o57;
// 10745
o58 = {};
// 10746
o27["30"] = o58;
// 10747
o59 = {};
// 10748
o27["31"] = o59;
// 10749
o60 = {};
// 10750
o27["32"] = o60;
// 10751
o61 = {};
// 10752
o27["33"] = o61;
// 10753
o62 = {};
// 10754
o27["34"] = o62;
// 10755
o63 = {};
// 10756
o27["35"] = o63;
// 10757
o64 = {};
// 10758
o27["36"] = o64;
// 10759
o65 = {};
// 10760
o27["37"] = o65;
// 10761
o66 = {};
// 10762
o27["38"] = o66;
// 10763
o67 = {};
// 10764
o27["39"] = o67;
// 10765
o68 = {};
// 10766
o27["40"] = o68;
// 10767
o69 = {};
// 10768
o27["41"] = o69;
// 10769
o70 = {};
// 10770
o27["42"] = o70;
// undefined
o27 = null;
// 10771
// 10772
// 10773
o28.className = "navHeader";
// 10774
// 10775
// 10776
o29.className = "mts mbm droppableNav uiSideNavSection uiFutureSideNavSection";
// 10777
// 10778
// 10779
o30.className = "buttonWrap";
// 10780
// 10781
// 10782
o31.className = "rfloat";
// 10783
// 10784
// 10785
o32.className = "";
// 10786
// 10787
// 10788
o33.className = "linkWrap noCount";
// 10789
// 10790
// 10791
o34.className = "buttonWrap";
// 10792
// 10793
// undefined
fo925563445_729_className = function() { return fo925563445_729_className.returns[fo925563445_729_className.inst++]; };
fo925563445_729_className.returns = [];
fo925563445_729_className.inst = 0;
defineGetter(o35, "className", fo925563445_729_className);
// undefined
fo925563445_729_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10795
// 10796
// 10797
o36.className = "wrap";
// 10798
// 10799
// 10800
o37.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 10801
// 10802
// 10803
o38.className = "uiMenu uiSelectorMenu";
// 10804
// 10805
// 10806
o39.className = "rfloat";
// 10807
// 10808
// 10809
o40.className = "";
// 10810
// 10811
// 10812
o41.className = "linkWrap noCount";
// 10813
// 10814
// 10815
o42.className = "buttonWrap";
// 10816
// 10817
// undefined
fo925563445_737_className = function() { return fo925563445_737_className.returns[fo925563445_737_className.inst++]; };
fo925563445_737_className.returns = [];
fo925563445_737_className.inst = 0;
defineGetter(o43, "className", fo925563445_737_className);
// undefined
fo925563445_737_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10819
// 10820
// 10821
o44.className = "wrap";
// 10822
// 10823
// 10824
o45.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 10825
// 10826
// 10827
o46.className = "uiMenu uiSelectorMenu";
// 10828
// 10829
// 10830
o47.className = "rfloat";
// 10831
// 10832
// 10833
o48.className = "";
// 10834
// 10835
// 10836
o49.className = "linkWrap noCount";
// 10837
// 10838
// 10839
o50.className = "rfloat";
// 10840
// 10841
// 10842
o51.className = "";
// 10843
// 10844
// 10845
o52.className = "buttonWrap";
// 10846
// 10847
// undefined
fo925563445_747_className = function() { return fo925563445_747_className.returns[fo925563445_747_className.inst++]; };
fo925563445_747_className.returns = [];
fo925563445_747_className.inst = 0;
defineGetter(o53, "className", fo925563445_747_className);
// undefined
fo925563445_747_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10849
// 10850
// 10851
o54.className = "wrap";
// 10852
// 10853
// 10854
o55.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 10855
// 10856
// 10857
o56.className = "uiMenu uiSelectorMenu";
// 10858
// 10859
// 10860
o57.className = "rfloat";
// 10861
// 10862
// 10863
o58.className = "";
// 10864
// 10865
// 10866
o59.className = "linkWrap noCount";
// 10867
// 10868
// 10869
o60.className = "rfloat";
// 10870
// 10871
// 10872
o61.className = "";
// 10873
// 10874
// 10875
o62.className = "buttonWrap";
// 10876
// 10877
// undefined
fo925563445_757_className = function() { return fo925563445_757_className.returns[fo925563445_757_className.inst++]; };
fo925563445_757_className.returns = [];
fo925563445_757_className.inst = 0;
defineGetter(o63, "className", fo925563445_757_className);
// undefined
fo925563445_757_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10879
// 10880
// 10881
o64.className = "wrap";
// 10882
// 10883
// 10884
o65.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 10885
// 10886
// 10887
o66.className = "uiMenu uiSelectorMenu";
// 10888
// 10889
// 10890
o67.className = "rfloat";
// 10891
// 10892
// 10893
o68.className = "";
// 10894
// 10895
// 10896
o69.className = "linkWrap noCount";
// 10897
// 10898
// 10899
o70.className = "actionLinks stat_elem";
// 10900
// 10901
// 10902
// 10903
// 10904
// 10905
// 10906
// undefined
fo925563445_729_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_729_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10910
// 10911
// 10912
// 10913
// 10914
// undefined
fo925563445_737_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_737_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10918
// 10919
// 10920
// 10921
// 10922
// undefined
fo925563445_747_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_747_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10926
// 10927
// 10928
// 10929
// 10930
// undefined
fo925563445_757_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_757_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 10934
// 10935
// 10936
// 10938
// 10939
// 10940
o27 = {};
// 10941
f925563445_577.returns.push(o27);
// 10942
o27.length = 43;
// 10943
o27["0"] = o28;
// 10944
o27["1"] = o29;
// undefined
o29 = null;
// 10945
o27["2"] = o30;
// undefined
o30 = null;
// 10946
o27["3"] = o31;
// undefined
o31 = null;
// 10947
o27["4"] = o32;
// undefined
o32 = null;
// 10948
o27["5"] = o33;
// undefined
o33 = null;
// 10949
o27["6"] = o34;
// undefined
o34 = null;
// 10950
o27["7"] = o35;
// undefined
o35 = null;
// 10951
o27["8"] = o36;
// undefined
o36 = null;
// 10952
o27["9"] = o37;
// undefined
o37 = null;
// 10953
o27["10"] = o38;
// undefined
o38 = null;
// 10954
o27["11"] = o39;
// undefined
o39 = null;
// 10955
o27["12"] = o40;
// undefined
o40 = null;
// 10956
o27["13"] = o41;
// undefined
o41 = null;
// 10957
o27["14"] = o42;
// undefined
o42 = null;
// 10958
o27["15"] = o43;
// undefined
o43 = null;
// 10959
o27["16"] = o44;
// undefined
o44 = null;
// 10960
o27["17"] = o45;
// undefined
o45 = null;
// 10961
o27["18"] = o46;
// undefined
o46 = null;
// 10962
o27["19"] = o47;
// undefined
o47 = null;
// 10963
o27["20"] = o48;
// undefined
o48 = null;
// 10964
o27["21"] = o49;
// undefined
o49 = null;
// 10965
o27["22"] = o50;
// undefined
o50 = null;
// 10966
o27["23"] = o51;
// undefined
o51 = null;
// 10967
o27["24"] = o52;
// undefined
o52 = null;
// 10968
o27["25"] = o53;
// undefined
o53 = null;
// 10969
o27["26"] = o54;
// undefined
o54 = null;
// 10970
o27["27"] = o55;
// undefined
o55 = null;
// 10971
o27["28"] = o56;
// undefined
o56 = null;
// 10972
o27["29"] = o57;
// undefined
o57 = null;
// 10973
o27["30"] = o58;
// undefined
o58 = null;
// 10974
o27["31"] = o59;
// undefined
o59 = null;
// 10975
o27["32"] = o60;
// undefined
o60 = null;
// 10976
o27["33"] = o61;
// undefined
o61 = null;
// 10977
o27["34"] = o62;
// undefined
o62 = null;
// 10978
o27["35"] = o63;
// undefined
o63 = null;
// 10979
o27["36"] = o64;
// undefined
o64 = null;
// 10980
o27["37"] = o65;
// undefined
o65 = null;
// 10981
o27["38"] = o66;
// undefined
o66 = null;
// 10982
o27["39"] = o67;
// undefined
o67 = null;
// 10983
o27["40"] = o68;
// undefined
o68 = null;
// 10984
o27["41"] = o69;
// undefined
o69 = null;
// 10985
o27["42"] = o70;
// undefined
o27 = null;
// undefined
o70 = null;
// 10986
// 10987
// 10989
// 10990
// 10992
// 10993
// 10995
// 10996
// 10998
// 10999
// 11001
// 11002
// 11004
// 11005
// 11007
// 11008
// undefined
fo925563445_729_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 11010
// 11011
// 11013
// 11014
// 11016
// 11017
// 11019
// 11020
// 11022
// 11023
// 11025
// 11026
// 11028
// 11029
// 11031
// 11032
// undefined
fo925563445_737_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 11034
// 11035
// 11037
// 11038
// 11040
// 11041
// 11043
// 11044
// 11046
// 11047
// 11049
// 11050
// 11052
// 11053
// 11055
// 11056
// 11058
// 11059
// 11061
// 11062
// undefined
fo925563445_747_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 11064
// 11065
// 11067
// 11068
// 11070
// 11071
// 11073
// 11074
// 11076
// 11077
// 11079
// 11080
// 11082
// 11083
// 11085
// 11086
// 11088
// 11089
// 11091
// 11092
// undefined
fo925563445_757_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 11094
// 11095
// 11097
// 11098
// 11100
// 11101
// 11103
// 11104
// 11106
// 11107
// 11109
// 11110
// 11112
// 11113
// 11115
// 11116
// 11117
// 11118
// 11119
// 11120
// 11121
// 11122
// 11123
// 11124
// 11125
// 11126
// 11127
// 11128
// 11129
// 11130
// 11131
// 11132
// 11133
// 11134
// 11135
// 11136
// 11137
// 11138
// 11139
// 11140
// 11141
// 11142
// 11143
// 11144
// 11145
// 11146
// 11148
// 11149
// 11150
// 11151
// 11152
// 11153
// 11155
// 11156
// 11157
// 11158
// 11159
// 11160
// 11161
// 11162
o28.getElementsByTagName = f925563445_577;
// undefined
o28 = null;
// 11163
// 11164
// 11165
o27 = {};
// 11166
f925563445_577.returns.push(o27);
// 11167
o27.length = 0;
// undefined
o27 = null;
// 11168
// 11169
// 11170
// 11172
// 11173
// 11174
o27 = {};
// 11175
f925563445_577.returns.push(o27);
// 11176
o27.length = 0;
// undefined
o27 = null;
// 11177
// 11178
// 11179
// 11180
// 11181
// 11182
// 11183
// 11184
// 11185
// 11186
// 11187
// 11188
// 11189
// 11190
// 11191
// 11192
// 11193
// 11194
// 11195
// 11196
// 11197
// 11198
// 11199
// 11200
// 11201
// 11202
// 11203
// 11204
// 11205
// 11206
// 11207
// 11208
// 11209
// 11210
// 11211
// 11212
// 11213
// 11214
// 11215
// 11216
// 11217
// 11218
// 11219
// 11220
// 11221
// 11222
// 11223
// 11224
// 11225
// 11226
// 11227
// 11228
// 11229
// 11230
// 11231
// 11232
// 11233
// 11234
// 11235
// 11236
// 11237
// 11238
// 11239
// 11240
// 11242
// 11243
o27 = {};
// 11244
f925563445_457.returns.push(o27);
// 11245
// 11246
// 11247
// 11248
// 11249
// 11250
// 11251
// 11252
// 11253
// 11254
// 11255
// 11256
// 11257
// 11258
// 11259
// 11260
// 11261
// 11262
// 11263
// 11264
// 11265
// 11266
// 11267
// 11268
o27.className = "sideNavItem stat_elem";
// 11269
// 11270
// 11271
// 11272
// 11273
// 11274
// 11276
// 11277
// 11278
// 11279
// 11280
// 11281
// 11282
// 11283
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 11284
// 11285
// 11286
o27 = {};
// 11287
f925563445_577.returns.push(o27);
// 11288
o27.length = 4;
// 11289
o28 = {};
// 11290
o27["0"] = o28;
// 11291
o29 = {};
// 11292
o27["1"] = o29;
// 11293
o30 = {};
// 11294
o27["2"] = o30;
// 11295
o31 = {};
// 11296
o27["3"] = o31;
// undefined
o27 = null;
// 11297
// 11298
// 11299
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 11300
// 11301
// 11302
o29.className = "itemAnchor";
// undefined
o29 = null;
// 11303
// 11304
// 11305
o30.className = "itemAnchor";
// undefined
o30 = null;
// 11306
// 11307
// 11308
o31.className = "item clearfix sortableItem";
// 11310
// 11311
// 11312
// 11313
// 11314
// 11315
// 11316
// 11319
o31.nodeName = "A";
// 11320
// 11321
// undefined
fo925563445_773___FB_TOKEN = function() { return fo925563445_773___FB_TOKEN.returns[fo925563445_773___FB_TOKEN.inst++]; };
fo925563445_773___FB_TOKEN.returns = [];
fo925563445_773___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_773___FB_TOKEN);
// undefined
fo925563445_773___FB_TOKEN.returns.push(null);
// 11324
o31.getAttribute = f925563445_468;
// 11326
// 11327
f925563445_468.returns.push(null);
// 11328
// 11329
// 11330
// 11331
// 11332
// 11333
// 11334
// 11335
// 11336
o27 = {};
// undefined
fo925563445_773___FB_TOKEN.returns.push(o27);
// 11338
o27["0"] = 29;
// 11339
o31.JSBNG__addEventListener = f925563445_433;
// 11341
// 11342
f925563445_433.returns.push(undefined);
// 11343
// 11344
// undefined
fo925563445_773___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 11347
o31.onclick = null;
// undefined
o31 = null;
// 11349
// 11350
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 11351
// 11352
// 11353
// 11354
// 11355
// 11356
// 11357
// 11358
// 11359
// 11360
// 11361
// 11362
// 11363
// 11364
// 11365
// 11366
// 11367
// 11368
// 11369
// 11371
// 11372
o27 = {};
// 11373
f925563445_457.returns.push(o27);
// 11374
// 11375
// 11376
// 11377
// 11378
// 11379
// 11380
// 11381
// 11382
// 11383
// 11384
// 11385
// 11386
// 11387
// 11388
// 11389
// 11390
// 11391
// 11392
// 11393
// 11394
// 11395
// 11396
// 11397
o27.className = "sideNavItem stat_elem";
// 11398
// 11399
// 11400
// 11401
// 11402
// 11403
// 11405
// 11406
// 11407
// 11408
// 11409
// 11410
// 11411
// 11412
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 11413
// 11414
// 11415
o27 = {};
// 11416
f925563445_577.returns.push(o27);
// 11417
o27.length = 4;
// 11418
o28 = {};
// 11419
o27["0"] = o28;
// 11420
o29 = {};
// 11421
o27["1"] = o29;
// 11422
o30 = {};
// 11423
o27["2"] = o30;
// 11424
o31 = {};
// 11425
o27["3"] = o31;
// undefined
o27 = null;
// 11426
// 11427
// 11428
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 11429
// 11430
// 11431
o29.className = "itemAnchor";
// undefined
o29 = null;
// 11432
// 11433
// 11434
o30.className = "itemAnchor";
// undefined
o30 = null;
// 11435
// 11436
// 11437
o31.className = "item clearfix sortableItem";
// 11439
// 11440
// 11441
// 11442
// 11443
// 11444
// 11445
// 11448
o31.nodeName = "A";
// 11449
// 11450
// undefined
fo925563445_780___FB_TOKEN = function() { return fo925563445_780___FB_TOKEN.returns[fo925563445_780___FB_TOKEN.inst++]; };
fo925563445_780___FB_TOKEN.returns = [];
fo925563445_780___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_780___FB_TOKEN);
// undefined
fo925563445_780___FB_TOKEN.returns.push(null);
// 11453
o31.getAttribute = f925563445_468;
// 11455
// 11456
f925563445_468.returns.push(null);
// 11457
// 11458
// 11459
// 11460
// 11461
// 11462
// 11463
// 11464
// 11465
o27 = {};
// undefined
fo925563445_780___FB_TOKEN.returns.push(o27);
// 11467
o27["0"] = 30;
// 11468
o31.JSBNG__addEventListener = f925563445_433;
// 11470
// 11471
f925563445_433.returns.push(undefined);
// 11472
// 11473
// undefined
fo925563445_780___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 11476
o31.onclick = null;
// undefined
o31 = null;
// 11478
// 11479
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 11480
// 11481
// 11482
// 11483
// 11484
// 11485
// 11486
// 11487
// 11488
// 11489
// 11490
// 11491
// 11492
// 11493
// 11494
// 11495
// 11496
// 11497
// 11498
// 11500
// 11501
o27 = {};
// 11502
f925563445_457.returns.push(o27);
// 11503
// 11504
// 11505
// 11506
// 11507
// 11508
// 11509
// 11510
// 11511
// 11512
// 11513
// 11514
// 11515
// 11516
// 11517
// 11518
// 11519
// 11520
// 11521
// 11522
// 11523
// 11524
// 11525
// 11526
o27.className = "sideNavItem stat_elem";
// 11527
// 11528
// 11529
// 11530
// 11531
// 11532
// 11534
// 11535
// 11536
// 11537
// 11538
// 11539
// 11540
// 11541
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 11542
// 11543
// 11544
o27 = {};
// 11545
f925563445_577.returns.push(o27);
// 11546
o27.length = 8;
// 11547
o28 = {};
// 11548
o27["0"] = o28;
// 11549
o29 = {};
// 11550
o27["1"] = o29;
// 11551
o30 = {};
// 11552
o27["2"] = o30;
// 11553
o31 = {};
// 11554
o27["3"] = o31;
// 11555
o32 = {};
// 11556
o27["4"] = o32;
// 11557
o33 = {};
// 11558
o27["5"] = o33;
// 11559
o34 = {};
// 11560
o27["6"] = o34;
// 11561
o35 = {};
// 11562
o27["7"] = o35;
// undefined
o27 = null;
// 11563
// 11564
// 11565
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 11566
// 11567
// 11568
o29.className = "itemAnchor";
// undefined
o29 = null;
// 11569
// 11570
// 11571
o30.className = "itemAnchor";
// undefined
o30 = null;
// 11572
// 11573
// 11574
o31.className = "item clearfix sortableItem";
// 11575
// 11576
// 11577
o32.className = "subitem clearfix";
// 11578
// 11579
// 11580
o33.className = "subitem clearfix";
// 11581
// 11582
// 11583
o34.className = "subitem clearfix";
// 11584
// 11585
// 11586
o35.className = "subitem clearfix";
// 11588
// 11589
// 11590
// 11591
// 11592
// 11593
// 11594
// 11597
o31.nodeName = "A";
// 11598
// 11599
// undefined
fo925563445_787___FB_TOKEN = function() { return fo925563445_787___FB_TOKEN.returns[fo925563445_787___FB_TOKEN.inst++]; };
fo925563445_787___FB_TOKEN.returns = [];
fo925563445_787___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_787___FB_TOKEN);
// undefined
fo925563445_787___FB_TOKEN.returns.push(null);
// 11602
o31.getAttribute = f925563445_468;
// 11604
// 11605
f925563445_468.returns.push(null);
// 11606
// 11607
// 11608
// 11609
// 11610
// 11611
// 11612
// 11613
// 11614
o27 = {};
// undefined
fo925563445_787___FB_TOKEN.returns.push(o27);
// 11616
o27["0"] = 31;
// 11617
o31.JSBNG__addEventListener = f925563445_433;
// 11619
// 11620
f925563445_433.returns.push(undefined);
// 11621
// 11622
// undefined
fo925563445_787___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 11625
o31.onclick = null;
// undefined
o31 = null;
// 11627
// 11628
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 11629
// 11630
// 11631
// 11632
// 11633
// 11634
// 11635
// 11636
// 11637
// 11638
// 11639
// 11640
// 11641
// 11642
// 11643
// 11644
// 11645
// 11646
// 11647
// 11649
// 11650
o27 = {};
// 11651
f925563445_457.returns.push(o27);
// 11652
// 11653
// 11654
// 11655
// 11656
// 11657
// 11658
// 11659
// 11660
// 11661
// 11662
// 11663
// 11664
// 11665
// 11666
// 11667
// 11668
// 11669
// 11670
// 11671
// 11672
// 11673
// 11674
o27.className = "";
// 11675
// 11676
// 11677
// 11678
// 11679
// 11680
// 11682
// 11683
// 11684
// 11685
// 11686
// 11687
// 11688
// 11689
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 11690
// 11691
// 11692
o27 = {};
// 11693
f925563445_577.returns.push(o27);
// 11694
o27.length = 1;
// 11695
o27["0"] = o32;
// undefined
o27 = null;
// 11696
// 11697
// 11699
// 11700
// 11701
// 11703
// 11704
// 11705
o27 = {};
// 11706
f925563445_577.returns.push(o27);
// 11707
o27.length = 1;
// 11708
o27["0"] = o32;
// undefined
o27 = null;
// 11709
// 11710
// 11713
// 11714
// 11715
// 11716
// 11717
// 11718
// 11719
// 11722
o32.nodeName = "A";
// 11723
// 11724
// undefined
fo925563445_788___FB_TOKEN = function() { return fo925563445_788___FB_TOKEN.returns[fo925563445_788___FB_TOKEN.inst++]; };
fo925563445_788___FB_TOKEN.returns = [];
fo925563445_788___FB_TOKEN.inst = 0;
defineGetter(o32, "__FB_TOKEN", fo925563445_788___FB_TOKEN);
// undefined
fo925563445_788___FB_TOKEN.returns.push(null);
// 11727
o32.getAttribute = f925563445_468;
// 11729
// 11730
f925563445_468.returns.push(null);
// 11731
// 11732
// 11733
// 11734
// 11735
// 11736
// 11737
// 11738
// 11739
o27 = {};
// undefined
fo925563445_788___FB_TOKEN.returns.push(o27);
// 11741
o27["0"] = 32;
// 11742
o32.JSBNG__addEventListener = f925563445_433;
// 11744
// 11745
f925563445_433.returns.push(undefined);
// 11746
// 11747
// undefined
fo925563445_788___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 11750
o32.onclick = null;
// undefined
o32 = null;
// 11752
// 11753
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 11754
// 11755
// 11756
// 11757
// 11758
// 11759
// 11760
// 11761
// 11762
// 11763
// 11764
// 11765
// 11766
// 11767
// 11768
// 11769
// 11770
// 11771
// 11772
// 11774
// 11775
o27 = {};
// 11776
f925563445_457.returns.push(o27);
// 11777
// 11778
// 11779
// 11780
// 11781
// 11782
// 11783
// 11784
// 11785
// 11786
// 11787
// 11788
// 11789
// 11790
// 11791
// 11792
// 11793
// 11794
// 11795
// 11796
// 11797
// 11798
// 11799
o27.className = "";
// 11800
// 11801
// 11802
// 11803
// 11804
// 11805
// 11807
// 11808
// 11809
// 11810
// 11811
// 11812
// 11813
// 11814
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 11815
// 11816
// 11817
o27 = {};
// 11818
f925563445_577.returns.push(o27);
// 11819
o27.length = 1;
// 11820
o27["0"] = o33;
// undefined
o27 = null;
// 11821
// 11822
// 11824
// 11825
// 11826
// 11828
// 11829
// 11830
o27 = {};
// 11831
f925563445_577.returns.push(o27);
// 11832
o27.length = 1;
// 11833
o27["0"] = o33;
// undefined
o27 = null;
// 11834
// 11835
// 11838
// 11839
// 11840
// 11841
// 11842
// 11843
// 11844
// 11847
o33.nodeName = "A";
// 11848
// 11849
// undefined
fo925563445_789___FB_TOKEN = function() { return fo925563445_789___FB_TOKEN.returns[fo925563445_789___FB_TOKEN.inst++]; };
fo925563445_789___FB_TOKEN.returns = [];
fo925563445_789___FB_TOKEN.inst = 0;
defineGetter(o33, "__FB_TOKEN", fo925563445_789___FB_TOKEN);
// undefined
fo925563445_789___FB_TOKEN.returns.push(null);
// 11852
o33.getAttribute = f925563445_468;
// 11854
// 11855
f925563445_468.returns.push(null);
// 11856
// 11857
// 11858
// 11859
// 11860
// 11861
// 11862
// 11863
// 11864
o27 = {};
// undefined
fo925563445_789___FB_TOKEN.returns.push(o27);
// 11866
o27["0"] = 33;
// 11867
o33.JSBNG__addEventListener = f925563445_433;
// 11869
// 11870
f925563445_433.returns.push(undefined);
// 11871
// 11872
// undefined
fo925563445_789___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 11875
o33.onclick = null;
// undefined
o33 = null;
// 11877
// 11878
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 11879
// 11880
// 11881
// 11882
// 11883
// 11884
// 11885
// 11886
// 11887
// 11888
// 11889
// 11890
// 11891
// 11892
// 11893
// 11894
// 11895
// 11896
// 11897
// 11899
// 11900
o27 = {};
// 11901
f925563445_457.returns.push(o27);
// 11902
// 11903
// 11904
// 11905
// 11906
// 11907
// 11908
// 11909
// 11910
// 11911
// 11912
// 11913
// 11914
// 11915
// 11916
// 11917
// 11918
// 11919
// 11920
// 11921
// 11922
// 11923
// 11924
o27.className = "";
// 11925
// 11926
// 11927
// 11928
// 11929
// 11930
// 11932
// 11933
// 11934
// 11935
// 11936
// 11937
// 11938
// 11939
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 11940
// 11941
// 11942
o27 = {};
// 11943
f925563445_577.returns.push(o27);
// 11944
o27.length = 1;
// 11945
o27["0"] = o34;
// undefined
o27 = null;
// 11946
// 11947
// 11949
// 11950
// 11951
// 11953
// 11954
// 11955
o27 = {};
// 11956
f925563445_577.returns.push(o27);
// 11957
o27.length = 1;
// 11958
o27["0"] = o34;
// undefined
o27 = null;
// 11959
// 11960
// 11963
// 11964
// 11965
// 11966
// 11967
// 11968
// 11969
// 11972
o34.nodeName = "A";
// 11973
// 11974
// undefined
fo925563445_790___FB_TOKEN = function() { return fo925563445_790___FB_TOKEN.returns[fo925563445_790___FB_TOKEN.inst++]; };
fo925563445_790___FB_TOKEN.returns = [];
fo925563445_790___FB_TOKEN.inst = 0;
defineGetter(o34, "__FB_TOKEN", fo925563445_790___FB_TOKEN);
// undefined
fo925563445_790___FB_TOKEN.returns.push(null);
// 11977
o34.getAttribute = f925563445_468;
// 11979
// 11980
f925563445_468.returns.push(null);
// 11981
// 11982
// 11983
// 11984
// 11985
// 11986
// 11987
// 11988
// 11989
o27 = {};
// undefined
fo925563445_790___FB_TOKEN.returns.push(o27);
// 11991
o27["0"] = 34;
// 11992
o34.JSBNG__addEventListener = f925563445_433;
// 11994
// 11995
f925563445_433.returns.push(undefined);
// 11996
// 11997
// undefined
fo925563445_790___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 12000
o34.onclick = null;
// undefined
o34 = null;
// 12002
// 12003
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 12004
// 12005
// 12006
// 12007
// 12008
// 12009
// 12010
// 12011
// 12012
// 12013
// 12014
// 12015
// 12016
// 12017
// 12018
// 12019
// 12020
// 12021
// 12022
// 12024
// 12025
o27 = {};
// 12026
f925563445_457.returns.push(o27);
// 12027
// 12028
// 12029
// 12030
// 12031
// 12032
// 12033
// 12034
// 12035
// 12036
// 12037
// 12038
// 12039
// 12040
// 12041
// 12042
// 12043
// 12044
// 12045
// 12046
// 12047
// 12048
// 12049
o27.className = "";
// 12050
// 12051
// 12052
// 12053
// 12054
// 12055
// 12057
// 12058
// 12059
// 12060
// 12061
// 12062
// 12063
// 12064
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 12065
// 12066
// 12067
o27 = {};
// 12068
f925563445_577.returns.push(o27);
// 12069
o27.length = 1;
// 12070
o27["0"] = o35;
// undefined
o27 = null;
// 12071
// 12072
// 12074
// 12075
// 12076
// 12078
// 12079
// 12080
o27 = {};
// 12081
f925563445_577.returns.push(o27);
// 12082
o27.length = 1;
// 12083
o27["0"] = o35;
// undefined
o27 = null;
// 12084
// 12085
// 12088
// 12089
// 12090
// 12091
// 12092
// 12093
// 12094
// 12097
o35.nodeName = "A";
// 12098
// 12099
// undefined
fo925563445_791___FB_TOKEN = function() { return fo925563445_791___FB_TOKEN.returns[fo925563445_791___FB_TOKEN.inst++]; };
fo925563445_791___FB_TOKEN.returns = [];
fo925563445_791___FB_TOKEN.inst = 0;
defineGetter(o35, "__FB_TOKEN", fo925563445_791___FB_TOKEN);
// undefined
fo925563445_791___FB_TOKEN.returns.push(null);
// 12102
o35.getAttribute = f925563445_468;
// 12104
// 12105
f925563445_468.returns.push(null);
// 12106
// 12107
// 12108
// 12109
// 12110
// 12111
// 12112
// 12113
// 12114
o27 = {};
// undefined
fo925563445_791___FB_TOKEN.returns.push(o27);
// 12116
o27["0"] = 35;
// 12117
o35.JSBNG__addEventListener = f925563445_433;
// 12119
// 12120
f925563445_433.returns.push(undefined);
// 12121
// 12122
// undefined
fo925563445_791___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 12125
o35.onclick = null;
// undefined
o35 = null;
// 12127
// 12128
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 12129
// 12130
// 12131
// 12132
// 12133
// 12134
// 12135
// 12136
// 12137
// 12138
// 12139
// 12140
// 12141
// 12142
// 12143
// 12144
// 12145
// 12146
// 12147
// 12149
// 12150
o27 = {};
// 12151
f925563445_457.returns.push(o27);
// 12152
// 12153
// 12154
// 12155
// 12156
// 12157
// 12158
// 12159
// 12160
// 12161
// 12162
// 12163
// 12164
// 12165
// 12166
// 12167
// 12168
// 12169
// 12170
// 12171
// 12172
// 12173
// 12174
// 12175
// 12176
// 12177
o27.className = "sideNavItem stat_elem";
// 12178
// 12179
// 12180
// 12181
// 12182
// 12183
// 12185
// 12186
// 12187
// 12188
// 12189
// 12190
// 12191
// 12192
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 12193
// 12194
// 12195
o27 = {};
// 12196
f925563445_577.returns.push(o27);
// 12197
o27.length = 4;
// 12198
o28 = {};
// 12199
o27["0"] = o28;
// 12200
o29 = {};
// 12201
o27["1"] = o29;
// 12202
o30 = {};
// 12203
o27["2"] = o30;
// 12204
o31 = {};
// 12205
o27["3"] = o31;
// undefined
o27 = null;
// 12206
// 12207
// 12208
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 12209
// 12210
// 12211
o29.className = "itemAnchor";
// undefined
o29 = null;
// 12212
// 12213
// 12214
o30.className = "itemAnchor";
// undefined
o30 = null;
// 12215
// 12216
// 12217
o31.className = "item clearfix sortableItem";
// 12219
// 12220
// 12221
// 12222
// 12223
// 12224
// 12225
// 12228
o31.nodeName = "A";
// 12229
// 12230
// undefined
fo925563445_814___FB_TOKEN = function() { return fo925563445_814___FB_TOKEN.returns[fo925563445_814___FB_TOKEN.inst++]; };
fo925563445_814___FB_TOKEN.returns = [];
fo925563445_814___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_814___FB_TOKEN);
// undefined
fo925563445_814___FB_TOKEN.returns.push(null);
// 12233
o31.getAttribute = f925563445_468;
// 12235
// 12236
f925563445_468.returns.push(null);
// 12237
// 12238
// 12239
// 12240
// 12241
// 12242
// 12243
// 12244
// 12245
o27 = {};
// undefined
fo925563445_814___FB_TOKEN.returns.push(o27);
// 12247
o27["0"] = 36;
// 12248
o31.JSBNG__addEventListener = f925563445_433;
// 12250
// 12251
f925563445_433.returns.push(undefined);
// 12252
// 12253
// undefined
fo925563445_814___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 12256
o31.onclick = null;
// undefined
o31 = null;
// 12258
// 12259
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 12260
// 12261
// 12262
// 12263
// 12264
// 12265
// 12266
// 12267
// 12268
// 12269
// 12270
// 12271
// 12272
// 12273
// 12274
// 12275
// 12276
// 12277
// 12278
// 12280
// 12281
o27 = {};
// 12282
f925563445_457.returns.push(o27);
// 12283
// 12284
// 12285
// 12286
// 12287
// 12288
// 12289
// 12290
// 12291
// 12292
// 12293
// 12294
// 12295
// 12296
// 12297
// 12298
// 12299
// 12300
// 12301
// 12302
// 12303
// 12304
// 12305
o27.className = "sideNavItem stat_elem";
// 12306
// 12307
// 12308
// 12309
// 12310
// 12311
// 12313
// 12314
// 12315
// 12316
// 12317
// 12318
// 12319
// 12320
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 12321
// 12322
// 12323
o27 = {};
// 12324
f925563445_577.returns.push(o27);
// 12325
o27.length = 4;
// 12326
o28 = {};
// 12327
o27["0"] = o28;
// 12328
o29 = {};
// 12329
o27["1"] = o29;
// 12330
o30 = {};
// 12331
o27["2"] = o30;
// 12332
o31 = {};
// 12333
o27["3"] = o31;
// undefined
o27 = null;
// 12334
// 12335
// 12336
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 12337
// 12338
// 12339
o29.className = "itemAnchor";
// undefined
o29 = null;
// 12340
// 12341
// 12342
o30.className = "itemAnchor";
// undefined
o30 = null;
// 12343
// 12344
// 12345
o31.className = "item clearfix sortableItem";
// 12347
// 12348
// 12349
// 12350
// 12351
// 12352
// 12353
// 12356
o31.nodeName = "A";
// 12357
// 12358
// undefined
fo925563445_821___FB_TOKEN = function() { return fo925563445_821___FB_TOKEN.returns[fo925563445_821___FB_TOKEN.inst++]; };
fo925563445_821___FB_TOKEN.returns = [];
fo925563445_821___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_821___FB_TOKEN);
// undefined
fo925563445_821___FB_TOKEN.returns.push(null);
// 12361
o31.getAttribute = f925563445_468;
// 12363
// 12364
f925563445_468.returns.push(null);
// 12365
// 12366
// 12367
// 12368
// 12369
// 12370
// 12371
// 12372
// 12373
o27 = {};
// undefined
fo925563445_821___FB_TOKEN.returns.push(o27);
// 12375
o27["0"] = 37;
// 12376
o31.JSBNG__addEventListener = f925563445_433;
// 12378
// 12379
f925563445_433.returns.push(undefined);
// 12380
// 12381
// undefined
fo925563445_821___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 12384
o31.onclick = null;
// undefined
o31 = null;
// 12386
// 12387
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 12388
// 12389
// 12390
// 12391
// 12392
// 12393
// 12394
// 12395
// 12396
// 12397
// 12398
// 12399
// 12400
// 12401
// 12402
// 12403
// 12405
// 12406
o27 = {};
// 12407
f925563445_457.returns.push(o27);
// 12409
// 12410
// 12411
// 12412
// 12413
// 12414
// 12415
// 12418
o27.nodeName = "DIV";
// 12419
// 12420
// undefined
fo925563445_823___FB_TOKEN = function() { return fo925563445_823___FB_TOKEN.returns[fo925563445_823___FB_TOKEN.inst++]; };
fo925563445_823___FB_TOKEN.returns = [];
fo925563445_823___FB_TOKEN.inst = 0;
defineGetter(o27, "__FB_TOKEN", fo925563445_823___FB_TOKEN);
// undefined
fo925563445_823___FB_TOKEN.returns.push(null);
// 12423
o27.getAttribute = f925563445_468;
// 12425
// 12426
f925563445_468.returns.push(null);
// 12427
// 12428
// 12429
// 12430
// 12431
// 12432
// 12433
// 12434
// 12435
o28 = {};
// undefined
fo925563445_823___FB_TOKEN.returns.push(o28);
// 12437
o28["0"] = 38;
// 12438
o27.JSBNG__addEventListener = f925563445_433;
// 12440
// 12441
f925563445_433.returns.push(undefined);
// 12442
// 12443
// undefined
fo925563445_823___FB_TOKEN.returns.push(o28);
// undefined
o28 = null;
// 12446
o27.onclick = null;
// 12448
// 12449
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 12450
// 12451
// 12452
// 12453
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 12454
// 12455
// 12456
o27 = {};
// 12457
f925563445_577.returns.push(o27);
// 12458
o27.length = 52;
// 12459
o28 = {};
// 12460
o27["0"] = o28;
// 12461
o29 = {};
// 12462
o27["1"] = o29;
// 12463
o30 = {};
// 12464
o27["2"] = o30;
// 12465
o31 = {};
// 12466
o27["3"] = o31;
// 12467
o32 = {};
// 12468
o27["4"] = o32;
// 12469
o33 = {};
// 12470
o27["5"] = o33;
// 12471
o34 = {};
// 12472
o27["6"] = o34;
// 12473
o35 = {};
// 12474
o27["7"] = o35;
// 12475
o36 = {};
// 12476
o27["8"] = o36;
// 12477
o37 = {};
// 12478
o27["9"] = o37;
// 12479
o38 = {};
// 12480
o27["10"] = o38;
// 12481
o39 = {};
// 12482
o27["11"] = o39;
// 12483
o40 = {};
// 12484
o27["12"] = o40;
// 12485
o41 = {};
// 12486
o27["13"] = o41;
// 12487
o42 = {};
// 12488
o27["14"] = o42;
// 12489
o43 = {};
// 12490
o27["15"] = o43;
// 12491
o44 = {};
// 12492
o27["16"] = o44;
// 12493
o45 = {};
// 12494
o27["17"] = o45;
// 12495
o46 = {};
// 12496
o27["18"] = o46;
// 12497
o47 = {};
// 12498
o27["19"] = o47;
// 12499
o48 = {};
// 12500
o27["20"] = o48;
// 12501
o49 = {};
// 12502
o27["21"] = o49;
// 12503
o50 = {};
// 12504
o27["22"] = o50;
// 12505
o51 = {};
// 12506
o27["23"] = o51;
// 12507
o52 = {};
// 12508
o27["24"] = o52;
// 12509
o53 = {};
// 12510
o27["25"] = o53;
// 12511
o54 = {};
// 12512
o27["26"] = o54;
// 12513
o55 = {};
// 12514
o27["27"] = o55;
// 12515
o56 = {};
// 12516
o27["28"] = o56;
// 12517
o57 = {};
// 12518
o27["29"] = o57;
// 12519
o58 = {};
// 12520
o27["30"] = o58;
// 12521
o59 = {};
// 12522
o27["31"] = o59;
// 12523
o60 = {};
// 12524
o27["32"] = o60;
// 12525
o61 = {};
// 12526
o27["33"] = o61;
// 12527
o62 = {};
// 12528
o27["34"] = o62;
// 12529
o63 = {};
// 12530
o27["35"] = o63;
// 12531
o64 = {};
// 12532
o27["36"] = o64;
// 12533
o65 = {};
// 12534
o27["37"] = o65;
// 12535
o66 = {};
// 12536
o27["38"] = o66;
// 12537
o67 = {};
// 12538
o27["39"] = o67;
// 12539
o68 = {};
// 12540
o27["40"] = o68;
// 12541
o69 = {};
// 12542
o27["41"] = o69;
// 12543
o70 = {};
// 12544
o27["42"] = o70;
// 12545
o71 = {};
// 12546
o27["43"] = o71;
// 12547
o72 = {};
// 12548
o27["44"] = o72;
// 12549
o73 = {};
// 12550
o27["45"] = o73;
// 12551
o74 = {};
// 12552
o27["46"] = o74;
// 12553
o75 = {};
// 12554
o27["47"] = o75;
// 12555
o76 = {};
// 12556
o27["48"] = o76;
// 12557
o77 = {};
// 12558
o27["49"] = o77;
// 12559
o78 = {};
// 12560
o27["50"] = o78;
// 12561
o79 = {};
// 12562
o27["51"] = o79;
// undefined
o27 = null;
// 12563
// 12564
// 12565
o28.className = "navHeader";
// 12566
// 12567
// 12568
o29.className = "clearfix";
// 12569
// 12570
// 12571
o30.className = "lfloat";
// 12572
// 12573
// 12574
o31.className = "bookmarksNavSeeAll";
// 12575
// 12576
// 12577
o32.className = "buttonWrap";
// 12578
// 12579
// undefined
fo925563445_831_className = function() { return fo925563445_831_className.returns[fo925563445_831_className.inst++]; };
fo925563445_831_className.returns = [];
fo925563445_831_className.inst = 0;
defineGetter(o33, "className", fo925563445_831_className);
// undefined
fo925563445_831_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12581
// 12582
// 12583
o34.className = "wrap";
// 12584
// 12585
// 12586
o35.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 12587
// 12588
// 12589
o36.className = "uiMenu uiSelectorMenu";
// 12590
// 12591
// 12592
o37.className = "rfloat";
// 12593
// 12594
// 12595
o38.className = "";
// 12596
// 12597
// 12598
o39.className = "linkWrap noCount";
// 12599
// 12600
// 12601
o40.className = "buttonWrap";
// 12602
// 12603
// undefined
fo925563445_839_className = function() { return fo925563445_839_className.returns[fo925563445_839_className.inst++]; };
fo925563445_839_className.returns = [];
fo925563445_839_className.inst = 0;
defineGetter(o41, "className", fo925563445_839_className);
// undefined
fo925563445_839_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12605
// 12606
// 12607
o42.className = "wrap";
// 12608
// 12609
// 12610
o43.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 12611
// 12612
// 12613
o44.className = "uiMenu uiSelectorMenu";
// 12614
// 12615
// 12616
o45.className = "rfloat";
// 12617
// 12618
// 12619
o46.className = "";
// 12620
// 12621
// 12622
o47.className = "linkWrap noCount";
// 12623
// 12624
// 12625
o48.className = "buttonWrap";
// 12626
// 12627
// undefined
fo925563445_847_className = function() { return fo925563445_847_className.returns[fo925563445_847_className.inst++]; };
fo925563445_847_className.returns = [];
fo925563445_847_className.inst = 0;
defineGetter(o49, "className", fo925563445_847_className);
// undefined
fo925563445_847_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12629
// 12630
// 12631
o50.className = "wrap";
// 12632
// 12633
// 12634
o51.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 12635
// 12636
// 12637
o52.className = "uiMenu uiSelectorMenu";
// 12638
// 12639
// 12640
o53.className = "rfloat";
// 12641
// 12642
// 12643
o54.className = "";
// 12644
// 12645
// 12646
o55.className = "linkWrap noCount";
// 12647
// 12648
// 12649
o56.className = "rfloat";
// 12650
// 12651
// 12652
o57.className = "";
// 12653
// 12654
// 12655
o58.className = "rfloat";
// 12656
// 12657
// 12658
o59.className = "";
// 12659
// 12660
// 12661
o60.className = "rfloat";
// 12662
// 12663
// 12664
o61.className = "";
// 12665
// 12666
// 12667
o62.className = "rfloat";
// 12668
// 12669
// 12670
o63.className = "";
// 12671
// 12672
// 12673
o64.className = "buttonWrap";
// 12674
// 12675
// undefined
fo925563445_863_className = function() { return fo925563445_863_className.returns[fo925563445_863_className.inst++]; };
fo925563445_863_className.returns = [];
fo925563445_863_className.inst = 0;
defineGetter(o65, "className", fo925563445_863_className);
// undefined
fo925563445_863_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12677
// 12678
// 12679
o66.className = "wrap";
// 12680
// 12681
// 12682
o67.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 12683
// 12684
// 12685
o68.className = "uiMenu uiSelectorMenu";
// 12686
// 12687
// 12688
o69.className = "rfloat";
// 12689
// 12690
// 12691
o70.className = "";
// 12692
// 12693
// 12694
o71.className = "linkWrap noCount";
// 12695
// 12696
// 12697
o72.className = "buttonWrap";
// 12698
// 12699
// undefined
fo925563445_871_className = function() { return fo925563445_871_className.returns[fo925563445_871_className.inst++]; };
fo925563445_871_className.returns = [];
fo925563445_871_className.inst = 0;
defineGetter(o73, "className", fo925563445_871_className);
// undefined
fo925563445_871_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12701
// 12702
// 12703
o74.className = "wrap";
// 12704
// 12705
// 12706
o75.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 12707
// 12708
// 12709
o76.className = "uiMenu uiSelectorMenu";
// 12710
// 12711
// 12712
o77.className = "rfloat";
// 12713
// 12714
// 12715
o78.className = "";
// 12716
// 12717
// 12718
o79.className = "linkWrap noCount";
// 12719
// 12720
// 12721
// 12722
// 12723
// 12724
// 12725
// undefined
fo925563445_831_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_831_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12729
// 12730
// 12731
// 12732
// 12733
// undefined
fo925563445_839_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_839_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12737
// 12738
// 12739
// 12740
// 12741
// undefined
fo925563445_847_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_847_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12745
// 12746
// 12747
// 12748
// 12749
// undefined
fo925563445_863_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_863_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12753
// 12754
// 12755
// 12756
// 12757
// undefined
fo925563445_871_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_871_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 12761
// 12762
// 12763
// 12765
// 12766
// 12767
o27 = {};
// 12768
f925563445_577.returns.push(o27);
// 12769
o27.length = 52;
// 12770
o27["0"] = o28;
// 12771
o27["1"] = o29;
// undefined
o29 = null;
// 12772
o27["2"] = o30;
// undefined
o30 = null;
// 12773
o27["3"] = o31;
// undefined
o31 = null;
// 12774
o27["4"] = o32;
// undefined
o32 = null;
// 12775
o27["5"] = o33;
// undefined
o33 = null;
// 12776
o27["6"] = o34;
// undefined
o34 = null;
// 12777
o27["7"] = o35;
// undefined
o35 = null;
// 12778
o27["8"] = o36;
// undefined
o36 = null;
// 12779
o27["9"] = o37;
// undefined
o37 = null;
// 12780
o27["10"] = o38;
// undefined
o38 = null;
// 12781
o27["11"] = o39;
// undefined
o39 = null;
// 12782
o27["12"] = o40;
// undefined
o40 = null;
// 12783
o27["13"] = o41;
// undefined
o41 = null;
// 12784
o27["14"] = o42;
// undefined
o42 = null;
// 12785
o27["15"] = o43;
// undefined
o43 = null;
// 12786
o27["16"] = o44;
// undefined
o44 = null;
// 12787
o27["17"] = o45;
// undefined
o45 = null;
// 12788
o27["18"] = o46;
// undefined
o46 = null;
// 12789
o27["19"] = o47;
// undefined
o47 = null;
// 12790
o27["20"] = o48;
// undefined
o48 = null;
// 12791
o27["21"] = o49;
// undefined
o49 = null;
// 12792
o27["22"] = o50;
// undefined
o50 = null;
// 12793
o27["23"] = o51;
// undefined
o51 = null;
// 12794
o27["24"] = o52;
// undefined
o52 = null;
// 12795
o27["25"] = o53;
// undefined
o53 = null;
// 12796
o27["26"] = o54;
// undefined
o54 = null;
// 12797
o27["27"] = o55;
// undefined
o55 = null;
// 12798
o27["28"] = o56;
// undefined
o56 = null;
// 12799
o27["29"] = o57;
// undefined
o57 = null;
// 12800
o27["30"] = o58;
// undefined
o58 = null;
// 12801
o27["31"] = o59;
// undefined
o59 = null;
// 12802
o27["32"] = o60;
// undefined
o60 = null;
// 12803
o27["33"] = o61;
// undefined
o61 = null;
// 12804
o27["34"] = o62;
// undefined
o62 = null;
// 12805
o27["35"] = o63;
// undefined
o63 = null;
// 12806
o27["36"] = o64;
// undefined
o64 = null;
// 12807
o27["37"] = o65;
// undefined
o65 = null;
// 12808
o27["38"] = o66;
// undefined
o66 = null;
// 12809
o27["39"] = o67;
// undefined
o67 = null;
// 12810
o27["40"] = o68;
// undefined
o68 = null;
// 12811
o27["41"] = o69;
// undefined
o69 = null;
// 12812
o27["42"] = o70;
// undefined
o70 = null;
// 12813
o27["43"] = o71;
// undefined
o71 = null;
// 12814
o27["44"] = o72;
// undefined
o72 = null;
// 12815
o27["45"] = o73;
// undefined
o73 = null;
// 12816
o27["46"] = o74;
// undefined
o74 = null;
// 12817
o27["47"] = o75;
// undefined
o75 = null;
// 12818
o27["48"] = o76;
// undefined
o76 = null;
// 12819
o27["49"] = o77;
// undefined
o77 = null;
// 12820
o27["50"] = o78;
// undefined
o78 = null;
// 12821
o27["51"] = o79;
// undefined
o27 = null;
// undefined
o79 = null;
// 12822
// 12823
// 12825
// 12826
// 12828
// 12829
// 12831
// 12832
// 12834
// 12835
// 12837
// 12838
// undefined
fo925563445_831_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 12840
// 12841
// 12843
// 12844
// 12846
// 12847
// 12849
// 12850
// 12852
// 12853
// 12855
// 12856
// 12858
// 12859
// 12861
// 12862
// undefined
fo925563445_839_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 12864
// 12865
// 12867
// 12868
// 12870
// 12871
// 12873
// 12874
// 12876
// 12877
// 12879
// 12880
// 12882
// 12883
// 12885
// 12886
// undefined
fo925563445_847_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 12888
// 12889
// 12891
// 12892
// 12894
// 12895
// 12897
// 12898
// 12900
// 12901
// 12903
// 12904
// 12906
// 12907
// 12909
// 12910
// 12912
// 12913
// 12915
// 12916
// 12918
// 12919
// 12921
// 12922
// 12924
// 12925
// 12927
// 12928
// 12930
// 12931
// 12933
// 12934
// undefined
fo925563445_863_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 12936
// 12937
// 12939
// 12940
// 12942
// 12943
// 12945
// 12946
// 12948
// 12949
// 12951
// 12952
// 12954
// 12955
// 12957
// 12958
// undefined
fo925563445_871_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 12960
// 12961
// 12963
// 12964
// 12966
// 12967
// 12969
// 12970
// 12972
// 12973
// 12975
// 12976
// 12978
// 12979
// 12980
// 12981
// 12982
// 12983
// 12984
// 12985
// 12986
// 12987
// 12988
// 12989
// 12990
// 12991
// 12992
// 12993
// 12994
// 12995
// 12996
// 12997
// 12998
// 12999
// 13000
// 13001
// 13002
// 13003
// 13004
// 13005
// 13006
// 13007
// 13008
// 13009
// 13011
// 13012
// 13013
// 13014
// 13015
// 13016
// 13018
// 13019
// 13020
// 13021
// 13022
// 13023
// 13024
// 13025
o28.getElementsByTagName = f925563445_577;
// undefined
o28 = null;
// 13026
// 13027
// 13028
o27 = {};
// 13029
f925563445_577.returns.push(o27);
// 13030
o27.length = 1;
// 13031
o28 = {};
// 13032
o27["0"] = o28;
// undefined
o27 = null;
// 13033
// 13034
// 13035
o28.className = "";
// 13036
// 13037
// 13038
// 13040
// 13041
// 13042
o27 = {};
// 13043
f925563445_577.returns.push(o27);
// 13044
o27.length = 1;
// 13045
o27["0"] = o28;
// undefined
o27 = null;
// undefined
o28 = null;
// 13046
// 13047
// 13049
// 13050
// 13051
// 13052
// 13053
// 13054
// 13055
// 13056
// 13057
// 13058
// 13059
// 13060
// 13061
// 13062
// 13063
// 13064
// 13065
// 13066
// 13067
// 13068
// 13069
// 13070
// 13071
// 13072
// 13073
// 13074
// 13075
// 13076
// 13077
// 13078
// 13079
// 13081
// 13082
o27 = {};
// 13083
f925563445_457.returns.push(o27);
// 13084
// 13085
// 13086
// 13087
// 13088
// 13089
// 13090
// 13091
// 13092
// 13093
// 13094
// 13095
// 13096
// 13097
// 13098
// 13099
// 13100
// 13101
// 13102
// 13103
// 13104
// 13105
// 13106
// 13107
o27.className = "sideNavItem stat_elem";
// 13108
// 13109
// 13110
// 13111
// 13112
// 13113
// 13115
// 13116
// 13117
// 13118
// 13119
// 13120
// 13121
// 13122
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 13123
// 13124
// 13125
o27 = {};
// 13126
f925563445_577.returns.push(o27);
// 13127
o27.length = 4;
// 13128
o28 = {};
// 13129
o27["0"] = o28;
// 13130
o29 = {};
// 13131
o27["1"] = o29;
// 13132
o30 = {};
// 13133
o27["2"] = o30;
// 13134
o31 = {};
// 13135
o27["3"] = o31;
// undefined
o27 = null;
// 13136
// 13137
// 13138
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 13139
// 13140
// 13141
o29.className = "itemAnchor";
// undefined
o29 = null;
// 13142
// 13143
// 13144
o30.className = "itemAnchor";
// undefined
o30 = null;
// 13145
// 13146
// 13147
o31.className = "item clearfix sortableItem";
// 13149
// 13150
// 13151
// 13152
// 13153
// 13154
// 13155
// 13158
o31.nodeName = "A";
// 13159
// 13160
// undefined
fo925563445_887___FB_TOKEN = function() { return fo925563445_887___FB_TOKEN.returns[fo925563445_887___FB_TOKEN.inst++]; };
fo925563445_887___FB_TOKEN.returns = [];
fo925563445_887___FB_TOKEN.inst = 0;
defineGetter(o31, "__FB_TOKEN", fo925563445_887___FB_TOKEN);
// undefined
fo925563445_887___FB_TOKEN.returns.push(null);
// 13163
o31.getAttribute = f925563445_468;
// 13165
// 13166
f925563445_468.returns.push(null);
// 13167
// 13168
// 13169
// 13170
// 13171
// 13172
// 13173
// 13174
// 13175
o27 = {};
// undefined
fo925563445_887___FB_TOKEN.returns.push(o27);
// 13177
o27["0"] = 39;
// 13178
o31.JSBNG__addEventListener = f925563445_433;
// 13180
// 13181
f925563445_433.returns.push(undefined);
// 13182
// 13183
// undefined
fo925563445_887___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 13186
o31.onclick = null;
// undefined
o31 = null;
// 13188
// 13189
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 13190
// 13191
// 13192
// 13193
// 13194
// 13195
// 13196
// 13197
// 13198
// 13199
// 13200
// 13201
// 13202
// 13203
// 13204
// 13205
// 13207
// 13208
o27 = {};
// 13209
f925563445_457.returns.push(o27);
// 13211
// 13212
// 13213
// 13214
// 13215
// 13216
// 13217
// 13220
o27.nodeName = "DIV";
// 13221
// 13222
// undefined
fo925563445_889___FB_TOKEN = function() { return fo925563445_889___FB_TOKEN.returns[fo925563445_889___FB_TOKEN.inst++]; };
fo925563445_889___FB_TOKEN.returns = [];
fo925563445_889___FB_TOKEN.inst = 0;
defineGetter(o27, "__FB_TOKEN", fo925563445_889___FB_TOKEN);
// undefined
fo925563445_889___FB_TOKEN.returns.push(null);
// 13225
o27.getAttribute = f925563445_468;
// 13227
// 13228
f925563445_468.returns.push(null);
// 13229
// 13230
// 13231
// 13232
// 13233
// 13234
// 13235
// 13236
// 13237
o28 = {};
// undefined
fo925563445_889___FB_TOKEN.returns.push(o28);
// 13239
o28["0"] = 40;
// 13240
o27.JSBNG__addEventListener = f925563445_433;
// 13242
// 13243
f925563445_433.returns.push(undefined);
// 13244
// 13245
// undefined
fo925563445_889___FB_TOKEN.returns.push(o28);
// undefined
o28 = null;
// 13248
o27.onclick = null;
// 13250
// 13251
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 13252
// 13253
// 13254
// 13255
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 13256
// 13257
// 13258
o27 = {};
// 13259
f925563445_577.returns.push(o27);
// 13260
o27.length = 9;
// 13261
o28 = {};
// 13262
o27["0"] = o28;
// 13263
o29 = {};
// 13264
o27["1"] = o29;
// 13265
o30 = {};
// 13266
o27["2"] = o30;
// 13267
o31 = {};
// 13268
o27["3"] = o31;
// 13269
o32 = {};
// 13270
o27["4"] = o32;
// 13271
o33 = {};
// 13272
o27["5"] = o33;
// 13273
o34 = {};
// 13274
o27["6"] = o34;
// 13275
o35 = {};
// 13276
o27["7"] = o35;
// 13277
o36 = {};
// 13278
o27["8"] = o36;
// undefined
o27 = null;
// 13279
// 13280
// 13281
o28.className = "navHeader";
// 13282
// 13283
// 13284
o29.className = "buttonWrap";
// 13285
// 13286
// undefined
fo925563445_894_className = function() { return fo925563445_894_className.returns[fo925563445_894_className.inst++]; };
fo925563445_894_className.returns = [];
fo925563445_894_className.inst = 0;
defineGetter(o30, "className", fo925563445_894_className);
// undefined
fo925563445_894_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 13288
// 13289
// 13290
o31.className = "wrap";
// 13291
// 13292
// 13293
o32.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 13294
// 13295
// 13296
o33.className = "uiMenu uiSelectorMenu";
// 13297
// 13298
// 13299
o34.className = "rfloat";
// 13300
// 13301
// 13302
o35.className = "";
// 13303
// 13304
// 13305
o36.className = "linkWrap noCount";
// 13306
// 13307
// 13308
// 13309
// 13310
// 13311
// 13312
// undefined
fo925563445_894_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_894_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 13316
// 13317
// 13318
// 13320
// 13321
// 13322
o27 = {};
// 13323
f925563445_577.returns.push(o27);
// 13324
o27.length = 9;
// 13325
o27["0"] = o28;
// 13326
o27["1"] = o29;
// undefined
o29 = null;
// 13327
o27["2"] = o30;
// undefined
o30 = null;
// 13328
o27["3"] = o31;
// undefined
o31 = null;
// 13329
o27["4"] = o32;
// undefined
o32 = null;
// 13330
o27["5"] = o33;
// undefined
o33 = null;
// 13331
o27["6"] = o34;
// undefined
o34 = null;
// 13332
o27["7"] = o35;
// undefined
o35 = null;
// 13333
o27["8"] = o36;
// undefined
o27 = null;
// undefined
o36 = null;
// 13334
// 13335
// 13337
// 13338
// 13340
// 13341
// undefined
fo925563445_894_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 13343
// 13344
// 13346
// 13347
// 13349
// 13350
// 13352
// 13353
// 13355
// 13356
// 13358
// 13359
// 13361
// 13362
// 13363
// 13364
// 13365
// 13366
// 13367
// 13368
// 13369
// 13370
// 13371
// 13372
// 13373
// 13374
// 13375
// 13376
// 13377
// 13378
// 13379
// 13380
// 13381
// 13382
// 13383
// 13384
// 13385
// 13386
// 13387
// 13388
// 13389
// 13390
// 13391
// 13392
// 13394
// 13395
// 13396
// 13397
// 13398
// 13399
// 13401
// 13402
// 13403
// 13404
// 13405
// 13406
// 13407
// 13408
o28.getElementsByTagName = f925563445_577;
// undefined
o28 = null;
// 13409
// 13410
// 13411
o27 = {};
// 13412
f925563445_577.returns.push(o27);
// 13413
o27.length = 0;
// undefined
o27 = null;
// 13414
// 13415
// 13416
// 13418
// 13419
// 13420
o27 = {};
// 13421
f925563445_577.returns.push(o27);
// 13422
o27.length = 0;
// undefined
o27 = null;
// 13423
// 13424
// 13425
// 13426
// 13427
// 13428
// 13429
// 13430
// 13431
// 13432
// 13433
// 13434
// 13435
// 13436
// 13437
// 13438
// 13439
// 13440
// 13441
// 13442
// 13443
// 13444
// 13445
// 13446
// 13447
// 13448
// 13449
// 13450
// 13452
// 13453
o27 = {};
// 13454
f925563445_457.returns.push(o27);
// 13456
// 13457
// 13458
// 13459
// 13460
// 13461
// 13462
// 13465
o27.nodeName = "DIV";
// 13466
// 13467
// undefined
fo925563445_904___FB_TOKEN = function() { return fo925563445_904___FB_TOKEN.returns[fo925563445_904___FB_TOKEN.inst++]; };
fo925563445_904___FB_TOKEN.returns = [];
fo925563445_904___FB_TOKEN.inst = 0;
defineGetter(o27, "__FB_TOKEN", fo925563445_904___FB_TOKEN);
// undefined
fo925563445_904___FB_TOKEN.returns.push(null);
// 13470
o27.getAttribute = f925563445_468;
// 13472
// 13473
f925563445_468.returns.push(null);
// 13474
// 13475
// 13476
// 13477
// 13478
// 13479
// 13480
// 13481
// 13482
o28 = {};
// undefined
fo925563445_904___FB_TOKEN.returns.push(o28);
// 13484
o28["0"] = 41;
// 13485
o27.JSBNG__addEventListener = f925563445_433;
// 13487
// 13488
f925563445_433.returns.push(undefined);
// 13489
// 13490
// undefined
fo925563445_904___FB_TOKEN.returns.push(o28);
// undefined
o28 = null;
// 13493
o27.onclick = null;
// 13495
// 13496
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 13497
// 13498
// 13499
// 13500
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 13501
// 13502
// 13503
o27 = {};
// 13504
f925563445_577.returns.push(o27);
// 13505
o27.length = 1;
// 13506
o28 = {};
// 13507
o27["0"] = o28;
// undefined
o27 = null;
// 13508
// 13509
// 13510
o28.className = "navHeader hidden_elem";
// 13511
// 13512
// 13513
// 13514
// 13515
// 13517
// 13518
// 13519
o27 = {};
// 13520
f925563445_577.returns.push(o27);
// 13521
o27.length = 1;
// 13522
o27["0"] = o28;
// undefined
o27 = null;
// 13523
// 13524
// 13526
// 13527
// 13528
// 13529
// 13530
// 13531
// 13532
// 13533
// 13534
// 13535
// 13536
// 13537
// 13538
// 13539
// 13540
// 13541
// 13542
// 13543
// 13544
// 13545
// 13546
// 13547
// 13548
// 13549
// 13550
// 13551
// 13552
// 13553
// 13554
// 13555
// 13556
// 13557
// 13559
// 13560
// 13561
// 13562
// 13563
// 13564
// 13566
// 13567
// 13568
// 13569
// 13570
// 13571
// 13572
// 13573
o28.getElementsByTagName = f925563445_577;
// undefined
o28 = null;
// 13574
// 13575
// 13576
o27 = {};
// 13577
f925563445_577.returns.push(o27);
// 13578
o27.length = 0;
// undefined
o27 = null;
// 13579
// 13580
// 13581
// 13583
// 13584
// 13585
o27 = {};
// 13586
f925563445_577.returns.push(o27);
// 13587
o27.length = 0;
// undefined
o27 = null;
// 13588
// 13589
// 13590
// 13591
// 13592
// 13593
// 13594
// 13595
// 13596
// 13597
// 13598
// 13599
// 13600
// 13601
// 13602
// 13603
// 13604
// 13605
// 13606
// 13607
// 13608
// 13609
// 13610
// 13611
// 13612
// 13613
// 13614
// 13615
// 13616
// 13617
// 13618
// 13620
// 13621
o27 = {};
// 13622
f925563445_457.returns.push(o27);
// 13623
// 13624
// 13625
// 13626
// 13627
// 13628
// 13629
// 13630
// 13631
// 13632
// 13633
// 13634
// 13635
// 13636
// 13637
// 13638
// 13639
// 13640
// 13641
// 13642
// 13643
// 13644
// 13645
o27.className = "sideNavItem stat_elem";
// 13646
// 13647
// 13648
// 13649
// 13650
// 13651
// 13653
// 13654
// 13655
// 13656
// 13657
// 13658
// 13659
// 13660
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 13661
// 13662
// 13663
o27 = {};
// 13664
f925563445_577.returns.push(o27);
// 13665
o27.length = 5;
// 13666
o28 = {};
// 13667
o27["0"] = o28;
// 13668
o29 = {};
// 13669
o27["1"] = o29;
// 13670
o30 = {};
// 13671
o27["2"] = o30;
// 13672
o31 = {};
// 13673
o27["3"] = o31;
// 13674
o32 = {};
// 13675
o27["4"] = o32;
// undefined
o27 = null;
// 13676
// 13677
// 13678
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 13679
// 13680
// 13681
o29.className = "itemAnchor";
// undefined
o29 = null;
// 13682
// 13683
// 13684
o30.className = "itemAnchor";
// undefined
o30 = null;
// 13685
// 13686
// 13687
o31.className = "itemAnchor";
// undefined
o31 = null;
// 13688
// 13689
// 13690
o32.className = "item clearfix sortableItem";
// 13692
// 13693
// 13694
// 13695
// 13696
// 13697
// 13698
// 13701
o32.nodeName = "A";
// 13702
// 13703
// undefined
fo925563445_917___FB_TOKEN = function() { return fo925563445_917___FB_TOKEN.returns[fo925563445_917___FB_TOKEN.inst++]; };
fo925563445_917___FB_TOKEN.returns = [];
fo925563445_917___FB_TOKEN.inst = 0;
defineGetter(o32, "__FB_TOKEN", fo925563445_917___FB_TOKEN);
// undefined
fo925563445_917___FB_TOKEN.returns.push(null);
// 13706
o32.getAttribute = f925563445_468;
// 13708
// 13709
f925563445_468.returns.push(null);
// 13710
// 13711
// 13712
// 13713
// 13714
// 13715
// 13716
// 13717
// 13718
o27 = {};
// undefined
fo925563445_917___FB_TOKEN.returns.push(o27);
// 13720
o27["0"] = 42;
// 13721
o32.JSBNG__addEventListener = f925563445_433;
// 13723
// 13724
f925563445_433.returns.push(undefined);
// 13725
// 13726
// undefined
fo925563445_917___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 13729
o32.onclick = null;
// undefined
o32 = null;
// 13731
// 13732
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 13733
// 13734
// 13735
// 13736
// 13737
// 13738
// 13739
// 13740
// 13741
// 13742
// 13743
// 13744
// 13745
// 13746
// 13747
// 13748
// 13749
// 13750
// 13751
// 13753
// 13754
o27 = {};
// 13755
f925563445_457.returns.push(o27);
// 13756
// 13757
// 13758
// 13759
// 13760
// 13761
// 13762
// 13763
// 13764
// 13765
// 13766
// 13767
// 13768
// 13769
// 13770
// 13771
// 13772
// 13773
// 13774
// 13775
// 13776
// 13777
// 13778
o27.className = "sideNavItem stat_elem";
// 13779
// 13780
// 13781
// 13782
// 13783
// 13784
// 13786
// 13787
// 13788
// 13789
// 13790
// 13791
// 13792
// 13793
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 13794
// 13795
// 13796
o27 = {};
// 13797
f925563445_577.returns.push(o27);
// 13798
o27.length = 5;
// 13799
o28 = {};
// 13800
o27["0"] = o28;
// 13801
o29 = {};
// 13802
o27["1"] = o29;
// 13803
o30 = {};
// 13804
o27["2"] = o30;
// 13805
o31 = {};
// 13806
o27["3"] = o31;
// 13807
o32 = {};
// 13808
o27["4"] = o32;
// undefined
o27 = null;
// 13809
// 13810
// 13811
o28.className = "uiSelectorButton uiCloseButton";
// undefined
o28 = null;
// 13812
// 13813
// 13814
o29.className = "itemAnchor";
// undefined
o29 = null;
// 13815
// 13816
// 13817
o30.className = "itemAnchor";
// undefined
o30 = null;
// 13818
// 13819
// 13820
o31.className = "itemAnchor";
// undefined
o31 = null;
// 13821
// 13822
// 13823
o32.className = "item clearfix sortableItem";
// 13825
// 13826
// 13827
// 13828
// 13829
// 13830
// 13831
// 13834
o32.nodeName = "A";
// 13835
// 13836
// undefined
fo925563445_925___FB_TOKEN = function() { return fo925563445_925___FB_TOKEN.returns[fo925563445_925___FB_TOKEN.inst++]; };
fo925563445_925___FB_TOKEN.returns = [];
fo925563445_925___FB_TOKEN.inst = 0;
defineGetter(o32, "__FB_TOKEN", fo925563445_925___FB_TOKEN);
// undefined
fo925563445_925___FB_TOKEN.returns.push(null);
// 13839
o32.getAttribute = f925563445_468;
// 13841
// 13842
f925563445_468.returns.push(null);
// 13843
// 13844
// 13845
// 13846
// 13847
// 13848
// 13849
// 13850
// 13851
o27 = {};
// undefined
fo925563445_925___FB_TOKEN.returns.push(o27);
// 13853
o27["0"] = 43;
// 13854
o32.JSBNG__addEventListener = f925563445_433;
// 13856
// 13857
f925563445_433.returns.push(undefined);
// 13858
// 13859
// undefined
fo925563445_925___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 13862
o32.onclick = null;
// undefined
o32 = null;
// 13864
// 13865
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 13866
// 13867
// 13868
// 13869
// 13870
// 13871
// 13872
// 13873
// 13874
// 13875
// 13876
// 13877
// 13878
// 13879
// 13880
// 13881
// 13883
// 13884
o27 = {};
// 13885
f925563445_457.returns.push(o27);
// 13887
// 13888
// 13889
// 13890
// 13891
// 13892
// 13893
// 13896
o27.nodeName = "DIV";
// 13897
// 13898
// undefined
fo925563445_927___FB_TOKEN = function() { return fo925563445_927___FB_TOKEN.returns[fo925563445_927___FB_TOKEN.inst++]; };
fo925563445_927___FB_TOKEN.returns = [];
fo925563445_927___FB_TOKEN.inst = 0;
defineGetter(o27, "__FB_TOKEN", fo925563445_927___FB_TOKEN);
// undefined
fo925563445_927___FB_TOKEN.returns.push(null);
// 13901
o27.getAttribute = f925563445_468;
// 13903
// 13904
f925563445_468.returns.push(null);
// 13905
// 13906
// 13907
// 13908
// 13909
// 13910
// 13911
// 13912
// 13913
o28 = {};
// undefined
fo925563445_927___FB_TOKEN.returns.push(o28);
// 13915
o28["0"] = 44;
// 13916
o27.JSBNG__addEventListener = f925563445_433;
// 13918
// 13919
f925563445_433.returns.push(undefined);
// 13920
// 13921
// undefined
fo925563445_927___FB_TOKEN.returns.push(o28);
// undefined
o28 = null;
// 13924
o27.onclick = null;
// 13926
// 13927
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 13928
// 13929
// 13930
// 13931
o27.getElementsByTagName = f925563445_577;
// undefined
o27 = null;
// 13932
// 13933
// 13934
o27 = {};
// 13935
f925563445_577.returns.push(o27);
// 13936
o27.length = 21;
// 13937
o28 = {};
// 13938
o27["0"] = o28;
// 13939
o29 = {};
// 13940
o27["1"] = o29;
// 13941
o30 = {};
// 13942
o27["2"] = o30;
// 13943
o31 = {};
// 13944
o27["3"] = o31;
// 13945
o32 = {};
// 13946
o27["4"] = o32;
// 13947
o33 = {};
// 13948
o27["5"] = o33;
// 13949
o34 = {};
// 13950
o27["6"] = o34;
// 13951
o35 = {};
// 13952
o27["7"] = o35;
// 13953
o36 = {};
// 13954
o27["8"] = o36;
// 13955
o37 = {};
// 13956
o27["9"] = o37;
// 13957
o38 = {};
// 13958
o27["10"] = o38;
// 13959
o39 = {};
// 13960
o27["11"] = o39;
// 13961
o40 = {};
// 13962
o27["12"] = o40;
// 13963
o41 = {};
// 13964
o27["13"] = o41;
// 13965
o42 = {};
// 13966
o27["14"] = o42;
// 13967
o43 = {};
// 13968
o27["15"] = o43;
// 13969
o44 = {};
// 13970
o27["16"] = o44;
// 13971
o45 = {};
// 13972
o27["17"] = o45;
// 13973
o46 = {};
// 13974
o27["18"] = o46;
// 13975
o47 = {};
// 13976
o27["19"] = o47;
// 13977
o48 = {};
// 13978
o27["20"] = o48;
// undefined
o27 = null;
// 13979
// 13980
// 13981
o28.className = "navHeader";
// 13982
// 13983
// 13984
o29.className = "clearfix";
// 13985
// 13986
// 13987
o30.className = "lfloat";
// 13988
// 13989
// 13990
o31.className = "bookmarksNavSeeAll";
// 13991
// 13992
// 13993
o32.className = "buttonWrap";
// 13994
// 13995
// undefined
fo925563445_935_className = function() { return fo925563445_935_className.returns[fo925563445_935_className.inst++]; };
fo925563445_935_className.returns = [];
fo925563445_935_className.inst = 0;
defineGetter(o33, "className", fo925563445_935_className);
// undefined
fo925563445_935_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 13997
// 13998
// 13999
o34.className = "wrap";
// 14000
// 14001
// 14002
o35.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 14003
// 14004
// 14005
o36.className = "uiMenu uiSelectorMenu";
// 14006
// 14007
// 14008
o37.className = "rfloat";
// 14009
// 14010
// 14011
o38.className = "";
// 14012
// 14013
// 14014
o39.className = "linkWrap noCount";
// 14015
// 14016
// 14017
o40.className = "buttonWrap";
// 14018
// 14019
// undefined
fo925563445_943_className = function() { return fo925563445_943_className.returns[fo925563445_943_className.inst++]; };
fo925563445_943_className.returns = [];
fo925563445_943_className.inst = 0;
defineGetter(o41, "className", fo925563445_943_className);
// undefined
fo925563445_943_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 14021
// 14022
// 14023
o42.className = "wrap";
// 14024
// 14025
// 14026
o43.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 14027
// 14028
// 14029
o44.className = "uiMenu uiSelectorMenu";
// 14030
// 14031
// 14032
o45.className = "rfloat";
// 14033
// 14034
// 14035
o46.className = "";
// 14036
// 14037
// 14038
o47.className = "linkWrap noCount";
// 14039
// 14040
// 14041
o48.className = "";
// 14042
// 14043
// 14044
// 14045
// 14046
// 14047
// 14048
// undefined
fo925563445_935_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_935_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 14052
// 14053
// 14054
// 14055
// 14056
// undefined
fo925563445_943_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// undefined
fo925563445_943_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton");
// 14060
// 14061
// 14062
// 14064
// 14065
// 14066
o27 = {};
// 14067
f925563445_577.returns.push(o27);
// 14068
o27.length = 21;
// 14069
o27["0"] = o28;
// 14070
o27["1"] = o29;
// undefined
o29 = null;
// 14071
o27["2"] = o30;
// undefined
o30 = null;
// 14072
o27["3"] = o31;
// undefined
o31 = null;
// 14073
o27["4"] = o32;
// undefined
o32 = null;
// 14074
o27["5"] = o33;
// undefined
o33 = null;
// 14075
o27["6"] = o34;
// undefined
o34 = null;
// 14076
o27["7"] = o35;
// undefined
o35 = null;
// 14077
o27["8"] = o36;
// undefined
o36 = null;
// 14078
o27["9"] = o37;
// undefined
o37 = null;
// 14079
o27["10"] = o38;
// undefined
o38 = null;
// 14080
o27["11"] = o39;
// undefined
o39 = null;
// 14081
o27["12"] = o40;
// undefined
o40 = null;
// 14082
o27["13"] = o41;
// undefined
o41 = null;
// 14083
o27["14"] = o42;
// undefined
o42 = null;
// 14084
o27["15"] = o43;
// undefined
o43 = null;
// 14085
o27["16"] = o44;
// undefined
o44 = null;
// 14086
o27["17"] = o45;
// undefined
o45 = null;
// 14087
o27["18"] = o46;
// undefined
o46 = null;
// 14088
o27["19"] = o47;
// undefined
o47 = null;
// 14089
o27["20"] = o48;
// undefined
o27 = null;
// undefined
o48 = null;
// 14090
// 14091
// 14093
// 14094
// 14096
// 14097
// 14099
// 14100
// 14102
// 14103
// 14105
// 14106
// undefined
fo925563445_935_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 14108
// 14109
// 14111
// 14112
// 14114
// 14115
// 14117
// 14118
// 14120
// 14121
// 14123
// 14124
// 14126
// 14127
// 14129
// 14130
// undefined
fo925563445_943_className.returns.push("uiSelector inlineBlock mas bookmarksMenuButton uiSideNavEditButton");
// 14132
// 14133
// 14135
// 14136
// 14138
// 14139
// 14141
// 14142
// 14144
// 14145
// 14147
// 14148
// 14150
// 14151
// 14153
// 14154
// 14155
// 14156
// 14157
// 14158
// 14159
// 14160
// 14161
// 14162
// 14163
// 14164
// 14165
// 14166
// 14167
// 14168
// 14169
// 14170
// 14171
// 14172
// 14173
// 14174
// 14175
// 14176
// 14177
// 14178
// 14179
// 14180
// 14181
// 14182
// 14183
// 14184
// 14186
// 14187
// 14188
// 14189
// 14190
// 14191
// 14193
// 14194
// 14195
// 14196
// 14197
// 14198
// 14199
// 14200
o28.getElementsByTagName = f925563445_577;
// undefined
o28 = null;
// 14201
// 14202
// 14203
o27 = {};
// 14204
f925563445_577.returns.push(o27);
// 14205
o27.length = 1;
// 14206
o28 = {};
// 14207
o27["0"] = o28;
// undefined
o27 = null;
// 14208
// 14209
// 14210
o28.className = "";
// 14211
// 14212
// 14213
// 14215
// 14216
// 14217
o27 = {};
// 14218
f925563445_577.returns.push(o27);
// 14219
o27.length = 1;
// 14220
o27["0"] = o28;
// undefined
o27 = null;
// undefined
o28 = null;
// 14221
// 14222
// 14224
// 14225
// 14226
// 14227
// 14228
// 14229
// 14230
// 14231
// 14232
// 14233
// 14234
// 14235
// 14236
// 14237
// 14238
// 14239
// 14240
// 14241
// 14242
// 14243
// 14244
// 14245
// 14246
// 14247
// 14248
// 14249
// 14250
// 14251
// 14252
// 14253
// 14254
// 14255
// 14256
// 14257
// 14258
// 14259
// 14260
// 14261
// 14262
// 14263
// 14264
// 14265
// 14266
// 14267
// 14268
// 14269
// 14270
// undefined
fo925563445_624_readyState = function() { return fo925563445_624_readyState.returns[fo925563445_624_readyState.inst++]; };
fo925563445_624_readyState.returns = [];
fo925563445_624_readyState.inst = 0;
defineGetter(o25, "readyState", fo925563445_624_readyState);
// undefined
fo925563445_624_readyState.returns.push(1);
// 14273
// 14274
// 14275
// 14276
// 14277
// 14278
// 14279
// 14280
// 14281
// 14282
// 14283
// 14284
// 14285
// 14286
// 14287
// 14288
// 14289
// 14290
// 14291
// 14292
// 14293
// 14294
// 14295
// 14296
// 14297
// 14298
// 14299
// 14300
// 14301
// 14302
// 14303
// 14304
// 14305
// 14306
// 14307
// 14308
// 14309
// 14311
// 14312
// 14313
// 14314
// 14315
// 14316
// 14317
// 14318
// 14319
// 14320
// 14321
// 14322
// 14323
// 14324
// 14325
// 14326
// 14327
// 14328
// 14329
// 14330
// 14331
// 14332
// 14333
// 14334
// 14335
// 14336
// 14337
// 14338
// 14339
// 14340
// 14341
// 14342
// 14343
// 14344
// 14345
// 14346
// 14347
// 14348
// 14349
// 14350
// 14351
// 14352
// 14353
// 14354
// 14355
// 14356
// 14357
// 14358
// 14359
// 14360
// 14361
// 14362
// 14363
// 14364
// 14365
o5.clientHeight = 709;
// 14367
o5.scrollWidth = 1265;
// 14368
// 14369
// 14370
// 14371
// 14372
// undefined
fo925563445_427_className.returns.push(" sidebarMode ticker");
// 14375
// 14376
// 14379
// 14380
// 14381
// 14382
// 14385
// 14386
f925563445_426.returns.push(0.6848442952614278);
// 14387
// 14388
// 14389
// 14390
o27 = {};
// 14391
f925563445_75.returns.push(o27);
// 14393
// 14394
o28 = {};
// 14395
f925563445_457.returns.push(o28);
// 14396
// 14397
f925563445_426.returns.push(0.7928249216638505);
// 14398
o28.value = "116b3858a89f8fb09d086e629ed60785";
// undefined
o28 = null;
// 14399
// undefined
o27 = null;
// 14400
// 14401
// 14402
// 14403
// 14404
// 14405
// 14406
// 14407
// 14408
// 14417
// 14418
// 14419
// 14420
// 14421
// 14422
// 14425
// 14426
// 14427
// 14428
// 14429
// 14430
// 14431
// 14433
// 14434
f925563445_457.returns.push(o4);
// 14435
// 14436
// undefined
fo925563445_622_className = function() { return fo925563445_622_className.returns[fo925563445_622_className.inst++]; };
fo925563445_622_className.returns = [];
fo925563445_622_className.inst = 0;
defineGetter(o4, "className", fo925563445_622_className);
// undefined
fo925563445_622_className.returns.push("clearfix uiMorePager stat_elem uiMorePagerCenter");
// 14438
// 14440
// 14441
o27 = {};
// 14442
f925563445_457.returns.push(o27);
// 14443
// 14444
// 14445
o27.tagName = "FORM";
// 14446
o28 = {};
// 14447
o27.elements = o28;
// undefined
o27 = null;
// 14448
// 14449
// 14450
// 14451
// 14452
// 14453
o28.JSBNG__name = null;
// undefined
o28 = null;
// 14454
// 14455
// 14456
// 14457
// 14458
// 14459
// 14460
// 14461
// 14462
// 14463
// 14464
// 14465
// 14466
// 14467
// 14468
// 14469
// 14470
// 14471
// 14472
// 14473
// 14474
// 14475
// 14476
// 14477
// 14478
// 14479
// 14480
// 14482
// 14483
// 14484
// 14485
// 14486
// 14487
// 14488
// 14489
// 14490
// 14491
// 14492
// 14493
// 14494
// 14495
// 14497
// 14498
f925563445_457.returns.push(o4);
// undefined
o4 = null;
// 14499
// 14500
// 14501
// 14502
// 14503
// 14504
// 14505
// 14506
// 14507
// 14508
// 14509
// 14510
// 14511
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; wd=1280x709");
// 14513
// 14514
// 14515
// 14516
// 14517
// 14518
// 14519
// 14520
// 14521
// 14522
// 14523
// 14524
// 14525
// 14526
// 14527
// 14528
// 14529
// 14530
// 14531
// 14532
// 14533
// 14534
// 14535
// 14536
// 14537
// 14538
// 14539
// 14540
// 14541
// 14542
// 14543
// 14544
// 14545
// 14546
// 14547
// 14548
// 14549
// 14550
// 14551
// 14552
// 14553
// 14554
// 14555
// 14556
// 14557
// 14558
// 14559
// 14560
// 14561
// 14562
// 14563
// 14564
// 14565
// 14566
// 14567
// 14568
// 14569
// 14570
// 14571
// 14572
// 14573
// 14574
// 14575
// 14576
// 14577
// 14578
// 14579
// 14580
// 14581
// 14582
o4 = {};
// 14583
f925563445_74.returns.push(o4);
// 14584
// 14585
// 14586
// 14587
// 14588
// 14589
o4.open = f925563445_625;
// 14590
// 14591
// 14592
f925563445_625.returns.push(undefined);
// 14593
// 14594
o4.setRequestHeader = f925563445_626;
// 14595
// 14596
f925563445_626.returns.push(undefined);
// 14598
// 14599
f925563445_626.returns.push(undefined);
// 14600
// 14601
// 14602
// 14603
// 14604
// 14605
// 14606
// undefined
fo925563445_622_className.returns.push("clearfix uiMorePager stat_elem uiMorePagerCenter");
// undefined
fo925563445_622_className.returns.push("clearfix uiMorePager stat_elem uiMorePagerCenter");
// 14610
// 14611
// 14612
o4.send = f925563445_627;
// 14613
// 14614
f925563445_627.returns.push(undefined);
// 14615
// 14616
// 14617
// 14618
// 14619
// undefined
fo925563445_959_readyState = function() { return fo925563445_959_readyState.returns[fo925563445_959_readyState.inst++]; };
fo925563445_959_readyState.returns = [];
fo925563445_959_readyState.inst = 0;
defineGetter(o4, "readyState", fo925563445_959_readyState);
// undefined
fo925563445_959_readyState.returns.push(1);
// 14622
// 14623
// 14624
// 14625
// 14626
// 14627
// 14628
// 14629
// 14630
// 14631
// 14632
// 14633
// 14634
// 14635
// 14636
// 14637
// 14638
// 14639
// 14640
// 14641
// 14642
// 14643
// 14644
// 14645
// 14646
// 14647
// 14648
// 14649
// 14650
// 14652
// 14653
// 14654
// 14655
// 14656
// 14657
// 14658
// 14659
// 14660
// 14661
// 14662
// 14663
// 14664
// 14665
// 14666
// 14667
// 14668
// 14669
// 14670
// 14671
// 14672
// 14673
// 14674
// 14675
// 14676
// 14677
// 14678
// 14679
// 14680
// 14681
// 14682
// 14683
// 14684
// 14685
// 14686
// 14687
// 14688
// 14689
// 14690
// 14691
// 14692
// 14693
// 14694
// 14695
// 14696
// 14697
// 14698
// 14699
// 14700
// 14701
// 14702
// 14703
// 14704
// 14705
// 14706
// 14707
// 14708
// 14709
// 14710
// 14711
// 14712
// 14713
// 14714
// 14715
// 14716
// 14717
// 14718
// 14719
// 14720
// 14721
// 14722
// 14723
// 14724
// 14725
// 14726
// 14727
// 14728
// 14729
// 14730
// 14731
// 14732
// 14733
// 14734
// 14735
// 14736
// 14737
// 14738
// 14739
// 14740
// 14741
// 14742
// 14743
// 14744
// 14745
// 14746
// 14747
// 14748
// 14749
// 14750
// 14751
// 14752
// 14753
// 14754
// 14755
// 14756
// 14757
// 14758
// 14759
// 14760
// 14761
// 14762
// 14763
// 14764
// 14765
// 14766
// 14767
// 14768
// 14769
// 14770
// 14771
// 14772
// 14773
// 14774
// 14775
// 14776
// 14777
// 14778
// 14779
// 14780
// 14781
// 14783
// 14784
o27 = {};
// 14785
f925563445_457.returns.push(o27);
// 14786
// 14787
// 14788
// 14789
o27.__FB_TOKEN = null;
// 14790
// 14791
// 14793
// 14794
o28 = {};
// 14795
f925563445_457.returns.push(o28);
// 14796
// 14798
// 14799
o29 = {};
// 14800
f925563445_457.returns.push(o29);
// 14801
// 14802
// 14803
// 14804
// 14805
// 14806
// 14807
// 14808
// 14809
// 14810
// 14811
// 14812
// 14813
// 14814
// 14815
// 14816
// 14817
// 14818
// 14819
o28.getElementsByTagName = f925563445_577;
// 14820
// 14821
// 14822
o30 = {};
// 14823
f925563445_577.returns.push(o30);
// 14824
o30.length = 11;
// 14825
o31 = {};
// 14826
o30["0"] = o31;
// 14827
o32 = {};
// 14828
o30["1"] = o32;
// 14829
o33 = {};
// 14830
o30["2"] = o33;
// 14831
o34 = {};
// 14832
o30["3"] = o34;
// 14833
o30["4"] = o27;
// 14834
o35 = {};
// 14835
o30["5"] = o35;
// 14836
o36 = {};
// 14837
o30["6"] = o36;
// 14838
o30["7"] = o29;
// 14839
o37 = {};
// 14840
o30["8"] = o37;
// 14841
o38 = {};
// 14842
o30["9"] = o38;
// 14843
o39 = {};
// 14844
o30["10"] = o39;
// undefined
o30 = null;
// 14845
// 14846
// 14847
o31.className = "uiHeader uiHeaderTopBorder uiHeaderNav uiHeaderNavEmpty";
// undefined
o31 = null;
// 14848
// 14849
// 14850
o32.className = "clearfix uiHeaderTop";
// undefined
o32 = null;
// 14851
// 14852
// 14853
o33.className = "";
// undefined
o33 = null;
// 14854
// 14855
// 14856
o34.className = "pas";
// undefined
o34 = null;
// 14857
// 14858
// 14859
o27.className = "uiTypeahead uiClearableTypeahead fbChatTypeahead typeahead hideIfOffline";
// undefined
o27 = null;
// 14860
// 14861
// 14862
o35.className = "wrap";
// undefined
o35 = null;
// 14863
// 14864
// 14865
o36.className = "innerWrap";
// undefined
o36 = null;
// 14866
// 14867
// 14868
o29.className = "uiFacepile uiFacepileMedium hideIfOffline fbFriendsOnlineFacepile";
// 14869
// 14870
// 14871
o37.className = "UIImageBlock clearfix navigationLink showIfOffline";
// undefined
o37 = null;
// 14872
// 14873
// 14874
o38.className = "fbChatOfflineMessage UIImageBlock_Content UIImageBlock_ICON_Content fsm fwn fcg";
// undefined
o38 = null;
// 14875
// 14876
// 14877
o39.className = "fbChatTypeaheadView hidden_elem";
// undefined
o39 = null;
// 14878
// 14879
// 14880
// 14881
// 14882
// 14883
// 14884
// 14885
// 14886
// 14887
// 14888
// 14889
// 14890
// 14891
// 14892
// 14893
// 14894
o27 = {};
// 14895
o29.firstChild = o27;
// undefined
o27 = null;
// 14896
// 14897
// 14898
// 14899
// 14900
// 14901
// 14902
// 14903
// 14904
// 14905
// 14906
// 14907
// 14908
// 14909
// 14910
// 14911
// 14912
// 14913
// 14914
// 14915
// 14916
// 14917
// 14918
// 14919
// 14920
// 14921
// 14922
// 14923
// 14924
// 14925
// 14926
// 14927
// 14928
// 14929
// 14930
// 14931
// 14933
// 14934
// 14935
// 14936
// 14937
// 14938
// 14939
// 14942
o29.nodeName = "DIV";
// 14943
// 14944
// undefined
fo925563445_962___FB_TOKEN = function() { return fo925563445_962___FB_TOKEN.returns[fo925563445_962___FB_TOKEN.inst++]; };
fo925563445_962___FB_TOKEN.returns = [];
fo925563445_962___FB_TOKEN.inst = 0;
defineGetter(o29, "__FB_TOKEN", fo925563445_962___FB_TOKEN);
// undefined
fo925563445_962___FB_TOKEN.returns.push(null);
// 14947
o29.getAttribute = f925563445_468;
// 14949
// 14950
f925563445_468.returns.push(null);
// 14951
// 14952
// 14953
// 14954
// 14955
// 14956
// 14957
// 14958
// 14959
o27 = {};
// undefined
fo925563445_962___FB_TOKEN.returns.push(o27);
// 14961
o27["0"] = 46;
// 14962
o29.JSBNG__addEventListener = f925563445_433;
// 14964
// 14965
f925563445_433.returns.push(undefined);
// 14966
// 14967
// undefined
fo925563445_962___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 14970
o29.onclick = null;
// undefined
o29 = null;
// 14972
// 14973
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 14974
// 14975
// 14976
o27 = {};
// 14977
f925563445_0.returns.push(o27);
// undefined
o27 = null;
// 14978
// 14979
// 14980
// 14981
// 14982
// 14983
// 14984
// 14985
// 14986
// 14987
// 14988
// 14989
// 14990
// 14991
// 14993
// 14994
// 14995
// 14996
// 14997
// 14998
// 14999
// 15000
// 15001
// 15002
// 15003
// 15004
// 15005
// 15006
// 15007
// 15008
// 15009
// 15010
// 15011
// 15012
// 15013
// 15014
// 15015
// 15016
// 15017
// 15018
// 15019
// 15020
// 15021
// 15022
// 15023
o27 = {};
// 15024
f925563445_0.returns.push(o27);
// undefined
o27 = null;
// 15025
// 15026
// 15027
// 15028
f925563445_13.returns.push(12);
// 15029
// 15030
// 15031
// 15032
// 15033
// 15034
// 15035
// 15036
// 15038
// 15039
// 15040
// 15041
// 15042
// 15043
// 15044
// 15045
// 15046
// 15047
// 15048
// 15049
// 15050
// 15051
// 15052
// 15053
// 15054
// 15055
// 15056
// 15057
// 15058
// 15059
// 15060
// 15061
// 15062
// 15063
// 15065
// 15066
// 15067
// 15068
// 15069
// 15070
// 15071
// 15072
// 15073
// 15074
// 15075
// 15076
// 15077
// 15078
// 15079
// 15080
// 15081
// 15082
// 15083
// 15084
// 15085
// 15086
// 15087
// 15088
// 15089
// 15090
// 15091
// 15092
// 15093
// 15094
// 15095
// 15096
// 15097
// 15098
// 15099
// 15100
// 15101
// 15102
// 15103
// 15104
// 15105
// 15106
// 15107
// 15108
// 15109
// 15110
// 15111
// 15112
// 15113
// 15114
// 15115
// 15116
// 15117
// 15118
// 15119
// 15120
// 15121
// 15122
// 15123
// 15124
// 15125
// 15126
// 15127
// 15128
// 15129
// 15130
// 15131
// 15132
// 15133
// 15134
// 15135
// 15136
// 15137
// 15138
// 15139
// 15140
// 15141
// 15142
// 15143
// 15144
// 15145
// 15146
// 15147
// 15148
// 15149
// 15150
// 15151
// 15152
// 15153
// 15154
// 15155
// 15156
// 15157
// 15158
// 15159
// 15160
// 15161
// 15162
// 15163
// 15164
// 15165
// 15167
// 15168
// 15169
// 15170
// 15171
// 15172
// 15173
// 15174
// 15175
// 15176
// 15177
// 15178
// 15179
// 15180
// 15181
// 15182
// 15183
// 15184
// 15185
// 15186
// 15187
// 15188
// 15189
// 15190
// 15191
// 15192
// 15193
// 15194
// 15195
// 15196
// 15197
// 15198
// 15199
// 15200
// 15201
// 15202
// 15203
// 15204
// 15205
// 15206
// 15207
// 15208
// 15209
// 15210
// 15211
// 15212
// 15213
// 15214
// 15215
// 15216
// 15217
// 15218
// 15219
// 15220
// 15221
// 15222
// 15223
// 15224
// 15225
// 15226
// 15227
// 15228
// 15229
// 15230
// 15231
// 15232
// 15233
// 15234
// 15235
// 15236
// 15237
// 15238
// 15239
// 15240
// 15241
// 15242
// 15243
// 15244
// 15245
// 15246
// 15247
// 15248
// 15249
// 15250
// 15251
// 15252
// 15253
// 15254
// 15255
// 15256
// 15257
// 15258
// 15259
// 15260
// 15261
// 15262
// 15263
// 15264
// 15265
// 15266
// 15267
// 15268
// 15269
// 15270
// 15271
// 15272
// 15273
// 15274
// 15275
// 15276
// 15278
// 15279
o27 = {};
// 15280
f925563445_457.returns.push(o27);
// 15281
// 15282
// 15284
// 15285
o29 = {};
// 15286
f925563445_457.returns.push(o29);
// 15287
// 15288
// 15289
// 15290
// 15291
// 15292
// 15293
// 15294
// 15295
// 15296
// 15298
// 15299
o30 = {};
// 15300
f925563445_457.returns.push(o30);
// 15301
// 15302
// 15303
// 15304
o30.__FB_TOKEN = null;
// 15305
// 15306
// 15307
// 15308
// 15309
// 15310
// 15311
o27.getElementsByTagName = f925563445_577;
// 15312
// 15313
// 15314
o31 = {};
// 15315
f925563445_577.returns.push(o31);
// 15316
o31.length = 18;
// 15317
o32 = {};
// 15318
o31["0"] = o32;
// 15319
o33 = {};
// 15320
o31["1"] = o33;
// 15321
o34 = {};
// 15322
o31["2"] = o34;
// 15323
o35 = {};
// 15324
o31["3"] = o35;
// 15325
o36 = {};
// 15326
o31["4"] = o36;
// 15327
o37 = {};
// 15328
o31["5"] = o37;
// 15329
o38 = {};
// 15330
o31["6"] = o38;
// 15331
o39 = {};
// 15332
o31["7"] = o39;
// 15333
o40 = {};
// 15334
o31["8"] = o40;
// 15335
o41 = {};
// 15336
o31["9"] = o41;
// 15337
o42 = {};
// 15338
o31["10"] = o42;
// 15339
o31["11"] = o30;
// 15340
o43 = {};
// 15341
o31["12"] = o43;
// 15342
o44 = {};
// 15343
o31["13"] = o44;
// 15344
o45 = {};
// 15345
o31["14"] = o45;
// 15346
o46 = {};
// 15347
o31["15"] = o46;
// 15348
o47 = {};
// 15349
o31["16"] = o47;
// 15350
o48 = {};
// 15351
o31["17"] = o48;
// undefined
o31 = null;
// 15352
// 15353
// 15354
o32.className = "fbChatSidebarBody";
// 15355
// 15356
// 15357
o33.className = "uiScrollableArea scrollableOrderedList fade";
// 15358
// 15359
// 15360
o34.className = "uiScrollableAreaWrap scrollable";
// 15361
// 15362
// 15363
o35.className = "uiScrollableAreaBody";
// 15364
// 15365
// 15366
o36.className = "uiScrollableAreaContent";
// 15367
// 15368
// 15369
o37.className = "phs fcg";
// 15370
// 15371
// 15372
o38.className = "uiScrollableAreaTrack invisible_elem";
// 15373
// 15374
// 15375
o39.className = "uiScrollableAreaGripper";
// 15376
// 15377
// 15378
o40.className = "fbChatTypeaheadView hidden_elem";
// 15379
// 15380
// 15381
o41.className = "fbChatSidebarMessage clearfix";
// 15382
// 15383
// 15384
o42.className = "message fcg";
// 15385
// 15386
// 15387
o30.className = "uiTypeahead uiClearableTypeahead fbChatTypeahead";
// 15388
// 15389
// 15390
o43.className = "wrap";
// 15391
// 15392
// 15393
o44.className = "innerWrap";
// 15394
// 15395
// 15396
o45.className = "uiSelector inlineBlock fbChatSidebarDropdown button uiSelectorBottomUp uiSelectorRight";
// 15397
// 15398
// 15399
o46.className = "wrap";
// 15400
// 15401
// 15402
o47.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 15403
// 15404
// 15405
o48.className = "uiMenu uiSelectorMenu";
// 15406
// 15407
// 15408
// 15409
// 15411
// 15412
// 15413
o31 = {};
// 15414
f925563445_577.returns.push(o31);
// 15415
o31.length = 18;
// 15416
o31["0"] = o32;
// 15417
o31["1"] = o33;
// 15418
o31["2"] = o34;
// 15419
o31["3"] = o35;
// 15420
o31["4"] = o36;
// 15421
o31["5"] = o37;
// 15422
o31["6"] = o38;
// 15423
o31["7"] = o39;
// 15424
o31["8"] = o40;
// 15425
o31["9"] = o41;
// 15426
o31["10"] = o42;
// 15427
o31["11"] = o30;
// 15428
o31["12"] = o43;
// 15429
o31["13"] = o44;
// 15430
o31["14"] = o45;
// 15431
o31["15"] = o46;
// 15432
o31["16"] = o47;
// 15433
o31["17"] = o48;
// undefined
o31 = null;
// 15434
// 15435
// 15437
// 15438
// 15440
// 15441
// 15443
// 15444
// 15446
// 15447
// 15449
// 15450
// 15452
// 15453
// 15455
// 15456
// 15458
// 15459
// 15461
// 15462
// 15464
// 15465
// 15467
// 15468
// 15470
// 15471
// 15473
// 15474
// 15476
// 15477
// 15479
// 15480
// 15482
// 15483
// 15485
// 15486
// 15488
// 15489
o41.getElementsByTagName = f925563445_577;
// undefined
o41 = null;
// 15490
// 15491
// 15492
o31 = {};
// 15493
f925563445_577.returns.push(o31);
// 15494
o31.length = 1;
// 15495
o31["0"] = o42;
// undefined
o31 = null;
// 15496
// 15497
// 15499
// 15500
// 15501
// 15502
// 15503
o32.getElementsByTagName = f925563445_577;
// undefined
o32 = null;
// 15504
// 15505
// 15506
o31 = {};
// 15507
f925563445_577.returns.push(o31);
// 15508
o31.length = 8;
// 15509
o31["0"] = o33;
// 15510
o31["1"] = o34;
// 15511
o31["2"] = o35;
// 15512
o31["3"] = o36;
// 15513
o31["4"] = o37;
// 15514
o31["5"] = o38;
// 15515
o31["6"] = o39;
// 15516
o31["7"] = o40;
// undefined
o31 = null;
// 15517
// 15518
// 15520
// 15521
// 15523
// 15524
// 15526
// 15527
// 15529
// 15530
// 15532
// 15533
// 15535
// 15536
// 15538
// 15539
// 15541
// 15542
// 15543
// 15544
// 15545
// 15546
o34.nodeName = "DIV";
// 15547
// 15548
// 15549
// 15550
// 15552
o34.nodeType = 1;
// 15553
// 15554
o29.nodeName = "UL";
// 15555
// 15556
// 15557
// 15558
// 15560
o29.nodeType = 1;
// 15561
f925563445_1001 = function() { return f925563445_1001.returns[f925563445_1001.inst++]; };
f925563445_1001.returns = [];
f925563445_1001.inst = 0;
// 15562
o34.contains = f925563445_1001;
// 15564
// 15565
f925563445_1001.returns.push(true);
// 15566
// 15567
// 15568
// 15569
// 15570
// 15571
// 15572
// 15573
// 15574
// 15575
// 15576
// 15577
// 15578
// 15579
// 15580
// 15581
// 15582
// 15584
// 15585
// 15586
// 15587
// 15588
// 15589
// 15590
// 15593
o0.nodeName = "#document";
// 15594
// 15595
// undefined
fo925563445_1___FB_TOKEN = function() { return fo925563445_1___FB_TOKEN.returns[fo925563445_1___FB_TOKEN.inst++]; };
fo925563445_1___FB_TOKEN.returns = [];
fo925563445_1___FB_TOKEN.inst = 0;
defineGetter(o0, "__FB_TOKEN", fo925563445_1___FB_TOKEN);
// undefined
fo925563445_1___FB_TOKEN.returns.push(null);
// 15598
o0.getAttribute = null;
// 15599
// 15600
// 15601
// 15602
// 15603
// 15604
// 15605
// 15606
// 15607
o31 = {};
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 15609
o31["0"] = 48;
// 15612
// 15613
f925563445_433.returns.push(undefined);
// 15614
// 15615
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 15618
o0.onmousemove = null;
// 15620
// 15621
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 15623
// 15624
// 15627
// 15628
// 15629
// 15630
// 15631
// 15632
// 15633
// 15634
// 15635
// 15636
// 15637
// 15638
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 15639
// 15640
// 15641
// 15642
// 15643
// 15644
// 15645
// 15646
// 15647
// 15648
// 15649
// 15650
// 15651
// 15652
// 15653
// 15654
// 15655
// 15656
// 15657
// 15658
// 15659
// 15660
// 15661
// 15662
// 15663
// 15664
// 15665
// 15666
// 15667
// 15668
// 15669
// 15670
// 15671
// 15672
// 15673
// 15674
// 15675
// 15676
// 15677
// 15678
// 15679
// 15680
// 15681
// 15682
// 15683
// 15684
// 15685
// 15686
// 15687
// 15688
// 15689
// 15690
// 15691
// 15692
// 15693
// 15694
// 15695
// 15696
// 15697
// 15698
// 15699
// 15700
// 15701
// 15702
// 15703
// 15704
// 15705
// 15706
// 15707
// 15708
// 15709
// 15710
// 15711
// 15712
// 15713
// 15714
// 15715
// 15716
// 15717
// 15718
// 15719
// 15720
// 15722
// 15723
f925563445_457.returns.push(o33);
// 15724
// 15725
// 15726
// 15727
// 15728
// 15729
o33.getElementsByTagName = f925563445_577;
// 15730
// 15731
// 15732
o32 = {};
// 15733
f925563445_577.returns.push(o32);
// 15734
o32.length = 6;
// 15735
o32["0"] = o34;
// 15736
o32["1"] = o35;
// 15737
o32["2"] = o36;
// 15738
o32["3"] = o37;
// 15739
o32["4"] = o38;
// 15740
o32["5"] = o39;
// undefined
o32 = null;
// 15741
// 15742
// 15744
// 15745
// 15747
// 15748
// 15750
// 15751
// 15753
// 15754
// 15756
// 15757
// 15759
// 15760
// 15761
// 15762
// 15763
o34.getElementsByTagName = f925563445_577;
// 15764
// 15765
// 15766
o32 = {};
// 15767
f925563445_577.returns.push(o32);
// 15768
o32.length = 3;
// 15769
o32["0"] = o35;
// 15770
o32["1"] = o36;
// 15771
o32["2"] = o37;
// undefined
o32 = null;
// 15772
// 15773
// 15775
// 15776
// 15778
// 15779
// 15781
// 15782
// 15783
// 15784
// 15786
// 15787
// 15788
o32 = {};
// 15789
f925563445_577.returns.push(o32);
// 15790
o32.length = 6;
// 15791
o32["0"] = o34;
// 15792
o32["1"] = o35;
// 15793
o32["2"] = o36;
// undefined
o36 = null;
// 15794
o32["3"] = o37;
// undefined
o37 = null;
// 15795
o32["4"] = o38;
// 15796
o32["5"] = o39;
// undefined
o32 = null;
// 15797
// 15798
// 15800
// 15801
// 15803
// 15804
// 15806
// 15807
// 15809
// 15810
// 15812
// 15813
// 15815
// 15816
// 15817
// 15818
// 15819
o38.getElementsByTagName = f925563445_577;
// 15820
// 15821
// 15822
o32 = {};
// 15823
f925563445_577.returns.push(o32);
// 15824
o32.length = 1;
// 15825
o32["0"] = o39;
// undefined
o32 = null;
// 15826
// 15827
// 15829
// 15830
o33.clientHeight = 0;
// 15831
o35.offsetHeight = 0;
// undefined
o35 = null;
// 15832
o38.offsetHeight = 0;
// undefined
o38 = null;
// 15833
// 15834
// 15835
// 15836
// 15837
// 15840
// 15841
// 15842
o34.scrollTop = 0;
// 15843
o34.scrollHeight = 0;
// 15844
o34.clientHeight = 0;
// 15845
// 15846
// 15847
// 15848
// 15849
// 15851
// 15852
// 15853
// 15854
// 15855
// 15858
// 15859
// 15860
// 15861
// 15862
// 15863
// 15864
// 15868
// 15869
// undefined
fo925563445_983___FB_TOKEN = function() { return fo925563445_983___FB_TOKEN.returns[fo925563445_983___FB_TOKEN.inst++]; };
fo925563445_983___FB_TOKEN.returns = [];
fo925563445_983___FB_TOKEN.inst = 0;
defineGetter(o34, "__FB_TOKEN", fo925563445_983___FB_TOKEN);
// undefined
fo925563445_983___FB_TOKEN.returns.push(null);
// 15872
o34.getAttribute = f925563445_468;
// 15874
// 15875
f925563445_468.returns.push(null);
// 15876
// 15877
// 15878
// 15879
// 15880
// 15881
// 15882
// 15883
// 15884
o32 = {};
// undefined
fo925563445_983___FB_TOKEN.returns.push(o32);
// 15886
o32["0"] = 49;
// 15887
o34.JSBNG__addEventListener = f925563445_433;
// 15889
// 15890
f925563445_433.returns.push(undefined);
// 15891
// 15892
// undefined
fo925563445_983___FB_TOKEN.returns.push(o32);
// undefined
o32 = null;
// 15895
o34.onjsbng__scroll = null;
// undefined
o34 = null;
// 15897
// 15898
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 15900
// 15901
// 15902
// 15903
// 15904
// 15905
// 15906
// 15907
// 15908
// 15909
// 15910
// 15913
o33.nodeName = "DIV";
// 15914
// 15915
// undefined
fo925563445_982___FB_TOKEN = function() { return fo925563445_982___FB_TOKEN.returns[fo925563445_982___FB_TOKEN.inst++]; };
fo925563445_982___FB_TOKEN.returns = [];
fo925563445_982___FB_TOKEN.inst = 0;
defineGetter(o33, "__FB_TOKEN", fo925563445_982___FB_TOKEN);
// undefined
fo925563445_982___FB_TOKEN.returns.push(null);
// 15918
o33.getAttribute = f925563445_468;
// 15920
// 15921
f925563445_468.returns.push(null);
// 15922
// 15923
// 15924
// 15925
// 15926
// 15927
// 15928
// 15929
// 15930
// 15931
o32 = {};
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 15933
o32["0"] = 50;
// 15934
o33.JSBNG__addEventListener = f925563445_433;
// 15936
// 15937
f925563445_433.returns.push(undefined);
// 15938
// 15939
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 15942
o33.onmouseover = null;
// 15944
// 15945
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 15947
// 15948
// 15949
// 15950
// 15951
// 15952
// 15953
// 15954
// 15955
// 15956
// 15957
// 15961
// 15962
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 15965
// 15966
// 15967
// 15968
// 15969
// 15970
// 15971
// 15972
// 15973
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 15976
// 15977
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 15979
// 15980
// 15981
// 15982
// 15983
// 15984
// 15985
// 15989
// 15990
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 15993
// 15994
// 15995
// 15996
// 15997
// 15998
// 15999
// 16000
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 16005
// 16006
f925563445_433.returns.push(undefined);
// 16007
// 16008
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 16011
o33.onmousemove = null;
// 16013
// 16014
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16016
// 16017
// 16018
// 16019
// 16020
// 16021
// 16022
// 16023
// 16024
// 16025
// 16026
// 16030
// 16031
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 16034
// 16035
// 16036
// 16037
// 16038
// 16039
// 16040
// 16041
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 16046
// 16047
f925563445_433.returns.push(undefined);
// 16048
// 16049
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// 16052
o33.onmouseout = null;
// undefined
o33 = null;
// 16054
// 16055
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16056
// 16057
// 16059
// 16060
// 16061
// 16062
// 16063
// 16064
// 16065
// 16068
o39.nodeName = "DIV";
// 16069
// 16070
// undefined
fo925563445_988___FB_TOKEN = function() { return fo925563445_988___FB_TOKEN.returns[fo925563445_988___FB_TOKEN.inst++]; };
fo925563445_988___FB_TOKEN.returns = [];
fo925563445_988___FB_TOKEN.inst = 0;
defineGetter(o39, "__FB_TOKEN", fo925563445_988___FB_TOKEN);
// undefined
fo925563445_988___FB_TOKEN.returns.push(null);
// 16073
o39.getAttribute = f925563445_468;
// 16075
// 16076
f925563445_468.returns.push(null);
// 16077
// 16078
// 16079
// 16080
// 16081
// 16082
// 16083
// 16084
// 16085
o33 = {};
// undefined
fo925563445_988___FB_TOKEN.returns.push(o33);
// 16087
o33["0"] = 51;
// 16088
o39.JSBNG__addEventListener = f925563445_433;
// 16090
// 16091
f925563445_433.returns.push(undefined);
// 16092
// 16093
// undefined
fo925563445_988___FB_TOKEN.returns.push(o33);
// undefined
o33 = null;
// 16096
o39.onmousedown = null;
// undefined
o39 = null;
// 16098
// 16099
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16100
// 16101
// 16102
// 16103
// 16104
// 16105
// 16106
// 16107
// 16108
// 16109
// 16110
// 16111
// 16112
// 16113
// 16114
// 16115
// undefined
fo925563445_982___FB_TOKEN.returns.push(o32);
// undefined
o32 = null;
// 16118
// 16119
// 16120
// 16122
// 16123
f925563445_457.returns.push(o45);
// 16124
// 16125
// 16126
// 16127
// 16128
// 16129
// 16130
// 16131
// 16132
// 16133
// 16134
// 16135
// 16136
// 16137
// 16138
// 16139
// 16140
// 16141
// 16142
// 16143
// 16144
// 16145
// 16146
// 16147
// 16148
// 16149
// 16150
// 16151
// 16152
// 16153
// 16154
// 16155
// 16156
// 16157
// 16158
// 16159
// 16160
// 16161
// 16162
// 16163
// 16164
// 16165
// 16166
// 16167
// 16168
// 16169
// 16170
// 16171
// 16172
// 16173
// 16174
// 16175
// 16177
// 16178
// 16179
// 16180
// 16181
// 16182
// 16183
// 16187
// 16188
// undefined
fo925563445_978___FB_TOKEN = function() { return fo925563445_978___FB_TOKEN.returns[fo925563445_978___FB_TOKEN.inst++]; };
fo925563445_978___FB_TOKEN.returns = [];
fo925563445_978___FB_TOKEN.inst = 0;
defineGetter(o29, "__FB_TOKEN", fo925563445_978___FB_TOKEN);
// undefined
fo925563445_978___FB_TOKEN.returns.push(null);
// 16191
o29.getAttribute = f925563445_468;
// 16193
// 16194
f925563445_468.returns.push(null);
// 16195
// 16196
// 16197
// 16198
// 16199
// 16200
// 16201
// 16202
// 16203
o32 = {};
// undefined
fo925563445_978___FB_TOKEN.returns.push(o32);
// 16205
o32["0"] = 52;
// 16206
o29.JSBNG__addEventListener = f925563445_433;
// 16208
// 16209
f925563445_433.returns.push(undefined);
// 16210
// 16211
// undefined
fo925563445_978___FB_TOKEN.returns.push(o32);
// undefined
o32 = null;
// 16214
o29.onclick = null;
// undefined
o29 = null;
// 16216
// 16217
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16218
// 16219
// 16220
// 16221
// 16222
// 16223
// 16224
// 16225
// 16226
// 16227
// 16228
// 16229
// 16230
// 16231
// 16232
// 16233
// 16234
// 16235
// 16236
// 16237
// 16238
// 16239
// 16240
// 16241
// 16242
// 16243
// 16244
// 16245
// 16246
// 16247
// 16248
// 16249
// 16250
// 16251
// 16252
// 16253
// 16254
// 16255
// 16256
// 16257
// 16258
// 16259
// 16260
// 16261
// 16262
// 16263
// 16264
// 16265
// 16266
// 16267
// 16268
// 16269
// 16270
// 16271
// 16272
// 16273
// 16274
// 16275
// 16276
// 16277
// 16278
// 16279
// 16280
// 16281
// 16282
// 16283
// 16284
// 16285
// 16286
// 16287
// 16288
// 16289
// 16290
// 16291
// 16292
// 16293
// 16295
// 16296
o29 = {};
// 16297
f925563445_457.returns.push(o29);
// 16298
// 16299
// 16300
// 16303
// 16304
// 16305
// 16306
// 16307
o29.offsetWidth = 30;
// 16308
o29.offsetHeight = 25;
// 16309
// 16310
// 16311
// 16313
// 16314
o32 = {};
// 16315
f925563445_457.returns.push(o32);
// 16316
// 16317
// 16318
// 16319
o33 = {};
// 16320
f925563445_4.returns.push(o33);
// 16321
o33.getPropertyValue = f925563445_461;
// undefined
o33 = null;
// 16322
// 16323
// 16324
f925563445_461.returns.push("relative");
// 16325
// 16326
// 16327
// 16328
// 16329
o32.offsetWidth = 1265;
// 16330
o32.offsetHeight = 38;
// undefined
o32 = null;
// 16331
// 16332
// 16333
// 16334
// 16335
// 16336
// 16337
// 16339
// 16340
// 16341
// 16342
// 16343
// 16344
// 16345
// 16349
// 16350
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 16353
// 16354
// 16355
// 16356
// 16357
// 16358
// 16359
// 16360
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 16363
// 16364
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16366
// 16367
// 16368
// 16369
// 16370
// 16371
// 16372
// 16375
o29.nodeName = "DIV";
// 16376
// 16377
// undefined
fo925563445_1011___FB_TOKEN = function() { return fo925563445_1011___FB_TOKEN.returns[fo925563445_1011___FB_TOKEN.inst++]; };
fo925563445_1011___FB_TOKEN.returns = [];
fo925563445_1011___FB_TOKEN.inst = 0;
defineGetter(o29, "__FB_TOKEN", fo925563445_1011___FB_TOKEN);
// undefined
fo925563445_1011___FB_TOKEN.returns.push(null);
// 16380
o29.getAttribute = f925563445_468;
// 16382
// 16383
f925563445_468.returns.push(null);
// 16384
// 16385
// 16386
// 16387
// 16388
// 16389
// 16390
// 16391
// 16392
o32 = {};
// undefined
fo925563445_1011___FB_TOKEN.returns.push(o32);
// 16394
o32["0"] = 53;
// 16395
o29.JSBNG__addEventListener = f925563445_433;
// 16397
// 16398
f925563445_433.returns.push(undefined);
// 16399
// 16400
// undefined
fo925563445_1011___FB_TOKEN.returns.push(o32);
// undefined
o32 = null;
// 16403
o29.onclick = null;
// 16405
// 16406
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16408
// 16409
// 16410
// 16411
// 16412
// 16413
// 16414
// 16417
// 16418
// 16419
// 16420
// 16421
// 16422
// 16423
// 16424
// 16425
// 16426
// 16427
// 16428
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16429
// 16430
// 16431
// 16432
// 16433
// 16434
// 16435
// 16436
// 16437
// 16438
// 16439
// 16440
// 16441
// 16442
// 16443
// 16444
// 16445
// 16446
// 16447
// 16448
// 16449
// 16450
// 16451
// 16452
// 16453
// 16454
// 16455
// 16456
// 16457
// 16458
// 16459
// 16460
// 16461
// 16462
// 16463
// 16464
// 16465
o29.getElementsByTagName = f925563445_577;
// undefined
o29 = null;
// 16466
// 16467
// 16468
o29 = {};
// 16469
f925563445_577.returns.push(o29);
// 16470
o29.length = 9;
// 16471
o32 = {};
// 16472
o29["0"] = o32;
// 16473
o33 = {};
// 16474
o29["1"] = o33;
// 16475
o34 = {};
// 16476
o29["2"] = o34;
// 16477
o35 = {};
// 16478
o29["3"] = o35;
// 16479
o36 = {};
// 16480
o29["4"] = o36;
// 16481
o37 = {};
// 16482
o29["5"] = o37;
// 16483
o38 = {};
// 16484
o29["6"] = o38;
// 16485
o39 = {};
// 16486
o29["7"] = o39;
// 16487
o41 = {};
// 16488
o29["8"] = o41;
// undefined
o29 = null;
// 16489
// 16490
// 16491
o32.className = "fbNubButton";
// undefined
o32 = null;
// 16492
// 16493
// 16494
o33.className = "fbNubButton";
// undefined
o33 = null;
// 16495
// 16496
// 16497
o34.className = "fbNubButton";
// 16498
// 16499
// 16500
o35.className = "uiSelectorButton uiCloseButton";
// 16501
// 16502
// 16503
o36.className = "itemAnchor";
// 16504
// 16505
// 16506
o37.className = "itemAnchor";
// 16507
// 16508
// 16509
o38.className = "itemAnchor";
// 16510
// 16511
// 16512
o39.className = "uiTooltip fbNubButton";
// 16513
// 16514
// 16515
o41.className = "uiTooltip fbNubButton";
// 16516
// 16517
// 16519
// 16520
// 16522
// 16523
// 16525
// 16526
// 16528
// 16529
// 16531
// 16532
// 16533
// 16534
// 16535
// 16536
// 16537
// 16538
// 16539
// 16540
// 16541
// 16542
// 16543
// 16544
// 16545
o39.getElementsByTagName = f925563445_577;
// undefined
o39 = null;
// 16546
// 16547
// 16548
o29 = {};
// 16549
f925563445_577.returns.push(o29);
// 16550
o29.length = 2;
// 16551
o32 = {};
// 16552
o29["0"] = o32;
// 16553
o33 = {};
// 16554
o29["1"] = o33;
// undefined
o29 = null;
// 16555
// 16556
// 16557
o32.className = "uiTooltipWrap top right righttop";
// undefined
o32 = null;
// 16558
// 16559
// 16560
o33.className = "uiTooltipText uiTooltipNoWrap";
// undefined
o33 = null;
// 16561
// 16562
// 16564
// 16565
// 16566
// 16567
// 16568
// 16569
// 16570
// 16571
// 16572
// 16573
// 16574
o41.getElementsByTagName = f925563445_577;
// 16575
// 16576
// 16577
o29 = {};
// 16578
f925563445_577.returns.push(o29);
// 16579
o29.length = 2;
// 16580
o32 = {};
// 16581
o29["0"] = o32;
// 16582
o33 = {};
// 16583
o29["1"] = o33;
// undefined
o29 = null;
// 16584
// 16585
// 16586
o32.className = "uiTooltipWrap top right righttop";
// 16587
// 16588
// 16589
o33.className = "uiTooltipText uiTooltipNoWrap";
// 16590
// 16591
// 16593
// 16594
// 16595
// 16596
// 16597
// 16598
// 16599
// 16600
// 16601
// 16602
// 16603
// 16604
// 16605
// 16606
// 16607
// 16608
// 16609
// 16610
// 16611
// 16612
// 16613
// 16614
// 16615
// 16616
// 16617
// 16618
// 16619
// 16622
// 16623
// 16627
// 16628
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 16631
// 16632
// 16633
// 16634
// 16635
// 16636
// 16637
// 16638
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 16641
// 16642
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16643
// 16644
// 16645
// 16646
// 16647
// 16648
// 16649
// 16650
// 16651
// 16652
// 16653
// 16654
// 16655
// 16656
// 16657
// 16658
// 16659
// 16660
// 16662
// 16663
o29 = {};
// 16664
f925563445_457.returns.push(o29);
// 16665
// 16666
// 16667
// 16668
// 16669
f925563445_426.returns.push(0.9433215027675033);
// 16671
// 16672
// 16673
// 16674
// 16675
// 16676
// 16677
// 16680
o29.nodeName = "IFRAME";
// 16681
// 16682
// undefined
fo925563445_1031___FB_TOKEN = function() { return fo925563445_1031___FB_TOKEN.returns[fo925563445_1031___FB_TOKEN.inst++]; };
fo925563445_1031___FB_TOKEN.returns = [];
fo925563445_1031___FB_TOKEN.inst = 0;
defineGetter(o29, "__FB_TOKEN", fo925563445_1031___FB_TOKEN);
// undefined
fo925563445_1031___FB_TOKEN.returns.push(null);
// 16685
o29.getAttribute = f925563445_468;
// 16687
// 16688
f925563445_468.returns.push(null);
// 16689
// 16690
// 16691
// 16692
// 16693
// 16694
// 16695
// 16696
// 16697
o39 = {};
// undefined
fo925563445_1031___FB_TOKEN.returns.push(o39);
// 16699
o39["0"] = 54;
// 16700
o29.JSBNG__addEventListener = f925563445_433;
// 16702
// 16703
f925563445_433.returns.push(undefined);
// 16704
// 16705
// undefined
fo925563445_1031___FB_TOKEN.returns.push(o39);
// undefined
o39 = null;
// 16708
o29.onload = null;
// undefined
o29 = null;
// 16710
// 16711
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16712
// 16713
// 16714
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199");
// 16716
// 16717
// 16718
// 16719
// 16720
// 16721
// 16722
// 16723
// 16724
// 16725
// 16726
// 16727
// 16728
// 16729
// 16730
// 16731
// 16732
// 16733
// 16734
// 16735
// 16736
f925563445_7.returns.push(undefined);
// 16737
// 16738
// 16739
// 16740
// 16741
// 16742
// 16744
// 16745
// 16746
// 16747
// 16748
// 16749
// 16750
// 16753
// 16754
// 16755
// 16756
// 16757
// 16758
// 16759
// 16760
// 16761
// 16762
// 16763
// 16764
f925563445_7.returns.push(undefined);
// 16765
// 16766
// 16767
// 16768
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16770
// 16771
// 16772
// 16773
// 16774
// 16775
// 16776
// 16779
// 16780
// 16781
// 16782
// 16783
// 16784
// 16785
// 16786
// 16787
// 16788
// 16789
// 16790
f925563445_7.returns.push(undefined);
// 16791
// 16792
// 16793
// 16794
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 16795
// 16796
// 16797
// 16798
// 16799
// 16800
// 16801
// 16802
// 16803
// 16804
// 16805
// 16806
// 16807
// 16808
// 16809
// 16810
// 16811
// 16812
// 16813
// 16814
// 16815
// 16816
// 16817
// 16818
// 16819
// 16820
// 16821
// 16822
o29 = {};
// 16823
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 16824
// 16825
// 16826
f925563445_426.returns.push(0.4313518274575472);
// 16827
// 16828
// 16829
// 16830
f925563445_12.returns.push(13);
// 16831
// 16832
// 16833
// 16834
// 16835
// 16836
// 16837
// 16838
// 16839
// 16840
// 16841
// 16842
// 16843
o29 = {};
// 16844
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 16845
// 16846
// 16847
// 16848
// 16849
f925563445_1035 = function() { return f925563445_1035.returns[f925563445_1035.inst++]; };
f925563445_1035.returns = [];
f925563445_1035.inst = 0;
// 16850
o1.setItem = f925563445_1035;
// 16851
// 16852
f925563445_1035.returns.push(undefined);
// 16853
// 16855
// 16856
f925563445_1035.returns.push(undefined);
// 16857
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199");
// 16859
// 16860
o29 = {};
// 16861
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199");
// 16863
// 16864
// 16866
// 16867
// 16868
f925563445_432.returns.push("[\"wOYp\",null,\"channel-connectivity\",{\"idle\":null},4]");
// 16869
// 16871
// 16872
// 16873
f925563445_1037 = function() { return f925563445_1037.returns[f925563445_1037.inst++]; };
f925563445_1037.returns = [];
f925563445_1037.inst = 0;
// 16874
o1.removeItem = f925563445_1037;
// undefined
o1 = null;
// 16875
// 16876
// 16877
f925563445_1037.returns.push(undefined);
// 16878
// 16880
// 16881
f925563445_1035.returns.push(undefined);
// 16882
// 16883
// 16884
o1 = {};
// 16885
f925563445_0.returns.push(o1);
// undefined
o1 = null;
// 16886
// 16887
// 16888
// 16889
f925563445_12.returns.push(14);
// 16890
// 16891
// 16892
// 16893
// 16894
// 16895
// 16896
// 16897
// 16898
// 16899
// 16900
// 16901
// 16902
// 16903
// 16904
// 16905
// 16906
// 16907
// 16908
// 16909
// 16910
// 16911
// 16912
// 16913
// 16914
// 16915
// 16916
// 16917
// 16918
// 16919
// 16920
// 16921
// 16922
// 16923
// 16924
// 16925
// 16926
// 16927
// 16928
// 16929
// 16930
// 16931
// 16932
// 16933
// 16934
// 16935
// 16936
// 16937
// 16938
// 16939
// 16940
// 16941
// 16942
// 16943
// 16944
// 16945
// 16946
// 16947
// 16948
// 16949
// 16950
// 16951
// 16952
// 16953
// 16954
// 16955
// 16956
// 16957
// 16958
// 16959
// 16960
// 16961
// 16962
// 16963
// 16964
// 16965
// 16966
// 16967
// 16968
// 16969
// 16970
// 16971
// 16972
// 16973
// 16974
// 16975
// 16976
// 16977
// 16978
// 16979
// 16980
// 16981
// 16982
// 16983
// 16984
// 16985
// 16986
// 16987
// 16988
// 16989
// 16990
// 16991
// 16992
// 16993
// 16994
// 16995
// 16996
// 16997
// 16998
// 16999
// 17000
// 17001
// 17002
// 17003
// 17004
// 17005
// 17006
// 17007
// 17008
// 17009
// 17010
// 17011
// 17012
// 17013
// 17014
// 17015
// 17016
// 17017
o1 = {};
// 17018
f925563445_0.returns.push(o1);
// 17019
o1.getTime = f925563445_435;
// undefined
o1 = null;
// 17020
// 17021
f925563445_435.returns.push(1318265708653);
// 17022
// 17023
// 17024
// 17025
o1 = {};
// 17026
f925563445_0.returns.push(o1);
// 17027
o1.getTime = f925563445_435;
// undefined
o1 = null;
// 17028
// 17029
f925563445_435.returns.push(1318265708653);
// 17030
// 17031
// 17032
// 17034
// 17035
o1 = {};
// 17036
f925563445_457.returns.push(o1);
// 17037
// 17038
// 17039
// 17040
// 17041
// 17042
// 17043
// 17044
// 17045
// 17046
// 17047
// 17048
// 17049
// 17050
// 17051
// 17052
// 17053
// 17054
// 17055
// 17056
// 17057
// 17058
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 17060
// 17061
// 17062
// 17063
// 17064
// 17065
// 17066
// 17067
// 17068
// 17069
// 17070
// 17071
// 17072
// 17073
// 17074
// 17075
// 17076
// 17077
// 17078
// 17079
f925563445_13.returns.push(15);
// 17080
// 17081
// 17082
// 17083
// 17084
// 17085
// 17086
// 17087
// 17088
// 17089
o1.className = "fbNubGroup clearfix offline";
// 17090
// 17091
// 17092
// 17093
// 17094
// 17095
// 17096
// 17097
// 17098
// 17099
// 17100
// 17101
// 17102
// 17103
// 17104
// 17105
// 17106
// 17107
// 17108
// 17109
// 17110
// 17111
// 17112
// 17113
// 17114
// 17115
// 17116
// 17117
// 17118
// 17119
// 17120
// 17121
f925563445_12.returns.push(16);
// 17122
// 17123
// 17124
// 17125
// 17126
// 17127
// 17128
o29 = {};
// 17129
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 17130
// 17131
// 17132
// 17133
// 17134
// 17135
// 17136
// 17137
// 17138
f925563445_12.returns.push(17);
// 17139
// 17140
// 17141
// 17142
// 17143
// 17144
// 17145
// 17146
// 17147
// 17148
o29 = {};
// 17149
f925563445_0.returns.push(o29);
// 17150
o29.getTime = f925563445_435;
// undefined
o29 = null;
// 17151
// 17152
f925563445_435.returns.push(1318265708658);
// 17153
// 17154
// 17155
// 17156
// 17157
// 17158
// 17159
// 17160
// 17161
// 17162
// 17163
o29 = {};
// 17164
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 17165
// 17166
// 17167
// 17168
// 17170
// 17171
f925563445_1035.returns.push(undefined);
// 17172
// 17174
// 17175
f925563445_1035.returns.push(undefined);
// 17176
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 17178
// 17179
o29 = {};
// 17180
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 17182
// 17183
// 17185
// 17186
// 17187
f925563445_432.returns.push("[\"wOYp\",null,\"realtime-error\",{\"data\":\"13003:warning:presence:displaying_shutdown:connection_shutdown\"},4]");
// 17188
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 17191
// 17193
// 17194
// 17196
// 17197
// 17198
f925563445_1037.returns.push(undefined);
// 17199
// 17201
// 17202
f925563445_1035.returns.push(undefined);
// 17203
// 17204
// 17205
o29 = {};
// 17206
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 17207
// 17208
// 17209
// 17210
// 17211
o29 = {};
// 17212
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 17213
// 17214
// 17215
// 17216
// 17218
// 17219
f925563445_1035.returns.push(undefined);
// 17220
// 17222
// 17223
f925563445_1035.returns.push(undefined);
// 17224
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D");
// 17226
// 17227
o29 = {};
// 17228
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D");
// 17230
// 17231
// 17233
// 17234
// 17235
f925563445_432.returns.push("[\"wOYp\",null,\"realtime-error\",{\"data\":\"13001:shutdown:presence:connection_shutdown\"},4]");
// 17236
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D");
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D");
// 17239
// 17241
// 17242
// 17244
// 17245
// 17246
f925563445_1037.returns.push(undefined);
// 17247
// 17249
// 17250
f925563445_1035.returns.push(undefined);
// 17251
// 17252
// 17253
o29 = {};
// 17254
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 17255
// 17256
// 17257
// 17258
// 17259
// 17260
// 17261
// 17262
// 17264
// 17265
o29 = {};
// 17266
f925563445_457.returns.push(o29);
// 17267
// 17268
// 17269
// 17270
// 17271
o29.getElementsByTagName = f925563445_577;
// undefined
o29 = null;
// 17272
// 17273
// 17274
o29 = {};
// 17275
f925563445_577.returns.push(o29);
// 17276
o29.length = 1;
// 17277
o29["0"] = o41;
// undefined
o29 = null;
// undefined
o41 = null;
// 17278
// 17279
// 17281
// 17282
// 17283
// 17284
// 17285
// 17287
// 17288
// 17289
// 17290
// 17291
// 17293
// 17294
// 17295
// 17297
// 17298
// 17299
// 17300
// 17302
// 17303
// 17304
o29 = {};
// 17305
f925563445_577.returns.push(o29);
// 17306
o29.length = 2;
// 17307
o29["0"] = o32;
// undefined
o32 = null;
// 17308
o29["1"] = o33;
// undefined
o29 = null;
// 17309
// 17310
// 17312
// 17313
// 17315
// 17316
// 17317
o33.nodeName = "SPAN";
// 17318
// 17319
// 17320
o29 = {};
// undefined
fo925563445_1030_firstChild = function() { return fo925563445_1030_firstChild.returns[fo925563445_1030_firstChild.inst++]; };
fo925563445_1030_firstChild.returns = [];
fo925563445_1030_firstChild.inst = 0;
defineGetter(o33, "firstChild", fo925563445_1030_firstChild);
// undefined
fo925563445_1030_firstChild.returns.push(o29);
// undefined
fo925563445_1030_firstChild.returns.push(o29);
// 17323
// 17324
// 17325
o29.parentNode = o33;
// 17327
o33.removeChild = f925563445_465;
// 17328
// 17329
f925563445_465.returns.push(o29);
// undefined
o29 = null;
// undefined
fo925563445_1030_firstChild.returns.push(null);
// 17331
// 17332
// 17334
// 17335
// 17336
// 17338
// 17339
// 17340
// 17341
// 17343
o33.nodeType = 1;
// 17345
// 17346
o29 = {};
// 17347
f925563445_487.returns.push(o29);
// 17348
// 17349
// 17350
f925563445_1055 = function() { return f925563445_1055.returns[f925563445_1055.inst++]; };
f925563445_1055.returns = [];
f925563445_1055.inst = 0;
// 17351
o0.createTextNode = f925563445_1055;
// 17352
// 17353
o32 = {};
// 17354
f925563445_1055.returns.push(o32);
// 17355
o29.appendChild = f925563445_441;
// 17356
// 17357
f925563445_441.returns.push(o32);
// undefined
o32 = null;
// 17358
// 17359
o33.appendChild = f925563445_441;
// undefined
o33 = null;
// 17360
// 17361
f925563445_441.returns.push(o29);
// undefined
o29 = null;
// 17362
// 17363
// 17364
// 17365
// 17366
// 17367
// 17368
// 17369
// 17370
// 17371
// 17372
// 17373
// 17374
// 17375
// 17376
// 17377
// 17378
// 17379
// 17380
// 17381
// 17382
// 17383
// 17384
// 17385
// 17386
// 17387
// 17388
// 17389
// 17390
// 17391
// 17392
// 17393
// 17394
// 17395
// 17396
// 17397
// 17398
// 17399
// 17400
// 17401
// 17402
// 17403
// 17404
// 17405
// 17406
// 17407
// 17408
// 17409
// 17410
// 17411
// 17412
// 17413
// 17414
// 17415
// 17416
// 17417
// 17418
// 17419
o29 = {};
// 17420
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 17421
// 17422
// 17423
// 17424
// 17425
// 17426
// 17427
// 17428
f925563445_14.returns.push(undefined);
// 17429
// 17430
// 17431
// 17432
// 17433
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D; _e_wOYp_2=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213001%3Ashutdown%3Apresence%3Aconnection_shutdown%22%7D%2C4%5D");
// 17435
// 17436
// 17437
// 17438
// 17439
// 17440
// 17441
// 17442
// 17443
// 17444
// 17445
// 17446
// 17447
// 17448
// 17449
// 17450
// 17451
// 17452
// 17453
// 17454
// 17455
// 17456
// 17457
// 17458
// 17459
// 17460
// 17461
// 17462
f925563445_14.returns.push(undefined);
// 17463
// 17464
// 17465
// 17466
// 17467
// 17468
// 17469
// 17470
// 17471
// 17472
// 17473
// 17474
// 17475
// 17476
// 17477
// 17479
// 17480
f925563445_457.returns.push(o28);
// 17481
// 17482
// 17483
// 17484
// 17485
// 17486
// 17487
o28.className = "isOffline";
// 17488
// 17489
// 17490
// 17491
// 17492
// 17493
// 17494
// 17495
// 17496
// 17497
// 17498
// 17499
// 17500
// 17501
// 17502
// 17503
// 17504
// 17505
// 17506
// 17507
// 17508
// 17509
// 17510
// 17511
// 17512
// 17513
// 17514
// 17515
// 17516
// 17517
// 17518
// 17519
// 17520
// 17521
// 17522
// 17523
// 17524
// 17525
// 17526
// 17527
// 17528
// 17529
// 17530
// 17531
// 17532
// 17533
// 17534
// 17535
// 17536
// 17537
// 17538
// 17539
// 17540
// 17541
// 17542
// 17543
// 17544
// 17545
// 17546
// 17547
// 17548
// 17549
// 17550
// 17551
// 17552
// 17553
// 17554
// 17555
// 17556
// 17557
// 17558
// 17559
// 17560
// 17561
// 17562
// 17563
// 17564
// 17565
// 17566
// 17567
// 17568
// 17569
// 17570
// 17571
// 17572
// 17573
o29 = {};
// 17574
f925563445_0.returns.push(o29);
// undefined
o29 = null;
// 17575
// 17576
// 17577
// 17578
// 17579
// 17580
// 17581
// 17582
// 17583
// 17584
// 17585
// 17586
// 17587
// 17588
// 17589
// 17590
// 17591
// 17592
// 17593
// 17594
// 17595
// 17596
// 17597
// 17598
// 17599
// 17600
// 17601
// 17602
// 17603
// 17604
// 17605
// 17606
// 17607
// 17608
// 17609
// 17610
// 17611
// 17612
// 17613
// 17614
// 17615
// 17616
// 17617
// 17618
// 17619
// 17620
// 17621
// 17622
// 17623
// 17624
// 17625
// 17626
// 17627
// 17628
// 17629
// 17630
// 17631
// 17632
// 17634
// 17635
f925563445_457.returns.push(o28);
// undefined
o28 = null;
// 17636
// 17637
// 17638
// 17639
// 17640
// 17641
// 17643
// 17644
// 17645
// 17646
// 17647
// 17648
// 17649
// 17650
// 17651
// 17652
// 17653
// 17654
// 17655
// 17656
o42.nodeName = "DIV";
// 17657
// 17658
// 17659
o42.firstChild = null;
// 17660
// 17661
// 17663
// 17664
// 17665
// 17666
o42.innerHTML = "";
// 17667
// 17668
// 17669
// 17670
// 17671
o28 = {};
// 17672
o42.childNodes = o28;
// undefined
o42 = null;
// undefined
o28 = null;
// 17673
// 17674
// 17675
// 17676
// 17677
// 17678
// undefined
fo925563445_977_className = function() { return fo925563445_977_className.returns[fo925563445_977_className.inst++]; };
fo925563445_977_className.returns = [];
fo925563445_977_className.inst = 0;
defineGetter(o27, "className", fo925563445_977_className);
// undefined
o27 = null;
// undefined
fo925563445_977_className.returns.push("fbChatSidebar hidden_elem");
// undefined
fo925563445_977_className.returns.push("fbChatSidebar hidden_elem");
// 17682
// 17683
// 17684
// 17685
// 17686
// 17687
// 17688
// 17689
// 17690
// 17693
// 17694
// 17695
// 17696
// 17697
// 17698
// 17699
// 17700
// 17701
// 17702
// 17704
// 17705
// 17706
// 17707
// 17708
// undefined
fo925563445_427_className.returns.push(" sidebarMode ticker");
// 17710
// 17711
// 17712
// 17713
// 17714
// 17715
// 17716
// 17717
// undefined
fo925563445_977_className.returns.push("fbChatSidebar hidden_elem offline");
// 17720
// 17721
// 17722
// 17723
// undefined
fo925563445_427_className.returns.push(" sidebarMode ticker");
// undefined
fo925563445_427_className.returns.push(" sidebarMode ticker");
// 17727
// 17728
// 17729
// 17730
// 17731
// 17732
// 17733
// 17734
// 17735
// 17736
// 17737
// 17738
// 17739
// 17740
// 17741
// 17742
// 17743
// 17744
// 17745
// 17746
// 17747
// 17748
// 17749
// 17750
// 17751
// 17752
// 17753
// 17754
// 17755
// 17756
// 17757
// 17758
// 17759
// 17760
// 17761
// 17762
// 17763
// 17764
// 17765
// 17766
// 17767
// 17768
// 17769
// 17770
// 17771
// 17772
// 17773
// 17774
// 17775
// 17776
// 17777
// 17778
// 17779
// 17780
// 17781
// 17782
// 17783
// 17784
// 17785
// 17786
// 17787
// 17788
// 17789
// 17790
// 17791
// 17792
// 17793
// 17794
// 17795
// 17796
// 17797
// 17798
// 17799
// 17800
// 17801
// 17802
// 17803
// 17804
// 17805
// 17806
// 17807
// 17808
// 17809
// 17810
// 17811
// 17812
// 17813
// 17814
// 17815
// 17816
// 17817
// 17819
// 17820
f925563445_457.returns.push(o40);
// 17821
// 17822
// 17823
// 17824
// 17825
// 17827
// 17828
// 17829
// 17830
// 17831
// 17832
// 17833
// 17834
// 17835
// 17836
// 17837
// 17838
// 17842
// 17843
// 17844
o40.nodeName = "DIV";
// 17845
// 17846
// undefined
fo925563445_989___FB_TOKEN = function() { return fo925563445_989___FB_TOKEN.returns[fo925563445_989___FB_TOKEN.inst++]; };
fo925563445_989___FB_TOKEN.returns = [];
fo925563445_989___FB_TOKEN.inst = 0;
defineGetter(o40, "__FB_TOKEN", fo925563445_989___FB_TOKEN);
// undefined
fo925563445_989___FB_TOKEN.returns.push(null);
// 17849
o40.getAttribute = f925563445_468;
// 17851
// 17852
f925563445_468.returns.push(null);
// 17853
// 17854
// 17855
// 17856
// 17857
// 17858
// 17859
// 17860
// 17861
o27 = {};
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 17863
o27["0"] = 55;
// 17864
o40.JSBNG__addEventListener = f925563445_433;
// 17866
// 17867
f925563445_433.returns.push(undefined);
// 17868
// 17869
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 17872
o40.onmouseup = null;
// 17874
// 17875
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 17877
// 17878
// 17880
// 17881
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 17884
// 17885
// 17886
// 17887
// 17888
// 17889
// 17890
// 17891
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 17896
// 17897
f925563445_433.returns.push(undefined);
// 17898
// 17899
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 17902
o40.onmouseover = null;
// 17904
// 17905
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 17906
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 17907
// 17908
// 17909
// 17910
// 17911
// 17912
// 17913
// 17914
// 17915
// 17916
// 17917
// 17918
// 17919
// 17920
// 17921
// 17922
// 17923
// 17924
// 17925
// 17926
// 17927
o30.getElementsByTagName = f925563445_577;
// 17928
// 17929
// 17930
o28 = {};
// 17931
f925563445_577.returns.push(o28);
// 17932
o28.length = 7;
// 17933
o28["0"] = o43;
// 17934
o29 = {};
// 17935
o28["1"] = o29;
// 17936
o32 = {};
// 17937
o28["2"] = o32;
// 17938
o33 = {};
// 17939
o28["3"] = o33;
// 17940
o28["4"] = o44;
// 17941
o39 = {};
// 17942
o28["5"] = o39;
// 17943
o41 = {};
// 17944
o28["6"] = o41;
// undefined
o28 = null;
// 17945
// 17946
// 17948
// 17949
// 17950
o29.className = "clear uiCloseButton";
// undefined
o29 = null;
// 17951
// 17952
// 17953
o32.className = "";
// 17954
// 17955
// 17956
o33.className = "hiddenInput";
// 17957
// 17958
// 17960
// 17961
// undefined
fo925563445_1065_className = function() { return fo925563445_1065_className.returns[fo925563445_1065_className.inst++]; };
fo925563445_1065_className.returns = [];
fo925563445_1065_className.inst = 0;
defineGetter(o39, "className", fo925563445_1065_className);
// undefined
fo925563445_1065_className.returns.push("inputtext inputsearch textInput DOMControl_placeholder");
// 17963
// 17964
// 17965
o41.className = "uiLoadingIndicatorAsync img";
// undefined
o41 = null;
// 17966
// 17967
// 17968
// 17969
o39.getElementsByTagName = f925563445_577;
// 17970
// 17971
// 17972
o28 = {};
// 17973
f925563445_577.returns.push(o28);
// 17974
o28.length = 0;
// undefined
o28 = null;
// 17975
// 17976
// 17977
// 17978
// 17980
// 17981
// 17982
o28 = {};
// 17983
f925563445_577.returns.push(o28);
// 17984
o28.length = 2;
// 17985
o28["0"] = o43;
// undefined
o43 = null;
// 17986
o28["1"] = o44;
// undefined
o28 = null;
// undefined
o44 = null;
// 17987
// 17988
// 17990
// 17991
// 17993
// 17994
// 17995
// 17996
// 17998
// 17999
// 18000
o28 = {};
// 18001
f925563445_577.returns.push(o28);
// 18002
o28.length = 3;
// 18003
o28["0"] = o32;
// undefined
o32 = null;
// 18004
o28["1"] = o33;
// 18005
o28["2"] = o39;
// undefined
o28 = null;
// 18006
// 18007
// 18009
// 18010
// 18012
// 18013
// undefined
fo925563445_1065_className.returns.push("inputtext inputsearch textInput DOMControl_placeholder");
// 18015
// 18016
// 18017
// 18018
// 18019
// 18020
// 18021
// 18022
// 18023
// 18024
// 18025
// 18026
// 18027
// 18028
// 18029
// 18030
// 18031
// 18032
// 18033
// 18034
// 18035
// 18036
// 18037
// 18038
// 18039
// 18040
// 18041
// 18042
// 18043
// 18044
// 18045
// 18046
// 18047
// 18048
// 18049
// 18050
// 18051
// 18052
// 18053
// 18054
// 18055
// 18056
// 18057
// 18058
// 18059
// 18060
// 18061
// 18062
// 18063
// 18064
// 18065
// 18066
// 18067
// 18068
// 18069
// 18070
// 18071
// 18072
// 18073
// 18074
// 18075
// 18076
// 18077
// 18078
// 18079
// 18081
// 18082
// 18083
// 18084
// 18085
// 18086
// 18087
// 18088
// 18089
// 18090
// 18091
// 18092
// 18093
// 18097
// 18098
// 18100
// 18101
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 18104
// 18105
// 18106
// 18107
// 18108
// 18109
// 18110
// 18111
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 18114
// 18115
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18117
// 18118
// 18120
// 18121
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 18124
// 18125
// 18126
// 18127
// 18128
// 18129
// 18130
// 18131
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// 18136
// 18137
f925563445_433.returns.push(undefined);
// 18138
// 18139
// undefined
fo925563445_989___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 18142
o40.onmousedown = null;
// 18144
// 18145
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18146
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18147
// 18148
// 18149
// 18150
// 18151
// 18152
// 18153
// 18154
// 18155
// 18156
// 18157
// 18158
// 18159
// 18160
// 18162
// 18163
// 18167
// 18168
// 18169
o39.nodeName = "INPUT";
// 18170
// 18171
// undefined
fo925563445_1065___FB_TOKEN = function() { return fo925563445_1065___FB_TOKEN.returns[fo925563445_1065___FB_TOKEN.inst++]; };
fo925563445_1065___FB_TOKEN.returns = [];
fo925563445_1065___FB_TOKEN.inst = 0;
defineGetter(o39, "__FB_TOKEN", fo925563445_1065___FB_TOKEN);
// undefined
fo925563445_1065___FB_TOKEN.returns.push(null);
// 18174
o39.getAttribute = f925563445_468;
// 18176
// 18177
f925563445_468.returns.push(null);
// 18178
// 18179
// 18180
// 18181
// 18182
// 18183
// 18184
// 18185
// 18186
o27 = {};
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18188
o27["0"] = 56;
// 18189
o39.JSBNG__addEventListener = f925563445_433;
// 18191
// 18192
f925563445_433.returns.push(undefined);
// 18193
// 18194
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18197
o39.onjsbng__blur = null;
// 18199
// 18200
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18202
// 18203
// 18205
// 18206
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18209
// 18210
// 18211
// 18212
// 18213
// 18214
// 18215
// 18216
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18221
// 18222
f925563445_433.returns.push(undefined);
// 18223
// 18224
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18227
o39.onjsbng__focus = null;
// 18229
// 18230
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18232
// 18233
// 18235
// 18236
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18239
// 18240
// 18241
// 18242
// 18243
// 18244
// 18245
// 18246
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18251
// 18252
f925563445_433.returns.push(undefined);
// 18253
// 18254
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18257
o39.onclick = null;
// 18259
// 18260
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18262
// 18263
// 18265
// 18266
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18269
// 18270
// 18271
// 18272
// 18273
// 18274
// 18275
// 18276
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18281
// 18282
f925563445_433.returns.push(undefined);
// 18283
// 18284
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18287
o39.onkeyup = null;
// 18289
// 18290
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18292
// 18293
// 18295
// 18296
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18299
// 18300
// 18301
// 18302
// 18303
// 18304
// 18305
// 18306
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18311
// 18312
f925563445_433.returns.push(undefined);
// 18313
// 18314
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18317
o39.onkeydown = null;
// 18319
// 18320
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18321
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18323
// 18324
// 18325
// 18326
// 18327
// 18328
// 18329
// 18333
// 18334
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18337
// 18338
// 18339
// 18340
// 18341
// 18342
// 18343
// 18344
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18349
// 18350
f925563445_433.returns.push(undefined);
// 18351
// 18352
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// 18355
o39.onkeypress = null;
// 18357
// 18358
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18359
// 18360
// 18361
o28 = {};
// 18362
o30.parentNode = o28;
// undefined
o30 = null;
// undefined
o28 = null;
// 18363
// 18364
// 18365
// 18366
o28 = {};
// 18367
f925563445_4.returns.push(o28);
// 18368
o28.getPropertyValue = f925563445_461;
// undefined
o28 = null;
// 18369
// 18370
// 18371
f925563445_461.returns.push("static");
// 18372
// 18373
// 18374
// 18375
// 18376
// 18377
// 18378
// 18379
// 18380
// 18381
// 18382
// 18383
// 18384
// 18385
// 18386
// 18387
// 18388
// 18389
// 18390
// 18391
// 18392
// 18393
// 18394
// 18395
// 18396
// 18397
// undefined
o33 = null;
// 18398
// 18399
// 18400
// 18401
// 18402
// 18403
// 18404
// 18405
// 18406
// 18407
// 18408
// 18409
// 18410
// 18411
// 18412
// 18413
// 18414
// 18415
// 18416
// 18417
// 18418
// 18419
// 18420
// undefined
fo925563445_1065_className.returns.push("inputtext inputsearch textInput DOMControl_placeholder");
// undefined
fo925563445_1065_className.returns.push("inputtext inputsearch textInput DOMControl_placeholder");
// 18424
// 18426
// 18427
f925563445_468.returns.push(null);
// 18428
// 18429
// 18430
// undefined
fo925563445_1065___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 18435
// 18436
f925563445_468.returns.push(null);
// 18437
// 18438
o0.activeElement = o3;
// 18440
// 18441
f925563445_468.returns.push("Search");
// 18442
// 18443
// 18444
// 18445
// 18446
// 18447
// undefined
fo925563445_1065_className.returns.push("inputtext inputsearch textInput ");
// undefined
fo925563445_1065_className.returns.push("inputtext inputsearch textInput ");
// 18451
o27 = {};
// 18452
o39.style = o27;
// undefined
o39 = null;
// 18453
// undefined
o27 = null;
// 18454
// 18455
// undefined
o40 = null;
// 18456
// 18457
// 18458
// 18459
// 18460
// 18461
// 18462
// 18463
// 18464
// 18465
// 18466
// 18467
// 18468
// 18469
// 18470
// 18471
// 18472
// 18473
// 18474
// 18475
// 18476
// 18477
// 18478
// 18479
// 18480
// 18481
// 18482
// 18483
// 18484
// 18485
// 18486
// 18487
// 18488
// 18489
// 18490
// 18491
// 18492
// 18493
// 18494
// 18495
// 18496
// 18497
// 18498
o45.getElementsByTagName = f925563445_577;
// 18499
// 18500
// 18501
o27 = {};
// 18502
f925563445_577.returns.push(o27);
// 18503
o27.length = 3;
// 18504
o27["0"] = o46;
// 18505
o27["1"] = o47;
// 18506
o27["2"] = o48;
// undefined
o27 = null;
// 18507
// 18508
// 18510
// 18511
// 18513
// 18514
// 18516
// 18517
// 18518
// 18519
// 18520
o48.getElementsByTagName = f925563445_577;
// 18521
// 18522
// 18523
o27 = {};
// 18524
f925563445_577.returns.push(o27);
// 18525
o27.length = 4;
// 18526
o28 = {};
// 18527
o27["0"] = o28;
// 18528
o29 = {};
// 18529
o27["1"] = o29;
// 18530
o30 = {};
// 18531
o27["2"] = o30;
// 18532
o32 = {};
// 18533
o27["3"] = o32;
// undefined
o27 = null;
// 18534
// 18535
// 18536
o28.className = "uiMenuItem uiMenuItemCheckbox uiSelectorOption";
// 18537
// 18538
// 18539
o29.className = "uiMenuItem uiMenuItemCheckbox uiSelectorOption checked";
// 18540
// 18541
// 18542
o30.className = "uiMenuSeparator";
// 18543
// 18544
// 18545
o32.className = "uiMenuItem";
// 18546
// 18547
// 18548
// 18549
// 18551
// 18552
// 18553
// 18555
// 18556
// 18557
// 18559
// 18560
// 18561
// 18562
// 18563
// 18565
o27 = {};
// 18566
o29.parentNode = o27;
// 18567
// 18568
// 18569
o27.className = "uiMenuInner";
// 18570
o27.parentNode = o48;
// 18571
// 18572
// 18574
o48.parentNode = o47;
// 18575
// 18576
// 18578
o47.parentNode = o46;
// 18579
// 18580
// 18582
o46.parentNode = o45;
// undefined
o45 = null;
// 18583
// 18584
// 18586
// 18587
// 18588
// 18589
// 18591
// 18592
// 18593
o33 = {};
// 18594
f925563445_577.returns.push(o33);
// 18595
o33.length = 1;
// 18596
o39 = {};
// 18597
o33["0"] = o39;
// undefined
o33 = null;
// 18598
// 18599
// 18600
// 18601
// 18602
// 18604
// 18605
// 18606
o33 = {};
// 18607
f925563445_577.returns.push(o33);
// 18608
o33.length = 3;
// 18609
o33["0"] = o46;
// 18610
o33["1"] = o47;
// 18611
o33["2"] = o48;
// undefined
o33 = null;
// 18612
// 18613
// 18615
// 18616
// 18618
// 18619
// 18621
// 18622
// 18623
// 18624
// 18626
// 18627
// 18628
o33 = {};
// 18629
f925563445_577.returns.push(o33);
// 18630
o33.length = 4;
// 18631
o33["0"] = o28;
// 18632
o33["1"] = o29;
// 18633
o33["2"] = o30;
// 18634
o33["3"] = o32;
// undefined
o33 = null;
// 18635
// 18636
// 18638
// 18639
// 18641
// 18642
// 18644
// 18645
// 18647
// 18648
// 18649
// 18650
// 18652
// 18653
// 18654
// 18656
// 18657
// 18658
// 18660
// 18661
o33 = {};
// undefined
fo925563445_1082_options = function() { return fo925563445_1082_options.returns[fo925563445_1082_options.inst++]; };
fo925563445_1082_options.returns = [];
fo925563445_1082_options.inst = 0;
defineGetter(o39, "options", fo925563445_1082_options);
// undefined
fo925563445_1082_options.returns.push(o33);
// 18663
o40 = {};
// 18664
o33["2"] = o40;
// undefined
o33 = null;
// 18665
o40.value = "sound";
// undefined
o40 = null;
// 18666
// 18667
// 18668
// 18669
// 18670
// 18672
o28.parentNode = o27;
// undefined
o27 = null;
// 18673
// 18674
// 18677
// 18678
// 18681
// 18682
// 18685
// 18686
// 18689
// 18690
// 18692
// 18693
// 18694
// 18695
// 18697
// 18698
// 18699
o27 = {};
// 18700
f925563445_577.returns.push(o27);
// 18701
o27.length = 1;
// 18702
o27["0"] = o39;
// undefined
o27 = null;
// undefined
o39 = null;
// 18703
// 18704
// 18705
// 18706
// 18707
// 18709
// 18710
// 18711
o27 = {};
// 18712
f925563445_577.returns.push(o27);
// 18713
o27.length = 3;
// 18714
o27["0"] = o46;
// undefined
o46 = null;
// 18715
o27["1"] = o47;
// undefined
o47 = null;
// 18716
o27["2"] = o48;
// undefined
o27 = null;
// undefined
o48 = null;
// 18717
// 18718
// 18720
// 18721
// 18723
// 18724
// 18726
// 18727
// 18728
// 18729
// 18731
// 18732
// 18733
o27 = {};
// 18734
f925563445_577.returns.push(o27);
// 18735
o27.length = 4;
// 18736
o27["0"] = o28;
// undefined
o28 = null;
// 18737
o27["1"] = o29;
// undefined
o29 = null;
// 18738
o27["2"] = o30;
// undefined
o30 = null;
// 18739
o27["3"] = o32;
// undefined
o27 = null;
// undefined
o32 = null;
// 18740
// 18741
// 18743
// 18744
// 18746
// 18747
// 18749
// 18750
// 18752
// 18753
// 18754
// 18755
// 18757
// 18758
// 18759
// 18761
// 18762
// 18763
// 18765
// 18766
o27 = {};
// undefined
fo925563445_1082_options.returns.push(o27);
// 18768
o28 = {};
// 18769
o27["1"] = o28;
// undefined
o27 = null;
// 18770
o28.value = "visibility";
// undefined
o28 = null;
// 18771
// 18772
// 18773
// 18774
// 18776
// 18777
// 18778
// 18779
// 18780
// 18781
// 18782
// 18783
// 18784
// 18785
// 18786
// 18787
// 18788
// 18789
// 18790
// 18791
// 18792
// 18793
// 18794
// 18795
// 18796
// 18797
// 18798
// 18799
// 18800
// 18801
// 18802
// 18803
// 18804
// 18805
// 18806
// 18807
// 18808
// 18809
// 18810
// 18811
// 18812
// 18813
// 18814
// 18815
// 18816
// 18817
// 18818
// 18819
// 18820
// 18821
// 18822
// 18823
// 18824
// 18825
// 18826
// 18827
// 18828
// 18829
// 18830
// 18831
// 18832
// 18833
// 18834
// 18835
// 18836
// 18837
// 18838
// 18839
// 18840
// 18841
// 18842
// 18843
// 18844
// 18845
// 18846
// 18847
// 18848
// 18849
// 18850
// 18851
// 18852
// 18853
// 18854
// 18855
// 18856
// 18857
// 18858
// 18859
// 18860
// 18861
// 18862
// 18863
// 18864
// 18865
// 18866
// 18867
// 18868
// 18869
// 18870
// 18871
// 18872
// 18873
// 18874
// 18875
// 18876
// 18877
// 18878
// 18879
// 18880
// 18881
// 18882
// 18883
// 18884
// 18885
// 18886
// 18887
// 18888
// 18889
// 18890
// 18891
// 18892
// 18893
// 18894
// 18895
// 18896
// 18897
// 18898
// 18899
// 18900
// 18901
// 18902
// 18903
// 18904
// 18905
// 18906
// 18907
// 18908
// 18909
// 18910
// 18911
// 18912
// 18913
// 18914
// 18915
// 18916
// 18917
// 18918
// 18919
// 18920
// 18921
// 18922
// 18923
// 18924
// 18925
// 18926
// 18927
// 18928
// 18929
// 18930
// 18931
// 18932
// 18933
// 18934
// 18935
// 18936
// 18937
// 18938
// 18939
// 18940
// 18941
// 18942
// 18943
// 18944
// 18945
// 18946
// 18947
// 18948
// 18949
// 18950
// 18951
// 18952
// 18953
// 18954
// 18955
// 18956
// 18957
// 18959
// 18960
// 18961
// 18962
// 18963
// 18964
// 18965
// 18968
// 18969
// 18970
// 18971
// 18972
// 18973
// 18974
// 18975
// 18976
// 18977
// 18978
// 18979
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 18981
// 18982
// 18983
// 18984
// 18985
// 18986
// 18987
// 18990
// 18991
// 18992
// 18993
// 18994
// 18995
// 18996
// 18997
// 18998
// 18999
// 19000
// 19001
f925563445_7.returns.push(undefined);
// 19002
// 19003
// 19004
// 19005
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 19006
// 19007
// 19008
// 19009
// 19010
// 19011
// 19012
// 19013
// 19014
// 19015
// 19016
// 19017
// 19018
// 19019
// 19020
// 19021
// 19022
// 19023
// 19024
// 19025
// 19026
// 19027
// 19028
// 19029
// 19030
// 19031
// 19032
// 19033
// 19034
// 19035
// 19036
// 19037
// 19038
// 19039
// 19040
// 19041
// 19042
// 19043
// 19044
// 19045
// 19046
// 19047
o27 = {};
// 19048
f925563445_0.returns.push(o27);
// 19049
o27.getTime = f925563445_435;
// undefined
o27 = null;
// 19050
// 19051
f925563445_435.returns.push(1318265708745);
// 19052
// 19053
// 19054
// 19055
// 19056
o27 = {};
// 19057
f925563445_0.returns.push(o27);
// undefined
o27 = null;
// 19058
// 19059
// 19060
// 19061
// 19062
// 19063
// 19064
// 19065
// 19066
// 19067
// 19068
// 19069
// 19070
// 19071
// 19072
// 19073
// 19074
// 19075
// 19076
// 19077
// 19078
// 19079
// 19080
// 19082
// 19083
o27 = {};
// 19084
f925563445_457.returns.push(o27);
// 19085
// 19087
// 19088
o28 = {};
// 19089
f925563445_457.returns.push(o28);
// 19090
// 19092
// 19093
o29 = {};
// 19094
f925563445_457.returns.push(o29);
// 19095
// 19096
// 19097
// 19098
// 19099
o27.getElementsByTagName = f925563445_577;
// 19100
// 19101
// 19102
o30 = {};
// 19103
f925563445_577.returns.push(o30);
// 19104
o30.length = 4;
// 19105
o32 = {};
// 19106
o30["0"] = o32;
// 19107
o30["1"] = o28;
// 19108
o30["2"] = o29;
// 19109
o33 = {};
// 19110
o30["3"] = o33;
// undefined
o30 = null;
// 19111
// 19112
// undefined
fo925563445_1098_className = function() { return fo925563445_1098_className.returns[fo925563445_1098_className.inst++]; };
fo925563445_1098_className.returns = [];
fo925563445_1098_className.inst = 0;
defineGetter(o32, "className", fo925563445_1098_className);
// undefined
fo925563445_1098_className.returns.push("fbNub hidden_elem next");
// 19114
// 19115
// 19116
o28.className = "fbNubGroup clearfix";
// 19117
// 19118
// 19119
o29.className = "fbNubGroup clearfix";
// 19120
// 19121
// undefined
fo925563445_1099_className = function() { return fo925563445_1099_className.returns[fo925563445_1099_className.inst++]; };
fo925563445_1099_className.returns = [];
fo925563445_1099_className.inst = 0;
defineGetter(o33, "className", fo925563445_1099_className);
// undefined
fo925563445_1099_className.returns.push("fbNub hidden_elem previous");
// 19124
// 19125
// 19126
// 19127
// 19128
// 19129
// 19130
// 19133
o32.nodeName = "DIV";
// 19134
// 19135
// undefined
fo925563445_1098___FB_TOKEN = function() { return fo925563445_1098___FB_TOKEN.returns[fo925563445_1098___FB_TOKEN.inst++]; };
fo925563445_1098___FB_TOKEN.returns = [];
fo925563445_1098___FB_TOKEN.inst = 0;
defineGetter(o32, "__FB_TOKEN", fo925563445_1098___FB_TOKEN);
// undefined
fo925563445_1098___FB_TOKEN.returns.push(null);
// 19138
o32.getAttribute = f925563445_468;
// 19140
// 19141
f925563445_468.returns.push(null);
// 19142
// 19143
// 19144
// 19145
// 19146
// 19147
// 19148
// 19149
// 19150
o30 = {};
// undefined
fo925563445_1098___FB_TOKEN.returns.push(o30);
// 19152
o30["0"] = 57;
// 19153
o32.JSBNG__addEventListener = f925563445_433;
// 19155
// 19156
f925563445_433.returns.push(undefined);
// 19157
// 19158
// undefined
fo925563445_1098___FB_TOKEN.returns.push(o30);
// undefined
o30 = null;
// 19161
o32.onclick = null;
// 19163
// 19164
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 19165
// 19166
// 19167
// 19168
// 19170
// 19171
// 19172
o30 = {};
// 19173
f925563445_577.returns.push(o30);
// 19174
o30.length = 4;
// 19175
o30["0"] = o32;
// 19176
o30["1"] = o28;
// 19177
o30["2"] = o29;
// 19178
o30["3"] = o33;
// undefined
o30 = null;
// 19179
// 19180
// undefined
fo925563445_1098_className.returns.push("fbNub hidden_elem next");
// 19182
// 19183
// 19185
// 19186
// 19188
// 19189
// undefined
fo925563445_1099_className.returns.push("fbNub hidden_elem previous");
// 19192
// 19193
// 19194
// 19195
// 19196
// 19197
// 19198
// 19201
o33.nodeName = "DIV";
// 19202
// 19203
// undefined
fo925563445_1099___FB_TOKEN = function() { return fo925563445_1099___FB_TOKEN.returns[fo925563445_1099___FB_TOKEN.inst++]; };
fo925563445_1099___FB_TOKEN.returns = [];
fo925563445_1099___FB_TOKEN.inst = 0;
defineGetter(o33, "__FB_TOKEN", fo925563445_1099___FB_TOKEN);
// undefined
fo925563445_1099___FB_TOKEN.returns.push(null);
// 19206
o33.getAttribute = f925563445_468;
// 19208
// 19209
f925563445_468.returns.push(null);
// 19210
// 19211
// 19212
// 19213
// 19214
// 19215
// 19216
// 19217
// 19218
o30 = {};
// undefined
fo925563445_1099___FB_TOKEN.returns.push(o30);
// 19220
o30["0"] = 58;
// 19221
o33.JSBNG__addEventListener = f925563445_433;
// 19223
// 19224
f925563445_433.returns.push(undefined);
// 19225
// 19226
// undefined
fo925563445_1099___FB_TOKEN.returns.push(o30);
// undefined
o30 = null;
// 19229
o33.onclick = null;
// 19231
// 19232
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 19233
// 19234
// 19235
// 19236
// 19237
o32.getElementsByTagName = f925563445_577;
// undefined
o32 = null;
// 19238
// 19239
// 19240
o30 = {};
// 19241
f925563445_577.returns.push(o30);
// 19242
o30.length = 3;
// 19243
o32 = {};
// 19244
o30["0"] = o32;
// 19245
o39 = {};
// 19246
o30["1"] = o39;
// 19247
o40 = {};
// 19248
o30["2"] = o40;
// undefined
o30 = null;
// 19249
// 19250
// 19251
o32.className = "arrow";
// 19252
// 19253
// 19254
o39.className = "numTabs";
// 19255
// 19256
// undefined
fo925563445_1106_className = function() { return fo925563445_1106_className.returns[fo925563445_1106_className.inst++]; };
fo925563445_1106_className.returns = [];
fo925563445_1106_className.inst = 0;
defineGetter(o40, "className", fo925563445_1106_className);
// undefined
fo925563445_1106_className.returns.push("numMessages");
// 19258
// 19259
// 19260
// 19261
// 19262
o33.getElementsByTagName = f925563445_577;
// undefined
o33 = null;
// 19263
// 19264
// 19265
o30 = {};
// 19266
f925563445_577.returns.push(o30);
// 19267
o30.length = 3;
// 19268
o33 = {};
// 19269
o30["0"] = o33;
// 19270
o41 = {};
// 19271
o30["1"] = o41;
// 19272
o42 = {};
// 19273
o30["2"] = o42;
// undefined
o30 = null;
// 19274
// 19275
// undefined
fo925563445_1108_className = function() { return fo925563445_1108_className.returns[fo925563445_1108_className.inst++]; };
fo925563445_1108_className.returns = [];
fo925563445_1108_className.inst = 0;
defineGetter(o33, "className", fo925563445_1108_className);
// undefined
fo925563445_1108_className.returns.push("numMessages");
// 19277
// 19278
// 19279
o41.className = "numTabs";
// 19280
// 19281
// 19282
o42.className = "arrow";
// 19283
// 19284
// 19285
// 19286
// 19288
// 19289
// 19290
o30 = {};
// 19291
f925563445_577.returns.push(o30);
// 19292
o30.length = 3;
// 19293
o30["0"] = o32;
// undefined
o32 = null;
// 19294
o30["1"] = o39;
// 19295
o30["2"] = o40;
// undefined
o30 = null;
// 19296
// 19297
// 19299
// 19300
// 19302
// 19303
// undefined
fo925563445_1106_className.returns.push("numMessages");
// 19305
// 19306
// 19307
// 19308
// 19310
// 19311
// 19312
o30 = {};
// 19313
f925563445_577.returns.push(o30);
// 19314
o30.length = 3;
// 19315
o30["0"] = o33;
// 19316
o30["1"] = o41;
// 19317
o30["2"] = o42;
// undefined
o30 = null;
// undefined
o42 = null;
// 19318
// 19319
// undefined
fo925563445_1108_className.returns.push("numMessages");
// 19321
// 19322
// 19324
// 19325
// 19327
// 19328
// 19329
// 19330
// 19331
// 19332
// 19333
// 19334
// 19335
// 19336
// 19337
// 19338
// 19339
// 19340
// 19341
// 19342
// 19343
// 19344
// 19345
// 19346
// 19347
// 19348
// 19349
// 19350
// 19351
// 19352
// 19353
// 19354
// 19355
// 19356
// 19361
// 19362
// 19364
// 19365
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 19368
// 19369
// 19370
// 19371
// 19372
// 19373
// 19374
// 19375
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 19380
// 19381
f925563445_433.returns.push(undefined);
// 19382
// 19383
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 19386
f925563445_1113 = function() { return f925563445_1113.returns[f925563445_1113.inst++]; };
f925563445_1113.returns = [];
f925563445_1113.inst = 0;
// 19387
o5.onclick = f925563445_1113;
// 19392
// 19394
// 19395
// 19397
// 19398
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 19401
// 19402
// 19403
// 19404
// 19405
// 19406
// 19407
// 19408
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 19411
// 19412
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 19414
// 19415
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 19416
// 19417
// 19418
// 19419
// 19420
// 19421
// 19422
o29.__FB_TOKEN = null;
// 19423
// undefined
o29 = null;
// 19424
// 19425
// 19426
// 19427
// 19428
// 19429
// 19430
// 19431
// 19432
// 19433
// 19434
// 19435
// 19436
// 19437
// 19439
// 19440
// 19441
// 19442
// 19443
// 19444
// 19445
// 19448
// 19449
// 19450
// 19451
// 19452
// 19453
// 19454
// 19455
// 19456
// 19457
// 19458
// 19459
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 19460
// 19461
// 19462
// 19463
// 19464
// 19465
// 19467
o3.clientWidth = 1265;
// undefined
o3 = null;
// 19468
// 19469
// 19470
// 19472
o28.parentNode = o27;
// 19473
// 19474
// 19475
o27.className = "fbNubGroup clearfix hide_on_popped_out";
// 19476
o27.parentNode = o1;
// 19477
// 19478
// 19480
o3 = {};
// 19481
o1.parentNode = o3;
// undefined
o1 = null;
// 19482
// 19483
// 19484
o3.className = "clearfix rNubContainer";
// 19485
o1 = {};
// 19486
o3.parentNode = o1;
// 19487
// 19488
// 19489
o1.className = "fbDock clearfix";
// 19490
o1.firstChild = o3;
// undefined
o1 = null;
// 19491
o3.clientWidth = 184;
// 19492
o3.nextSibling = null;
// undefined
o3 = null;
// 19493
// 19494
o28.clientWidth = 0;
// undefined
o28 = null;
// 19495
// 19496
// 19497
// 19498
// 19499
// 19500
// 19501
// 19502
// 19503
// 19504
// undefined
fo925563445_1098_className.returns.push("fbNub hidden_elem next");
// undefined
fo925563445_1098_className.returns.push("fbNub hidden_elem next");
// 19508
// 19509
// 19510
// 19511
// undefined
fo925563445_1099_className.returns.push("fbNub hidden_elem previous");
// undefined
fo925563445_1099_className.returns.push("fbNub hidden_elem previous");
// 19515
// 19516
// 19517
// 19518
// 19519
// undefined
fo925563445_1098_className.returns.push("fbNub hidden_elem next disabled");
// 19521
// 19522
// 19523
// 19524
// 19525
// undefined
fo925563445_1099_className.returns.push("fbNub hidden_elem previous disabled");
// 19527
// 19528
// 19529
// 19530
// 19531
// 19532
// 19533
// 19534
// 19535
// undefined
fo925563445_1108_className.returns.push("numMessages");
// undefined
fo925563445_1108_className.returns.push("numMessages");
// 19539
// 19540
// 19541
// 19542
// 19543
// 19544
// undefined
fo925563445_1106_className.returns.push("numMessages");
// undefined
fo925563445_1106_className.returns.push("numMessages");
// 19548
// 19549
// 19550
// 19551
// 19552
// 19553
// 19554
// 19555
// 19556
// 19557
// 19558
// 19559
// 19560
// 19561
// 19562
// 19563
// 19564
// 19565
// 19566
// 19567
// 19568
// 19569
// 19570
// undefined
fo925563445_1098_className.returns.push("fbNub hidden_elem next disabled");
// 19572
// 19573
// 19574
// 19575
// undefined
fo925563445_1099_className.returns.push("fbNub hidden_elem previous disabled");
// 19577
// 19578
// 19579
// 19580
// 19581
// undefined
fo925563445_1098_className.returns.push("fbNub hidden_elem next disabled");
// 19583
// 19584
// 19585
// 19586
// 19587
// undefined
fo925563445_1099_className.returns.push("fbNub hidden_elem previous disabled");
// 19589
// undefined
o39 = null;
// 19590
// undefined
o41 = null;
// 19591
// 19592
// undefined
o33 = null;
// 19593
// 19594
// 19595
// 19596
// 19597
// undefined
fo925563445_1108_className.returns.push("numMessages hidden_elem");
// 19599
// undefined
o40 = null;
// 19600
// 19601
// 19602
// 19603
// 19604
// undefined
fo925563445_1106_className.returns.push("numMessages hidden_elem");
// 19606
// 19607
// 19608
// 19609
// 19611
// 19612
f925563445_457.returns.push(o27);
// 19613
// 19614
// 19615
// 19616
// 19617
o27.__FB_TOKEN = null;
// 19618
// undefined
o27 = null;
// 19619
// 19620
// 19621
// 19622
// 19623
// 19624
// 19625
// 19626
// 19627
// 19628
// 19629
// 19630
// 19631
// 19632
// 19633
// 19634
// 19635
// 19636
// 19637
// 19638
// 19639
// 19640
// 19641
// 19642
// 19643
// 19644
// 19645
// 19646
// 19647
// 19648
// 19649
// 19650
// 19651
// 19652
// 19653
// 19654
// 19655
// 19656
// 19657
// 19658
// 19659
// 19660
// 19661
// 19662
// 19663
// 19664
// 19665
// 19666
// 19667
// 19668
// 19669
// 19670
// 19671
// 19672
// 19673
// 19674
// 19675
// 19676
// 19677
// 19678
// 19680
// 19681
o1 = {};
// 19682
f925563445_457.returns.push(o1);
// 19683
// 19684
// 19686
// 19687
o3 = {};
// 19688
f925563445_457.returns.push(o3);
// 19689
// 19690
// 19691
// 19692
// 19693
// 19694
// 19695
// 19696
// 19697
// 19698
// 19700
// 19701
o27 = {};
// 19702
f925563445_457.returns.push(o27);
// 19703
// 19704
// 19705
// 19706
o27.__FB_TOKEN = null;
// 19707
// 19708
// 19709
// 19710
// 19711
// 19712
// 19713
// 19714
// undefined
fo925563445_1116___FB_TOKEN = function() { return fo925563445_1116___FB_TOKEN.returns[fo925563445_1116___FB_TOKEN.inst++]; };
fo925563445_1116___FB_TOKEN.returns = [];
fo925563445_1116___FB_TOKEN.inst = 0;
defineGetter(o1, "__FB_TOKEN", fo925563445_1116___FB_TOKEN);
// undefined
fo925563445_1116___FB_TOKEN.returns.push(null);
// 19717
// 19718
// 19719
// 19720
// 19721
// 19722
// 19723
// 19724
// 19725
// 19726
// 19727
// 19728
// 19729
// 19730
// 19731
// 19732
// 19733
// 19734
// 19735
// 19736
// 19737
o1.getElementsByTagName = f925563445_577;
// 19738
// 19739
// 19740
o28 = {};
// 19741
f925563445_577.returns.push(o28);
// 19742
o28.length = 5;
// 19743
o28["0"] = o34;
// 19744
o28["1"] = o35;
// undefined
o35 = null;
// 19745
o28["2"] = o36;
// undefined
o36 = null;
// 19746
o28["3"] = o37;
// undefined
o37 = null;
// 19747
o28["4"] = o38;
// undefined
o28 = null;
// undefined
o38 = null;
// 19748
// 19749
// 19751
// 19752
// 19754
// 19755
// 19757
// 19758
// 19760
// 19761
// 19763
// 19764
// 19765
// 19766
// 19768
// 19769
// 19770
o28 = {};
// 19771
f925563445_577.returns.push(o28);
// 19772
o28.length = 4;
// 19773
o29 = {};
// 19774
o28["0"] = o29;
// 19775
o30 = {};
// 19776
o28["1"] = o30;
// 19777
o32 = {};
// 19778
o28["2"] = o32;
// 19779
o33 = {};
// 19780
o28["3"] = o33;
// undefined
o28 = null;
// 19781
// 19782
// 19783
o29.className = "label";
// undefined
o29 = null;
// 19784
// 19785
// 19786
o30.className = "itemLabel fsm";
// undefined
o30 = null;
// 19787
// 19788
// 19789
o32.className = "itemLabel fsm";
// undefined
o32 = null;
// 19790
// 19791
// 19792
o33.className = "itemLabel fsm";
// undefined
o33 = null;
// 19793
// 19794
// 19795
// 19796
// 19798
// 19799
// 19800
o28 = {};
// 19801
f925563445_577.returns.push(o28);
// 19802
o28.length = 18;
// 19803
o29 = {};
// 19804
o28["0"] = o29;
// 19805
o30 = {};
// 19806
o28["1"] = o30;
// 19807
o32 = {};
// 19808
o28["2"] = o32;
// 19809
o33 = {};
// 19810
o28["3"] = o33;
// 19811
o35 = {};
// 19812
o28["4"] = o35;
// 19813
o36 = {};
// 19814
o28["5"] = o36;
// 19815
o37 = {};
// 19816
o28["6"] = o37;
// 19817
o38 = {};
// 19818
o28["7"] = o38;
// 19819
o39 = {};
// 19820
o28["8"] = o39;
// 19821
o40 = {};
// 19822
o28["9"] = o40;
// 19823
o41 = {};
// 19824
o28["10"] = o41;
// 19825
o42 = {};
// 19826
o28["11"] = o42;
// 19827
o43 = {};
// 19828
o28["12"] = o43;
// 19829
o44 = {};
// 19830
o28["13"] = o44;
// 19831
o45 = {};
// 19832
o28["14"] = o45;
// 19833
o28["15"] = o27;
// 19834
o46 = {};
// 19835
o28["16"] = o46;
// 19836
o47 = {};
// 19837
o28["17"] = o47;
// undefined
o28 = null;
// 19838
// 19839
// 19840
o29.className = "fbNubFlyout uiToggleFlyout";
// 19841
// 19842
// 19843
o30.className = "fbNubFlyoutOuter";
// 19844
// 19845
// 19846
o32.className = "fbNubFlyoutInner";
// 19847
// 19848
// 19849
o33.className = "clearfix fbNubFlyoutTitlebar";
// 19850
// 19851
// 19852
o35.className = "uiSelector inlineBlock fbChatSidebarDropdown button rfloat uiSelectorRight";
// 19853
// 19854
// 19855
o36.className = "wrap";
// 19856
// 19857
// 19858
o37.className = "uiSelectorMenuWrapper uiToggleFlyout";
// 19859
// 19860
// 19861
o38.className = "uiMenu uiSelectorMenu";
// 19862
// 19863
// 19864
o39.className = "titlebarLabel clearfix";
// 19865
// 19866
// 19867
o40.className = "titlebarTextWrapper";
// 19868
// 19869
// 19870
o41.className = "fbNubFlyoutBody scrollable";
// 19871
// 19872
// 19873
o42.className = "fbNubFlyoutBodyContent";
// 19874
// 19875
// 19876
o43.className = "phs fcg";
// 19877
// 19878
// 19879
o44.className = "fbChatTypeaheadView hidden_elem";
// 19880
// 19881
// 19882
o45.className = "fbNubFlyoutFooter";
// 19883
// 19884
// 19885
o27.className = "uiTypeahead uiClearableTypeahead fbChatTypeahead";
// 19886
// 19887
// 19888
o46.className = "wrap";
// 19889
// 19890
// 19891
o47.className = "innerWrap";
// 19892
// 19893
// 19894
// 19895
// 19897
// 19898
// 19899
o28 = {};
// 19900
f925563445_577.returns.push(o28);
// 19901
o28.length = 18;
// 19902
o28["0"] = o29;
// undefined
o29 = null;
// 19903
o28["1"] = o30;
// undefined
o30 = null;
// 19904
o28["2"] = o32;
// undefined
o32 = null;
// 19905
o28["3"] = o33;
// 19906
o28["4"] = o35;
// 19907
o28["5"] = o36;
// 19908
o28["6"] = o37;
// 19909
o28["7"] = o38;
// 19910
o28["8"] = o39;
// undefined
o39 = null;
// 19911
o28["9"] = o40;
// undefined
o40 = null;
// 19912
o28["10"] = o41;
// 19913
o28["11"] = o42;
// undefined
o42 = null;
// 19914
o28["12"] = o43;
// undefined
o43 = null;
// 19915
o28["13"] = o44;
// undefined
o44 = null;
// 19916
o28["14"] = o45;
// undefined
o45 = null;
// 19917
o28["15"] = o27;
// undefined
o27 = null;
// 19918
o28["16"] = o46;
// undefined
o46 = null;
// 19919
o28["17"] = o47;
// undefined
o28 = null;
// undefined
o47 = null;
// 19920
// 19921
// 19923
// 19924
// 19926
// 19927
// 19929
// 19930
// 19932
// 19933
// 19935
// 19936
// 19938
// 19939
// 19941
// 19942
// 19944
// 19945
// 19947
// 19948
// 19950
// 19951
// 19953
// 19954
// 19956
// 19957
// 19959
// 19960
// 19962
// 19963
// 19965
// 19966
// 19968
// 19969
// 19971
// 19972
// 19974
// 19975
// 19976
// 19977
// 19978
// 19979
// 19980
// 19981
// 19982
// 19983
// 19984
// 19985
// 19986
// 19987
// 19988
// 19989
// 19990
// 19991
// 19992
// 19993
// 19994
// 19995
// 19996
// 19997
// 19998
// 19999
// 20000
// 20001
// 20002
// 20003
// 20004
// 20005
// 20006
// 20007
// 20008
// 20009
// 20010
o33.__FB_TOKEN = null;
// 20011
// undefined
o33 = null;
// 20012
// 20013
// 20014
// 20015
// 20016
// 20017
// 20018
// 20019
// 20020
// 20021
// 20022
// 20023
// 20024
// 20025
// 20026
// 20027
// 20028
o41.nodeName = "DIV";
// 20029
// 20030
// 20031
// 20032
// 20034
o41.nodeType = 1;
// 20035
// 20036
o3.nodeName = "UL";
// 20037
// 20038
// 20039
// 20040
// 20042
o3.nodeType = 1;
// 20043
o41.contains = f925563445_1001;
// undefined
o41 = null;
// 20045
// 20046
f925563445_1001.returns.push(true);
// 20047
// 20048
// 20049
// 20050
// 20051
// 20052
// 20053
// 20054
// 20055
// 20056
// 20057
// 20058
// 20059
// 20060
// 20061
// 20062
// 20063
// 20064
// 20065
// 20066
// 20067
// 20068
// 20069
// 20070
// 20071
// 20072
// 20073
// 20074
// 20075
// 20076
// 20077
// 20078
// 20079
// 20080
// 20081
// 20082
// 20083
// 20084
// 20085
// 20086
// 20087
// 20088
// 20090
// 20091
// 20092
// 20093
// 20094
// 20095
// 20096
// 20099
o1.nodeName = "DIV";
// 20100
// 20101
// 20102
o27 = {};
// undefined
fo925563445_1116___FB_TOKEN.returns.push(o27);
// 20104
o27["0"] = 62;
// 20105
o1.getAttribute = f925563445_468;
// 20107
// 20108
f925563445_468.returns.push(null);
// 20109
// 20110
// 20111
// 20112
// 20113
// 20114
// 20115
// 20116
// undefined
fo925563445_1116___FB_TOKEN.returns.push(o27);
// 20119
o1.JSBNG__addEventListener = f925563445_433;
// 20121
// 20122
f925563445_433.returns.push(undefined);
// 20123
// 20124
// undefined
fo925563445_1116___FB_TOKEN.returns.push(o27);
// undefined
o27 = null;
// 20127
o1.onkeydown = null;
// undefined
o1 = null;
// 20129
// 20130
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 20132
// 20133
// 20134
// 20135
// 20136
// 20137
// 20138
// 20141
o34.nodeName = "A";
// 20142
// 20143
// undefined
fo925563445_1018___FB_TOKEN = function() { return fo925563445_1018___FB_TOKEN.returns[fo925563445_1018___FB_TOKEN.inst++]; };
fo925563445_1018___FB_TOKEN.returns = [];
fo925563445_1018___FB_TOKEN.inst = 0;
defineGetter(o34, "__FB_TOKEN", fo925563445_1018___FB_TOKEN);
// undefined
fo925563445_1018___FB_TOKEN.returns.push(null);
// 20146
o34.getAttribute = f925563445_468;
// 20148
// 20149
f925563445_468.returns.push(null);
// 20150
// 20151
// 20152
// 20153
// 20154
// 20155
// 20156
// 20157
// 20158
o1 = {};
// undefined
fo925563445_1018___FB_TOKEN.returns.push(o1);
// 20160
o1["0"] = 64;
// 20161
o34.JSBNG__addEventListener = f925563445_433;
// 20163
// 20164
f925563445_433.returns.push(undefined);
// 20165
// 20166
// undefined
fo925563445_1018___FB_TOKEN.returns.push(o1);
// 20169
o34.onclick = null;
// undefined
o34 = null;
// 20171
// 20172
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 20173
// 20174
// 20175
// 20176
// 20177
// 20178
// 20179
// 20180
// 20181
// 20182
// 20183
// 20184
// 20185
// 20186
// 20187
// 20188
// 20189
// 20190
// 20191
// 20192
// 20193
// 20194
// 20195
// 20196
// 20197
// 20198
// 20199
// 20200
// 20201
// 20202
// 20203
// 20204
// 20205
// 20206
// 20207
// 20208
// 20209
// 20210
// 20211
// 20212
// 20213
// 20214
// 20215
// 20216
// 20217
// 20218
// 20219
// 20220
// 20221
// 20222
// 20223
// 20224
// 20225
// 20226
// 20227
// 20228
// 20229
// 20230
// 20231
// 20232
// 20233
// 20234
// 20235
// 20236
// 20237
// 20238
// 20239
// 20240
// 20241
// 20242
// 20243
// 20244
// 20245
// 20247
// 20248
// 20249
// 20250
// 20254
// 20255
// undefined
fo925563445_1018___FB_TOKEN.returns.push(o1);
// 20258
// 20259
// 20260
// 20261
// 20262
// 20263
// 20264
// 20265
// undefined
fo925563445_1018___FB_TOKEN.returns.push(o1);
// undefined
o1 = null;
// 20268
// 20269
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 20270
// 20271
// 20272
// 20273
// 20275
// 20276
f925563445_457.returns.push(o35);
// 20277
// 20278
// 20279
// 20280
// 20281
// 20282
// 20283
// 20284
// 20285
// 20286
// 20287
// 20288
// 20289
// 20290
// 20291
// 20292
// 20293
// 20294
// 20295
// 20296
// 20297
// 20298
// 20299
// 20300
// 20301
// 20302
// 20303
// 20304
// 20305
// 20306
// 20307
// 20308
// 20309
// 20310
// 20311
// 20312
// 20313
// 20314
// 20315
// 20316
// 20317
// 20318
// 20319
// 20320
// 20321
// 20322
// 20323
// 20324
// 20325
// 20326
// 20327
// 20328
// 20329
// 20330
// 20331
// 20332
// 20333
// 20334
o35.getElementsByTagName = f925563445_577;
// 20335
// 20336
// 20337
o1 = {};
// 20338
f925563445_577.returns.push(o1);
// 20339
o1.length = 3;
// 20340
o1["0"] = o36;
// 20341
o1["1"] = o37;
// 20342
o1["2"] = o38;
// undefined
o1 = null;
// 20343
// 20344
// 20346
// 20347
// 20349
// 20350
// 20352
// 20353
// 20354
// 20355
// 20356
o38.getElementsByTagName = f925563445_577;
// 20357
// 20358
// 20359
o1 = {};
// 20360
f925563445_577.returns.push(o1);
// 20361
o1.length = 4;
// 20362
o27 = {};
// 20363
o1["0"] = o27;
// 20364
o28 = {};
// 20365
o1["1"] = o28;
// 20366
o29 = {};
// 20367
o1["2"] = o29;
// 20368
o30 = {};
// 20369
o1["3"] = o30;
// undefined
o1 = null;
// 20370
// 20371
// 20372
o27.className = "uiMenuItem uiMenuItemCheckbox uiSelectorOption";
// 20373
// 20374
// 20375
o28.className = "uiMenuItem uiMenuItemCheckbox uiSelectorOption checked";
// 20376
// 20377
// 20378
o29.className = "uiMenuSeparator";
// 20379
// 20380
// 20381
o30.className = "uiMenuItem";
// 20382
// 20383
// 20384
// 20385
// 20387
// 20388
// 20389
// 20391
// 20392
// 20393
// 20395
// 20396
// 20397
// 20398
// 20399
// 20401
o1 = {};
// 20402
o28.parentNode = o1;
// 20403
// 20404
// 20405
o1.className = "uiMenuInner";
// 20406
o1.parentNode = o38;
// 20407
// 20408
// 20410
o38.parentNode = o37;
// 20411
// 20412
// 20414
o37.parentNode = o36;
// 20415
// 20416
// 20418
o36.parentNode = o35;
// undefined
o35 = null;
// 20419
// 20420
// 20422
// 20423
// 20424
// 20425
// 20427
// 20428
// 20429
o32 = {};
// 20430
f925563445_577.returns.push(o32);
// 20431
o32.length = 1;
// 20432
o33 = {};
// 20433
o32["0"] = o33;
// undefined
o32 = null;
// 20434
// 20435
// 20436
// 20437
// 20438
// 20440
// 20441
// 20442
o32 = {};
// 20443
f925563445_577.returns.push(o32);
// 20444
o32.length = 3;
// 20445
o32["0"] = o36;
// 20446
o32["1"] = o37;
// 20447
o32["2"] = o38;
// undefined
o32 = null;
// 20448
// 20449
// 20451
// 20452
// 20454
// 20455
// 20457
// 20458
// 20459
// 20460
// 20462
// 20463
// 20464
o32 = {};
// 20465
f925563445_577.returns.push(o32);
// 20466
o32.length = 4;
// 20467
o32["0"] = o27;
// 20468
o32["1"] = o28;
// 20469
o32["2"] = o29;
// 20470
o32["3"] = o30;
// undefined
o32 = null;
// 20471
// 20472
// 20474
// 20475
// 20477
// 20478
// 20480
// 20481
// 20483
// 20484
// 20485
// 20486
// 20488
// 20489
// 20490
// 20492
// 20493
// 20494
// 20496
// 20497
o32 = {};
// undefined
fo925563445_1154_options = function() { return fo925563445_1154_options.returns[fo925563445_1154_options.inst++]; };
fo925563445_1154_options.returns = [];
fo925563445_1154_options.inst = 0;
defineGetter(o33, "options", fo925563445_1154_options);
// undefined
fo925563445_1154_options.returns.push(o32);
// 20499
o34 = {};
// 20500
o32["2"] = o34;
// undefined
o32 = null;
// 20501
o34.value = "sound";
// undefined
o34 = null;
// 20502
// 20503
// 20504
// 20505
// 20506
// 20508
o27.parentNode = o1;
// undefined
o1 = null;
// 20509
// 20510
// 20513
// 20514
// 20517
// 20518
// 20521
// 20522
// 20525
// 20526
// 20528
// 20529
// 20530
// 20531
// 20533
// 20534
// 20535
o1 = {};
// 20536
f925563445_577.returns.push(o1);
// 20537
o1.length = 1;
// 20538
o1["0"] = o33;
// undefined
o1 = null;
// undefined
o33 = null;
// 20539
// 20540
// 20541
// 20542
// 20543
// 20545
// 20546
// 20547
o1 = {};
// 20548
f925563445_577.returns.push(o1);
// 20549
o1.length = 3;
// 20550
o1["0"] = o36;
// undefined
o36 = null;
// 20551
o1["1"] = o37;
// undefined
o37 = null;
// 20552
o1["2"] = o38;
// undefined
o1 = null;
// undefined
o38 = null;
// 20553
// 20554
// 20556
// 20557
// 20559
// 20560
// 20562
// 20563
// 20564
// 20565
// 20567
// 20568
// 20569
o1 = {};
// 20570
f925563445_577.returns.push(o1);
// 20571
o1.length = 4;
// 20572
o1["0"] = o27;
// undefined
o27 = null;
// 20573
o1["1"] = o28;
// undefined
o28 = null;
// 20574
o1["2"] = o29;
// undefined
o29 = null;
// 20575
o1["3"] = o30;
// undefined
o1 = null;
// undefined
o30 = null;
// 20576
// 20577
// 20579
// 20580
// 20582
// 20583
// 20585
// 20586
// 20588
// 20589
// 20590
// 20591
// 20593
// 20594
// 20595
// 20597
// 20598
// 20599
// 20601
// 20602
o1 = {};
// undefined
fo925563445_1154_options.returns.push(o1);
// 20604
o27 = {};
// 20605
o1["1"] = o27;
// undefined
o1 = null;
// 20606
o27.value = "visibility";
// undefined
o27 = null;
// 20607
// 20608
// 20609
// 20610
// 20612
// 20613
// 20614
// 20615
// 20616
// 20617
// 20618
// 20620
// 20621
// 20622
// 20623
// 20624
// 20625
// 20626
// 20630
// 20631
// undefined
fo925563445_1117___FB_TOKEN = function() { return fo925563445_1117___FB_TOKEN.returns[fo925563445_1117___FB_TOKEN.inst++]; };
fo925563445_1117___FB_TOKEN.returns = [];
fo925563445_1117___FB_TOKEN.inst = 0;
defineGetter(o3, "__FB_TOKEN", fo925563445_1117___FB_TOKEN);
// undefined
fo925563445_1117___FB_TOKEN.returns.push(null);
// 20634
o3.getAttribute = f925563445_468;
// 20636
// 20637
f925563445_468.returns.push(null);
// 20638
// 20639
// 20640
// 20641
// 20642
// 20643
// 20644
// 20645
// 20646
o1 = {};
// undefined
fo925563445_1117___FB_TOKEN.returns.push(o1);
// 20648
o1["0"] = 65;
// 20649
o3.JSBNG__addEventListener = f925563445_433;
// 20651
// 20652
f925563445_433.returns.push(undefined);
// 20653
// 20654
// undefined
fo925563445_1117___FB_TOKEN.returns.push(o1);
// undefined
o1 = null;
// 20657
o3.onclick = null;
// undefined
o3 = null;
// 20659
// 20660
f925563445_552.returns.push({__JSBNG_unknown_object:true});
// 20661
// 20662
// 20663
// 20664
// 20665
// 20666
// 20667
// 20668
// 20669
// 20670
// 20671
// 20672
// 20673
// 20674
// 20675
// 20676
// 20677
// 20678
// 20679
// 20680
// 20681
// 20682
// 20683
// 20684
// 20685
// 20686
// 20687
// 20688
// 20689
// 20690
// 20691
// 20692
// 20693
// 20694
// 20695
// 20696
// 20697
// 20698
// 20699
// 20700
// 20701
// 20702
// 20703
// 20704
// 20705
// 20706
// 20707
// 20708
// 20709
// 20710
// 20711
// 20712
// 20713
// 20714
// 20715
// 20716
// 20717
// 20718
// 20719
// 20720
// 20721
// 20722
// 20723
// 20724
// 20725
// 20726
// 20727
// 20728
o22._inherits_from_prototype = true;
// 20729
o22.type = null;
// 20730
// 20731
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 20734
// 20735
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 20738
o1 = {};
// 20739
o3 = {};
// 20741
// 20742
// 20743
// 20744
// 20745
// 20746
// 20749
// 20750
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 20753
// 20754
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 20757
o27 = {};
// 20758
o28 = {};
// 20760
// 20761
// 20762
// 20763
// 20764
// 20765
// 20768
// 20769
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 20772
// 20773
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 20776
o29 = {};
// 20777
o30 = {};
// 20779
// 20780
// 20781
// 20782
// 20783
// undefined
fo925563445_624_readyState.returns.push(2);
// 20785
// 20786
// 20787
// 20788
// undefined
fo925563445_624_readyState.returns.push(3);
// 20790
// 20791
// 20792
// 20793
// undefined
fo925563445_624_readyState.returns.push(4);
// 20795
// 20796
f925563445_1171 = function() { return f925563445_1171.returns[f925563445_1171.inst++]; };
f925563445_1171.returns = [];
f925563445_1171.inst = 0;
// 20797
o25.getResponseHeader = f925563445_1171;
// 20799
// 20800
f925563445_1171.returns.push("10.65.25.57");
// 20802
// 20803
f925563445_1171.returns.push("10.65.25.57");
// 20804
o25.JSBNG__status = 200;
// undefined
o25 = null;
// 20805
// 20806
// 20808
// 20809
// 20810
// 20811
// 20812
// 20813
// 20814
o2.onLine = true;
// undefined
o2 = null;
// 20815
// 20816
// 20817
// 20818
// 20819
// 20820
// 20821
// 20822
// 20823
// 20824
// 20825
// 20826
// 20827
// 20828
// 20829
// 20830
// 20831
f925563445_14.returns.push(undefined);
// 20832
// 20833
// 20834
// 20835
// 20836
// 20837
// 20838
f925563445_426.returns.push(0.24807350849732757);
// 20839
// 20840
// 20841
// 20842
// 20843
// 20844
// 20845
// 20846
// 20847
f925563445_14.returns.push(undefined);
// 20848
// 20849
o2 = {};
// 20850
f925563445_0.returns.push(o2);
// 20851
o2.getTime = f925563445_435;
// undefined
o2 = null;
// 20852
// 20853
f925563445_435.returns.push(1318265708823);
// 20854
// 20855
// 20856
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D; _e_wOYp_2=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213001%3Ashutdown%3Apresence%3Aconnection_shutdown%22%7D%2C4%5D");
// 20858
// 20859
// 20860
// 20861
// 20862
o2 = {};
// 20863
f925563445_0.returns.push(o2);
// 20864
o2.getTime = f925563445_435;
// undefined
o2 = null;
// 20865
// 20866
f925563445_435.returns.push(1318265708824);
// 20867
// 20868
// 20869
// 20870
// 20871
// 20872
// 20873
// 20874
// 20875
// 20876
// 20877
// 20878
// 20879
// 20880
// 20881
// 20882
// 20883
// 20884
// 20885
// 20886
// 20887
// 20888
// 20889
o2 = {};
// 20890
f925563445_0.returns.push(o2);
// 20891
f925563445_1175 = function() { return f925563445_1175.returns[f925563445_1175.inst++]; };
f925563445_1175.returns = [];
f925563445_1175.inst = 0;
// 20893
// 20894
f925563445_1175.returns.push(1318265708824);
// 20895
// 20896
// 20897
o25 = {};
// 20898
f925563445_0.returns.push(o25);
// 20900
// 20901
f925563445_1175.returns.push(1318265708825);
// 20902
// 20903
// 20904
// 20905
o32 = {};
// 20906
f925563445_0.returns.push(o32);
// 20907
o32.getTime = f925563445_435;
// undefined
o32 = null;
// 20908
// 20909
f925563445_435.returns.push(1318265708825);
// 20910
// 20911
// 20912
// 20913
// 20914
// 20915
// 20916
// 20917
// 20918
// 20919
// 20920
// 20921
// 20922
// 20923
// 20924
// 20925
// 20926
// 20927
// 20928
// 20929
// 20930
// 20931
// 20932
// 20933
// 20934
// 20935
// 20936
// 20937
// 20938
// 20939
// 20940
// 20941
// 20942
// 20943
// 20944
// 20945
// 20946
// 20947
// 20948
// 20949
// 20950
// 20951
// 20952
// 20953
// 20954
// 20955
// 20956
// 20957
// 20958
// 20959
// 20960
// 20961
// 20962
// 20963
// 20964
// 20965
// 20966
// 20967
// 20968
// 20969
// 20970
// 20971
// 20972
// 20973
// 20974
// 20975
// 20976
// 20977
// 20978
// 20979
// 20980
// 20981
// 20982
// 20983
// 20984
// 20985
// 20986
// 20987
// 20988
// 20989
// 20990
// 20991
// 20992
// 20993
// 20994
// 20995
// 20996
// 20997
// 20998
// 20999
// 21000
// 21001
// 21002
// 21003
// 21004
// 21005
// 21006
// 21007
// 21008
// 21009
// 21010
// 21011
// 21012
// 21013
// 21014
// 21015
// 21016
// 21017
// 21018
// 21019
// 21020
// 21021
// 21022
// 21023
// 21024
// 21025
// 21026
// 21027
// 21028
// 21029
// 21030
// 21031
// 21032
// 21033
// 21034
// 21035
// 21036
// 21037
// 21038
// 21039
// 21040
// 21041
// 21042
// 21043
// 21044
// 21045
// 21046
// 21047
// 21048
// 21049
// 21050
// 21051
// 21052
// 21053
// 21054
// 21055
// 21056
// 21057
// 21058
// 21059
// 21060
// 21061
// 21062
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D; _e_wOYp_2=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213001%3Ashutdown%3Apresence%3Aconnection_shutdown%22%7D%2C4%5D");
// 21064
// 21065
// 21066
// 21069
// 21070
// 21071
// 21072
// 21073
// 21074
// 21075
// 21076
// 21077
// 21078
// 21079
// 21080
// 21081
// 21082
// 21083
// 21084
// 21085
// 21086
// 21087
// 21088
// 21089
// 21090
// 21091
// 21092
// 21093
// 21094
// 21095
// 21096
// 21097
// 21098
// 21099
// 21100
// 21101
// 21103
// 21104
// 21105
// 21106
// 21107
// 21108
// 21109
// 21110
// 21111
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; _e_wOYp_0=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D; _e_wOYp_1=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213003%3Awarning%3Apresence%3Adisplaying_shutdown%3Aconnection_shutdown%22%7D%2C4%5D; _e_wOYp_2=%5B%22wOYp%22%2Cnull%2C%22realtime-error%22%2C%7B%22data%22%3A%2213001%3Ashutdown%3Apresence%3Aconnection_shutdown%22%7D%2C4%5D; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC");
// 21113
// 21114
// 21115
// 21116
// 21117
o32 = {};
// 21118
f925563445_0.returns.push(o32);
// undefined
o32 = null;
// 21119
// 21120
// 21121
// 21122
// 21123
// 21124
// 21125
// 21126
// 21127
// 21128
// 21129
// 21130
// 21131
// 21132
// 21133
// 21134
// 21135
// 21136
// 21137
// 21138
// 21139
// 21140
// 21141
// 21142
// 21143
// 21144
// 21146
// 21147
// 21148
// 21149
// 21150
// 21151
// 21152
// 21153
// 21154
// 21155
// 21156
// 21157
// 21158
// 21159
// 21160
// 21161
// 21162
// 21163
// 21164
// 21165
// 21166
// 21167
// 21168
// 21169
// 21170
// 21171
// 21172
// 21173
// 21174
// 21175
// 21176
// 21177
// 21178
// 21179
// 21180
// 21181
// 21182
// 21183
// 21184
// 21185
// 21186
// 21187
// 21188
// 21189
// 21190
// 21191
// 21192
// 21193
// 21194
// 21195
// 21196
// 21197
// 21198
// 21199
// 21200
// 21201
// 21202
// 21203
// 21204
// 21205
// 21206
// 21207
// 21208
// 21209
// 21210
// 21211
// 21212
// 21213
// 21214
// 21215
// 21216
// 21217
// 21218
// 21219
// 21220
// 21221
// 21222
// 21223
// 21224
// 21225
// 21226
// 21227
// 21228
// 21229
// 21230
// 21231
// 21232
// 21233
// 21234
// 21235
// 21236
// 21237
// 21238
// 21239
// 21240
// 21241
// 21242
// 21243
// 21244
// 21245
// 21246
// 21247
// 21248
// 21249
// 21250
// 21251
// 21252
// 21253
// 21254
// 21255
// 21256
// 21257
// 21258
// 21259
// 21260
// 21261
o32 = {};
// 21262
f925563445_74.returns.push(o32);
// 21263
// 21264
// 21265
// 21266
// 21267
// 21268
o32.open = f925563445_625;
// 21269
// 21270
// 21271
f925563445_625.returns.push(undefined);
// 21272
// 21273
o32.setRequestHeader = f925563445_626;
// 21274
// 21275
f925563445_626.returns.push(undefined);
// 21276
// 21277
// 21278
// 21279
o32.send = f925563445_627;
// 21280
// 21281
f925563445_627.returns.push(undefined);
// 21282
// 21283
// 21284
// 21285
// 21286
// undefined
fo925563445_1179_readyState = function() { return fo925563445_1179_readyState.returns[fo925563445_1179_readyState.inst++]; };
fo925563445_1179_readyState.returns = [];
fo925563445_1179_readyState.inst = 0;
defineGetter(o32, "readyState", fo925563445_1179_readyState);
// undefined
fo925563445_1179_readyState.returns.push(1);
// 21289
// 21290
// 21291
// 21292
// 21293
// 21294
// 21295
// 21296
// 21297
// 21298
// 21299
// 21300
// 21301
// 21302
// 21303
// 21304
// 21305
// 21306
// 21307
// 21308
// 21309
// 21310
// 21311
// 21312
// 21313
// 21314
// 21315
// 21316
// 21317
// 21318
// 21319
// 21320
// 21321
// 21322
// 21323
// 21324
// 21325
// 21326
// 21327
// 21328
// 21329
// 21330
// 21331
// 21332
// 21333
// 21334
// 21335
// 21336
// 21337
// 21338
// 21339
// 21340
// 21341
// 21342
// 21343
// 21344
// 21345
// 21346
// 21347
// 21348
// 21349
// 21350
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 21352
// 21353
// 21354
// 21355
// 21356
// 21357
// 21358
// 21359
// 21360
// 21361
// 21362
// 21363
// 21364
// 21365
// 21366
// 21367
// 21368
// 21369
// 21370
// 21371
// 21372
// 21373
// 21374
// 21375
// 21376
// 21377
// 21378
// 21379
// 21380
// 21382
// 21383
// 21384
// 21385
// 21386
// 21387
// 21388
// 21389
// 21390
// 21391
// 21392
// 21393
// 21394
// 21395
// 21396
// 21397
// 21398
// 21399
// 21400
// 21401
// 21402
// 21403
// 21404
// 21405
// 21406
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 21408
// 21409
// 21410
// 21411
// 21412
// 21413
// 21414
// 21415
// 21416
// 21417
// 21418
// 21419
// 21420
// 21421
// 21422
// 21423
// 21424
// 21425
// 21426
// 21427
// 21428
// 21429
// 21430
// 21431
// 21432
// 21433
// 21434
// 21435
// 21436
// 21437
// 21438
// 21439
// 21440
// 21441
// 21442
// 21443
// 21444
// 21445
// 21446
// 21447
// 21448
// 21449
// 21450
// 21451
// 21452
// 21453
// 21454
// 21455
// 21456
// 21457
// 21458
// 21459
// 21460
// 21461
// 21462
// 21463
// 21464
// 21465
// 21466
// 21467
// 21468
// 21469
// 21470
o33 = {};
// 21471
f925563445_74.returns.push(o33);
// 21472
// 21473
// 21474
// 21475
// 21476
// 21477
o33.open = f925563445_625;
// 21478
// 21479
// 21480
f925563445_625.returns.push(undefined);
// 21481
// 21482
o33.setRequestHeader = f925563445_626;
// 21483
// 21484
f925563445_626.returns.push(undefined);
// 21486
// 21487
f925563445_626.returns.push(undefined);
// 21488
// 21489
// 21490
// 21491
o33.send = f925563445_627;
// 21492
// 21493
f925563445_627.returns.push(undefined);
// 21494
// 21495
// 21496
// 21497
// 21498
// 21499
// 21500
// 21501
// 21502
// 21503
// 21504
// 21505
// 21506
// 21507
// 21508
// 21509
// 21510
// 21511
// 21512
// 21513
// 21514
// 21515
// 21516
// 21517
// 21518
// 21519
// 21520
// 21521
o34 = {};
// 21522
f925563445_0.returns.push(o34);
// 21523
f925563445_1182 = function() { return f925563445_1182.returns[f925563445_1182.inst++]; };
f925563445_1182.returns = [];
f925563445_1182.inst = 0;
// 21524
o34.getTimezoneOffset = f925563445_1182;
// 21525
// 21526
f925563445_1182.returns.push(240);
// 21527
o34.getTime = f925563445_435;
// undefined
o34 = null;
// 21528
// 21529
f925563445_435.returns.push(1318265709080);
// 21530
// 21531
// 21532
// 21533
// 21534
// 21535
// 21536
// 21537
// 21538
// 21539
// 21540
// 21541
// 21542
// 21543
// 21544
// 21545
// 21546
// 21547
// 21548
// 21549
// 21550
// 21551
// 21552
// 21553
// 21554
// 21555
// 21556
// 21557
// 21558
// 21559
// 21560
// 21561
// 21562
// 21563
// 21564
// 21565
// 21566
// 21567
// 21568
// 21569
// 21570
// 21571
// 21572
// 21573
// 21574
// 21575
// 21576
// 21577
// 21578
// 21579
// 21580
// 21581
// 21582
// 21583
// 21584
// 21585
// 21586
// 21587
// 21588
// 21589
// 21590
// 21591
// 21592
// 21593
// 21594
// 21595
// 21596
// 21597
// 21598
// 21599
// 21600
// 21601
// 21602
// 21603
// 21604
// 21605
// 21606
// 21607
// 21608
// 21609
// 21610
// 21611
// 21612
// 21613
// 21615
// 21616
// 21617
o34 = {};
// 21618
f925563445_577.returns.push(o34);
// 21619
o34.length = 11;
// 21620
o35 = {};
// 21621
o34["0"] = o35;
// 21622
o36 = {};
// 21623
o34["1"] = o36;
// 21624
o37 = {};
// 21625
o34["2"] = o37;
// 21626
o38 = {};
// 21627
o34["3"] = o38;
// 21628
o39 = {};
// 21629
o34["4"] = o39;
// 21630
o40 = {};
// 21631
o34["5"] = o40;
// 21632
o41 = {};
// 21633
o34["6"] = o41;
// 21634
o42 = {};
// 21635
o34["7"] = o42;
// 21636
o43 = {};
// 21637
o34["8"] = o43;
// 21638
o44 = {};
// 21639
o34["9"] = o44;
// 21640
o45 = {};
// 21641
o34["10"] = o45;
// undefined
o34 = null;
// 21642
// 21643
// 21644
o35.className = "itemLabel fsm";
// undefined
o35 = null;
// 21645
// 21646
// 21647
o36.className = "itemLabel fsm";
// undefined
o36 = null;
// 21648
// 21649
// 21650
o37.className = "count hidden_elem uiSideNavCount";
// 21651
// 21652
// 21653
o38.className = "countValue fss";
// 21654
// 21655
// 21656
o39.className = "grip";
// undefined
o39 = null;
// 21657
// 21658
// 21659
o40.className = "imgWrap";
// undefined
o40 = null;
// 21660
// 21661
// 21662
o41.className = "count hidden_elem uiSideNavCount";
// 21663
// 21664
// 21665
o42.className = "countValue fss";
// 21666
// 21667
// 21668
o43.className = "maxCountIndicator";
// 21669
// 21670
// 21671
o44.className = "linkChild";
// 21672
// 21673
// 21674
o45.className = "mover hidden_elem";
// undefined
o45 = null;
// 21675
// 21676
// 21677
// 21678
o37.getElementsByTagName = f925563445_577;
// undefined
o37 = null;
// 21679
// 21680
// 21681
o34 = {};
// 21682
f925563445_577.returns.push(o34);
// 21683
o34.length = 1;
// 21684
o34["0"] = o38;
// undefined
o34 = null;
// 21685
// 21686
// 21688
// 21689
// 21690
// 21691
// 21692
// 21693
// 21694
o34 = {};
// 21695
o38.firstChild = o34;
// undefined
o38 = null;
// 21696
o34.nodeValue = "0";
// undefined
o34 = null;
// 21697
// 21698
// 21699
// 21700
// 21701
// 21702
// 21703
// 21704
// 21705
// 21706
// 21707
// 21708
// 21709
// 21710
// 21711
// 21712
// 21713
// 21714
// 21715
// 21716
// 21717
// 21718
// 21719
// 21720
// 21721
// 21722
// 21723
// 21724
// 21725
// 21726
// 21727
// 21728
// 21729
// 21730
// 21731
// 21732
// 21733
// 21734
// 21735
// 21736
// 21737
// 21738
// 21739
// 21740
// 21741
// 21742
// 21743
// 21744
// 21745
// 21746
// 21747
// 21748
// 21749
// 21750
// 21751
// 21752
// 21753
// 21754
// 21755
// 21756
// 21757
// 21758
// 21759
// 21761
// 21762
// 21763
o34 = {};
// 21764
f925563445_577.returns.push(o34);
// 21765
o34.length = 4;
// 21766
o34["0"] = o41;
// 21767
o34["1"] = o42;
// 21768
o34["2"] = o43;
// 21769
o34["3"] = o44;
// undefined
o34 = null;
// undefined
o44 = null;
// 21770
// 21771
// 21773
// 21774
// 21776
// 21777
// 21779
// 21780
// 21782
// 21783
// 21784
// 21785
o41.getElementsByTagName = f925563445_577;
// undefined
o41 = null;
// 21786
// 21787
// 21788
o34 = {};
// 21789
f925563445_577.returns.push(o34);
// 21790
o34.length = 2;
// 21791
o34["0"] = o42;
// 21792
o34["1"] = o43;
// undefined
o34 = null;
// 21793
// 21794
// 21796
// 21797
// 21799
// 21800
// 21801
// 21803
// 21804
// 21805
o34 = {};
// 21806
f925563445_577.returns.push(o34);
// 21807
o34.length = 2;
// 21808
o34["0"] = o42;
// 21809
o34["1"] = o43;
// undefined
o34 = null;
// undefined
o43 = null;
// 21810
// 21811
// 21813
// 21814
// 21816
// 21817
// 21818
// 21819
// 21820
// 21821
// 21822
// 21823
// 21824
// 21825
// 21826
// 21827
// 21828
// 21829
// 21830
// 21831
// 21832
// 21833
// 21834
// 21835
// 21836
// 21837
// 21838
// 21839
// 21840
// 21841
// 21842
// 21843
// 21844
// 21845
// 21846
// 21847
o34 = {};
// 21848
o42.firstChild = o34;
// undefined
o42 = null;
// 21849
o34.nodeValue = "0";
// undefined
o34 = null;
// 21850
// 21851
// 21852
// 21853
// 21854
// 21855
// 21856
// 21857
// 21858
// 21859
// 21860
// 21861
// 21862
// 21863
// 21864
// 21865
// 21866
// 21867
// 21868
// 21869
// 21870
// 21871
// 21872
// 21873
// 21874
// 21875
// 21876
// 21877
// 21878
// 21879
// 21880
// 21881
// 21882
// 21883
// 21884
// 21885
// 21886
// 21887
// 21888
// 21889
// 21890
// 21891
// 21892
// 21893
// 21894
// 21895
// 21896
// 21897
// 21898
// 21899
// 21900
// 21901
// 21903
// 21904
// 21905
// 21906
// 21907
// 21908
// 21909
// 21910
// 21911
// 21912
// 21913
// 21914
// 21915
// 21916
// 21917
// 21918
// 21919
// 21920
// 21921
// 21922
// 21923
// 21924
// 21925
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 21927
// 21928
// 21929
// 21930
// 21931
// 21932
// 21933
// 21934
// 21935
// 21936
// 21937
// 21938
// 21939
// 21940
// 21941
// 21942
// 21943
// 21944
// 21945
// 21946
// 21947
// 21948
// 21949
// 21950
// 21951
// 21952
// 21953
// 21954
// 21955
// 21956
// 21957
// 21958
// 21959
// 21960
// 21961
// 21962
// 21963
// 21964
// 21965
// 21966
// 21967
// 21968
// 21969
// 21970
// 21971
// 21972
// 21973
// 21974
// 21975
// 21976
// 21977
// 21978
// 21979
// 21980
// 21981
// 21982
// 21983
// 21984
// 21985
// 21986
// 21987
// 21988
// 21989
// 21990
// 21991
// 21992
// 21993
// 21994
// 21995
// 21996
// 21997
// 21998
// 21999
// 22000
// 22001
// 22002
// 22003
// 22004
// 22005
// 22006
// 22007
// 22008
// 22009
// 22010
// 22011
// 22012
// 22013
// 22014
o34 = {};
// 22015
f925563445_74.returns.push(o34);
// 22016
// 22017
// 22018
// 22019
// 22020
// 22021
o34.open = f925563445_625;
// 22022
// 22023
// 22024
f925563445_625.returns.push(undefined);
// 22025
// 22026
o34.setRequestHeader = f925563445_626;
// 22027
// 22028
f925563445_626.returns.push(undefined);
// 22030
// 22031
f925563445_626.returns.push(undefined);
// 22032
// 22033
// 22034
// 22035
o34.send = f925563445_627;
// 22036
// 22037
f925563445_627.returns.push(undefined);
// 22038
// 22039
// 22040
// 22041
// 22042
// 22043
// 22044
// 22045
// 22046
// 22047
// 22048
// 22049
// 22050
// 22051
// 22052
// 22053
// 22054
// 22055
// 22056
// 22057
// 22058
// 22059
// 22060
// undefined
fo925563445_1180_readyState = function() { return fo925563445_1180_readyState.returns[fo925563445_1180_readyState.inst++]; };
fo925563445_1180_readyState.returns = [];
fo925563445_1180_readyState.inst = 0;
defineGetter(o33, "readyState", fo925563445_1180_readyState);
// undefined
fo925563445_1180_readyState.returns.push(1);
// 22062
// 22063
// 22064
// 22065
// undefined
fo925563445_1201_readyState = function() { return fo925563445_1201_readyState.returns[fo925563445_1201_readyState.inst++]; };
fo925563445_1201_readyState.returns = [];
fo925563445_1201_readyState.inst = 0;
defineGetter(o34, "readyState", fo925563445_1201_readyState);
// undefined
fo925563445_1201_readyState.returns.push(1);
// 22067
// 22068
// 22069
// 22070
// 22071
// 22074
// 22075
// 22076
// 22077
// 22078
o35 = {};
// 22079
o36 = {};
// 22081
// 22082
// 22083
// 22084
// 22085
// 22086
// 22089
// 22090
// 22091
// 22092
// 22093
o37 = {};
// 22094
o38 = {};
// 22096
// 22097
// 22098
// 22099
// 22100
// undefined
fo925563445_1179_readyState.returns.push(2);
// 22102
// 22103
// 22104
// 22105
// undefined
fo925563445_1179_readyState.returns.push(3);
// 22107
// 22108
// 22109
// 22110
// undefined
fo925563445_1179_readyState.returns.push(4);
// 22112
// 22113
o32.getResponseHeader = f925563445_1171;
// 22115
// 22116
f925563445_1171.returns.push("10.65.37.39");
// 22118
// 22119
f925563445_1171.returns.push("10.65.37.39");
// 22120
o32.JSBNG__status = 200;
// undefined
o32 = null;
// 22121
// 22122
// 22124
// 22125
// 22126
// 22127
// 22128
// 22129
// 22131
// 22132
// 22133
// 22134
// 22135
// 22136
// 22137
// 22138
// 22139
// 22140
// 22141
// 22142
// 22143
// 22144
// 22145
// 22146
// 22147
f925563445_14.returns.push(undefined);
// 22148
// 22149
// 22150
// 22151
// 22152
// 22153
// 22154
// 22155
// 22156
// 22157
// 22158
// 22159
// 22160
// 22161
// 22162
// 22163
// 22164
o32 = {};
// 22165
f925563445_0.returns.push(o32);
// 22166
o32.getTime = f925563445_435;
// undefined
o32 = null;
// 22167
// 22168
f925563445_435.returns.push(1318265709105);
// 22169
// 22170
// 22171
// 22172
// 22173
// 22174
// 22175
// 22176
// 22177
f925563445_12.returns.push(18);
// 22178
// 22179
// 22180
// 22181
// 22182
o32 = {};
// 22183
f925563445_0.returns.push(o32);
// undefined
o32 = null;
// 22184
// 22185
// 22186
// 22187
// 22188
f925563445_426.returns.push(0.4874163190834224);
// 22189
// 22190
// 22191
// 22192
o32 = {};
// 22193
f925563445_0.returns.push(o32);
// undefined
o32 = null;
// 22194
// 22195
// 22196
// 22197
// 22198
// 22199
// 22200
// 22201
// 22202
f925563445_12.returns.push(19);
// 22203
// 22204
// 22205
// 22206
// 22207
// 22208
// 22209
// 22212
// 22213
// 22214
// 22215
// 22216
o32 = {};
// 22217
o39 = {};
// 22219
// 22220
// 22221
// 22222
// 22223
// 22224
// 22227
// 22228
// 22229
// 22230
// 22231
o40 = {};
// 22232
o41 = {};
// 22234
// 22235
// 22236
// 22237
// 22238
// 22239
// 22242
// 22243
// 22244
// 22245
// 22246
o42 = {};
// 22247
o43 = {};
// 22249
// 22250
// 22251
// 22252
// 22253
// 22254
// 22257
// 22258
// 22259
// 22260
// 22261
o44 = {};
// 22262
o45 = {};
// 22264
// 22265
// 22266
// 22267
// 22268
// 22269
// 22272
// 22273
// 22274
// 22275
// 22276
o46 = {};
// 22277
o47 = {};
// 22279
// 22280
// 22281
// 22282
// 22283
// 22284
// 22287
// 22288
// 22289
// 22290
// 22291
o48 = {};
// 22292
o49 = {};
// 22294
// 22295
// 22296
// 22297
// 22298
// 22299
// 22302
// 22303
// 22304
// 22305
// 22306
o50 = {};
// 22307
o51 = {};
// 22309
// 22310
// 22311
// 22312
// 22313
// 22314
// 22317
// 22318
// 22319
// 22320
// 22321
o52 = {};
// 22322
o53 = {};
// 22324
// 22325
// 22326
// 22327
// 22328
// 22329
// 22332
// 22333
// 22334
// 22335
// 22336
o54 = {};
// 22337
o55 = {};
// 22339
// 22340
// 22341
// 22342
// 22343
// 22344
// 22347
// 22348
// 22349
// 22350
// 22351
o56 = {};
// 22352
o57 = {};
// 22354
// 22355
// 22356
// 22357
// 22358
// 22359
// 22362
// 22363
// 22364
// 22365
// 22366
o58 = {};
// 22367
o59 = {};
// 22369
// 22370
// 22371
// 22372
// 22373
// 22374
// 22377
// 22378
// 22379
// 22380
// 22381
o60 = {};
// 22382
o61 = {};
// 22384
// 22385
// 22386
// 22387
// 22388
// 22389
// 22392
// 22393
// 22394
// 22395
// 22396
o62 = {};
// 22397
o63 = {};
// 22399
// 22400
// 22401
// 22402
// 22403
// 22404
// 22407
// 22408
// 22409
// 22410
// 22411
o64 = {};
// 22412
o65 = {};
// 22414
// 22415
// 22416
// 22417
// 22418
// undefined
fo925563445_1180_readyState.returns.push(2);
// 22420
// 22421
// 22422
// 22423
// undefined
fo925563445_1180_readyState.returns.push(3);
// 22425
// 22426
// 22427
// 22428
// undefined
fo925563445_1180_readyState.returns.push(4);
// 22430
// 22431
o33.getResponseHeader = f925563445_1171;
// 22433
// 22434
f925563445_1171.returns.push("10.65.41.33");
// 22436
// 22437
f925563445_1171.returns.push("10.65.41.33");
// 22438
o33.JSBNG__status = 200;
// undefined
o33 = null;
// 22439
// 22440
// 22442
// 22443
// 22444
// 22445
// 22446
// 22447
// 22449
// 22450
// 22451
// 22452
// 22453
// 22454
// 22455
// 22456
// 22457
// 22458
// 22459
// 22460
// 22461
// 22462
// 22463
// 22464
// 22465
f925563445_14.returns.push(undefined);
// 22466
// 22467
// 22468
// 22469
// 22470
// 22471
// 22472
f925563445_426.returns.push(0.4764978236053139);
// 22473
// 22474
// 22475
// 22476
// 22477
// 22478
// undefined
fo925563445_1201_readyState.returns.push(2);
// 22480
// 22481
// 22482
// 22483
// undefined
fo925563445_1201_readyState.returns.push(3);
// 22485
// 22486
// 22487
// 22488
// undefined
fo925563445_1201_readyState.returns.push(4);
// 22490
// 22491
o34.getResponseHeader = f925563445_1171;
// 22493
// 22494
f925563445_1171.returns.push("10.62.192.40");
// 22496
// 22497
f925563445_1171.returns.push("10.62.192.40");
// 22498
o34.JSBNG__status = 200;
// undefined
o34 = null;
// 22499
// 22500
// 22502
// 22503
// 22504
// 22505
// 22506
// 22507
// 22509
// 22510
// 22511
// 22512
// 22513
// 22514
// 22515
// 22516
// 22517
// 22518
// 22519
// 22520
// 22521
// 22522
// 22523
// 22524
// 22525
f925563445_14.returns.push(undefined);
// 22526
// 22527
// 22528
// 22529
// 22530
// 22531
// 22532
f925563445_426.returns.push(0.7880751539487392);
// 22533
// 22534
// 22535
// 22536
// 22537
// 22538
// undefined
fo925563445_959_readyState.returns.push(2);
// 22540
// 22541
// 22542
// 22543
// undefined
fo925563445_959_readyState.returns.push(3);
// 22545
// 22546
// 22547
// 22548
// undefined
fo925563445_959_readyState.returns.push(3);
// 22550
// 22551
// 22552
// 22553
// undefined
fo925563445_959_readyState.returns.push(3);
// 22555
// 22556
// 22557
// 22558
// undefined
fo925563445_959_readyState.returns.push(4);
// 22560
// 22561
o4.getResponseHeader = f925563445_1171;
// 22563
// 22564
f925563445_1171.returns.push("10.65.38.55");
// 22566
// 22567
f925563445_1171.returns.push("10.65.38.55");
// 22568
o4.JSBNG__status = 200;
// undefined
o4 = null;
// 22569
// 22570
// 22572
// 22573
// 22574
// 22575
// 22576
// 22577
// 22579
// 22580
// 22581
// 22582
// 22583
// 22584
// 22585
// 22586
// 22587
// 22588
// 22589
// 22590
// 22591
// 22592
// 22593
// undefined
fo925563445_622_className.returns.push("clearfix uiMorePager stat_elem uiMorePagerCenter async_saving");
// undefined
fo925563445_622_className.returns.push("clearfix uiMorePager stat_elem uiMorePagerCenter async_saving");
// 22597
// 22598
// 22599
// 22600
// undefined
fo925563445_622_className.returns.push("clearfix uiMorePager stat_elem uiMorePagerCenter ");
// undefined
fo925563445_622_className.returns.push("clearfix uiMorePager stat_elem uiMorePagerCenter ");
// 22604
// 22605
// 22606
// 22607
// 22608
// 22609
f925563445_14.returns.push(undefined);
// 22610
// 22611
// 22612
// 22613
// 22614
// 22615
// 22616
f925563445_426.returns.push(0.1013260695617646);
// 22617
// 22618
// 22619
// 22620
// 22621
// 22622
// 22623
// 22624
o4 = {};
// 22625
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22626
// 22627
// 22628
f925563445_426.returns.push(0.2615745533257723);
// 22629
// 22630
// 22631
// 22632
f925563445_12.returns.push(20);
// 22634
// 22635
// 22636
o4 = {};
// 22637
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22638
// 22639
// 22640
// 22641
// 22642
// 22643
// 22644
// 22645
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 22647
// 22648
// 22649
// 22650
// 22651
// 22652
// 22653
// 22654
// 22655
// 22656
// 22657
// 22658
// 22659
// 22660
// 22661
// 22662
// 22663
// 22664
// 22665
// 22666
// 22667
// 22668
// 22669
// 22670
// 22671
// 22672
// 22673
// 22674
// 22675
// 22676
// 22677
// 22678
// 22679
// 22680
// 22681
// 22682
// 22683
// 22684
// 22685
// 22686
// 22687
// 22688
// 22689
// 22690
// 22691
// 22692
o4 = {};
// 22693
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22694
// 22695
// 22696
f925563445_426.returns.push(0.5161666152998805);
// 22697
// 22698
// 22699
// 22700
f925563445_12.returns.push(21);
// 22702
// 22703
// 22704
o4 = {};
// 22705
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22706
// 22707
// 22708
// 22709
// 22710
// 22711
// 22712
// 22713
o4 = {};
// 22714
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22715
// 22716
// 22717
// 22718
// 22720
// 22721
f925563445_1035.returns.push(undefined);
// 22722
// 22724
// 22725
f925563445_1035.returns.push(undefined);
// 22726
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 22728
// 22729
o4 = {};
// 22730
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 22732
// 22733
// 22735
// 22736
// 22737
f925563445_432.returns.push("[\"wOYp\",null,\"channel-connectivity\",{\"idle\":null},4]");
// 22738
// 22740
// 22741
// 22743
// 22744
// 22745
f925563445_1037.returns.push(undefined);
// 22746
// 22748
// 22749
f925563445_1035.returns.push(undefined);
// 22750
// 22751
// 22752
o4 = {};
// 22753
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22754
// 22755
// 22756
// 22757
f925563445_12.returns.push(22);
// 22758
// 22759
// 22760
// 22761
// 22762
// 22763
// 22764
// 22765
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_3=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 22767
// 22768
// 22769
// 22770
// 22771
// 22772
// 22773
o4 = {};
// 22774
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22775
// 22776
// 22777
f925563445_426.returns.push(0.9291730450931937);
// 22778
// 22779
// 22780
// 22781
f925563445_12.returns.push(23);
// 22782
// 22783
// 22784
// 22785
// 22786
// 22787
// 22788
// 22790
// 22791
// 22792
o4 = {};
// 22793
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22794
// 22795
// 22796
// 22797
// 22798
// 22799
// 22800
// 22801
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_3=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 22803
// 22804
// 22805
// 22806
// 22807
// 22808
// 22809
o4 = {};
// 22810
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22811
// 22812
// 22813
f925563445_426.returns.push(0.7450962015427649);
// 22814
// 22815
// 22816
// 22817
f925563445_12.returns.push(24);
// 22819
// 22820
// 22821
o4 = {};
// 22822
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22823
// 22824
// 22825
// 22826
// 22827
// 22828
o4 = {};
// 22829
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22830
// 22831
// 22832
f925563445_426.returns.push(0.9610402574762702);
// 22833
// 22834
// 22835
// 22836
f925563445_12.returns.push(25);
// 22837
// 22838
// 22839
// 22840
// 22841
// 22842
// 22843
// 22844
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_3=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 22846
// 22848
// 22849
// 22850
o4 = {};
// 22851
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22852
// 22853
// 22854
// 22855
// 22856
// 22857
o4 = {};
// 22858
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22859
// 22860
// 22861
f925563445_426.returns.push(0.06283501186408103);
// 22862
// 22863
// 22864
// 22865
f925563445_12.returns.push(26);
// 22866
// 22867
// 22868
// 22869
// 22870
// 22871
// 22872
// 22873
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_3=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 22875
// 22876
// 22877
// 22878
// 22879
// 22880
// 22881
// 22882
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_3=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 22884
// 22885
// 22886
// 22887
// 22888
o4 = {};
// 22889
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 22890
// 22891
// 22892
// 22893
// 22894
// 22895
// 22896
// 22897
// 22898
// 22899
// 22900
// 22901
// 22902
// 22903
// 22904
// 22905
// 22906
// 22907
// 22908
// 22909
// 22910
// 22911
// 22912
// 22913
// 22914
// 22915
// 22917
// 22918
// 22919
// 22920
// 22921
// 22922
// 22923
// 22924
// 22925
// 22926
// 22927
// 22928
// 22929
// 22930
// 22931
// 22932
// 22933
// 22934
// 22935
// 22936
// 22937
// 22938
// 22939
// 22940
// 22941
// 22942
// 22943
// 22944
// 22945
// 22946
// 22947
// 22948
// 22949
// 22950
// 22951
// 22952
// 22953
// 22954
// 22955
// 22956
// 22957
// 22958
// 22959
// 22960
// 22961
// 22962
// 22963
// 22964
// 22965
// 22966
// 22967
// 22968
// 22969
// 22970
// 22971
// 22972
// 22973
// 22974
// 22975
// 22976
// 22977
// 22978
// 22979
// 22980
// 22981
// 22982
// 22983
// 22984
// 22985
// 22986
// 22987
// 22988
// 22989
// 22990
// 22991
// 22992
// 22993
// 22994
// 22995
// 22996
// 22997
// 22998
// 22999
// 23000
// 23001
// 23002
// 23003
// 23004
// 23005
// 23006
// 23007
// 23008
// 23009
// 23010
// 23011
// 23012
// 23013
// 23014
// 23015
// 23016
// 23017
// 23018
// 23019
// 23020
// 23021
// 23022
// 23023
// 23024
// 23025
// 23026
// 23027
// 23028
// 23029
// 23030
// 23031
// 23032
o4 = {};
// 23033
f925563445_74.returns.push(o4);
// 23034
// 23035
// 23036
// 23037
// 23038
// 23039
o4.open = f925563445_625;
// 23040
// 23041
// 23042
f925563445_625.returns.push(undefined);
// 23043
// 23044
o4.setRequestHeader = f925563445_626;
// 23045
// 23046
f925563445_626.returns.push(undefined);
// 23047
// 23048
// 23049
// 23050
o4.send = f925563445_627;
// 23051
// 23052
f925563445_627.returns.push(undefined);
// 23053
// 23054
// 23055
// 23056
// 23057
// undefined
fo925563445_1252_readyState = function() { return fo925563445_1252_readyState.returns[fo925563445_1252_readyState.inst++]; };
fo925563445_1252_readyState.returns = [];
fo925563445_1252_readyState.inst = 0;
defineGetter(o4, "readyState", fo925563445_1252_readyState);
// undefined
fo925563445_1252_readyState.returns.push(1);
// 23059
// 23060
// 23061
// 23062
// undefined
fo925563445_1252_readyState.returns.push(2);
// 23064
// 23065
// 23066
// 23067
// undefined
fo925563445_1252_readyState.returns.push(3);
// 23069
// 23070
// 23071
// 23072
// undefined
fo925563445_1252_readyState.returns.push(4);
// 23074
// 23075
o4.getResponseHeader = f925563445_1171;
// 23077
// 23078
f925563445_1171.returns.push("10.65.41.34");
// 23080
// 23081
f925563445_1171.returns.push("10.65.41.34");
// 23082
o4.JSBNG__status = 200;
// undefined
o4 = null;
// 23083
// 23084
// 23086
// 23087
// 23088
// 23089
// 23090
// 23091
// 23093
// 23094
// 23095
// 23096
// 23097
// 23098
// 23099
// 23100
// 23101
// 23102
// 23103
// 23104
// 23105
// 23106
// 23107
// 23108
// 23109
f925563445_14.returns.push(undefined);
// 23110
// 23111
// 23112
// 23113
// 23114
// 23115
// 23116
// 23117
// 23118
// 23119
// 23120
// 23121
// 23122
// 23123
// 23124
// 23125
// 23126
o4 = {};
// 23127
f925563445_0.returns.push(o4);
// 23128
o4.getTime = f925563445_435;
// undefined
o4 = null;
// 23129
// 23130
f925563445_435.returns.push(1318265719342);
// 23131
// 23132
// 23133
// 23134
// 23135
// 23136
// 23137
// 23138
// 23139
f925563445_12.returns.push(27);
// 23140
// 23141
// 23142
// 23143
// 23144
o4 = {};
// 23145
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23146
// 23147
// 23148
// 23149
// 23150
f925563445_426.returns.push(0.4887543504592031);
// 23151
// 23152
// 23153
// 23154
o4 = {};
// 23155
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23156
// 23157
// 23158
// 23159
// 23160
// 23161
// 23162
// 23163
// 23164
f925563445_12.returns.push(28);
// 23165
// 23166
// 23167
// 23168
// 23169
// 23170
// 23171
// 23172
o4 = {};
// 23173
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23174
// 23175
// 23176
f925563445_426.returns.push(0.7287387405522168);
// 23177
// 23178
// 23179
// 23180
f925563445_12.returns.push(29);
// 23182
// 23183
// 23184
o4 = {};
// 23185
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23186
// 23187
// 23188
// 23189
// 23190
// 23191
// 23192
// 23193
o4 = {};
// 23194
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23195
// 23196
// 23197
// 23198
// 23200
// 23201
f925563445_1035.returns.push(undefined);
// 23202
// 23204
// 23205
f925563445_1035.returns.push(undefined);
// 23206
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 23208
// 23209
o4 = {};
// 23210
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80");
// 23212
// 23213
// 23215
// 23216
// 23217
f925563445_432.returns.push("[\"wOYp\",null,\"channel-connectivity\",{\"idle\":null},4]");
// 23218
// 23220
// 23221
// 23223
// 23224
// 23225
f925563445_1037.returns.push(undefined);
// 23226
// 23228
// 23229
f925563445_1035.returns.push(undefined);
// 23230
// 23231
// 23232
o4 = {};
// 23233
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23234
// 23235
// 23236
// 23237
f925563445_12.returns.push(30);
// 23238
// 23239
// 23240
// 23241
// 23242
// 23243
// 23244
// 23245
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_4=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 23247
// 23248
// 23249
// 23250
// 23251
// 23252
// 23253
o4 = {};
// 23254
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23255
// 23256
// 23257
f925563445_426.returns.push(0.775548882316798);
// 23258
// 23259
// 23260
// 23261
f925563445_12.returns.push(31);
// 23263
// 23264
// 23265
o4 = {};
// 23266
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23267
// 23268
// 23269
// 23270
// 23271
// 23272
// 23273
// 23274
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_4=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 23276
// 23277
// 23278
// 23279
// 23280
// 23281
// 23282
o4 = {};
// 23283
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23284
// 23285
// 23286
f925563445_426.returns.push(0.25731974467635155);
// 23287
// 23288
// 23289
// 23290
f925563445_12.returns.push(32);
// 23291
// 23292
// 23293
// 23294
// 23295
// 23296
o4 = {};
// 23297
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23298
// 23299
// 23300
f925563445_426.returns.push(0.6576182895805687);
// 23301
// 23302
// 23303
// 23304
f925563445_12.returns.push(33);
// 23305
// 23306
// 23307
// 23308
// 23309
// 23310
// 23311
// 23313
// 23314
// 23315
o4 = {};
// 23316
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23317
// 23318
// 23319
// 23320
// 23321
// 23322
// 23323
// 23324
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_4=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 23326
// 23327
// 23328
// 23329
// 23330
// 23331
// 23332
o4 = {};
// 23333
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23334
// 23335
// 23336
f925563445_426.returns.push(0.137124037835747);
// 23337
// 23338
// 23339
// 23340
f925563445_12.returns.push(34);
// 23342
// 23343
// 23344
o4 = {};
// 23345
f925563445_0.returns.push(o4);
// undefined
o4 = null;
// 23346
// 23347
// 23348
// 23349
// 23350
// 23351
// 23352
// 23353
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_4=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 23355
// 23356
// 23357
// 23358
// 23359
// 23360
// 23363
// 23364
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23367
// 23368
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23371
o4 = {};
// 23372
o33 = {};
// 23374
// 23375
// 23376
// 23377
// 23378
// 23379
// 23382
// 23383
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23386
// 23387
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23390
o34 = {};
// 23391
o66 = {};
// 23393
// 23394
// 23395
// 23396
// 23397
// 23398
// 23401
// 23402
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23405
// 23406
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23409
o67 = {};
// 23410
o68 = {};
// 23412
// 23413
// 23414
// 23415
// 23416
// 23417
// 23418
o69 = {};
// 23419
f925563445_0.returns.push(o69);
// undefined
o69 = null;
// 23420
// 23421
// 23422
f925563445_426.returns.push(0.694502308499068);
// 23423
// 23424
// 23425
// 23426
f925563445_12.returns.push(35);
// 23427
// 23428
// 23429
// 23430
// 23431
// 23434
// 23435
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23438
// 23439
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23442
o69 = {};
// 23443
o70 = {};
// 23445
// 23446
// 23447
// 23448
// 23449
// 23450
// 23453
// 23454
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23457
// 23458
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23461
o71 = {};
// 23462
o72 = {};
// 23464
// 23465
// 23466
// 23467
// 23468
// 23469
// 23472
// 23473
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23476
// 23477
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23480
o73 = {};
// 23481
o74 = {};
// 23483
// 23484
// 23485
// 23486
// 23487
// 23488
// 23491
// 23492
// undefined
fo925563445_573___FB_TOKEN.returns.push(o24);
// 23495
// 23496
// undefined
fo925563445_573___FB_TOKEN.returns.push(o24);
// undefined
o24 = null;
// 23499
o24 = {};
// 23500
o75 = {};
// 23502
// 23503
// 23504
// 23505
// 23506
// 23507
// 23510
// 23511
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23514
// 23515
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23518
o76 = {};
// 23519
o77 = {};
// 23521
// 23522
// 23523
// 23524
// 23525
// 23526
// 23529
// 23530
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23533
// 23534
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23537
o78 = {};
// 23538
o79 = {};
// 23540
// 23541
// 23542
// 23543
// 23544
// 23545
// 23548
// 23549
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23552
// 23553
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23556
o80 = {};
// 23557
o81 = {};
// 23559
// 23560
// 23561
// 23562
// 23563
// 23564
// 23567
// 23568
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23571
// 23572
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23575
o82 = {};
// 23576
o83 = {};
// 23578
// 23579
// 23580
// 23581
// 23582
// 23583
// 23586
// 23587
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23590
// 23591
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23594
o84 = {};
// 23595
o85 = {};
// 23597
// 23598
// 23599
// 23600
// 23601
// 23602
// 23605
// 23606
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23609
// 23610
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23613
o86 = {};
// 23614
o87 = {};
// 23616
// 23617
// 23618
// 23619
// 23620
// 23621
// 23624
// 23625
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23628
// 23629
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23632
o88 = {};
// 23633
o89 = {};
// 23635
// 23636
// 23637
// 23638
// 23639
// 23640
// 23643
// 23644
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23647
// 23648
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23651
o90 = {};
// 23652
o91 = {};
// 23654
// 23655
// 23656
// 23657
// 23658
// 23659
// 23662
// 23663
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23666
// 23667
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23670
o92 = {};
// 23671
o93 = {};
// 23673
// 23674
// 23675
// 23676
// 23677
// 23678
// 23681
// 23682
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23685
// 23686
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23689
o94 = {};
// 23690
o95 = {};
// 23692
// 23693
// 23694
// 23695
// 23696
// 23697
// 23700
// 23701
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23704
// 23705
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23708
o96 = {};
// 23709
o97 = {};
// 23711
// 23712
// 23713
// 23714
// 23715
// 23716
// 23719
// 23720
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23723
// 23724
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23727
o98 = {};
// 23728
o99 = {};
// 23730
// 23731
// 23732
// 23733
// 23734
// 23735
// 23738
// 23739
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23742
// 23743
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23746
o100 = {};
// 23747
o101 = {};
// 23749
// 23750
// 23751
// 23752
// 23753
// 23754
// 23757
// 23758
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23761
// 23762
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23765
o102 = {};
// 23766
o103 = {};
// 23768
// 23769
// 23770
// 23771
// 23772
// 23773
// 23776
// 23777
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23780
// 23781
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23784
o104 = {};
// 23785
o105 = {};
// 23787
// 23788
// 23789
// 23790
// 23791
// 23792
// 23795
// 23796
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23799
// 23800
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23803
o106 = {};
// 23804
o107 = {};
// 23806
// 23807
// 23808
// 23809
// 23810
// 23811
// 23814
// 23815
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23818
// 23819
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23822
o108 = {};
// 23823
o109 = {};
// 23825
// 23826
// 23827
// 23828
// 23829
// 23830
// 23833
// 23834
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23837
// 23838
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23841
o110 = {};
// 23842
o111 = {};
// 23844
// 23845
// 23846
// 23847
// 23848
// 23849
// 23852
// 23853
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23856
// 23857
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23860
o112 = {};
// 23861
o113 = {};
// 23863
// 23864
// 23865
// 23866
// 23867
// 23868
// 23871
// 23872
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23875
// 23876
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23879
o114 = {};
// 23880
o115 = {};
// 23882
// 23883
// 23884
// 23885
// 23886
// 23887
// 23890
// 23891
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23894
// 23895
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23898
o116 = {};
// 23899
o117 = {};
// 23901
// 23902
// 23903
// 23904
// 23905
// 23906
// 23909
// 23910
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23913
// 23914
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23917
o118 = {};
// 23918
o119 = {};
// 23920
// 23921
// 23922
// 23923
// 23924
// 23925
// 23928
// 23929
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23932
// 23933
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23936
o120 = {};
// 23937
o121 = {};
// 23939
// 23940
// 23941
// 23942
// 23943
// 23944
// 23947
// 23948
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23951
// 23952
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 23955
o122 = {};
// 23956
o123 = {};
// 23958
// 23959
// 23960
// 23961
// 23962
// 23963
// 23966
// 23967
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23970
// 23971
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 23974
o124 = {};
// 23975
o125 = {};
// 23977
// 23978
// 23979
// 23980
// 23981
// 23982
// 23985
// 23986
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23989
// 23990
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 23993
o126 = {};
// 23994
o127 = {};
// 23996
// 23997
// 23998
// 23999
// 24000
// 24001
// 24004
// 24005
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24008
// 24009
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24012
o128 = {};
// 24013
o129 = {};
// 24015
// 24016
// 24017
// 24018
// 24019
// 24020
// 24023
// 24024
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24027
// 24028
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24031
o130 = {};
// 24032
o131 = {};
// 24034
// 24035
// 24036
// 24037
// 24038
// 24039
// 24042
// 24043
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24046
// 24047
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24050
o132 = {};
// 24051
o133 = {};
// 24053
// 24054
// 24055
// 24056
// 24057
// 24058
// 24061
// 24062
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24065
// 24066
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24069
o134 = {};
// 24070
o135 = {};
// 24072
// 24073
// 24074
// 24075
// 24076
// 24077
// 24080
// 24081
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24084
// 24085
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24088
o136 = {};
// 24089
o137 = {};
// 24091
// 24092
// 24093
// 24094
// 24095
// 24096
// 24099
// 24100
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24103
// 24104
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24107
o138 = {};
// 24108
o139 = {};
// 24110
// 24111
// 24112
// 24113
// 24114
// 24115
// 24118
// 24119
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24122
// 24123
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24126
o140 = {};
// 24127
o141 = {};
// 24129
// 24130
// 24131
// 24132
// 24133
// 24134
// 24137
// 24138
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24141
// 24142
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24145
o142 = {};
// 24146
o143 = {};
// 24148
// 24149
// 24150
// 24151
// 24152
// 24153
// 24156
// 24157
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24160
// 24161
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24164
o144 = {};
// 24165
o145 = {};
// 24167
// 24168
// 24169
// 24170
// 24171
// 24172
// 24175
// 24176
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24179
// 24180
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24183
o146 = {};
// 24184
o147 = {};
// 24186
// 24187
// 24188
// 24189
// 24190
// 24191
// 24194
// 24195
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24198
// 24199
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24202
o148 = {};
// 24203
o149 = {};
// 24205
// 24206
// 24207
// 24208
// 24209
// 24210
// 24213
// 24214
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24217
// 24218
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24221
o150 = {};
// 24222
o151 = {};
// 24224
// 24225
// 24226
// 24227
// 24228
// 24229
// 24232
// 24233
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24236
// 24237
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24240
o152 = {};
// 24241
o153 = {};
// 24243
// 24244
// 24245
// 24246
// 24247
// 24248
// 24251
// 24252
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24255
// 24256
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24259
o154 = {};
// 24260
o155 = {};
// 24262
// 24263
// 24264
// 24265
// 24266
// 24267
// 24270
// 24271
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24274
// 24275
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24278
o156 = {};
// 24279
o157 = {};
// 24281
// 24282
// 24283
// 24284
// 24285
// 24286
// 24289
// 24290
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24293
// 24294
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24297
o158 = {};
// 24298
o159 = {};
// 24300
// 24301
// 24302
// 24303
// 24304
// 24305
// 24308
// 24309
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24312
// 24313
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24316
o160 = {};
// 24317
o161 = {};
// 24319
// 24320
// 24321
// 24322
// 24323
// 24324
// 24327
// 24328
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24331
// 24332
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24335
o162 = {};
// 24336
o163 = {};
// 24338
// 24339
// 24340
// 24341
// 24342
// 24343
// 24346
// 24347
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24350
// 24351
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24354
o164 = {};
// 24355
o165 = {};
// 24357
// 24358
// 24359
// 24360
// 24361
// 24362
// 24365
// 24366
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24369
// 24370
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24373
o166 = {};
// 24374
o167 = {};
// 24376
// 24377
// 24378
// 24379
// 24380
// 24381
// 24384
// 24385
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24388
// 24389
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24392
o168 = {};
// 24393
o169 = {};
// 24395
// 24396
// 24397
// 24398
// 24399
// 24400
// 24403
// 24404
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24407
// 24408
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24411
o170 = {};
// 24412
o171 = {};
// 24414
// 24415
// 24416
// 24417
// 24418
// 24419
// 24422
// 24423
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24426
// 24427
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24430
o172 = {};
// 24431
o173 = {};
// 24433
// 24434
// 24435
// 24436
// 24437
// 24438
// 24441
// 24442
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24445
// 24446
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24449
o174 = {};
// 24450
o175 = {};
// 24452
// 24453
// 24454
// 24455
// 24456
// 24457
// 24460
// 24461
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24464
// 24465
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24468
o176 = {};
// 24469
o177 = {};
// 24471
// 24472
// 24473
// 24474
// 24475
// 24476
// 24479
// 24480
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24483
// 24484
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24487
o178 = {};
// 24488
o179 = {};
// 24490
// 24491
// 24492
// 24493
// 24494
// 24495
// 24498
// 24499
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24502
// 24503
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24506
o180 = {};
// 24507
o181 = {};
// 24509
// 24510
// 24511
// 24512
// 24513
// 24514
// 24517
// 24518
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24521
// 24522
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24525
o182 = {};
// 24526
o183 = {};
// 24528
// 24529
// 24530
// 24531
// 24532
// 24533
// 24536
// 24537
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24540
// 24541
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24544
o184 = {};
// 24545
o185 = {};
// 24547
// 24548
// 24549
// 24550
// 24551
// 24552
// 24555
// 24556
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24559
// 24560
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24563
o186 = {};
// 24564
o187 = {};
// 24566
// 24567
// 24568
// 24569
// 24570
// 24571
// 24574
// 24575
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24578
// 24579
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24582
o188 = {};
// 24583
o189 = {};
// 24585
// 24586
// 24587
// 24588
// 24589
// 24590
// 24593
// 24594
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24597
// 24598
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24601
o190 = {};
// 24602
o191 = {};
// 24604
// 24605
// 24606
// 24607
// 24608
// 24609
// 24612
// 24613
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24616
// 24617
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24620
o192 = {};
// 24621
o193 = {};
// 24623
// 24624
// 24625
// 24626
// 24627
// 24628
// 24631
// 24632
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24635
// 24636
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24639
o194 = {};
// 24640
o195 = {};
// 24642
// 24643
// 24644
// 24645
// 24646
// 24647
// 24650
// 24651
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24654
// 24655
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24658
o196 = {};
// 24659
o197 = {};
// 24661
// 24662
// 24663
// 24664
// 24665
// 24666
// 24669
// 24670
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24673
// 24674
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24677
o198 = {};
// 24678
o199 = {};
// 24680
// 24681
// 24682
// 24683
// 24684
// 24685
// 24688
// 24689
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24692
// 24693
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24696
o200 = {};
// 24697
o201 = {};
// 24699
// 24700
// 24701
// 24702
// 24703
// 24704
// 24707
// 24708
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24711
// 24712
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24715
o202 = {};
// 24716
o203 = {};
// 24718
// 24719
// 24720
// 24721
// 24722
// 24723
// 24726
// 24727
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24730
// 24731
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24734
o204 = {};
// 24735
o205 = {};
// 24737
// 24738
// 24739
// 24740
// 24741
// 24742
// 24745
// 24746
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24749
// 24750
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24753
o206 = {};
// 24754
o207 = {};
// 24756
// 24757
// 24758
// 24759
// 24760
// 24761
// 24764
// 24765
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24768
// 24769
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24772
o208 = {};
// 24773
o209 = {};
// 24775
// 24776
// 24777
// 24778
// 24779
// 24780
// 24783
// 24784
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24787
// 24788
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24791
o210 = {};
// 24792
o211 = {};
// 24794
// 24796
// 24797
// 24798
o212 = {};
// 24799
f925563445_0.returns.push(o212);
// undefined
o212 = null;
// 24800
// 24801
// 24802
// 24803
// 24804
// 24807
// 24808
// 24809
// 24810
// 24811
o212 = {};
// 24812
o213 = {};
// 24814
// 24815
// 24816
// 24817
// 24818
// 24819
// 24822
// 24823
// 24824
// 24825
// 24826
o214 = {};
// 24827
o215 = {};
// 24829
// 24830
// 24831
// 24832
// 24833
// 24834
// 24837
// 24838
// 24839
// 24840
// 24841
o216 = {};
// 24842
o217 = {};
// 24844
// 24845
// 24846
// 24847
// 24848
// 24849
// 24852
// 24853
// 24854
// 24855
// 24856
o218 = {};
// 24857
o219 = {};
// 24859
// 24860
// 24861
// 24862
// 24863
// 24864
// 24867
// 24868
// 24869
// 24870
// 24871
o220 = {};
// 24872
o221 = {};
// 24874
// 24875
// 24876
// 24877
// 24878
// 24879
// 24882
// 24883
// 24884
// 24885
// 24886
o222 = {};
// 24887
o223 = {};
// 24889
// 24890
// 24891
// 24892
// 24893
// 24894
// 24895
// 24896
// 24897
// undefined
fo925563445_1_cookie.returns.push("c_user=100001812504199; presence=EDvF2EtimeF5302064613911762EchFDriF0CEstateFDpF0G318265708823K0H0EblcF0EsndF1OQ0EsF0CEblFDacF0EutF0EudF10238B00ElcF0CC; p=80; _e_wOYp_4=%5B%22wOYp%22%2Cnull%2C%22channel-connectivity%22%2C%7B%22idle%22%3Anull%7D%2C4%5D");
// 24899
// 24900
// 24901
// 24902
// 24903
// 24904
// 24907
// 24908
// 24909
// 24910
// 24911
o224 = {};
// 24912
o225 = {};
// 24914
// 24915
// 24916
// 24917
// 24918
// 24919
// 24922
// 24923
// 24924
// 24925
// 24926
o226 = {};
// 24927
o227 = {};
// 24929
// 24930
// 24931
// 24932
// 24933
// 24934
// 24937
// 24938
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// 24941
// 24942
// undefined
fo925563445_598___FB_TOKEN.returns.push(o26);
// undefined
o26 = null;
// 24945
o26 = {};
// 24946
o228 = {};
// 24948
// 24949
// 24950
// 24951
// 24952
// 24953
// 24956
// 24957
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// 24960
// 24961
// undefined
fo925563445_427___FB_TOKEN.returns.push(o23);
// undefined
o23 = null;
// 24964
o23 = {};
// 24965
o229 = {};
// 24967
// 24968
// 24969
// 24970
// 24971
// 24972
// 24975
// 24976
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24979
// 24980
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 24983
o230 = {};
// 24984
o231 = {};
// 24986
// 24987
// 24988
// 24989
// 24990
// 24991
// 24994
// 24995
// 24996
// 24997
// 24998
o232 = {};
// 24999
o233 = {};
// 25001
// 25002
// 25003
// 25004
// 25005
// 25006
// 25009
// 25010
// 25011
// 25012
// 25013
o234 = {};
// 25014
o235 = {};
// 25016
// 25017
// 25018
// 25019
// 25020
// 25021
// 25024
// 25025
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// 25028
// 25029
// undefined
fo925563445_1___FB_TOKEN.returns.push(o31);
// undefined
o31 = null;
// 25032
o31 = {};
// 25033
o236 = {};
// 25035
// 25036
// 25037
// 25038
// 25039
// 25040
// 25043
// 25044
// 25045
// 25046
// 25047
o237 = {};
// 25048
o238 = {};
// 25050
// 25051
// 25052
// 25053
// 25054
// 25055
// 25058
// 25059
// 25060
// 25061
// 25062
o239 = {};
// 25063
o240 = {};
// 25065
// 25066
// 25067
// 25068
// 25069
// 25070
// 25071
o241 = {};
// 25072
f925563445_0.returns.push(o241);
// undefined
o241 = null;
// 25073
// 25074
// 25075
f925563445_426.returns.push(0.7876625794451684);
// 25076
// 25077
// 25078
// 25079
f925563445_12.returns.push(36);
// 25081
// 25082
// 25083
// 25084
// 25085
// 25086
// 25087
// 25088
// 25089
// 25090
// 25091
// 25092
// 25093
// 25094
// 25095
// 25096
// 25097
// 25098
// 25099
// 25100
// 25101
// 25102
// 25103
// 25104
// 25105
// 25106
// 25109
// 25110
// 25111
// 25112
// 25113
o241 = {};
// 25114
o242 = {};
// 25116
// 25117
// 0
JSBNG_Replay$ = function(real, cb) { if (!real) return;
// 886
geval("CavalryLogger = false;\nwindow._script_path = \"/home.php\";\nwindow._EagleEyeSeed = \"wOYp\";\nwindow._EagleEyeSessionStorage = 1;");
// 887
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"LayX0\",]);\n}\n;\n;\nvoid (1);\nwindow.__DEV__ = ((window.__DEV__ || 0));\nif (((((((((!window.skipDomainLower && JSBNG__navigator)) && JSBNG__navigator.userAgent)) && JSBNG__document.domain.toLowerCase().match(/(^|\\.)facebook\\..*/))) && !((parseInt(((/Gecko\\/([0-9]+)/.exec(JSBNG__navigator.userAgent) || [])).pop(), 10) <= 20060508))))) {\n    JSBNG__document.domain = window.JSBNG__location.hostname.replace(/^.*(facebook\\..*)$/i, \"$1\");\n}\n;\n;\nwindow.JSBNG__onloadhooks = ((window.JSBNG__onloadhooks || []));\nwindow.JSBNG__onloadRegister = ((window.JSBNG__onloadRegister || function(a) {\n    JSBNG__onloadhooks.push(a);\n}));\nwindow.JSBNG__onafterloadhooks = ((window.JSBNG__onafterloadhooks || []));\nwindow.JSBNG__onafterloadRegister = ((window.JSBNG__onafterloadRegister || function(a) {\n    JSBNG__onafterloadhooks.push(a);\n}));\nfunction run_if_loaded(a, b) {\n    return ((window.loaded && b.call(a)));\n};\n;\nfunction run_with(b, a, c) {\n    Bootloader.loadComponents(a, bind(b, c));\n    return false;\n};\n;\nfunction wait_for_load(c, b, e) {\n    e = bind(c, e, b);\n    if (window.loaded) {\n        return e();\n    }\n;\n;\n    switch (((b || JSBNG__event)).type) {\n      case \"load\":\n    \n      case \"JSBNG__focus\":\n        JSBNG__onafterloadRegister(e);\n        return;\n      case \"click\":\n        var d = c.style, a = JSBNG__document.body.style;\n        d.cursor = a.cursor = \"progress\";\n        JSBNG__onafterloadRegister(function() {\n            d.cursor = a.cursor = \"\";\n            if (((c.tagName.toLowerCase() == \"a\"))) {\n                if (((((false !== e())) && c.href))) {\n                    window.JSBNG__location.href = c.href;\n                }\n            ;\n            ;\n            }\n             else if (c.click) {\n                c.click();\n            }\n            \n        ;\n        ;\n        });\n        break;\n    };\n;\n    return false;\n};\n;\nfunction bind(d, c) {\n    var a = Array.prototype.slice.call(arguments, 2);\n    function b() {\n        var f = ((d || ((((this == window)) ? false : this)))), e = a.concat(Array.prototype.slice.call(arguments));\n        if (((typeof (c) == \"string\"))) {\n            if (f[c]) {\n                return f[c].apply(f, e);\n            }\n        ;\n        ;\n        }\n         else return c.apply(f, e)\n    ;\n    };\n;\n    return b;\n};\n;\nvar curry = bind(null, bind, null);\nfunction env_get(a) {\n    return ((window.Env && Env[a]));\n};\n;\nJSBNG__document.documentElement.className = JSBNG__document.documentElement.className.replace(\"no_js\", \"\");\nfunction hasArrayNature(a) {\n    return ((((((((!!a && ((((typeof a == \"object\")) || ((typeof a == \"function\")))))) && ((\"length\" in a)))) && !((\"JSBNG__setInterval\" in a)))) && ((((((Object.prototype.toString.call(a) === \"[object Array]\")) || ((\"callee\" in a)))) || ((\"item\" in a))))));\n};\n;\nfunction $A(b) {\n    if (!hasArrayNature(b)) {\n        return [b,];\n    }\n;\n;\n    if (b.item) {\n        var a = b.length, c = new Array(a);\n        while (a--) {\n            c[a] = b[a];\n        ;\n        };\n    ;\n        return c;\n    }\n;\n;\n    return Array.prototype.slice.call(b);\n};\n;\nfunction eval_global(c) {\n    if (((\"string\" != typeof (c)))) {\n        throw new Error(((\"JS sent to eval_global is not a string.  Only strings \" + \"are permitted.\")));\n    }\n     else if (((\"\" == c))) {\n        return;\n    }\n    \n;\n;\n    var d = JSBNG__document.createElement(\"script\");\n    d.type = \"text/javascript\";\n    try {\n        d.appendChild(JSBNG__document.createTextNode(c));\n    } catch (a) {\n        d.text = c;\n    };\n;\n    var b = ((JSBNG__document.getElementsByTagName(\"head\")[0] || JSBNG__document.documentElement));\n    b.appendChild(d);\n    b.removeChild(d);\n};\n;\nfunction copy_properties(b, c) {\n    b = ((b || {\n    }));\n    c = ((c || {\n    }));\n    for (var a in c) {\n        b[a] = c[a];\n    ;\n    };\n;\n    if (((((((c.hasOwnProperty && c.hasOwnProperty(\"toString\"))) && ((typeof c.toString != \"undefined\")))) && ((b.toString !== c.toString))))) {\n        b.toString = c.toString;\n    }\n;\n;\n    return b;\n};\n;\nfunction add_properties(a, b) {\n    return copy_properties(((window[a] || (window[a] = {\n    }))), b);\n};\n;\nfunction is_empty(b) {\n    if (((b instanceof Array))) {\n        return ((b.length == 0));\n    }\n     else if (((b instanceof Object))) {\n        for (var a in b) {\n            return false;\n        };\n    ;\n        return true;\n    }\n     else return !b\n    \n;\n};\n;\nif (!window.async_callback) {\n    window.async_callback = function(a, b) {\n        return a;\n    };\n}\n;\n;\nfunction Arbiter() {\n    copy_properties(this, {\n        _listeners: [],\n        _events: {\n        },\n        _callbacks: {\n        },\n        _last_id: 1,\n        _listen: {\n        },\n        _index: {\n        }\n    });\n    copy_properties(this, Arbiter);\n};\n;\ncopy_properties(Arbiter, {\n    SUBSCRIBE_NEW: \"new\",\n    SUBSCRIBE_ALL: \"all\",\n    BEHAVIOR_EVENT: \"JSBNG__event\",\n    BEHAVIOR_PERSISTENT: \"persistent\",\n    BEHAVIOR_STATE: \"state\",\n    LIVEMESSAGE: \"livemessage\",\n    BOOTLOAD: \"bootload\",\n    FUNCTION_EXTENSION: \"function_ext\",\n    CONTEXT_CHANGE: \"ui/context-change\",\n    LIST_EDITOR_LISTS_CHANGED: \"listeditor/friend_lists_changed\",\n    CAROUSEL_ROTATE: \"carousel/rotate\",\n    subscribe: function(k, b, i) {\n        if (((!k || ((k.length == 0))))) {\n            return null;\n        }\n    ;\n    ;\n        k = $A(k);\n        var a = Arbiter._getInstance(this);\n        a._listeners.push({\n            callback: b,\n            types: k\n        });\n        var h = ((a._listeners.length - 1));\n        for (var d = 0; ((d < k.length)); d++) {\n            if (a._index[k[d]]) {\n                a._index[k[d]].push(h);\n            }\n             else a._index[k[d]] = [h,];\n        ;\n        ;\n        };\n    ;\n        i = ((i || Arbiter.SUBSCRIBE_ALL));\n        if (((i == Arbiter.SUBSCRIBE_ALL))) {\n            var c, j, g;\n            for (var e = 0; ((e < k.length)); e++) {\n                j = k[e];\n                if (((j in a._events))) {\n                    for (var f = 0; ((f < a._events[j].length)); f++) {\n                        c = a._events[j][f];\n                        g = b.apply(null, [j,c,]);\n                        if (((g === false))) {\n                            a._events[j].splice(f, 1);\n                            f--;\n                        }\n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        return {\n            subscriberID: h\n        };\n    },\n    unsubscribe: function(e) {\n        var a = Arbiter._getInstance(this);\n        var c = a._listeners[e.subscriberID];\n        if (!c) {\n            return;\n        }\n    ;\n    ;\n        for (var d = 0; ((d < c.types.length)); d++) {\n            var f = c.types[d];\n            if (a._index[f]) {\n                for (var b = 0; ((b < a._index[f].length)); b++) {\n                    if (((a._index[f][b] == e.subscriberID))) {\n                        a._index[f].splice(b, 1);\n                        if (((a._index[f].length == 0))) {\n                            delete a._index[f];\n                        }\n                    ;\n                    ;\n                        break;\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n        };\n    ;\n        delete a._listeners[e.subscriberID];\n    },\n    inform: function(j, c, b) {\n        var m = hasArrayNature(j);\n        var l = $A(j);\n        var a = Arbiter._getInstance(this);\n        var i = {\n        };\n        b = ((b || Arbiter.BEHAVIOR_EVENT));\n        for (var e = 0; ((e < l.length)); e++) {\n            var j = l[e], d = null;\n            if (((b == Arbiter.BEHAVIOR_PERSISTENT))) {\n                d = a._events.length;\n                if (!((j in a._events))) {\n                    a._events[j] = [];\n                }\n            ;\n            ;\n                a._events[j].push(c);\n                a._events[j]._stateful = false;\n            }\n             else if (((b == Arbiter.BEHAVIOR_STATE))) {\n                d = 0;\n                a._events[j] = [c,];\n                a._events[j]._stateful = true;\n            }\n             else if (((j in a._events))) {\n                a._events[j]._stateful = false;\n            }\n            \n            \n        ;\n        ;\n            ((window.ArbiterMonitor && ArbiterMonitor.record(\"JSBNG__event\", j, c, a)));\n            var h;\n            if (a._index[j]) {\n                var k = $A(a._index[j]);\n                for (var f = 0; ((f < k.length)); f++) {\n                    var g = a._listeners[k[f]];\n                    if (g) {\n                        h = g.callback.apply(null, [j,c,]);\n                        if (((h === false))) {\n                            if (((d !== null))) {\n                                a._events[j].splice(d, 1);\n                            }\n                        ;\n                        ;\n                            break;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            a._updateCallbacks(j, c);\n            ((window.ArbiterMonitor && ArbiterMonitor.record(\"done\", j, c, a)));\n            i[j] = h;\n        };\n    ;\n        return ((m ? i : i[l[0]]));\n    },\n    query: function(b) {\n        var a = Arbiter._getInstance(this);\n        if (!((b in a._events))) {\n            return null;\n        }\n    ;\n    ;\n        if (a._events[b].length) {\n            return a._events[b][0];\n        }\n    ;\n    ;\n        return null;\n    },\n    _instance: null,\n    _getInstance: function(a) {\n        if (((a instanceof Arbiter))) {\n            return a;\n        }\n    ;\n    ;\n        if (!Arbiter._instance) {\n            Arbiter._instance = new Arbiter();\n        }\n    ;\n    ;\n        return Arbiter._instance;\n    },\n    registerCallback: function(b, d) {\n        var h, c = 0, a = Arbiter._getInstance(this), g = false;\n        if (((typeof b == \"function\"))) {\n            h = a._last_id;\n            a._last_id++;\n            g = true;\n        }\n         else {\n            if (!a._callbacks[b]) {\n                return null;\n            }\n        ;\n        ;\n            h = b;\n        }\n    ;\n    ;\n        if (hasArrayNature(d)) {\n            var i = {\n            };\n            for (var f = 0; ((f < d.length)); f++) {\n                i[d[f]] = 1;\n            ;\n            };\n        ;\n            d = i;\n        }\n    ;\n    ;\n        for (var j in d) {\n            try {\n                if (a.query(j)) {\n                    continue;\n                }\n            ;\n            ;\n            } catch (e) {\n            \n            };\n        ;\n            c += d[j];\n            if (((a._listen[j] === undefined))) {\n                a._listen[j] = {\n                };\n            }\n        ;\n        ;\n            a._listen[j][h] = ((((a._listen[j][h] || 0)) + d[j]));\n        };\n    ;\n        if (((((c == 0)) && g))) {\n            b();\n            return null;\n        }\n    ;\n    ;\n        if (!g) {\n            a._callbacks[h].depnum += c;\n        }\n         else a._callbacks[h] = {\n            callback: async_callback(b, \"arbiter\"),\n            depnum: c\n        };\n    ;\n    ;\n        return h;\n    },\n    _updateCallbacks: function(d, c) {\n        if (((((c === null)) || !this._listen[d]))) {\n            return;\n        }\n    ;\n    ;\n        for (var b in this._listen[d]) {\n            this._listen[d][b]--;\n            if (((this._listen[d][b] <= 0))) {\n                delete this._listen[d][b];\n            }\n        ;\n        ;\n            this._callbacks[b].depnum--;\n            if (((this._callbacks[b].depnum <= 0))) {\n                var a = this._callbacks[b].callback;\n                delete this._callbacks[b];\n                a();\n            }\n        ;\n        ;\n        };\n    ;\n    }\n});\nvar Bootloader = ((window.Bootloader || {\n    configurePage: function(a) {\n        var g = {\n        };\n        var f = Bootloader.resolveResources(a);\n        var b;\n        for (b = 0; ((b < f.length)); b++) {\n            g[f[b].src] = f[b];\n            Bootloader.requested(f[b].JSBNG__name);\n            Bootloader._startCSSPoll(f[b].JSBNG__name);\n        };\n    ;\n        var d = JSBNG__document.getElementsByTagName(\"link\");\n        for (b = 0; ((b < d.length)); ++b) {\n            if (((d[b].rel != \"stylesheet\"))) {\n                continue;\n            }\n        ;\n        ;\n            for (var c in g) {\n                if (((d[b].href.indexOf(c) !== -1))) {\n                    var e = g[c].JSBNG__name;\n                    Bootloader._cssLinkMap[e] = {\n                        link: d[b]\n                    };\n                    if (g[c].permanent) {\n                        Bootloader._permanent[e] = true;\n                    }\n                ;\n                ;\n                    delete g[c];\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n    },\n    loadComponents: function(c, a) {\n        if (!Bootloader._bootloadEnabled) {\n            Bootloader._waitForBootloadEnabled.push([c,a,]);\n            return;\n        }\n    ;\n    ;\n        c = $A(c);\n        var f = [];\n        for (var d = 0; ((d < c.length)); ++d) {\n            if (!c[d]) {\n                continue;\n            }\n        ;\n        ;\n            var b = Bootloader._componentMap[c[d]];\n            if (!!b) {\n                for (var e = 0; ((e < b.length)); ++e) {\n                    f.push(b[e]);\n                ;\n                };\n            }\n        ;\n        ;\n        };\n    ;\n        Bootloader.loadResources(f, a);\n    },\n    loadResources: function(g, a, f, j) {\n        var b;\n        g = Bootloader.resolveResources($A(g));\n        if (f) {\n            var d = {\n            };\n            for (b = 0; ((b < g.length)); ++b) {\n                d[g[b].JSBNG__name] = true;\n            ;\n            };\n        ;\n            for (var c in Bootloader._requested) {\n                if (((((!((c in Bootloader._permanent)) && !((c in d)))) && !((c in Bootloader._earlyResources))))) {\n                    Bootloader._unloadResource(c);\n                }\n            ;\n            ;\n            };\n        ;\n            Bootloader._earlyResources = {\n            };\n        }\n    ;\n    ;\n        var k = [];\n        var e = [];\n        for (b = 0; ((b < g.length)); ++b) {\n            var h = g[b];\n            if (h.permanent) {\n                Bootloader._permanent[h.JSBNG__name] = true;\n            }\n        ;\n        ;\n            var i = ((((Arbiter.BOOTLOAD + \"/\")) + h.JSBNG__name));\n            if (((Arbiter.query(i) !== null))) {\n                continue;\n            }\n        ;\n        ;\n            if (!h.nonblocking) {\n                e.push(i);\n            }\n        ;\n        ;\n            if (!Bootloader._requested[h.JSBNG__name]) {\n                Bootloader.requested(h.JSBNG__name);\n                k.push(h);\n                ((window.CavalryLogger && CavalryLogger.getInstance().measureResources(h, j)));\n            }\n        ;\n        ;\n        };\n    ;\n        if (a) {\n            a = Arbiter.registerCallback(a, e);\n        }\n    ;\n    ;\n        for (b = 0; ((b < k.length)); ++b) {\n            Bootloader.requestResource(k[b].type, k[b].src, k[b].JSBNG__name);\n        ;\n        };\n    ;\n        return a;\n    },\n    requestResource: function(j, g, e) {\n        var b = Bootloader.getHardpoint();\n        if (((j == \"js\"))) {\n            var f = JSBNG__document.createElement(\"script\");\n            f.src = g;\n            f.type = \"text/javascript\";\n            f.async = true;\n            var a = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28), function() {\n                Bootloader.done([e,]);\n            }));\n            f.JSBNG__onload = f.JSBNG__onerror = a;\n            f.JSBNG__onreadystatechange = function() {\n                if (((this.readyState in {\n                    loaded: 1,\n                    complete: 1\n                }))) {\n                    a();\n                }\n            ;\n            ;\n            };\n            b.appendChild(f);\n        }\n         else if (((j == \"css\"))) {\n            if (JSBNG__document.createStyleSheet) {\n                var h = Bootloader._styleTags, i = -1;\n                for (var c = 0; ((c < h.length)); c++) {\n                    if (((h[c].imports.length < 25))) {\n                        i = c;\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                if (((i == -1))) {\n                    h.push(JSBNG__document.createStyleSheet());\n                    i = ((h.length - 1));\n                }\n            ;\n            ;\n                h[i].addImport(g);\n                Bootloader._cssLinkMap[e] = {\n                    tagIdx: i,\n                    href: g\n                };\n            }\n             else {\n                var d = JSBNG__document.createElement(\"link\");\n                d.rel = \"stylesheet\";\n                d.type = \"text/css\";\n                d.media = \"all\";\n                d.href = g;\n                Bootloader._cssLinkMap[e] = {\n                    link: d\n                };\n                b.appendChild(d);\n            }\n        ;\n        ;\n            Bootloader._startCSSPoll(e);\n        }\n        \n    ;\n    ;\n    },\n    _activeCSSPolls: {\n    },\n    _expireTime: null,\n    _runCSSPolls: function() {\n        var f;\n        var b = [];\n        var g = new JSBNG__Date().getTime();\n        if (((g >= Bootloader._expireTime))) {\n            if (window.send_error_signal) {\n                if (((Math.JSBNG__random() < 8831))) {\n                    send_error_signal(\"js_timeout_and_exception\", \"00001:error:CSS timeout.\");\n                }\n            ;\n            }\n        ;\n        ;\n            for (f in Bootloader._activeCSSPolls) {\n                b.push(f);\n            ;\n            };\n        ;\n        }\n         else {\n            var d = Bootloader._CSS_EXPECTED_HEIGHT;\n            var a;\n            for (f in Bootloader._activeCSSPolls) {\n                var i = Bootloader._activeCSSPolls[f];\n                var h = ((((((i.offsetHeight == d)) || ((i.currentStyle && ((i.currentStyle.height == ((d + \"px\")))))))) || ((((window.JSBNG__getComputedStyle && (a = JSBNG__document.defaultView.JSBNG__getComputedStyle(i, null)))) && ((a.getPropertyValue(\"height\") == ((d + \"px\"))))))));\n                if (h) {\n                    b.push(f);\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        if (!is_empty(b)) {\n            for (var e = 0; ((e < b.length)); e++) {\n                var c = Bootloader._activeCSSPolls[b[e]];\n                c.parentNode.removeChild(c);\n                delete Bootloader._activeCSSPolls[b[e]];\n            };\n        ;\n            Bootloader._expireTime = ((g + Bootloader._CSS_POLL_EXPIRATION));\n            Bootloader.done(b, true);\n        }\n    ;\n    ;\n        return is_empty(Bootloader._activeCSSPolls);\n    },\n    _startCSSPoll: function(c) {\n        var a = ((\"bootloader_\" + c.replace(/[^a-z0-9]/gi, \"_\")));\n        var d = JSBNG__document.createElement(\"meta\");\n        d.id = a;\n        Bootloader.getHardpoint().appendChild(d);\n        Bootloader._expireTime = ((new JSBNG__Date() + Bootloader._CSS_POLL_EXPIRATION));\n        var e = is_empty(Bootloader._activeCSSPolls);\n        Bootloader._activeCSSPolls[c] = d;\n        if (e) {\n            var b = JSBNG__setInterval(((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32), function _poll() {\n                if (Bootloader._runCSSPolls()) {\n                    ((b && JSBNG__clearInterval(b)));\n                }\n            ;\n            ;\n            })), 20, false);\n        }\n    ;\n    ;\n    },\n    done: function(e, b) {\n        Bootloader.requested(e);\n        if (!b) {\n            var d = {\n                sender: this\n            };\n            Arbiter.inform(Arbiter.BOOTLOAD, d, Arbiter.BEHAVIOR_EVENT);\n        }\n    ;\n    ;\n        for (var a = 0; ((a < e.length)); ++a) {\n            var c = e[a];\n            Arbiter.inform(((((Arbiter.BOOTLOAD + \"/\")) + c)), true, Arbiter.BEHAVIOR_STATE);\n        };\n    ;\n    },\n    requested: function(b) {\n        b = $A(b);\n        for (var a = 0; ((a < b.length)); ++a) {\n            Bootloader._requested[b[a]] = true;\n        ;\n        };\n    ;\n    },\n    enableBootload: function(b) {\n        for (var c in b) {\n            if (!Bootloader._componentMap[c]) {\n                Bootloader._componentMap[c] = b[c];\n            }\n        ;\n        ;\n        };\n    ;\n        if (!Bootloader._bootloadEnabled) {\n            Bootloader._bootloadEnabled = true;\n            var d = Bootloader._waitForBootloadEnabled;\n            for (var a = 0; ((a < d.length)); a++) {\n                Bootloader.loadComponents.apply(null, d[a]);\n            ;\n            };\n        ;\n            Bootloader._waitForBootloadEnabled = [];\n        }\n    ;\n    ;\n    },\n    _unloadResource: function(d) {\n        if (((d in Bootloader._cssLinkMap))) {\n            var b = Bootloader._cssLinkMap[d], c = b.link;\n            if (c) {\n                c.parentNode.removeChild(c);\n            }\n             else {\n                var e = Bootloader._styleTags[b.tagIdx];\n                for (var a = 0; ((a < e.imports.length)); a++) {\n                    if (((e.imports[a].href == b.href))) {\n                        e.removeImport(a);\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            delete Bootloader._cssLinkMap[d];\n            delete Bootloader._requested[d];\n            Arbiter.inform(((((Arbiter.BOOTLOAD + \"/\")) + d)), null, Arbiter.BEHAVIOR_STATE);\n        }\n    ;\n    ;\n    },\n    getHardpoint: function() {\n        if (!Bootloader._hardpoint) {\n            var a = JSBNG__document.getElementsByTagName(\"head\");\n            Bootloader._hardpoint = ((((a.length && a[0])) || JSBNG__document.body));\n        }\n    ;\n    ;\n        return Bootloader._hardpoint;\n    },\n    setResourceMap: function(b) {\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        for (var a in b) {\n            if (!b[a].JSBNG__name) {\n                b[a].JSBNG__name = a;\n            }\n        ;\n        ;\n            Bootloader._resources[a] = b[a];\n        };\n    ;\n    },\n    resolveResources: function(d, a) {\n        if (!d) {\n            return [];\n        }\n    ;\n    ;\n        var c = new Array(d.length);\n        for (var b = 0; ((b < d.length)); ++b) {\n            if (((!d[b].type && ((d[b] in Bootloader._resources))))) {\n                c[b] = Bootloader._resources[d[b]];\n                if (((a && ((a in c[b]))))) {\n                    c[b] = c[b][a];\n                }\n            ;\n            ;\n            }\n             else c[b] = d[b];\n        ;\n        ;\n        };\n    ;\n        return c;\n    },\n    loadEarlyResources: function(c) {\n        var a;\n        Bootloader.setResourceMap(c);\n        var b = [];\n        for (a in c) {\n            b.push(Bootloader._resources[a]);\n        ;\n        };\n    ;\n        Bootloader.loadResources(b);\n        for (a in c) {\n            var d = Bootloader._resources[a];\n            if (!d.permanent) {\n                Bootloader._earlyResources[d.JSBNG__name] = d;\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    isDisplayJS: function(a) {\n        if (((typeof a == \"string\"))) {\n            a = Bootloader._resources[a];\n        }\n    ;\n    ;\n        return a.displayjs;\n    },\n    _requested: {\n    },\n    _permanent: {\n    },\n    _componentMap: {\n    },\n    _cssLinkMap: {\n    },\n    _styleTags: [],\n    _hardpoint: null,\n    _resources: {\n    },\n    _earlyResources: {\n    },\n    _bootloadEnabled: false,\n    _waitForBootloadEnabled: [],\n    _CSS_POLL_EXPIRATION: 5000,\n    _CSS_EXPECTED_HEIGHT: 42\n}));\n(function() {\n    if (((window != window.JSBNG__top))) {\n        return;\n    }\n;\n;\n    var m = \"_e_\", o = ((window.JSBNG__name || \"\")).toString();\n    o = ((((((o.length == 7)) && ((m == o.substr(0, 3))))) ? o.substr(3) : (window.JSBNG__name = ((m + window._EagleEyeSeed))).substr(3)));\n    var j = ((((m + o)) + \"_\")), g = new JSBNG__Date(((+new JSBNG__Date() + 604800000))).toGMTString(), e = window.JSBNG__location.hostname.replace(/^.*(facebook\\..*)$/i, \"$1\"), f = ((((((\"; expires=\" + g)) + \";path=/; domain=\")) + e)), d = 0, p = false, k, n = ((window._EagleEyeSessionStorage && window.JSBNG__sessionStorage)), h = JSBNG__document.cookie.length, i = false, l = +new JSBNG__Date();\n    function c(q) {\n        return ((((((((j + (d++))) + \"=\")) + encodeURIComponent(q))) + f));\n    };\n;\n    function a() {\n        var q = [], t = false, s = 0, r = 0;\n        this.isEmpty = function() {\n            return !q.length;\n        };\n        this.enqueue = function(v, u) {\n            if (u) {\n                q.unshift(v);\n            }\n             else q.push(v);\n        ;\n        ;\n        };\n        this.dequeue = function() {\n            q.shift();\n        };\n        this.peek = function() {\n            return q[0];\n        };\n        this.clear = function(w) {\n            h = Math.min(h, JSBNG__document.cookie.length);\n            if (((!i && ((((new JSBNG__Date() - l)) > 60000))))) {\n                i = true;\n            }\n        ;\n        ;\n            var u = ((!w && ((JSBNG__document.cookie.search(m) >= 0))));\n            var zg = !!((window.Env && Env.cookie_header_limit));\n            var zb = ((((window.Env && Env.cookie_count_limit)) || 19));\n            var zc = ((((window.Env && Env.cookie_header_limit)) || 3950));\n            var z = ((zb - 5));\n            var za = ((zc - 1000));\n            while (!this.isEmpty()) {\n                var v = c(this.peek());\n                if (((zg && ((((v.length > zc)) || ((i && ((((v.length + h)) > zc))))))))) {\n                    this.dequeue();\n                    continue;\n                }\n            ;\n            ;\n                if (((((u || zg)) && ((((((JSBNG__document.cookie.length + v.length)) > zc)) || ((JSBNG__document.cookie.split(\";\").length > zb))))))) {\n                    break;\n                }\n            ;\n            ;\n                JSBNG__document.cookie = v;\n                u = true;\n                this.dequeue();\n            };\n        ;\n            var zd = +new JSBNG__Date();\n            if (((w || ((((((((!t && u)) && ((((r > 0)) && ((((Math.min(((10 * Math.pow(2, ((r - 1))))), 60000) + s)) < zd)))))) && ((p || ((((window.Arbiter && window.OnloadEvent)) && Arbiter.query(OnloadEvent.ONLOAD))))))) && ((((!this.isEmpty() || ((JSBNG__document.cookie.length > za)))) || ((JSBNG__document.cookie.split(\";\").length > z))))))))) {\n                var zf = new JSBNG__Image(), ze = this, x = ((((window._EagleEyeDomain || ((window.Env && Env.tracking_domain)))) || \"\"));\n                t = true;\n                zf.JSBNG__onload = function _EagleEye_logged() {\n                    t = false;\n                    r = 0;\n                    ze.clear();\n                };\n                zf.JSBNG__onerror = zf.JSBNG__onabort = function _EagleEye_error() {\n                    t = false;\n                    s = +new JSBNG__Date();\n                    r++;\n                };\n                var y = ((((window.Env && Env.fb_isb)) ? ((\"&fb_isb=\" + Env.fb_isb)) : \"\"));\n                var zh = ((window.Env ? ((\"&__user=\" + Env.user)) : \"\"));\n                zf.src = ((((((((((((((x + \"/ajax/nectar.php?asyncSignal=\")) + ((Math.floor(((Math.JSBNG__random() * 10000))) + 1)))) + y)) + zh)) + \"&\")) + ((!w ? \"\" : \"s=\")))) + zd));\n            }\n        ;\n        ;\n        };\n    };\n;\n    k = new a();\n    if (n) {\n        var b = function() {\n            var s = 0;\n            var u = s;\n            function r() {\n                var w = JSBNG__sessionStorage.getItem(\"_e_ids\");\n                if (w) {\n                    var v = ((w + \"\")).split(\";\");\n                    if (((v.length == 2))) {\n                        s = parseInt(v[0], 10);\n                        u = parseInt(v[1], 10);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            function t() {\n                var v = ((((s + \";\")) + u));\n                JSBNG__sessionStorage.setItem(\"_e_ids\", v);\n            };\n        ;\n            function q(v) {\n                return ((\"_e_\" + ((((v !== undefined)) ? v : s++))));\n            };\n        ;\n            this.isEmpty = function() {\n                return ((u === s));\n            };\n            this.enqueue = function(x, v) {\n                var w = ((v ? q(--u) : q()));\n                JSBNG__sessionStorage.setItem(w, x);\n                t();\n            };\n            this.dequeue = function() {\n                this.isEmpty();\n                JSBNG__sessionStorage.removeItem(q(u));\n                u++;\n                t();\n            };\n            this.peek = function() {\n                var v = JSBNG__sessionStorage.getItem(q(u));\n                return ((v ? ((v + \"\")) : v));\n            };\n            this.clear = k.clear;\n            r();\n        };\n        k = new b();\n    }\n;\n;\n    window.EagleEye = {\n        log: function(t, q, r) {\n            if (((window.Env && Env.no_cookies))) {\n                return;\n            }\n        ;\n        ;\n            var u = [o,+new JSBNG__Date(),t,].concat(q);\n            u.push(u.length);\n            function s() {\n                var w = JSON.stringify(u);\n                try {\n                    k.enqueue(w, !!r);\n                    k.clear(!!r);\n                } catch (v) {\n                    if (((n && ((v.code === 1000))))) {\n                        k = new a();\n                        n = false;\n                        s();\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            if (window.JSON) {\n                s();\n            }\n             else if (window.Bootloader) {\n                Bootloader.loadComponents(\"json\", s);\n            }\n            \n        ;\n        ;\n        },\n        createLogger: function(s, q) {\n            q = ((((q === undefined)) ? 1 : q));\n            var r = function(t, u) {\n                if (r.enabled) {\n                    EagleEye.log(s, t, u);\n                }\n            ;\n            ;\n            };\n            r.enabled = false;\n            Bootloader.loadComponents(\"string-extensions\", function() {\n                r._key = ((((((window.Env && Env.user)) || Math.JSBNG__random())) + s));\n                r.enabled = ((((((r._key.hash32() % 65535)) / 65535)) <= q));\n            });\n            return r;\n        },\n        getSessionID: function() {\n            return o;\n        },\n        loaded: function() {\n            p = true;\n        }\n    };\n})();\nvar Mixins = {\n    Arbiter: {\n        _getArbiterInstance: function() {\n            return ((this._arbiter || (this._arbiter = new Arbiter())));\n        },\n        inform: function(c, b, a) {\n            return this._getArbiterInstance().inform(c, b, a);\n        },\n        subscribe: function(c, a, b) {\n            return this._getArbiterInstance().subscribe(c, a, b);\n        },\n        unsubscribe: function(a) {\n            this._getArbiterInstance().unsubscribe(a);\n        }\n    }\n};\nClass = {\n    extend: function(a, b) {\n        if (!Metaprototype._arbiterHandle) {\n            Metaprototype._arbiterHandle = Arbiter.subscribe(Arbiter.BOOTLOAD, Metaprototype._onbootload.bind(Metaprototype));\n        }\n    ;\n    ;\n        Metaprototype._queue(a, b);\n    },\n    mixin: function(c, b) {\n        var a = Array.prototype.slice.call(arguments);\n        a[0] = a[0].prototype;\n        Function.mixin.apply(Function, a);\n    }\n};\nfunction Metaprototype() {\n\n};\n;\ncopy_properties(Metaprototype, {\n    makeFinal: function(a) {\n    \n    },\n    _pending: {\n    },\n    _queue: function(b, c) {\n        b.__class_extending = true;\n        var a = Arbiter.registerCallback(bind(Metaprototype, Metaprototype._apply, b, c), [((((Arbiter.FUNCTION_EXTENSION + \"/\")) + c)),Arbiter.BOOTLOAD,]);\n        if (((a !== null))) {\n            this._pending[c] = true;\n        }\n    ;\n    ;\n    },\n    _onbootload: function(b, a) {\n        this._update();\n    },\n    _update: function() {\n        for (var a in this._pending) {\n            if (!!window[a]) {\n                delete this._pending[a];\n                if (!window[a].__class_extending) {\n                    Arbiter.inform(((((Arbiter.FUNCTION_EXTENSION + \"/\")) + a)), true, Arbiter.BEHAVIOR_STATE);\n                }\n                 else window[a].__class_name = a;\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    _apply: function(a, c) {\n        delete a.__class_extending;\n        var d = __metaprototype(window[c], 0);\n        var b = __metaprototype(a, ((d.prototype.__level + 1)));\n        b.parent = d;\n        if (!!a.__class_name) {\n            Arbiter.inform(((((Arbiter.FUNCTION_EXTENSION + \"/\")) + a.__class_name)), true, Arbiter.BEHAVIOR_STATE);\n        }\n    ;\n    ;\n    }\n});\nfunction __metaprototype(c, a) {\n    if (c.__metaprototype) {\n        return c.__metaprototype;\n    }\n;\n;\n    var b = new Function();\n    b.construct = __metaprototype_construct;\n    b.prototype.construct = __metaprototype_wrap(c, a, true);\n    b.prototype.__level = a;\n    b.base = c;\n    c.prototype.parent = b;\n    c.__metaprototype = b;\n    return b;\n};\n;\nfunction __metaprototype_construct(a) {\n    __metaprototype_init(a.parent);\n    var d = [];\n    var c = a;\n    while (c.parent) {\n        var b = new c.parent();\n        d.push(b);\n        b.__instance = a;\n        c = c.parent;\n    };\n;\n    a.parent = d[1];\n    d.reverse();\n    d.pop();\n    a.__parents = d;\n    a.__instance = a;\n    return a.parent.construct.apply(a.parent, arguments);\n};\n;\nfunction __metaprototype_init(d) {\n    if (d.initialized) {\n        return;\n    }\n;\n;\n    var a = d.base.prototype;\n    if (d.parent) {\n        __metaprototype_init(d.parent);\n        var e = d.parent.prototype;\n        for (var b in e) {\n            if (((((((b != \"__level\")) && ((b != \"construct\")))) && ((a[b] === undefined))))) {\n                a[b] = d.prototype[b] = e[b];\n            }\n        ;\n        ;\n        };\n    ;\n    }\n;\n;\n    d.initialized = true;\n    var c = d.prototype.__level;\n    for (var b in a) {\n        if (((b != \"parent\"))) {\n            a[b] = d.prototype[b] = __metaprototype_wrap(a[b], c);\n        }\n    ;\n    ;\n    };\n;\n};\n;\nfunction __metaprototype_wrap(c, b, d) {\n    if (((((typeof c != \"function\")) || c.__prototyped))) {\n        return c;\n    }\n;\n;\n    var a = function() {\n        var g = this.__instance;\n        if (g) {\n            var h = g.parent;\n            g.parent = ((b ? g.__parents[((b - 1))] : null));\n            var e = arguments;\n            if (d) {\n                e = [];\n                for (var f = 1; ((f < arguments.length)); f++) {\n                    e.push(arguments[f]);\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            var i = c.apply(g, e);\n            g.parent = h;\n            return i;\n        }\n         else return c.apply(this, arguments)\n    ;\n    };\n    a.__prototyped = true;\n    return a;\n};\n;\nFunction.mixin = function() {\n    for (var b = 1, a = arguments.length; ((b < a)); ++b) {\n        copy_properties(arguments[0], ((Mixins[arguments[b]] || arguments[b])));\n    ;\n    };\n;\n};\nFunction.prototype.bind = function(b) {\n    var a = [b,this,].concat(Array.prototype.slice.call(arguments, 1));\n    return bind.apply(null, a);\n};\nFunction.prototype.curry = Function.prototype.bind.bind(null, null);\nFunction.prototype.shield = function(b) {\n    if (((typeof this != \"function\"))) {\n        throw new TypeException();\n    }\n;\n;\n    var a = this.bind.apply(this, $A(arguments));\n    return function() {\n        return a();\n    };\n};\nFunction.prototype.defer = function(b, a) {\n    if (((typeof this != \"function\"))) {\n        throw new TypeError();\n    }\n;\n;\n    b = ((b || 0));\n    return JSBNG__setTimeout(this, b, a);\n};\nfunction bagofholding() {\n\n};\n;\nfunction bagof(a) {\n    return function() {\n        return a;\n    };\n};\n;\nfunction set_ue_cookie(a) {\n    if (!((window.Env && Env.no_cookies))) {\n        JSBNG__document.cookie = ((((((\"act=\" + encodeURIComponent(a))) + \"; path=/; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n    }\n;\n;\n};\n;\n(function() {\n    UserNoOp = function() {\n    \n    };\n    var a = function() {\n        return this;\n    };\n    copy_properties(UserNoOp.prototype, {\n        add_event: a,\n        add_data: a,\n        set_ua_id: a,\n        set_namespace: a\n    });\n})();\nfunction UserAction(d, c, a) {\n    var b = ((((d + \"/\")) + c));\n    copy_properties(this, {\n        ue: b,\n        _ua_id: null,\n        _ts: d,\n        _ns: null,\n        _start_ts: d,\n        _prev_event: \"s\",\n        _ue_ts: d,\n        _ue_count: c,\n        _context: a,\n        _version: 1\n    });\n};\n;\nUserAction.enable = function(a) {\n    UserAction.enable[a] = true;\n};\ncopy_properties(UserAction.prototype, {\n    set_ua_id: function(a) {\n        this._ua_id = a;\n        return this;\n    },\n    set_namespace: function(a) {\n        this._ns = a;\n        return this;\n    },\n    add_event: function(c) {\n        if (!UserAction.enable.events) {\n            return this;\n        }\n    ;\n    ;\n        var d = (+new JSBNG__Date()), a = ((d - this._ts));\n        var b = [this._version,this.ue,this._ns,this._ua_id,this._prev_event,c,a,];\n        ((window.EagleEye && EagleEye.log(\"evt\", b)));\n        this._ts = d;\n        this._prev_event = c;\n        return this;\n    },\n    add_data: function(a) {\n        if (!UserAction.enable.data) {\n            return this;\n        }\n    ;\n    ;\n        return this;\n    }\n});\nvar user_action = (function() {\n    var d = 0, c = 0;\n    var b = null, a = null;\n    return function(h, e, JSBNG__event, g, f) {\n        var k = (+new JSBNG__Date()), j = ((((k + \"/\")) + d));\n        f = ((f || {\n        }));\n        if (((!h && JSBNG__event))) {\n            h = JSBNG__event.getTarget();\n        }\n    ;\n    ;\n        b = h;\n        a = JSBNG__event;\n        var i = new UserAction(k, d, e);\n        Arbiter.inform(\"UserAction/new\", {\n            ua: i,\n            node: h,\n            mode: g,\n            JSBNG__event: JSBNG__event,\n            extra_data: f\n        });\n        c = k;\n        d++;\n        return i;\n    };\n})();\nvar report_data = function(a, b) {\n    user_action(null, a, null, \"FORCE\", b);\n};\n(function() {\n    ClickRef = {\n    };\n    ClickRef.get_intern_ref = function(c) {\n        if (!!c) {\n            var b = {\n                profile_minifeed: 1,\n                info_tab: 1,\n                gb_content_and_toolbar: 1,\n                gb_muffin_area: 1,\n                ego: 1,\n                bookmarks_menu: 1,\n                jewelBoxNotif: 1,\n                jewelNotif: 1,\n                BeeperBox: 1,\n                navSearch: 1\n            };\n            for (var a = c; ((a && ((a != JSBNG__document.body)))); a = a.parentNode) {\n                if (((!a.id || ((typeof a.id !== \"string\"))))) {\n                    continue;\n                }\n            ;\n            ;\n                if (((a.id.substr(0, 8) == \"pagelet_\"))) {\n                    return a.id.substr(8);\n                }\n            ;\n            ;\n                if (((a.id.substr(0, 8) == \"box_app_\"))) {\n                    return a.id;\n                }\n            ;\n            ;\n                if (b[a.id]) {\n                    return a.id;\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        return \"-\";\n    };\n    ClickRef.get_href = function(b) {\n        var a = ((((((((b.getAttribute && ((b.getAttribute(\"ajaxify\") || b.getAttribute(\"data-endpoint\"))))) || b.action)) || b.href)) || b.JSBNG__name));\n        return a;\n    };\n    ClickRef.mouse_click_info = function(b) {\n        if (!ge(\"JSBNG__content\")) {\n            return [0,0,0,0,];\n        }\n    ;\n    ;\n        var a = $(\"JSBNG__content\");\n        var c = ((window.Vector2 ? Vector2.getEventPosition(b) : {\n            x: 0,\n            y: 0\n        }));\n        return [c.x,c.y,a.offsetLeft,a.clientWidth,];\n    };\n    ClickRef.should_report = function(b, a) {\n        if (((a == \"FORCE\"))) {\n            return true;\n        }\n    ;\n    ;\n        if (((a == \"INDIRECT\"))) {\n            return false;\n        }\n    ;\n    ;\n        return ((b && ClickRef.get_href(b)));\n    };\n    ClickRef.collect_data = function(l, h, JSBNG__event, d) {\n        var j = (((!window.ArbiterMonitor) ? \"r\" : \"a\")), g = [0,0,0,0,], k, e, f;\n        if (!!JSBNG__event) {\n            k = JSBNG__event.type;\n            if (((((k == \"click\")) && ge(\"JSBNG__content\")))) {\n                g = ClickRef.mouse_click_info(JSBNG__event);\n            }\n        ;\n        ;\n            var b = 0;\n            ((JSBNG__event.ctrlKey && (b += 1)));\n            ((JSBNG__event.shiftKey && (b += 2)));\n            ((JSBNG__event.altKey && (b += 4)));\n            ((JSBNG__event.metaKey && (b += 8)));\n            if (b) {\n                k += b;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (!!h) {\n            e = ClickRef.get_href(h);\n        }\n    ;\n    ;\n        var a = [];\n        if (window.ArbiterMonitor) {\n            f = ArbiterMonitor.getInternRef(h);\n            a = ArbiterMonitor.getActFields();\n        }\n    ;\n    ;\n        var c = {\n        };\n        if (window.collect_data_attribs) {\n            c = collect_data_attribs(h, [\"ft\",\"gt\",]);\n            copy_properties(c.ft, ((d.ft || {\n            })));\n            copy_properties(c.gt, ((d.gt || {\n            })));\n            if (c.gt.ua_id) {\n                l.set_ua_id(c.gt.ua_id);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var i = [l._ue_ts,l._ue_count,((e || \"-\")),l._context,((k || \"-\")),((f || ClickRef.get_intern_ref(h))),j,((window.URI ? URI.getRequestURI(true, true).getUnqualifiedURI().toString() : ((((JSBNG__location.pathname + JSBNG__location.search)) + JSBNG__location.hash)))),c,].concat(g).concat(a);\n        return i;\n    };\n    ClickRef.JSBNG__onNewUserAction = function(b, a) {\n        Bootloader.loadComponents(\"dom-collect\", function() {\n            if (ClickRef.should_report(a.node, a.mode)) {\n                var c = ClickRef.collect_data(a.ua, a.node, a.JSBNG__event, a.extra_data);\n                ClickRef.report(a.ua, c);\n            }\n        ;\n        ;\n        });\n    };\n    ClickRef.report = function(b, a) {\n        var c = b.ue;\n        set_ue_cookie(c);\n        ((window.EagleEye && EagleEye.log(\"act\", a)));\n    };\n    ((window.Arbiter && Arbiter.subscribe(\"UserAction/new\", ClickRef.JSBNG__onNewUserAction)));\n})();\nge = $ = function(a) {\n    return ((((typeof a == \"string\")) ? JSBNG__document.getElementById(a) : a));\n};\nCSS = ((window.CSS || {\n    hasClass: function(b, a) {\n        b = $(b);\n        return ((((((\" \" + b.className)) + \" \")).indexOf(((((\" \" + a)) + \" \"))) > -1));\n    },\n    addClass: function(b, a) {\n        b = $(b);\n        if (((a && !CSS.hasClass(b, a)))) {\n            b.className = ((((b.className + \" \")) + a));\n        }\n    ;\n    ;\n        return b;\n    },\n    removeClass: function(b, a) {\n        b = $(b);\n        if (CSS.hasClass(b, a)) {\n            b.className = b.className.replace(new RegExp(((((\"(^|\\\\s)\" + a)) + \"(?:\\\\s|$)\")), \"g\"), \"$1\");\n        }\n    ;\n    ;\n        return b;\n    },\n    toggleClass: function(b, a) {\n        return CSS.conditionClass(b, a, !CSS.hasClass(b, a));\n    },\n    conditionClass: function(c, b, a) {\n        return ((a ? CSS.addClass : CSS.removeClass))(c, b);\n    },\n    show: function(a) {\n        CSS.removeClass(a, \"hidden_elem\");\n    },\n    hide: function(a) {\n        CSS.addClass(a, \"hidden_elem\");\n    },\n    conditionShow: function(b, a) {\n        CSS.conditionClass(b, \"hidden_elem\", !a);\n    }\n}));\nvar Parent = {\n    byTag: function(a, b) {\n        b = b.toUpperCase();\n        while (((a && ((a.nodeName != b))))) {\n            a = a.parentNode;\n        ;\n        };\n    ;\n        return a;\n    },\n    byClass: function(b, a) {\n        while (((b && !CSS.hasClass(b, a)))) {\n            b = b.parentNode;\n        ;\n        };\n    ;\n        return b;\n    },\n    byAttribute: function(b, a) {\n        while (((b && ((!b.getAttribute || !b.getAttribute(a)))))) {\n            b = b.parentNode;\n        ;\n        };\n    ;\n        return b;\n    }\n};\nfunction trackReferrer(a, e) {\n    a = Parent.byAttribute(a, \"data-referrer\");\n    if (a) {\n        var d = ((/^(?:(?:[^:\\/?#]+):)?(?:\\/\\/(?:[^\\/?#]*))?([^?#]*)(?:\\?([^#]*))?(?:#(.*))?/.exec(e)[1] || \"\"));\n        if (!d) {\n            return;\n        }\n    ;\n    ;\n        var c = ((((d + \"|\")) + a.getAttribute(\"data-referrer\")));\n        var b = new JSBNG__Date();\n        b.setTime(((new JSBNG__Date().getTime() + 1000)));\n        JSBNG__document.cookie = ((((((((((((\"x-src=\" + encodeURIComponent(c))) + \"; \")) + \"expires=\")) + b.toGMTString())) + \";path=/; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n    }\n;\n;\n    return a;\n};\n;\n!function() {\n    if (window.__primer) {\n        return;\n    }\n;\n;\n    window.__primer = true;\n    var a = null;\n    var b = /async(?:-post)?|dialog(?:-pipe|-post)?|theater|toggle/;\n    JSBNG__document.documentElement.JSBNG__onclick = function(e) {\n        e = ((e || window.JSBNG__event));\n        a = ((e.target || e.srcElement));\n        var f = Parent.byTag(a, \"A\");\n        if (!f) {\n            return;\n        }\n    ;\n    ;\n        var c = f.getAttribute(\"ajaxify\");\n        var g = f.href;\n        var l = ((c || g));\n        if (l) {\n            var k = user_action(f, \"a\", e);\n            if (window.ArbiterMonitor) {\n                ArbiterMonitor.initUA(k, [f,]);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((((c && g)) && !(/#$/).test(g)))) {\n            var h = ((e.which && ((e.which != 1))));\n            var i = ((((((e.altKey || e.ctrlKey)) || e.metaKey)) || e.shiftKey));\n            if (((h || i))) {\n                return;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        trackReferrer(f, l);\n        var d = [\"dialog\",];\n        var j = ((f.rel && f.rel.match(b)));\n        j = ((j && j[0]));\n        switch (j) {\n          case \"dialog-pipe\":\n            d.push(\"ajaxpipe\");\n          case \"dialog\":\n        \n          case \"dialog-post\":\n            Bootloader.loadComponents(d, function() {\n                Dialog.bootstrap(l, null, ((j == \"dialog\")), null, null, f);\n            });\n            break;\n          case \"async\":\n        \n          case \"async-post\":\n            Bootloader.loadComponents(\"async\", function() {\n                AsyncRequest.bootstrap(l, f);\n            });\n            break;\n          case \"theater\":\n            if (((window.Env && ((Env.theater_ver == \"2\"))))) {\n                Bootloader.loadComponents(\"PhotoSnowbox\", function() {\n                    PhotoSnowbox.bootstrap(l, f);\n                });\n            }\n             else Bootloader.loadComponents(\"PhotoTheater\", function() {\n                PhotoTheater.bootstrap(l, f);\n            });\n        ;\n        ;\n            break;\n          case \"toggle\":\n            CSS.toggleClass(f.parentNode, \"openToggler\");\n            Bootloader.loadComponents(\"Toggler\", function() {\n                Toggler.bootstrap(f);\n            });\n            break;\n          default:\n            return;\n        };\n    ;\n        return false;\n    };\n    JSBNG__document.documentElement.JSBNG__onsubmit = function(c) {\n        c = ((c || window.JSBNG__event));\n        var d = ((c.target || c.srcElement));\n        if (((((d && ((d.nodeName == \"FORM\")))) && ((d.getAttribute(\"rel\") == \"async\"))))) {\n            var f = user_action(d, \"f\", c);\n            if (window.ArbiterMonitor) {\n                ArbiterMonitor.initUA(f, [d,]);\n            }\n        ;\n        ;\n            var e = a;\n            Bootloader.loadComponents(\"dom-form\", function() {\n                Form.bootstrap(d, e);\n            });\n            return false;\n        }\n    ;\n    ;\n    };\n}();\nvar ua = {\n    ie: function() {\n        return ((ua._populate() || this._ie));\n    },\n    ie64: function() {\n        return ((ua.ie() && this._win64));\n    },\n    firefox: function() {\n        return ((ua._populate() || this._firefox));\n    },\n    JSBNG__opera: function() {\n        return ((ua._populate() || this._opera));\n    },\n    safari: function() {\n        return ((ua._populate() || this._safari));\n    },\n    JSBNG__chrome: function() {\n        return ((ua._populate() || this._chrome));\n    },\n    windows: function() {\n        return ((ua._populate() || this._windows));\n    },\n    osx: function() {\n        return ((ua._populate() || this._osx));\n    },\n    linux: function() {\n        return ((ua._populate() || this._linux));\n    },\n    iphone: function() {\n        return ((ua._populate() || this._iphone));\n    },\n    _populated: false,\n    _populate: function() {\n        if (ua._populated) {\n            return;\n        }\n    ;\n    ;\n        ua._populated = true;\n        var d = JSBNG__navigator.userAgent;\n        var a = /(?:MSIE.(\\d+\\.\\d+))|(?:(?:Firefox|GranParadiso|Iceweasel).(\\d+\\.\\d+))|(?:Opera(?:.+Version.|.)(\\d+\\.\\d+))|(?:AppleWebKit.(\\d+(?:\\.\\d+)?))/.exec(d);\n        var c = /(Mac OS X)|(Windows)|(Linux)/.exec(d);\n        var b = /\\b(iPhone|iP[ao]d)/.exec(d);\n        ua._win64 = !!(/Win64/.exec(d));\n        if (a) {\n            ua._ie = ((a[1] ? parseFloat(a[1]) : NaN));\n            if (((ua._ie && JSBNG__document.documentMode))) {\n                ua._ie = JSBNG__document.documentMode;\n            }\n        ;\n        ;\n            ua._firefox = ((a[2] ? parseFloat(a[2]) : NaN));\n            ua._opera = ((a[3] ? parseFloat(a[3]) : NaN));\n            ua._safari = ((a[4] ? parseFloat(a[4]) : NaN));\n            if (ua._safari) {\n                a = /(?:Chrome\\/(\\d+\\.\\d+))/.exec(d);\n                ua._chrome = ((((a && a[1])) ? parseFloat(a[1]) : NaN));\n            }\n             else ua._chrome = NaN;\n        ;\n        ;\n        }\n         else ua._ie = ua._firefox = ua._opera = ua._chrome = ua._safari = NaN;\n    ;\n    ;\n        if (c) {\n            if (c[1]) {\n                var e = /(?:Mac OS X (\\d+(?:[._]\\d+)?))/.exec(d);\n                ua._osx = ((e ? parseFloat(e[1].replace(\"_\", \".\")) : true));\n            }\n             else ua._osx = false;\n        ;\n        ;\n            ua._windows = !!c[2];\n            ua._linux = !!c[3];\n        }\n         else ua._osx = ua._windows = ua._linux = false;\n    ;\n    ;\n        ua._iphone = b;\n    }\n};\nOnloadEvent = {\n    ONLOAD: \"JSBNG__onload/onload\",\n    ONLOAD_CALLBACK: \"JSBNG__onload/onload_callback\",\n    ONLOAD_DOMCONTENT: \"JSBNG__onload/dom_content_ready\",\n    ONLOAD_DOMCONTENT_CALLBACK: \"JSBNG__onload/domcontent_callback\",\n    ONBEFOREUNLOAD: \"JSBNG__onload/beforeunload\",\n    ONUNLOAD: \"JSBNG__onload/unload\"\n};\nfunction _include_quickling_events_default() {\n    return !window.loading_page_chrome;\n};\n;\nfunction JSBNG__onbeforeunloadRegister(a, b) {\n    if (((b === undefined))) {\n        b = _include_quickling_events_default();\n    }\n;\n;\n    ((b ? _addHook(\"JSBNG__onbeforeleavehooks\", a) : _addHook(\"JSBNG__onbeforeunloadhooks\", a)));\n};\n;\nfunction JSBNG__onunloadRegister(a) {\n    if (!window.JSBNG__onunload) {\n        window.JSBNG__onunload = function() {\n            Arbiter.inform(OnloadEvent.ONUNLOAD, true, Arbiter.BEHAVIOR_STATE);\n        };\n    }\n;\n;\n    _addHook(\"JSBNG__onunloadhooks\", a);\n};\n;\nfunction JSBNG__onleaveRegister(a) {\n    _addHook(\"JSBNG__onleavehooks\", a);\n};\n;\nfunction _addHook(b, a) {\n    window[b] = ((window[b] || [])).concat(a);\n};\n;\nfunction removeHook(a) {\n    window[a] = [];\n};\n;\n{\n    function _domcontentready() {\n        Arbiter.inform(OnloadEvent.ONLOAD_DOMCONTENT, true, Arbiter.BEHAVIOR_STATE);\n    };\n    ((window.top.JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_154.push)((_domcontentready)));\n};\n;\nfunction _bootstrapEventHandlers() {\n    var a = JSBNG__document, e = window;\n    if (a.JSBNG__addEventListener) {\n        if (((ua.safari() < 525))) {\n            var d = JSBNG__setInterval(function() {\n                if (/loaded|complete/.test(a.readyState)) {\n                    _domcontentready();\n                    JSBNG__clearInterval(d);\n                }\n            ;\n            ;\n            }, 10);\n        }\n         else a.JSBNG__addEventListener(\"DOMContentLoaded\", _domcontentready, true);\n    ;\n    ;\n    }\n     else {\n        var c = \"javascript:void(0)\";\n        if (((e.JSBNG__location.protocol == \"https:\"))) {\n            c = \"//:\";\n        }\n    ;\n    ;\n        a.write(((((((((\"\\u003Cscript onreadystatechange=\\\"if (this.readyState=='complete') {\" + \"this.parentNode.removeChild(this);_domcontentready();}\\\" \")) + \"defer=\\\"defer\\\" src=\\\"\")) + c)) + \"\\\"\\u003E\\u003C/script\\u003E\")));\n    }\n;\n;\n    var b = e.JSBNG__onload;\n    e.JSBNG__onload = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_157), function() {\n        ((e.CavalryLogger && CavalryLogger.getInstance().setTimeStamp(\"t_layout\")));\n        ((b && b()));\n        Arbiter.inform(OnloadEvent.ONLOAD, true, Arbiter.BEHAVIOR_STATE);\n    }));\n    e.JSBNG__onbeforeunload = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_158), function() {\n        var f = {\n        };\n        Arbiter.inform(OnloadEvent.ONBEFOREUNLOAD, f, Arbiter.BEHAVIOR_STATE);\n        if (!f.warn) {\n            Arbiter.inform(\"JSBNG__onload/exit\", true);\n        }\n    ;\n    ;\n        return f.warn;\n    }));\n};\n;\nJSBNG__onload_callback = Arbiter.registerCallback(function() {\n    ((window.CavalryLogger && CavalryLogger.getInstance().setTimeStamp(\"t_onload\")));\n    Arbiter.inform(OnloadEvent.ONLOAD_CALLBACK, true, Arbiter.BEHAVIOR_STATE);\n}, [OnloadEvent.ONLOAD,]);\ndomcontent_callback = Arbiter.registerCallback(function() {\n    ((window.CavalryLogger && CavalryLogger.getInstance().setTimeStamp(\"t_domcontent\")));\n    Arbiter.inform(OnloadEvent.ONLOAD_DOMCONTENT_CALLBACK, true, Arbiter.BEHAVIOR_STATE);\n}, [OnloadEvent.ONLOAD_DOMCONTENT,]);\nif (!window._eventHandlersBootstrapped) {\n    _eventHandlersBootstrapped = true;\n    _bootstrapEventHandlers();\n}\n;\n;\nfunction tx(b, a) {\n    if (((typeof _string_table == \"undefined\"))) {\n        return;\n    }\n;\n;\n    b = _string_table[b];\n    return _tx(b, a);\n};\n;\nfunction intl_ends_in_punct(a) {\n    if (((typeof a != \"string\"))) {\n        return false;\n    }\n;\n;\n    return a.match(new RegExp(((((((((((((((((((((((((((((((((((((((((((((((((((((intl_ends_in_punct.punct_char_class + \"[\")) + \")\\\"\")) + \"'\")) + \"\\u00bb\")) + \"\\u0f3b\")) + \"\\u0f3d\")) + \"\\u2019\")) + \"\\u201d\")) + \"\\u203a\")) + \"\\u3009\")) + \"\\u300b\")) + \"\\u300d\")) + \"\\u300f\")) + \"\\u3011\")) + \"\\u3015\")) + \"\\u3017\")) + \"\\u3019\")) + \"\\u301b\")) + \"\\u301e\")) + \"\\u301f\")) + \"\\ufd3f\")) + \"\\uff07\")) + \"\\uff09\")) + \"\\uff3d\")) + \"s\")) + \"]*$\"))));\n};\n;\nintl_ends_in_punct.punct_char_class = ((((((((((((((((((((((\"[\" + \".!?\")) + \"\\u3002\")) + \"\\uff01\")) + \"\\uff1f\")) + \"\\u0964\")) + \"\\u2026\")) + \"\\u0eaf\")) + \"\\u1801\")) + \"\\u0e2f\")) + \"\\uff0e\")) + \"]\"));\nfunction intl_render_list_separator() {\n    return _tx(\"{previous-items}, {next-items}\", {\n        \"previous-items\": \"\",\n        \"next-items\": \"\"\n    });\n};\n;\nfunction intl_phonological_rules(g) {\n    var e, d = g, f = window.intl_locale_rewrites, b, c;\n    try {\n        if (f) {\n            var pats = [], reps = [];\n            for (var p in f.patterns) {\n                var pat = p, rep = f.patterns[p];\n                for (b in f.meta) {\n                    e = new RegExp(b.slice(1, -1), \"g\");\n                    pat = pat.replace(e, f.meta[b]);\n                    rep = rep.replace(e, f.meta[b]);\n                };\n            ;\n                pats[pats.length] = pat;\n                reps[reps.length] = rep;\n            };\n        ;\n            for (var ii = 0; ((ii < pats.length)); ii++) {\n                e = new RegExp(pats[ii].slice(1, -1), \"g\");\n                if (((reps[ii] == \"javascript\"))) {\n                    c = g.match(e);\n                    b = ((c && c[0]));\n                    if (b) {\n                        g = g.replace(e, b.slice(1).toLowerCase());\n                    }\n                ;\n                ;\n                }\n                 else g = g.replace(e, reps[ii]);\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n    } catch (a) {\n        g = d;\n    };\n;\n    e = new RegExp(\"\\u0001\", \"g\");\n    g = g.replace(e, \"\");\n    return g;\n};\n;\nfunction _tx(e, a) {\n    if (!a) {\n        return e;\n    }\n;\n;\n    var d;\n    for (var c in a) {\n        if (intl_ends_in_punct(a[c])) {\n            d = new RegExp(((((((((\"\\\\{\" + c)) + \"\\\\}\")) + intl_ends_in_punct.punct_char_class)) + \"*\")), \"g\");\n        }\n         else d = new RegExp(((((\"\\\\{\" + c)) + \"\\\\}\")), \"g\");\n    ;\n    ;\n        var b = \"\";\n        if (((a[c][0] != \"~\"))) {\n            b = \"\\u0001\";\n        }\n    ;\n    ;\n        e = e.replace(d, ((((b + a[c])) + b)));\n    };\n;\n    e = intl_phonological_rules(e);\n    return e;\n};\n;\nInitialJSLoader = {\n    INITIAL_JS_READY: \"BOOTLOAD/JSREADY\",\n    load: function(a) {\n        InitialJSLoader.callback = Bootloader.loadResources(a, InitialJSLoader.callback);\n    },\n    callback: Arbiter.registerCallback(function() {\n        Arbiter.inform(InitialJSLoader.INITIAL_JS_READY, true, Arbiter.BEHAVIOR_STATE);\n    }, [OnloadEvent.ONLOAD_DOMCONTENT_CALLBACK,])\n};\nfunction goURI(b, a) {\n    b = b.toString();\n    if (((((!a && window.PageTransitions)) && PageTransitions.isInitialized()))) {\n        PageTransitions.go(b);\n    }\n     else if (((window.JSBNG__location.href == b))) {\n        window.JSBNG__location.reload();\n    }\n     else window.JSBNG__location.href = b;\n    \n;\n;\n};\n;\nfunction loadExternalJavascript(f, b, a) {\n    if (((f instanceof Array))) {\n        var e = f.shift(0);\n        if (e) {\n            loadExternalJavascript(e, function() {\n                if (f.length) {\n                    loadExternalJavascript(f, b, a);\n                }\n                 else ((b && b()));\n            ;\n            ;\n            }, a);\n        }\n         else if (b) {\n            b();\n        }\n        \n    ;\n    ;\n    }\n     else {\n        var c = ((a ? JSBNG__document.body : JSBNG__document.getElementsByTagName(\"head\")[0]));\n        var d = JSBNG__document.createElement(\"script\");\n        d.type = \"text/javascript\";\n        d.src = f;\n        if (b) {\n            d.JSBNG__onerror = d.JSBNG__onload = b;\n            d.JSBNG__onreadystatechange = function() {\n                if (((((this.readyState == \"complete\")) || ((this.readyState == \"loaded\"))))) {\n                    b();\n                }\n            ;\n            ;\n            };\n        }\n    ;\n    ;\n        c.appendChild(d);\n        return d;\n    }\n;\n;\n};\n;\nfunction invoke_callbacks(b, d) {\n    if (b) {\n        for (var c = 0; ((c < b.length)); c++) {\n            try {\n                (new Function(b[c])).apply(d);\n            } catch (a) {\n            \n            };\n        ;\n        };\n    }\n;\n;\n};\n;\n((window.JSLogger || (function() {\n    function b(d) {\n        this.cat = d;\n        this._counts = {\n        };\n    };\n;\n    var a = {\n        _JSLogger: b,\n        instances: {\n        },\n        backlog: [],\n        stringify: function(e) {\n            try {\n                return JSON.stringify(e);\n            } catch (d) {\n                return ((((\"{\\\"stringify_error\\\": \\\"\" + d.message)) + \"\\\"}\"));\n            };\n        ;\n        }\n    };\n    function c(d) {\n        b.prototype[d] = function(JSBNG__event, e) {\n            if (((a.backlog.length < 100))) {\n                a.backlog.push([this.cat,d,JSBNG__event,a.stringify(e),new JSBNG__Date(),]);\n            }\n        ;\n        ;\n        };\n    };\n;\n    c(\"debug\");\n    c(\"log\");\n    c(\"warn\");\n    c(\"error\");\n    c(\"bump\");\n    window.JSLogger = {\n        _: a,\n        DUMP_EVENT: \"jslogger/dump\",\n        create: function(d) {\n            return ((a.instances[d] || (a.instances[d] = new b(d))));\n        }\n    };\n})()));\nwindow.JSBNG__Event = ((window.JSBNG__Event || function() {\n\n}));\nJSBNG__Event.__inlineSubmit = function(b, JSBNG__event) {\n    var a = ((JSBNG__Event.__getHandler && JSBNG__Event.__getHandler(b, \"submit\")));\n    return ((a ? null : JSBNG__Event.__bubbleSubmit(b, JSBNG__event)));\n};\nJSBNG__Event.__bubbleSubmit = function(a, JSBNG__event) {\n    if (JSBNG__document.documentElement.JSBNG__attachEvent) {\n        var b;\n        while (((((b !== false)) && (a = a.parentNode)))) {\n            b = ((a.JSBNG__onsubmit ? a.JSBNG__onsubmit(JSBNG__event) : ((JSBNG__Event.__fire && JSBNG__Event.__fire(a, \"submit\", JSBNG__event)))));\n        ;\n        };\n    ;\n        return b;\n    }\n;\n;\n};\n((window.require || (function() {\n    var y = {\n    }, v = {\n    }, m = 0, x = this, h = 1, k = 2, i = \"special\", c = \"exports\", b = \"dependencies\", f = \"module\", l = \"waiting\", d = \"factory\", j = undefined, a = \"define\", e = \"global\", g = \"require\";\n    function z(zh) {\n        var zj = y[zh], zc, zg;\n        if (((zj[l] && ((zj[i] & k))))) {\n            p();\n        }\n    ;\n    ;\n        if (!zj[c]) {\n            var ze = zj[c] = {\n            }, zf = zj[d];\n            if (((Object.prototype.toString.call(zf) === \"[object Function]\"))) {\n                var zb = [], zd = zj[b], zi = zd.length;\n                if (((zj[i] & k))) {\n                    zi = Math.min(zi, zf.length);\n                }\n            ;\n            ;\n                for (zg = 0; ((zg < zi)); zg++) {\n                    zc = zd[zg];\n                    zb.push(((((zc === f)) ? zj : ((((zc === c)) ? ze : z(zc))))));\n                };\n            ;\n                var zk = zf.apply(x, zb);\n                if (zk) {\n                    zj[c] = zk;\n                }\n            ;\n            ;\n            }\n             else zj[c] = zf;\n        ;\n        ;\n        }\n    ;\n    ;\n        return zj[c];\n    };\n;\n    function u(ze, zc, zd, zb) {\n        if (((zc === j))) {\n            zc = [];\n            zd = ze;\n            ze = r();\n        }\n         else if (((zd === j))) {\n            zd = zc;\n            zc = ze;\n            ze = r();\n        }\n        \n    ;\n    ;\n        if (y[ze]) {\n            return;\n        }\n    ;\n    ;\n        var zf = {\n            id: ze\n        };\n        zf[d] = zd;\n        zf[b] = zc;\n        zf[i] = zb;\n        y[ze] = zf;\n        n(ze);\n    };\n;\n    function w(zb, zc) {\n        u(zb, zc, j, h);\n    };\n;\n    function p() {\n        var zc = {\n        }, zb;\n        for (zb in v) {\n            if (((((y[zb] && !zc[zb])) && ((y[zb][i] & k))))) {\n                q({\n                }, zb, zc);\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    function q(ze, zb, zf) {\n        zf[zb] = 1;\n        var zd = v[zb], zc;\n        if (!zd) {\n            return;\n        }\n    ;\n    ;\n        ze[zb] = 1;\n        for (zc in zd) {\n            if (((!y[zc][i] & k))) {\n                continue;\n            }\n        ;\n        ;\n            if (ze[zc]) {\n                delete zd[zc];\n                y[zc][l]--;\n                if (!y[zc][l]) {\n                    s(zc);\n                }\n            ;\n            ;\n            }\n             else q(ze, zc, zf);\n        ;\n        ;\n        };\n    ;\n        ze[zb] = 0;\n    };\n;\n    function r() {\n        return ((\"__mod__\" + m++));\n    };\n;\n    function n(zd) {\n        var ze = y[zd];\n        var zf = 0;\n        for (var zc = 0; ((zc < ze[b].length)); zc++) {\n            var zb = ze[b][zc];\n            if (((!y[zb] || y[zb][l]))) {\n                ((v[zb] || (v[zb] = {\n                })));\n                v[zb][zd] = 1;\n                zf++;\n            }\n        ;\n        ;\n        };\n    ;\n        ze[l] = zf;\n        if (!zf) {\n            s(zd);\n        }\n    ;\n    ;\n    };\n;\n    function s(zc) {\n        var zd = y[zc];\n        if (((zd[i] & h))) {\n            z(zc);\n        }\n    ;\n    ;\n        var ze = v[zc];\n        if (ze) {\n            delete v[zc];\n            for (var zb in ze) {\n                if (!--y[zb][l]) {\n                    s(zb);\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function o(zc, zb) {\n        y[zc] = {\n            id: zc\n        };\n        y[zc][c] = zb;\n    };\n;\n    o(f, 0);\n    o(c, 0);\n    o(a, u);\n    o(e, x);\n    o(g, z);\n    u.amd = {\n    };\n    x[a] = u;\n    x[g] = z;\n    z.ensure = w;\n    var t = [e,f,g,c,];\n    var za = false;\n    x.__d = function(ze, zc, zd, zb) {\n        u(ze, t.concat(zc), zd, ((zb || k)));\n        if (((y[ze][l] && !za))) {\n            za = JSBNG__setTimeout(function() {\n                p();\n                za = false;\n            }, 9);\n        }\n    ;\n    ;\n    };\n})()));\nJSCC = ((window.JSCC || function() {\n    var a = {\n    }, b = {\n    };\n    return {\n        get: function(c) {\n            if (((c in a))) {\n                b[c] = a[c]();\n                delete a[c];\n                return b[c];\n            }\n             else return b[c]\n        ;\n        },\n        init: function(c) {\n            copy_properties(a, c);\n        }\n    };\n}()));\nDynaTemplate = ((window.DynaTemplate || (function() {\n    var g = \"[[\", i = \"\\\\[\\\\[\", h = \"\\\\]\\\\]\";\n    var l = {\n    };\n    var a = {\n    };\n    function d(n, m) {\n        return ((m.indexOf(((g + n))) != -1));\n    };\n;\n    function e(m) {\n        return ((Object.prototype.toString.call(m) === \"[object Array]\"));\n    };\n;\n    function f(m) {\n        return ((m && ((typeof m == \"object\"))));\n    };\n;\n    function c(m) {\n        switch (m) {\n          case \"&\":\n            return \"&amp;\";\n          case \"\\\"\":\n            return \"&quot;\";\n          case \"'\":\n            return \"&#39;\";\n          case \"\\u003C\":\n            return \"&lt;\";\n          case \"\\u003E\":\n            return \"&gt;\";\n          default:\n            return m;\n        };\n    ;\n    };\n;\n    function b(m) {\n        m = String(((((m === null)) ? \"\" : m)));\n        return m.replace(/&(?!\\w+;)|[\"'<>]/g, c);\n    };\n;\n    function j(n) {\n        for (var m in n) {\n            var o = n[m];\n            a[o[0]] = o[1];\n            l[m] = o[1];\n        };\n    ;\n    };\n;\n    function k(p, m) {\n        if (((p.charAt(0) == \"@\"))) {\n            return k(a[p.substring(1)], m);\n        }\n    ;\n    ;\n        if (((d(\"#\", p) || d(\"^\", p)))) {\n            var o = new RegExp(((((((((((((((i + \"(\\\\^|\\\\#)\\\\s*(.+)\\\\s*\")) + h)) + \"\\u000a*([\\\\s\\\\S]+?)\")) + i)) + \"\\\\/\\\\s*\\\\2\\\\s*\")) + h)) + \"\\\\s*\")), \"mg\");\n            p = p.replace(o, function(q, v, t, r) {\n                var w = m[t];\n                w = ((((w && ((w.__html !== undefined)))) ? w.__html : w));\n                if (((v == \"^\"))) {\n                    if (((!w || ((e(w) && ((w.length === 0))))))) {\n                        return k(r, m);\n                    }\n                     else return \"\"\n                ;\n                }\n                 else if (((v == \"#\"))) {\n                    if (e(w)) {\n                        var u = [];\n                        for (var s = 0; ((s < w.length)); s++) {\n                            u.push(k(r, w[s]));\n                        ;\n                        };\n                    ;\n                        return u.join(\"\");\n                    }\n                     else if (f(w)) {\n                        return k(r, w);\n                    }\n                     else if (!((typeof w == \"function\"))) {\n                        if (w) {\n                            return k(r, m);\n                        }\n                    ;\n                    }\n                    \n                    \n                ;\n                ;\n                    return \"\";\n                }\n                \n            ;\n            ;\n            });\n        }\n    ;\n    ;\n        if (!d(\"\", p)) {\n            return p;\n        }\n    ;\n    ;\n        var n = new RegExp(((((((i + \"(\\u003E|\\\\[|&)?([^\\\\/#\\\\^]+?)\\\\1?\")) + h)) + \"+\")), \"g\");\n        return p.replace(n, function(q, s, r) {\n            r = r.replace(/^\\s*|\\s*$/g, \"\");\n            var t = m[r];\n            if (((!t || ((((t instanceof Array)) && ((t.length === 0))))))) {\n                return \"\";\n            }\n        ;\n        ;\n            switch (s) {\n              case \"\\u003E\":\n                if (((t[0].charAt(0) == \"@\"))) {\n                    return k(t[0], t[1]);\n                }\n                 else if (!((t[0] in l))) {\n                    return \"\";\n                }\n                \n            ;\n            ;\n                return k(l[t[0]], t[1]);\n              case \"&\":\n            \n              default:\n                if (((window.HTML && ((t instanceof HTML))))) {\n                    return t.toString();\n                }\n            ;\n            ;\n                return ((((t.__html !== undefined)) ? t.__html : b(t)));\n            };\n        ;\n        });\n    };\n;\n    return {\n        registerTemplates: j,\n        renderToHtml: k\n    };\n})()));\nfunction BigPipe(a) {\n    copy_properties(this, {\n        arbiter: Arbiter,\n        rootNodeID: \"JSBNG__content\",\n        lid: 0,\n        isAjax: false,\n        rrEnabled: true,\n        domContentCallback: domcontent_callback,\n        JSBNG__onloadCallback: JSBNG__onload_callback,\n        domContentEvt: OnloadEvent.ONLOAD_DOMCONTENT_CALLBACK,\n        JSBNG__onloadEvt: OnloadEvent.ONLOAD_CALLBACK,\n        forceFinish: false,\n        _phaseDoneCallbacks: [],\n        _currentPhase: 0,\n        _lastPhase: -1\n    });\n    copy_properties(this, a);\n    this._cavalry = ((((this.lid && window.CavalryLogger)) ? CavalryLogger.getInstance(this.lid) : null));\n    this._inst = ((this._cavalry && ((window._pagelet_profile || this._cavalry.isPageletProfiler()))));\n    BigPipe._current_instance = this;\n    if (((env_get(\"tti_vision\") == 1))) {\n        (new TTIVisualizer(this)).init();\n    }\n;\n;\n    this.arbiter.registerCallback(this.domContentCallback, [\"pagelet_displayed_all\",]);\n    this.arbiter.inform(\"phase_begin_0\", true, Arbiter.BEHAVIOR_STATE);\n    ((this._inst && this._cavalry.setTimeStamp(\"t_phase_begin_0\")));\n    this.JSBNG__onloadCallback = this.arbiter.registerCallback(this.JSBNG__onloadCallback, [\"pagelet_displayed_all\",]);\n};\n;\ncopy_properties(BigPipe.prototype, {\n    _ct: function(a) {\n        return ((((!a || ((((\"length\" in a)) && ((a.length === 0)))))) ? {\n        } : a));\n    },\n    _displayPagelet: function(e) {\n        if (this._inst) {\n            this._cavalry.JSBNG__onPageletEvent(\"display_start\", e.id);\n        }\n    ;\n    ;\n        e.JSBNG__content = this._ct(e.JSBNG__content);\n        var d = true;\n        for (var c in e.JSBNG__content) {\n            if (e.append) {\n                if (((e.append === \"bigpipe_root\"))) {\n                    target_id = this.rootNodeID;\n                }\n                 else target_id = e.append;\n            ;\n            ;\n            }\n             else target_id = c;\n        ;\n        ;\n            var b = JSBNG__document.getElementById(target_id), a = e.JSBNG__content[c];\n            if (b) {\n                if (a) {\n                    if (((typeof a != \"string\"))) {\n                        a = DynaTemplate.renderToHtml(a[0], a[1]);\n                    }\n                ;\n                ;\n                    if (((!e.append && e.has_inline_js))) {\n                        if (((window.DOM && window.HTML))) {\n                            DOM.setContent(b, HTML(a));\n                        }\n                         else {\n                            d = false;\n                            Bootloader.loadComponents(\"dom\", function() {\n                                DOM.setContent(b, HTML(a));\n                                this.arbiter.inform(((e.id + \"_displayed\")), true, Arbiter.BEHAVIOR_STATE);\n                            }.bind(this));\n                        }\n                    ;\n                    ;\n                    }\n                     else if (((e.append || ((ua.ie() < 8))))) {\n                        if (!e.append) {\n                            while (b.firstChild) {\n                                b.removeChild(b.firstChild);\n                            ;\n                            };\n                        }\n                    ;\n                    ;\n                        this._appendNodes(b, a);\n                    }\n                     else b.innerHTML = a;\n                    \n                ;\n                ;\n                }\n            ;\n            ;\n                if (this._inst) {\n                    this._cavalry.JSBNG__onPageletEvent(\"display\", e.id);\n                }\n            ;\n            ;\n                b.setAttribute(\"data-referrer\", ((b.getAttribute(\"data-referrer\") || target_id)));\n            }\n        ;\n        ;\n        };\n    ;\n        if (d) {\n            this.arbiter.inform(((e.id + \"_displayed\")), true, Arbiter.BEHAVIOR_STATE);\n        }\n    ;\n    ;\n        if (((e.cache_hit && ((env_get(\"pc_debug\") == 1))))) {\n            $(e.id).style.border = \"1px red solid\";\n        }\n    ;\n    ;\n    },\n    _appendNodes: function(a, d) {\n        var e = JSBNG__document.createElement(\"div\");\n        var c = ((ua.ie() < 7));\n        if (c) {\n            a.appendChild(e);\n        }\n    ;\n    ;\n        e.innerHTML = d;\n        var b = JSBNG__document.createDocumentFragment();\n        while (e.firstChild) {\n            b.appendChild(e.firstChild);\n        ;\n        };\n    ;\n        a.appendChild(b);\n        if (c) {\n            a.removeChild(e);\n        }\n    ;\n    ;\n    },\n    _downloadJsForPagelet: function(a) {\n        Bootloader.loadResources(((a.js || [])), bind(this, function() {\n            if (this._inst) {\n                this._cavalry.JSBNG__onPageletEvent(\"jsdone\", a.id);\n            }\n        ;\n        ;\n            a.requires = ((a.requires || []));\n            if (((!this.isAjax || ((a.phase >= 1))))) {\n                a.requires.push(\"uipage_onload\");\n            }\n        ;\n        ;\n            var c = bind(this, function() {\n                if (!this._isRelevant()) {\n                    return;\n                }\n            ;\n            ;\n                invoke_callbacks(a.JSBNG__onload);\n                if (((a.cacheable && !a.cache_hit))) {\n                    PageletCache.write(a);\n                }\n            ;\n            ;\n                if (this._inst) {\n                    this._cavalry.JSBNG__onPageletEvent(\"JSBNG__onload\", a.id);\n                }\n            ;\n            ;\n                this.arbiter.inform(\"pagelet_onload\", true, Arbiter.BEHAVIOR_EVENT);\n                ((a.provides && this.arbiter.inform(a.provides, true, Arbiter.BEHAVIOR_STATE)));\n            });\n            var b = bind(this, function() {\n                ((this._isRelevant() && invoke_callbacks(a.JSBNG__onafterload)));\n            });\n            if (this.delay) {\n                var d = c;\n                c = function() {\n                    JSBNG__setTimeout(d, 400);\n                };\n            }\n        ;\n        ;\n            this.arbiter.registerCallback(c, a.requires);\n            this.arbiter.registerCallback(b, [this.JSBNG__onloadEvt,]);\n        }), false, a.id);\n    },\n    _downloadCssAndDisplayPagelet: function(c) {\n        if (this._inst) {\n            this._cavalry.JSBNG__onPageletEvent(\"css\", c.id);\n        }\n    ;\n    ;\n        var b = bind(this, function() {\n            var d = ((c.display_dependency || []));\n            var f = [];\n            for (var e = 0; ((e < d.length)); e++) {\n                f.push(((d[e] + \"_displayed\")));\n            ;\n            };\n        ;\n            this.arbiter.registerCallback(this._displayPagelet.bind(this, c), f);\n        });\n        var a = ((c.css || []));\n        Bootloader.loadResources(a, b, false, c.id);\n        if (this._inst) {\n            this._cavalry.JSBNG__onPageletEvent(\"css_end\", c.id);\n        }\n    ;\n    ;\n    },\n    _downloadAndScheduleDisplayJS: function(d) {\n        var c = ((d.js || []));\n        var a = [];\n        for (var b = 0; ((b < c.length)); b++) {\n            if (Bootloader.isDisplayJS(c[b])) {\n                a.push(c[b]);\n            }\n        ;\n        ;\n        };\n    ;\n        Bootloader.loadResources(a, bind(this, function() {\n            if (((d.JSBNG__ondisplay && d.JSBNG__ondisplay.length))) {\n                this.arbiter.registerCallback(function() {\n                    invoke_callbacks(d.JSBNG__ondisplay);\n                }, [((d.id + \"_displayed\")),]);\n            }\n        ;\n        ;\n        }));\n    },\n    JSBNG__onPageletArrive: function(a) {\n        if (this._inst) {\n            this._cavalry.JSBNG__onPageletEvent(\"arrive\", a.id);\n        }\n    ;\n    ;\n        var b = a.phase;\n        if (!this._phaseDoneCallbacks[b]) {\n            this._phaseDoneCallbacks[b] = this.arbiter.registerCallback(this._onPhaseDone.bind(this), [((\"phase_complete_\" + b)),]);\n        }\n    ;\n    ;\n        this.arbiter.registerCallback(this._phaseDoneCallbacks[b], [((a.id + \"_displayed\")),]);\n        if (a.cacheable) {\n            if (a.cache_hit) {\n                Arbiter.registerCallback(function() {\n                    this.processPagelet(this.loadFromCache(a));\n                }.bind(this), [\"pagelet_cache_loaded\",]);\n            }\n             else {\n                PageletCache.write(a);\n                this.processPagelet(a);\n            }\n        ;\n        ;\n        }\n         else this.processPagelet(a);\n    ;\n    ;\n        if (this._inst) {\n            this._cavalry.JSBNG__onPageletEvent(\"arrive_end\", a.id);\n        }\n    ;\n    ;\n    },\n    processPagelet: function(b) {\n        var c = b.phase;\n        if (b.the_end) {\n            this._lastPhase = b.phase;\n        }\n    ;\n    ;\n        if (((b.tti_phase !== undefined))) {\n            this._ttiPhase = b.tti_phase;\n        }\n    ;\n    ;\n        ((b.jscc && invoke_callbacks([b.jscc,])));\n        ((b.tplts && DynaTemplate.registerTemplates(b.tplts)));\n        Bootloader.setResourceMap(b.resource_map);\n        Bootloader.enableBootload(this._ct(b.bootloadable));\n        var d = ((\"phase_begin_\" + c));\n        this.arbiter.registerCallback(this._downloadCssAndDisplayPagelet.bind(this, b), [d,]);\n        this.arbiter.registerCallback(this._downloadAndScheduleDisplayJS.bind(this, b), [d,]);\n        var a;\n        if (!this.jsNonBlock) {\n            a = this.domContentEvt;\n        }\n         else a = ((b.id + \"_displayed\"));\n    ;\n    ;\n        this.arbiter.registerCallback(this.JSBNG__onloadCallback, [\"pagelet_onload\",]);\n        this.arbiter.registerCallback(this._downloadJsForPagelet.bind(this, b), [a,]);\n        ((b.is_last && this.arbiter.inform(((\"phase_complete_\" + c)), true, Arbiter.BEHAVIOR_STATE)));\n    },\n    _onPhaseDone: function() {\n        if (((((this._currentPhase === this._ttiPhase)) && this.rrEnabled))) {\n            this.arbiter.inform(\"tti_bigpipe\", {\n                s: this.lid\n            }, Arbiter.BEHAVIOR_EVENT);\n            ((this._cavalry && this._cavalry.setTTIPhase(this._ttiPhase).measurePageLoad(true)));\n        }\n    ;\n    ;\n        var b = ((this._currentPhase + 1));\n        var a = bind(this, function() {\n            ((this._inst && this._cavalry.setTimeStamp(((\"t_phase_begin_\" + b)))));\n            this.arbiter.inform(((\"phase_begin_\" + b)), true, Arbiter.BEHAVIOR_STATE);\n        });\n        if (((((this._currentPhase === this._lastPhase)) && this._isRelevant()))) {\n            this.arbiter.inform(\"pagelet_displayed_all\", true, Arbiter.BEHAVIOR_STATE);\n        }\n    ;\n    ;\n        this._currentPhase++;\n        if (ua.ie()) {\n            JSBNG__setTimeout(a, 20);\n        }\n         else a();\n    ;\n    ;\n    },\n    _isRelevant: function() {\n        return ((((((this == BigPipe._current_instance)) || this.jsNonBlock)) || this.forceFinish));\n    }\n});\nfunction namespace(e, f) {\n    var d = e.split(\".\"), a = 0, b = d.length, c = ((f || window));\n    for (; ((a < b)); a++) {\n        if (!c[d[a]]) {\n            c[d[a]] = {\n            };\n        }\n    ;\n    ;\n        c = c[d[a]];\n    };\n;\n    return c;\n};\n;\nfunction incorporate_fragment(a) {\n    var c = /^(?:(?:[^:\\/?#]+):)?(?:\\/\\/(?:[^\\/?#]*))?([^?#]*)(?:\\?([^#]*))?(?:#(.*))?/;\n    var b = \"\";\n    a.href.replace(c, function(d, g, h, f) {\n        var e, i;\n        e = i = ((g + ((h ? ((\"?\" + h)) : \"\"))));\n        if (f) {\n            f = f.replace(/^(!|%21)/, \"\");\n            if (((f.charAt(0) == \"/\"))) {\n                e = f.replace(/^\\/+/, \"/\");\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((e != i))) {\n            if (window._script_path) {\n                JSBNG__document.cookie = ((((((\"rdir=\" + window._script_path)) + \"; path=/; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n            }\n        ;\n        ;\n            window.JSBNG__location.replace(((b + e)));\n        }\n    ;\n    ;\n    });\n};\n;\nif (((window._script_path !== undefined))) {\n    incorporate_fragment(window.JSBNG__location);\n}\n;\n;\n!function() {\n    var b = JSBNG__document.documentElement;\n    var a = function(c) {\n        c = ((c || window.JSBNG__event));\n        var d = ((c.target || c.srcElement));\n        var f = d.getAttribute(\"placeholder\");\n        if (f) {\n            var e = Parent.byClass(d, \"focus_target\");\n            if (((((\"JSBNG__focus\" == c.type)) || ((\"focusin\" == c.type))))) {\n                if (((((d.value == f)) && CSS.hasClass(d, \"DOMControl_placeholder\")))) {\n                    d.value = \"\";\n                    CSS.removeClass(d, \"DOMControl_placeholder\");\n                }\n            ;\n            ;\n                if (e) {\n                    CSS.addClass(e, \"child_is_active\");\n                    CSS.addClass(e, \"child_is_focused\");\n                    CSS.addClass(e, \"child_was_focused\");\n                    Arbiter.inform(\"reflow\");\n                }\n            ;\n            ;\n            }\n             else {\n                if (((d.value == \"\"))) {\n                    CSS.addClass(d, \"DOMControl_placeholder\");\n                    d.value = f;\n                    ((e && CSS.removeClass(e, \"child_is_active\")));\n                    d.style.direction = \"\";\n                }\n            ;\n            ;\n                ((e && CSS.removeClass(e, \"child_is_focused\")));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n    if (b.JSBNG__addEventListener) {\n        b.JSBNG__addEventListener(\"JSBNG__focus\", a, true);\n        b.JSBNG__addEventListener(\"JSBNG__blur\", a, true);\n    }\n     else b.JSBNG__onfocusin = b.JSBNG__onfocusout = a;\n;\n;\n}();\nJSBNG__document.documentElement.JSBNG__onkeydown = function(a) {\n    a = ((a || window.JSBNG__event));\n    var b = ((a.target || a.srcElement));\n    var c = ((((((((((((a.keyCode == 13)) && !a.altKey)) && !a.ctrlKey)) && !a.metaKey)) && !a.shiftKey)) && CSS.hasClass(b, \"enter_submit\")));\n    if (c) {\n        Bootloader.loadComponents([\"dom\",\"input-methods\",], function() {\n            if (!Input.isEmpty(b)) {\n                var d = ((DOM.scry(b.form, \".enter_submit_target\")[0] || DOM.scry(b.form, \"[type=\\\"submit\\\"]\")[0]));\n                ((d && d.click()));\n            }\n        ;\n        ;\n        });\n        return false;\n    }\n;\n;\n};\nfunction fc_click(a, b) {\n    user_action(a, \"ufi\");\n    fc_expand(a, b);\n};\n;\nfunction fc_expand(a, b) {\n    var c = Parent.byTag(a, \"form\");\n    fc_uncollapse(c);\n    CSS.removeClass(c, \"hidden_add_comment\");\n    if (((b !== false))) {\n        ((c.add_comment_text_text || c.add_comment_text)).JSBNG__focus();\n    }\n;\n;\n    return false;\n};\n;\nfunction fc_uncollapse(a) {\n    CSS.removeClass(a, \"collapsed_comments\");\n};\n;");
// 994
geval("((window.Bootloader && Bootloader.done([\"LayX0\",])));");
// 1011
geval("!function(a) {\n    if (((a.clientWidth > 1225))) {\n        a.className = ((a.className + \" sidebarMode ticker\"));\n    }\n;\n;\n}(JSBNG__document.documentElement);\n!function() {\n    var a, b = ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.sfb70ab12eee911300ccf01d20dbb588c58164ec7_2), function() {\n        a = ((a || JSBNG__document.getElementById(\"blueBarHolder\")));\n        if (((a && ((\"getBoundingClientRect\" in a))))) {\n            var c = a.getBoundingClientRect(), d = ((Math.round(c.JSBNG__top) - JSBNG__document.documentElement.clientTop));\n            CSS.conditionClass(a.firstChild, \"fixed_elem\", ((d <= 0)));\n        }\n    ;\n    ;\n    }));\n    ((window.JSBNG__attachEvent ? window.JSBNG__attachEvent(\"JSBNG__onscroll\", b) : window.JSBNG__addEventListener(\"JSBNG__scroll\", b, false)));\n    JSBNG__setTimeout(b, 0);\n}();");
// 1021
geval("function eaf46093fd0ab488f93549b5a0da44db97d3487ec(JSBNG__event) {\n    return run_with(this, [\"min-notifications-jewel\",], function() {\n        MinNotifications.bootstrap(this);\n    });\n};\n;");
// 1022
geval("function ead5fe1a1c3ec88a155611806c1ce4cc29d6ad355(JSBNG__event) {\n    ((window.Toggler && Toggler.hide()));\n};\n;");
// 1023
geval("function e779ff92abeaf0f223c7d9d063064240745b178e0(JSBNG__event) {\n    return JSBNG__Event.__inlineSubmit(this, JSBNG__event);\n};\n;");
// 1024
geval("function e61535a1e22332516efd3c6c67501d598124b6d3f(JSBNG__event) {\n    var q = $(\"q\");\n    if (((q.value == q.getAttribute(\"placeholder\")))) {\n        q.JSBNG__focus();\n        return false;\n    }\n;\n;\n};\n;");
// 1025
geval("function eb664a14a7878fd7bf895bc54cb3f97d7b7a1f6ef(JSBNG__event) {\n    $(\"search_first_focus\").value = (($(\"search_first_focus\").value || +new JSBNG__Date()));\n    var f = function() {\n        JSCC.get(\"j4e93235b3821f75251281633\").init([\"searchRecorderBasic\",\"showLoadingIndicator\",]);\n    ;\n    };\n    if (window.loaded) {\n        f();\n    }\n     else {\n        Bootloader.loadComponents(\"SearchBootloader\", f);\n    }\n;\n;\n;\n};\n;");
// 1026
geval("function ec947bbe355ddada62de81e698844615f666818dc(JSBNG__event) {\n    var q = $(\"q\");\n    if (((q.value == q.getAttribute(\"placeholder\")))) {\n        q.JSBNG__focus();\n        return false;\n    }\n;\n;\n};\n;");
// 1027
geval("function e2ce2666b90dcabe21e058d6441eef2510f3e257e(JSBNG__event) {\n    return JSBNG__Event.__inlineSubmit(this, JSBNG__event);\n};\n;");
// 1028
geval("function si_cj(m) {\n    JSBNG__setTimeout(function() {\n        new JSBNG__Image().src = ((((\"http://error.facebook.com/common/scribe_endpoint.php?c=si_clickjacking&t=3041\" + \"&m=\")) + m));\n    }, 5000);\n};\n;\nif (((((JSBNG__top != JSBNG__self)) && !false))) {\n    try {\n        if (((parent != JSBNG__top))) {\n            throw 1;\n        }\n    ;\n    ;\n        var si_cj_d = [\"apps.facebook.com\",\"/pages/\",\"apps.beta.facebook.com\",];\n        var href = JSBNG__top.JSBNG__location.href.toLowerCase();\n        for (var i = 0; ((i < si_cj_d.length)); i++) {\n            if (((href.indexOf(si_cj_d[i]) >= 0))) {\n                throw 1;\n            }\n        ;\n        ;\n        };\n    ;\n        si_cj(\"3 http://www.facebook.com/\");\n    } catch (e) {\n        si_cj(\"1 \\u0009http://www.facebook.com/\");\n        window.JSBNG__document.write(\"\\u003Cstyle\\u003Ebody * {display:none !important;}\\u003C/style\\u003E\\u003Ca href=\\\"#\\\" onclick=\\\"top.location.href=window.location.href\\\" style=\\\"display:block !important;padding:10px\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_447725\\\" style=\\\"display:block !important\\\"\\u003E\\u003C/i\\u003EGo to Facebook.com\\u003C/a\\u003E\");\n    };\n;\n}\n;\n;");
// 1029
geval("Env = {\n    user: 100001812504199,\n    locale: \"en_US\",\n    method: \"GET\",\n    start: (new JSBNG__Date()).getTime(),\n    ps_limit: 5,\n    ps_ratio: 4,\n    svn_rev: 455543,\n    vip: \"69.171.229.16\",\n    static_base: \"http://static.ak.fbcdn.net/\",\n    www_base: \"http://www.facebook.com/\",\n    rep_lag: 2,\n    post_form_id: \"116b3858a89f8fb09d086e629ed60785\",\n    fb_dtsg: \"AQAcNPub\",\n    lhsh: \"oAQBsXUUV\",\n    tracking_domain: \"http://pixel.facebook.com\",\n    retry_ajax_on_network_error: \"1\",\n    ajaxpipe_enabled: \"1\",\n    theater_ver: \"2\",\n    quickling_inactive_page_regex: \"^\\\\/(election08\\\\/|username\\\\/|ads\\\\/manage\\\\/|login\\\\.php|comments\\\\.php|logout\\\\.php|sorry\\\\.php|help\\\\.php|help\\\\?page.*|giftshop\\\\.php|ac\\\\.php|ae\\\\.php|ajax\\\\/emu\\\\/h\\\\.php|ajax\\\\/emu\\\\/f\\\\.php|ajax\\\\/emu\\\\/end\\\\.php|ext\\\\/|ads\\\\/create\\\\/|feeds\\\\/|.+(\\\\?|&)fb95_opt_(in|out)|intern\\\\/(?!example\\\\/page_cache)|sitetour\\\\/homepage_tour\\\\.php|badges\\\\/|quikvote\\\\/|syndication\\\\.php|identity_switch\\\\.php|campaign\\\\/landing\\\\.php|advertising\\\\/|webmessenger\\\\/|editalbum\\\\.php.+add=1|help\\\\/)|\\\\.pdf$\"\n};");
// 1035
geval("Bootloader.setResourceMap({\n    \"6liCk\": {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yO/r/0lyilyZ95tg.css\"\n    },\n    \"/V4PE\": {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yi/r/ErOKEBv7otW.css\"\n    },\n    kZ9Q2: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yk/r/W3vdX4klem6.css\"\n    },\n    \"6x0ig\": {\n        type: \"css\",\n        permanent: 1,\n        nonblocking: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yR/r/ITJh_KJve0v.css\"\n    },\n    \"/YYg5\": {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yK/r/JhfYeMyShBl.css\"\n    },\n    \"vcCu/\": {\n        type: \"css\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yk/r/tFdTwQZN9MQ.css\"\n    },\n    kkZVg: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yB/r/QksHb2iSNUJ.css\"\n    },\n    \"8nJ8+\": {\n        type: \"css\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yp/r/eVW1rpSAjFz.css\"\n    },\n    \"8DGr1\": {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yR/r/7RAlT4Yrd6o.css\"\n    },\n    awtL8: {\n        type: \"css\",\n        permanent: 1,\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yx/r/frCJopL7Yib.css\"\n    },\n    oIqym: {\n        type: \"css\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yE/r/6RXYuP4Hs2R.css\"\n    }\n});\nBootloader.setResourceMap({\n    Vroh4: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yn/r/FWoR59ji0Yz.js\"\n    },\n    poN6f: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/y-/r/AkEj5nFsB5x.js\"\n    },\n    jnsdD: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yY/r/joEoUC0OTXg.js\"\n    },\n    TLs0W: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yq/r/wUW56fVVLQ9.js\"\n    },\n    JR0hL: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yJ/r/q0eC-Bc3MIN.js\"\n    },\n    FmWj5: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yv/r/76YruyuNQ7D.js\"\n    },\n    LayX0: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yj/r/-eXzfKGl5Cz.js\"\n    },\n    YxBS7: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yc/r/DzkM-7DYccQ.js\"\n    },\n    chq0B: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/y1/r/5nc8pbGby2_.js\"\n    },\n    LKDC5: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/y2/r/AY1YqeIwnEK.js\"\n    },\n    JHHyn: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yz/r/JNhgJHRSgRa.js\"\n    },\n    \"p41+w\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yA/r/y6MlK33C8q4.js\"\n    },\n    uKqhc: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yK/r/xrEeXUiCo9E.js\"\n    },\n    P5VoD: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/y1/r/rmlRUk7TA_9.js\"\n    },\n    \"5uO4k\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/y2/r/lfQbziGpy1i.js\"\n    },\n    HKq5g: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/y0/r/jR74VmNc_zY.js\"\n    },\n    JYRWp: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yV/r/EqRfWOm2pRJ.js\"\n    },\n    Un380: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yO/r/ppS16rCIkyq.js\"\n    },\n    iVV76: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yL/r/YPRNBqQhJ3f.js\"\n    },\n    \"48vAQ\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yf/r/RBozOemm3nO.js\"\n    },\n    \"+21JG\": {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yY/r/jXroJWKvNyB.js\"\n    },\n    WcJlt: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yt/r/PCPtsV3LZHc.js\"\n    },\n    TY5y5: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yN/r/Oj9mOqsWKpH.js\"\n    },\n    K7hbr: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yK/r/vsyqz9a5cvv.js\"\n    },\n    cO5Tc: {\n        type: \"js\",\n        src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yd/r/bhtRPYrj4qc.js\"\n    }\n});\nBootloader.enableBootload({\n    async: [\"LayX0\",\"Vroh4\",\"6liCk\",],\n    \"iframe-shim\": [\"LayX0\",\"Vroh4\",\"YxBS7\",],\n    \"maxlength-form-listener\": [\"LayX0\",\"Vroh4\",\"poN6f\",],\n    dialog: [\"LayX0\",\"Vroh4\",\"6liCk\",],\n    \"dom-form\": [\"LayX0\",\"Vroh4\",\"6liCk\",],\n    PhotoTheater: [\"LayX0\",\"Vroh4\",\"poN6f\",\"6liCk\",\"chq0B\",],\n    PhotoTagger: [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",],\n    TagToken: [\"LayX0\",\"Vroh4\",\"LKDC5\",],\n    TagTokenizer: [\"LayX0\",\"Vroh4\",\"LKDC5\",\"poN6f\",\"6liCk\",\"chq0B\",],\n    \"fb-photos-theater-css\": [\"/YYg5\",],\n    animation: [\"LayX0\",\"Vroh4\",],\n    hovercard: [\"6liCk\",\"LayX0\",\"Vroh4\",\"poN6f\",],\n    \"live-js\": [\"LayX0\",\"jnsdD\",\"Vroh4\",\"poN6f\",],\n    photocrop2: [\"LayX0\",\"Vroh4\",\"vcCu/\",\"JHHyn\",],\n    \"fb-photos-photo-css\": [\"kkZVg\",],\n    \"fb-photos-snowbox-css\": [\"kkZVg\",],\n    \"video-rotate-snowbox\": [\"LayX0\",\"Vroh4\",\"6liCk\",\"p41+w\",],\n    json: [\"Vroh4\",],\n    \"string-extensions\": [\"Vroh4\",],\n    \"dom-collect\": [\"Vroh4\",\"uKqhc\",],\n    PhotoSnowbox: [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",],\n    Toggler: [\"LayX0\",\"Vroh4\",\"poN6f\",\"6liCk\",],\n    \"dom-scroll\": [\"LayX0\",\"Vroh4\",\"poN6f\",],\n    ajaxpipe: [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",],\n    \"dimension-tracking\": [\"Vroh4\",\"LayX0\",],\n    \"detect-broken-proxy-cache\": [\"Vroh4\",\"LayX0\",],\n    Music: [\"LayX0\",\"Vroh4\",\"TLs0W\",\"6liCk\",\"P5VoD\",\"jnsdD\",],\n    MusicDownloadController: [\"LayX0\",\"Vroh4\",\"6liCk\",\"TLs0W\",\"5uO4k\",\"8nJ8+\",],\n    Panda: [\"LayX0\",\"Vroh4\",\"TLs0W\",\"6liCk\",\"P5VoD\",\"jnsdD\",\"poN6f\",\"HKq5g\",\"8DGr1\",\"JYRWp\",\"Un380\",],\n    beeper: [\"LayX0\",\"Vroh4\",\"6liCk\",\"awtL8\",\"poN6f\",\"HKq5g\",\"jnsdD\",\"TLs0W\",\"iVV76\",\"48vAQ\",\"+21JG\",],\n    VideoChatPlugin: [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",\"HKq5g\",\"jnsdD\",\"JYRWp\",],\n    \"desktop-notifications\": [\"WcJlt\",],\n    VideoChatPluginCore: [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",\"HKq5g\",\"jnsdD\",\"JYRWp\",\"oIqym\",\"TY5y5\",],\n    SearchBootloader: [\"6liCk\",\"Vroh4\",\"LayX0\",\"poN6f\",\"TLs0W\",\"/V4PE\",\"K7hbr\",],\n    \"live-timer\": [\"LayX0\",\"Vroh4\",],\n    \"min-notifications-jewel\": [\"Vroh4\",\"LayX0\",\"6liCk\",\"poN6f\",\"cO5Tc\",],\n    \"autoset-timezone\": [\"LayX0\",\"Vroh4\",\"6liCk\",\"JR0hL\",]\n});\nArbiter.registerCallback(InitialJSLoader.callback, [\"BOOTLOAD/ROADRUNNER_READY\",]);\nArbiter.registerCallback(function() {\n    InitialJSLoader.load([\"Vroh4\",\"poN6f\",\"jnsdD\",\"TLs0W\",\"JR0hL\",\"FmWj5\",]);\n    Arbiter.inform(\"BOOTLOAD/ROADRUNNER_READY\", true, Arbiter.BEHAVIOR_STATE);\n}, [OnloadEvent.ONLOAD_DOMCONTENT_CALLBACK,]);");
// 1050
geval("Bootloader.configurePage([\"6liCk\",\"/V4PE\",\"kZ9Q2\",\"6x0ig\",]);\nBootloader.done([\"dOSA6\",\"IwQl0\",\"nkHV7\",]);\nJSCC.init({\n    j4e93235b3821f75251281631: function() {\n        return new AsyncLayout();\n    },\n    j4e93235b3821f75251281632: function() {\n        return new SearchDataSource({\n            0: false,\n            extraTypes: [\"friendlist\",],\n            maxResults: 8,\n            queryData: {\n                viewer: 100001812504199,\n                rsp: \"search\",\n                context: \"search\"\n            },\n            queryEndpoint: \"/ajax/typeahead/search.php\",\n            bootstrapData: {\n                viewer: 100001812504199,\n                token: \"v7\"\n            },\n            bootstrapEndpoint: \"/ajax/typeahead/search/first_degree.php\",\n            token: \"1318265594-7\",\n            genTime: 1318265691\n        });\n    },\n    j4e93235b3821f75251281633: function() {\n        return new Typeahead(JSCC.get(\"j4e93235b3821f75251281632\"), {\n            node_id: \"\",\n            ctor: \"SearchTypeaheadView\",\n            options: {\n                autoSelect: true,\n                renderer: \"search\",\n                typeObjects: {\n                    app: {\n                        uid: \"app\",\n                        text: \"app\",\n                        type: \"header\",\n                        markup: \"Apps\"\n                    },\n                    JSBNG__event: {\n                        uid: \"JSBNG__event\",\n                        text: \"JSBNG__event\",\n                        type: \"header\",\n                        markup: \"Events\"\n                    },\n                    group: {\n                        uid: \"group\",\n                        text: \"group\",\n                        type: \"header\",\n                        markup: \"Groups\"\n                    },\n                    page: {\n                        uid: \"page\",\n                        text: \"page\",\n                        type: \"header\",\n                        markup: \"Pages\"\n                    },\n                    place: {\n                        uid: \"place\",\n                        text: \"place\",\n                        type: \"header\",\n                        markup: \"Places\"\n                    },\n                    question: {\n                        uid: \"question\",\n                        text: \"question\",\n                        type: \"header\",\n                        markup: \"Questions\"\n                    },\n                    share: {\n                        uid: \"share\",\n                        text: \"share\",\n                        type: \"header\",\n                        markup: \"Shared Links\"\n                    },\n                    shortcut: {\n                        uid: \"shortcut\",\n                        text: \"shortcut\",\n                        type: \"header\",\n                        markup: \"Facebook\"\n                    },\n                    user: {\n                        uid: \"user\",\n                        text: \"user\",\n                        type: \"header\",\n                        markup: \"People\"\n                    },\n                    web: {\n                        uid: \"web\",\n                        text: \"web\",\n                        type: \"header\",\n                        markup: \"Web\"\n                    },\n                    song: {\n                        uid: \"song\",\n                        text: \"song\",\n                        type: \"header\",\n                        markup: \"Music\"\n                    },\n                    friendlist: {\n                        uid: \"friendlist\",\n                        text: \"friendlist\",\n                        type: \"header\",\n                        markup: \"Lists\"\n                    }\n                }\n            }\n        }, {\n            ctor: \"SearchTypeaheadCore\",\n            options: {\n                keepFocused: false,\n                resetOnSelect: true\n            }\n        }, $(\"upctjk_1\"));\n    },\n    j4e93235b3821f75251281634: function() {\n        return new JewelX();\n    },\n    j4e93235b3821f75251281635: function() {\n        return new JewelX();\n    },\n    j4e93235b3821f75251281636: function() {\n        return new JewelX();\n    }\n});\nJSBNG__onloadRegister(function() {\n    Quickling.init(\"455543;0\", 10, {\n        prefetch_logging: false\n    });\n});\nJSBNG__onloadRegister(function() {\n    window.intl_locale_rewrites = {\n        meta: {\n            \"/_B/\": \"^(.*[.,!?\\\\s]|)\",\n            \"/_E/\": \"([.,!?\\\\s].*|)$\"\n        },\n        patterns: {\n            \"/\\u0001(.*)('|&#039;)s\\u0001(?:'|&#039;)s(.*)/\": \"\\u0001$1$2s\\u0001$3\",\n            \"/_\\u0001([^\\u0001]*)\\u0001/e\": \"mb_strtolower(\\\"\\u0001$1\\u0001\\\")\",\n            \"/_\\u0001([^\\u0001]*)\\u0001/\": \"javascript\"\n        }\n    };\n});\nJSBNG__onloadRegister(function() {\n    DocumentTitle.set(\"Facebook\");\n});\nJSBNG__onloadRegister(function() {\n    JSCC.get(\"j4e93235b3821f75251281631\").init($(\"contentArea\"), $(\"rightCol\"), null, $(\"toolbarContainer\"));\n});\nJSBNG__onloadRegister(function() {\n    JSCC.get(\"j4e93235b3821f75251281633\").getData().JSBNG__onLoad(false, true);\n});\nJSBNG__onloadRegister(function() {\n    new CounterDisplay(\"messages_unread\", $(\"jewelInnerInboxCount\"), $(\"jewelOuterInboxCount\"), \"fbMessagesItemList\", \"jewelUnread\", true);\n});\nJSBNG__onloadRegister(function() {\n    window.presenceRequests = new RequestsJewel().init(JSCC.get(\"j4e93235b3821f75251281634\"), \"[fb]requests\", false);\n});\nJSBNG__onloadRegister(function() {\n    JSCC.get(\"j4e93235b3821f75251281634\").init(\"requests\", $(\"fbRequestsJewel\"));\n});\nJSBNG__onloadRegister(function() {\n    new MessagesJewel().init(JSCC.get(\"j4e93235b3821f75251281635\"), \"[fb]messages\");\n});\nJSBNG__onloadRegister(function() {\n    new CounterDisplay(\"messages_unseen\", $(\"messagesCountValue\"), $(\"messagesCountWrapper\"), \"fbMessagesJewel\", \"hasNew\", true);\n});\nJSBNG__onloadRegister(function() {\n    JSCC.get(\"j4e93235b3821f75251281635\").init(\"messages\", $(\"fbMessagesJewel\"));\n});\nJSBNG__onloadRegister(function() {\n    MessagingJewelMenubarController.FETCH_URI = \"/ajax/messaging/jewel_fetch.php\";\n});\nJSBNG__onloadRegister(function() {\n    MessagingJewelMenubarController.MARK_SEEN_URI = \"/ajax/messaging/jewel_mark_seen.php\";\n});\nJSBNG__onloadRegister(function() {\n    MessagingJewelMenubarController.ensureInitialized(\"fbMessagesJewel\", \"fbMessagesItemList\", true, false);\n});\nJSBNG__onloadRegister(function() {\n    window.presenceNotifications = new OriginalNotifications({\n        updateTime: 1318265691000,\n        latestNotif: null,\n        latestReadNotif: null,\n        updatePeriod: 480000,\n        cacheVersion: 2,\n        allowDesktopNotifications: false,\n        notifReceivedType: \"notification\",\n        wrapperID: \"fbNotificationsJewel\",\n        contentID: \"fbNotificationsList\",\n        counterInFront: 1\n    });\n});\nJSBNG__onloadRegister(function() {\n    Arbiter.inform(\"jewel/count-initial\", {\n        jewel: \"notifications\",\n        count: 0\n    }, Arbiter.BEHAVIOR_STATE);\n});\nJSBNG__onloadRegister(function() {\n    JSCC.get(\"j4e93235b3821f75251281636\").init(\"notifications\", $(\"fbNotificationsJewel\"));\n});\nJSBNG__onafterloadRegister(function() {\n    Bootloader.loadComponents([\"dimension-tracking\",], function() {\n    \n    });\n});\nJSBNG__onafterloadRegister(function() {\n    Bootloader.loadComponents([\"detect-broken-proxy-cache\",], function() {\n        detect_broken_proxy_cache(\"100001812504199\", \"c_user\");\n    });\n});\nJSBNG__onafterloadRegister(function() {\n    new AsyncRequest(\"http://www.facebook.com/desktop/notifier/transfer.php\").send();\n});\nJSBNG__onafterloadRegister(function() {\n    Bootloader.loadComponents([\"autoset-timezone\",], function() {\n        tz_autoset(1318265691, -240);\n    });\n});");
// 1210
geval("var big_pipe = new BigPipe({\n    lid: 0,\n    rrEnabled: 1,\n    forceFinish: true,\n    delay: 0\n});");
// 1231
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 0,\n    id: \"first_response\",\n    is_last: true,\n    css: [\"6liCk\",\"/V4PE\",\"kZ9Q2\",\"6x0ig\",],\n    js: [\"LayX0\",\"Vroh4\",\"poN6f\",\"jnsdD\",\"TLs0W\",\"JR0hL\",\"FmWj5\",]\n});");
// 1327
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_welcome_box\",\n    css: [\"6liCk\",\"kZ9Q2\",],\n    js: [\"LayX0\",\"Vroh4\",],\n    JSBNG__content: {\n        pagelet_welcome_box: \"\\u003Cdiv class=\\\"UIImageBlock clearfix fbxWelcomeBox UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"fbxWelcomeBoxBlock UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/profile.php?id=100001812504199\\\" aria-hidden=\\\"true\\\" tabindex=\\\"-1\\\"\\u003E\\u003Cimg class=\\\"fbxWelcomeBoxImg  img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-ash2/275624_100001812504199_1255023530_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"prs UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Ca class=\\\"fbxWelcomeBoxName\\\" href=\\\"http://www.facebook.com/profile.php?id=100001812504199\\\"\\u003EJavaScript TestEngineer\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n    }\n});");
// 1375
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_navigation\",\n    css: [\"6liCk\",],\n    bootloadable: {\n        \"explicit-hover\": [\"LayX0\",\"Vroh4\",\"N0vYn\",],\n        \"sortable-side-nav-js\": [\"LayX0\",\"Vroh4\",\"TZhVy\",\"yhiyK\",]\n    },\n    resource_map: {\n        N0vYn: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yX/r/UlMasnKKWwh.js\"\n        },\n        TZhVy: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/ya/r/3qfihdXqWRe.js\"\n        },\n        yhiyK: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/y_/r/zPfEHc0s43R.js\"\n        }\n    },\n    js: [\"LayX0\",\"Vroh4\",\"jnsdD\",\"JR0hL\",\"poN6f\",],\n    jscc: \"JSCC.init({\\\"j4e93235b817f574300851381\\\":function(){return new FutureHomeSideNav();}});\",\n    provides: [\"pagelet_controller::home_side_future_nav\",],\n    JSBNG__onload: [\"HomeNavController.init();\",\"JSCC.get('j4e93235b817f574300851381').init($(\\\"sideNav\\\"), \\\"nf\\\", false);\",],\n    JSBNG__content: {\n        pagelet_navigation: \"\\u003Cdiv class=\\\"uiFutureSideNav\\\" data-gt=\\\"&#123;&quot;ref&quot;:&quot;bookmarks&quot;&#125;\\\" id=\\\"sideNav\\\"\\u003E\\u003Cdiv id=\\\"pagelet_pinned_nav\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv id=\\\"pagelet_bookmark_nav\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n    }\n});");
// 1418
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_welcome\",\n    css: [\"6liCk\",\"9JGdO\",\"mmKR1\",\"moyc4\",\"yiX8X\",\"7s28Z\",\"6x0ig\",],\n    bootloadable: {\n        \"contact-importer-ffagent-js\": [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",\"dmww2\",\"SsWus\",\"rmJtS\",]\n    },\n    resource_map: {\n        VlW5K: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yQ/r/b-YUPM3SvFl.js\"\n        },\n        ctRPa: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yQ/r/6UTRJDqbmaC.js\"\n        },\n        LX4bR: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yl/r/FcgVl7CxwEf.js\"\n        },\n        VVPTI: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yC/r/K1e4uscht3y.js\"\n        },\n        \"9JGdO\": {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yF/r/vYo3MwTDdfx.css\"\n        },\n        mmKR1: {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yJ/r/C_P8QEyLdMN.css\"\n        },\n        moyc4: {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yN/r/GSjfqMDNeYA.css\"\n        },\n        yiX8X: {\n            type: \"css\",\n            permanent: 1,\n            nonblocking: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yd/r/7Yxx1DalIKW.css\"\n        },\n        \"7s28Z\": {\n            type: \"css\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yS/r/mbalw-zzuwd.css\"\n        },\n        dmww2: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yl/r/cEz46GCKP2F.js\"\n        },\n        SsWus: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yK/r/43XWfmdiKqa.js\"\n        },\n        rmJtS: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yi/r/PmTpIghTe1P.js\"\n        }\n    },\n    js: [\"LayX0\",\"Vroh4\",\"JR0hL\",\"VlW5K\",\"ctRPa\",\"poN6f\",\"LX4bR\",\"VVPTI\",],\n    JSBNG__onload: [\"CIWebmailValidator.init({\\\"msft\\\":\\\"|hotmail.com~|live.com~|msn.com~|q.com~|\\\",\\\"yahoo\\\":\\\"|att.net~|bellsouth.net~|rocketmail.com~|sbcglobal.net~|yahoo.com~|yahoo.fr~|ymail.com~|\\\",\\\"gmail\\\":\\\"|\\\",\\\"yahoo_jp\\\":\\\"|\\\",\\\"other\\\":\\\"|aim.com~|aol.com~|comcast.net~|cox.net~|earthlink.net~|optonline.net~|rr.com~|verizon.net~|\\\",\\\"tokens\\\":[]})\",\"window.__UIControllerRegistry[\\\"c4e93235b90f2e3635431017\\\"] = new CIWebmailInputController({\\\"type\\\":1,\\\"flow\\\":10,\\\"domain_id\\\":\\\"\\\",\\\"full_endpoint\\\":\\\"https:\\\\/\\\\/www.facebook.com\\\\/find-friends\\\\/index.php\\\",\\\"ajax_endpoint\\\":\\\"https:\\\\/\\\\/www.facebook.com\\\\/contact_importer\\\\/ajax\\\\/importer.php\\\",\\\"log_endpoint\\\":\\\"http:\\\\/\\\\/www.facebook.com\\\\/contact_importer\\\\/ajax\\\\/log_actions.php\\\",\\\"api_endpoint\\\":\\\"http:\\\\/\\\\/www.facebook.com\\\\/contact_importer\\\\/api.php\\\",\\\"progress_endpoint\\\":\\\"http:\\\\/\\\\/www.facebook.com\\\\/contact_importer\\\\/ajax\\\\/get_progress.php\\\",\\\"tracked_params\\\":\\\"{\\\\\\\"referer\\\\\\\":\\\\\\\"11\\\\\\\",\\\\\\\"invite_app_id\\\\\\\":\\\\\\\"238754736842\\\\\\\"}\\\",\\\"ACTION_ADD_FRIENDS\\\":4,\\\"ACTION_SEND_INVITES\\\":5,\\\"ACTION_ONE_STEP_ADD_FRIEND\\\":9,\\\"should_log_tti\\\":true,\\\"use_applet\\\":false}, {\\\"form\\\":\\\"upctjk_2_ci_form\\\",\\\"login_input\\\":\\\"upctjk_2_ci_login\\\",\\\"contacts_container\\\":\\\"\\\",\\\"widget\\\":\\\"upctjk_2_ci_webmail\\\",\\\"password\\\":\\\"upctjk_2_ci_password\\\"}, false, false).setAPIData({\\\"22\\\":1,\\\"3\\\":1,\\\"2\\\":1,\\\"1\\\":1,\\\"25\\\":1}, {\\\"msft\\\":1,\\\"yahoo\\\":3,\\\"gmail\\\":2,\\\"yahoo_jp\\\":22,\\\"other\\\":19}).toggleProgressBar(true); ;\",\"new OnVisible($(\\\"show_more_pager\\\"), function () {FriendBrowserCheckboxController.showMore();}, false, 1000);\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.setSpecialLists({\\\"close\\\":196338550436560,\\\"acq\\\":\\\"100001812504199_124542800973931\\\"});\",\"FriendStatus.initFriend(\\\"1178217920\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_4\\\"), ge(\\\"upctjk_5\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"1178217920\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"719575350\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_7\\\"), ge(\\\"upctjk_8\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"719575350\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"1392755739\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_10\\\"), ge(\\\"upctjk_11\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"1392755739\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"739387874\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_13\\\"), ge(\\\"upctjk_14\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"739387874\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"641235113\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_16\\\"), ge(\\\"upctjk_17\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"641235113\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"1158187133\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_19\\\"), ge(\\\"upctjk_20\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"1158187133\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"1773530057\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_22\\\"), ge(\\\"upctjk_23\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"1773530057\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"100000869473834\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_25\\\"), ge(\\\"upctjk_26\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"100000869473834\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"1621485611\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_28\\\"), ge(\\\"upctjk_29\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"1621485611\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",\"FriendStatus.initFriend(\\\"100000091865467\\\", 4, []);\",\"FriendListFlyoutController.init();\",\"AddFriendButton.init(ge(\\\"upctjk_31\\\"), ge(\\\"upctjk_32\\\"), ge(\\\"\\\"), ge(\\\"\\\"), \\\"100000091865467\\\", \\\"\\\", \\\"friend_browser\\\", \\\"unknown\\\", \\\"\\\\/ajax\\\\/add_friend\\\\/action.php\\\", \\\"friend_browser\\\");\",],\n    JSBNG__content: {\n        pagelet_welcome: \"\\u003Cdiv class=\\\"uiHeader uiHeaderWithImage uiHeaderBottomBorder uiHeaderPage\\\"\\u003E\\u003Cdiv class=\\\"clearfix uiHeaderTop\\\"\\u003E\\u003Cdiv class=\\\"uiHeaderActions rfloat\\\"\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Ch2 class=\\\"uiHeaderTitle\\\"\\u003E\\u003Ci class=\\\"uiHeaderImage img sp_14557j sx_b0986a\\\"\\u003E\\u003C/i\\u003EWelcome to Facebook, JavaScript.\\u003C/h2\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cul id=\\\"welcome_dashboard\\\"\\u003E\\u003Cli class=\\\"clearfix step\\\"\\u003E\\u003Ch3 class=\\\"step_indicator active_step\\\"\\u003E1\\u003C/h3\\u003E\\u003Cdiv class=\\\"welcome_task welcomeTaskImporter\\\"\\u003E\\u003Ch3\\u003ESearch your email for friends already on Facebook.\\u003C/h3\\u003E\\u003Cdiv class=\\\"importer_form\\\"\\u003E\\u003Cdiv class=\\\"contact_importer_widget ci_webmail\\\"\\u003E\\u003Cdiv id=\\\"upctjk_2_ci_webmail\\\" class=\\\"api\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cform class=\\\"ci_form\\\" action=\\\"https://www.facebook.com/find-friends/index.php\\\" method=\\\"post\\\" name=\\\"upctjk_2_ci_form\\\" id=\\\"upctjk_2_ci_form\\\" onsubmit=\\\"return function(event)&#123;return wait_for_load(this, event, function() &#123;__UIControllerRegistry[&quot;c4e93235b90f2e3635431017&quot;].onSubmit(); return false;&#125;);&#125;.call(this,event)!==false &amp;&amp; Event.__inlineSubmit(this,event)\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"post_form_id\\\" value=\\\"116b3858a89f8fb09d086e629ed60785\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" name=\\\"fb_dtsg\\\" value=\\\"AQAcNPub\\\" autocomplete=\\\"off\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"importer_action\\\" value=\\\"2\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"flow\\\" value=\\\"10\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"type\\\" value=\\\"1\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"callback_element_id\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"tracked_params\\\" value=\\\"&#123;&quot;referer&quot;:&quot;11&quot;,&quot;invite_app_id&quot;:&quot;238754736842&quot;&#125;\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"jsonp\\\" value=\\\"1\\\" /\\u003E\\u003Ctable class=\\\"uiInfoTable noBorder\\\"\\u003E\\u003Ctr class=\\\"dataRow\\\"\\u003E\\u003Cth class=\\\"label\\\"\\u003E\\u003Clabel for=\\\"upctjk_2_ci_login\\\"\\u003EYour Email:\\u003C/label\\u003E\\u003C/th\\u003E\\u003Ctd class=\\\"data\\\"\\u003E\\u003Cinput type=\\\"text\\\" class=\\\"inputtext ci_login\\\" value=\\\"akaquinn&#64;hotmail.com\\\" name=\\\"login_str\\\" id=\\\"upctjk_2_ci_login\\\" autocomplete=\\\"off\\\" /\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr class=\\\"ci_password_row hidden_elem dataRow\\\"\\u003E\\u003Cth class=\\\"label\\\"\\u003E\\u003Clabel for=\\\"upctjk_2_ci_password\\\"\\u003EEmail Password:\\u003C/label\\u003E\\u003C/th\\u003E\\u003Ctd class=\\\"data\\\"\\u003E\\u003Cinput type=\\\"password\\\" class=\\\"inputtext ci_password\\\" value=\\\"\\\" name=\\\"password\\\" id=\\\"upctjk_2_ci_password\\\" autocomplete=\\\"off\\\" /\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Cth class=\\\"label\\\"\\u003E\\u003C/th\\u003E\\u003Ctd class=\\\"data\\\"\\u003E\\u003Cdiv\\u003E\\u003Clabel class=\\\"yahoo_submit\\\"\\u003E\\u003Cimg src=\\\"/images/contact_importer/login_button/yahoo.png\\\" /\\u003E\\u003Cinput type=\\\"submit\\\" value=\\\"Sign In through Yahoo!\\\" /\\u003E\\u003C/label\\u003E\\u003Clabel class=\\\"uiButton uiButtonConfirm\\\" for=\\\"upctjk_3\\\"\\u003E\\u003Cinput value=\\\"Find Friends\\\" onclick=\\\"\\\" type=\\\"submit\\\" id=\\\"upctjk_3\\\" /\\u003E\\u003C/label\\u003E\\u003Cimg class=\\\"mts mls uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Cth class=\\\"label\\\"\\u003E\\u003C/th\\u003E\\u003Ctd class=\\\"data\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix disclaimer\\\"\\u003E\\u003Ci class=\\\"UIImageBlock_Image UIImageBlock_ICON_Image img sp_14557j sx_b394b5\\\"\\u003E\\u003Cu\\u003Eprivacy_lock\\u003C/u\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"UIImageBlock_Content UIImageBlock_ICON_Content fcg\\\"\\u003EFacebook won't store your password.\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003Ctr\\u003E\\u003Cth class=\\\"label\\\"\\u003E\\u003C/th\\u003E\\u003Ctd class=\\\"data\\\"\\u003E\\u003Cdiv class=\\\"unsupported_email\\\"\\u003E\\u003Cspan class=\\\"fwb\\\"\\u003EWe can&#039;t import contacts from this address yet.\\u003C/span\\u003E\\u003Cdiv class=\\\"mvs\\\"\\u003EYou may try one of our \\u003Ca href=\\\"/contact_importer/ajax/supported_domains.php\\\" rel=\\\"dialog\\\"\\u003Esupported email addresses\\u003C/a\\u003E. Also, if you can upload a CSV file or use Outlook, try using our \\u003Ca href=\\\"/find-friends/?expand=upload\\\"\\u003EFile Importer\\u003C/a\\u003E.\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/table\\u003E\\u003C/form\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ciframe src=\\\"http://www.facebook.com/contact_importer/api.php?type=1&amp;flow=10&amp;domain_id&amp;tracked_params%5Breferer%5D=11&amp;tracked_params%5Binvite_app_id%5D=238754736842&amp;api_instance=1&amp;login_str=akaquinn%40hotmail.com&amp;implicit_conf=1\\\" style=\\\"position: absolute; top:-10000px; left: -10000px;\\\"\\u003E\\u003C/iframe\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"clearfix step last\\\"\\u003E\\u003Ch3 class=\\\"step_indicator\\\"\\u003E2\\u003C/h3\\u003E\\u003Cdiv class=\\\"welcome_task\\\"\\u003E\\u003Ch3\\u003E\\u003Ca href=\\\"find-friends/browser/?ref=wd\\\"\\u003EAdd people you know\\u003C/a\\u003E\\u003C/h3\\u003E\\u003Cdiv class=\\\"welcome_description\\\"\\u003E\\u003Cform rel=\\\"async\\\" id=\\\"friend_browser_form\\\" action=\\\"/ajax/growth/friend_browser/checkbox.php\\\" method=\\\"post\\\" onsubmit=\\\"return Event.__inlineSubmit(this,event)\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"post_form_id\\\" value=\\\"116b3858a89f8fb09d086e629ed60785\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" name=\\\"fb_dtsg\\\" value=\\\"AQAcNPub\\\" autocomplete=\\\"off\\\" /\\u003E\\u003Cdiv\\u003E\\u003Cimg class=\\\"hidden_elem img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/y9/r/jKEcVPZFk-2.gif\\\" alt=\\\"\\\" id=\\\"friendBrowsingCheckboxContentLoadingIndicator\\\" width=\\\"32\\\" height=\\\"32\\\" /\\u003E\\u003Cdiv id=\\\"friendBrowserCheckboxResultsId\\\"\\u003E\\u003Cdiv id=\\\"friendBrowserCheckboxContentGrid\\\"\\u003E\\u003Cul class=\\\"uiList\\\"\\u003E\\u003Cli class=\\\"pbs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/broetje?ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/41477_1178217920_5817_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_1178217920\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"1178217920\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_1178217920\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_4\\\" for=\\\"upctjk_6\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_6\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"1178217920\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_5\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/broetje?ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;1178217920&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=1178217920\\\"\\u003EMichael Broetje\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003Ca class=\\\"uiLinkSubtle\\\" rel=\\\"dialog\\\" ajaxify=\\\"/ajax/browser/dialog/mutual_friends/?uid=1178217920\\\" href=\\\"/browse/mutual_friends/?uid=1178217920\\\"\\u003E1 mutual friend\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/jvitekjr?ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/195359_719575350_7681538_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_719575350\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"719575350\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_719575350\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_7\\\" for=\\\"upctjk_9\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_9\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"719575350\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_8\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/jvitekjr?ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;719575350&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=719575350\\\"\\u003EJan Vitek\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003Ca class=\\\"uiLinkSubtle\\\" rel=\\\"dialog\\\" ajaxify=\\\"/ajax/browser/dialog/mutual_friends/?uid=719575350\\\" href=\\\"/browse/mutual_friends/?uid=719575350\\\"\\u003E1 mutual friend\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/james.bertelson?ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/261068_1392755739_1628860611_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_1392755739\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"1392755739\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_1392755739\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_10\\\" for=\\\"upctjk_12\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_12\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"1392755739\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_11\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/james.bertelson?ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;1392755739&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=1392755739\\\"\\u003EJames Bertelson\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/sanchezs.sergio?ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/41374_739387874_1481_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_739387874\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"739387874\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_739387874\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_13\\\" for=\\\"upctjk_15\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_15\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"739387874\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_14\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/sanchezs.sergio?ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;739387874&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=739387874\\\"\\u003ESergio Sanchez\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/profile.php?id=641235113&amp;ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/273562_641235113_1313798731_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_641235113\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"641235113\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_641235113\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_16\\\" for=\\\"upctjk_18\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_18\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"641235113\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_17\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/profile.php?id=641235113&amp;ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;641235113&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=641235113\\\"\\u003EDagny Martinez\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/profile.php?id=1158187133&amp;ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/41396_1158187133_1241_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_1158187133\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"1158187133\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_1158187133\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_19\\\" for=\\\"upctjk_21\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_21\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"1158187133\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_20\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/profile.php?id=1158187133&amp;ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;1158187133&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=1158187133\\\"\\u003EWesley Card\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/profile.php?id=1773530057&amp;ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/41464_1773530057_5069_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_1773530057\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"1773530057\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_1773530057\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_22\\\" for=\\\"upctjk_24\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_24\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"1773530057\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_23\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/profile.php?id=1773530057&amp;ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;1773530057&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=1773530057\\\"\\u003ESteve Streicher\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/profile.php?id=100000869473834&amp;ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/273563_100000869473834_616856843_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_100000869473834\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"100000869473834\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_100000869473834\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_25\\\" for=\\\"upctjk_27\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_27\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"100000869473834\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_26\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/profile.php?id=100000869473834&amp;ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;100000869473834&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=100000869473834\\\"\\u003EWarren Nelson\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/robert.leist?ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/41376_1621485611_1625_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_1621485611\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"1621485611\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_1621485611\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_28\\\" for=\\\"upctjk_30\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_30\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"1621485611\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_29\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/robert.leist?ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;1621485611&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=1621485611\\\"\\u003ERobert Leist\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pvs friendBrowserListUnit uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix friendBrowserExtraSpacing UIImageBlock_Entity\\\"\\u003E\\u003Ca class=\\\"UIImageBlock_Image UIImageBlock_ENT_Image\\\" href=\\\"http://www.facebook.com/profile.php?id=100000091865467&amp;ref=pymk\\\" tabindex=\\\"-1\\\" aria-hidden=\\\"true\\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://profile.ak.fbcdn.net/hprofile-ak-snc4/49695_100000091865467_6382_q.jpg\\\" alt=\\\"\\\" /\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"UIImageBlock_Ext\\\"\\u003E\\u003Cdiv class=\\\"friendBrowserUnit \\\" id=\\\"friend_browser_unit_100000091865467\\\"\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"friendBrowserID\\\" name=\\\"friend_browser_id[]\\\" value=\\\"100000091865467\\\" /\\u003E\\u003Cdiv class=\\\"friendBrowserAddAsFriend stat_elem\\\" id=\\\"friendBrowserActionId_100000091865467\\\"\\u003E\\u003Cdiv class=\\\"FriendButton\\\"\\u003E\\u003Clabel class=\\\"FriendRequestAdd uiButton\\\" id=\\\"upctjk_31\\\" for=\\\"upctjk_33\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"Add Friend\\\" type=\\\"button\\\" id=\\\"upctjk_33\\\" /\\u003E\\u003C/label\\u003E\\u003Ca class=\\\"FriendRequestOutgoing enableFriendListFlyout hidden_elem uiButton\\\" role=\\\"button\\\" href=\\\"#\\\" data-profileid=\\\"100000091865467\\\" data-flloc=\\\"friend_browser\\\" id=\\\"upctjk_32\\\"\\u003E\\u003Ci class=\\\"mrs img sp_eqteur sx_a2d1ce\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiButtonText\\\"\\u003EFriend Request Sent\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock_Content UIImageBlock_ENT_Content\\\"\\u003E\\u003Cdiv class=\\\"fsl fwb fcb\\\"\\u003E\\u003Ca href=\\\"http://www.facebook.com/profile.php?id=100000091865467&amp;ref=pymk\\\" data-gt=\\\"&#123;&quot;engagement&quot;:&#123;&quot;eng_type&quot;:&quot;1&quot;,&quot;eng_src&quot;:&quot;1&quot;,&quot;eng_tid&quot;:&quot;100000091865467&quot;,&quot;eng_data&quot;:[]&#125;&#125;\\\" data-hovercard=\\\"/ajax/hovercard/hovercard.php?id=100000091865467\\\"\\u003EMatthew Lusky\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fsm fwn fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"pts uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003Cdiv id=\\\"friendBrowserCheckboxContentPager\\\"\\u003E\\u003Cdiv class=\\\"clearfix uiMorePager stat_elem uiMorePagerCenter\\\" id=\\\"show_more_pager\\\"\\u003E\\u003Cdiv\\u003E\\u003Ca class=\\\"pam uiBoxLightblue  uiMorePagerPrimary\\\" href=\\\"#\\\" onclick=\\\"FriendBrowserCheckboxController.showMore();\\\"\\u003EShow more\\u003C/a\\u003E\\u003Cspan class=\\\"uiMorePagerLoader pam uiBoxLightblue \\\"\\u003E\\u003Cimg class=\\\"img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" id=\\\"extra_data\\\" name=\\\"extra_data\\\" value=\\\"AQJF9tjZFDdpPRq_zq5nP-8Jhiriq0lP_uzSRdJOdYY-mWVEUyUlPpDYdLR0Hy5_s4M\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"results_elem_id\\\" value=\\\"friendBrowserCheckboxResultsId\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"page\\\" value=\\\"friend_browser\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"num_columns\\\" value=\\\"1\\\" /\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" name=\\\"render_list\\\" value=\\\"1\\\" /\\u003E\\u003C/form\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\"\n    }\n});");
// 1458
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 1,\n    id: \"pagelet_pinned_nav_lite\",\n    append: \"pagelet_pinned_nav\",\n    display_dependency: [\"pagelet_navigation\",],\n    is_last: true,\n    css: [\"6liCk\",\"kZ9Q2\",\"yiX8X\",\"6x0ig\",],\n    JSBNG__content: {\n        pagelet_pinned_nav_lite: \"\\u003Cdiv class=\\\"homeSideNav\\\" id=\\\"pinnedNav\\\"\\u003E\\u003Cdiv class=\\\"navHeader\\\"\\u003EFAVORITES\\u003C/div\\u003E\\u003Cdiv class=\\\"mts mbm droppableNav uiSideNavSection uiFutureSideNavSection\\\"\\u003E\\u003Cul class=\\\"uiSideNav\\\" role=\\\"navigation\\\" data-gt=\\\"&#123;&quot;nav_items_count&quot;:&quot;5&quot;,&quot;nav_section&quot;:&quot;pinnedNav&quot;&#125;\\\"\\u003E\\u003Cli class=\\\"sideNavItem stat_elem selectedItem open\\\" id=\\\"navItem_app_156203961126022\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix\\\" href=\\\"/?sk=welcome\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;156203961126022&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_14557j sx_b0986a\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EWelcome\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_4748854339\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix\\\" href=\\\"/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;4748854339&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_cgcm2h sx_b81b69\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003ENews Feed\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_217974574879787\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/messages/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;217974574879787&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;3&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_cgcm2h sx_6594cb\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EMessages\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_2344061033\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/events/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;2344061033&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;4&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_28f733\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EEvents\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_2356318349\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/?sk=fr\\\" title=\\\"Find Friends\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;2356318349&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;5&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_eqteur sx_c1cafe\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EFind Friends\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003Cdiv class=\\\"actionLinks stat_elem\\\"\\u003E\\u003Ca class=\\\"navEditDone\\\" href=\\\"#\\\" data-endpoint=\\\"/ajax/bookmark/edit/\\\"\\u003E\\u003Cspan class=\\\"navEdit\\\"\\u003EEdit\\u003C/span\\u003E\\u003Cspan class=\\\"navDone\\\"\\u003EDone\\u003C/span\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"loadingIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n    },\n    tti_phase: 1\n});");
// 1504
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 2,\n    id: \"pagelet_pinned_nav\",\n    css: [\"6liCk\",\"kZ9Q2\",\"yiX8X\",\"6x0ig\",],\n    resource_map: {\n        \"/yQAb\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yn/r/jLGM_hK_GG8.js\"\n        }\n    },\n    js: [\"LayX0\",\"Vroh4\",\"TLs0W\",\"/yQAb\",\"poN6f\",\"jnsdD\",\"JR0hL\",],\n    requires: [\"pagelet_controller::home_side_future_nav\",],\n    JSBNG__onload: [\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"pinnedNav\\\",\\\"editEndpoint\\\":\\\"\\\\/ajax\\\\/bookmark\\\\/edit\\\\/\\\"}, [{\\\"id\\\":\\\"navItem_app_156203961126022\\\",\\\"key\\\":[\\\"app_156203961126022\\\",\\\"welcome\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":true,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_4748854339\\\",\\\"key\\\":[\\\"app_4748854339\\\",\\\"nf\\\",\\\"h\\\",\\\"lf\\\",\\\"h\\\",\\\"lf\\\",\\\"app_2915120374\\\",\\\"pp\\\",\\\"app_10150110253435258\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_217974574879787\\\",\\\"key\\\":[\\\"app_217974574879787\\\",\\\"inbox\\\"],\\\"path\\\":[\\\"\\\\/messages\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_other\\\",\\\"key\\\":[\\\"other\\\"],\\\"path\\\":[\\\"\\\\/messages\\\\/other\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2344061033\\\",\\\"key\\\":[\\\"app_2344061033\\\",\\\"events\\\",\\\"bd\\\",\\\"pe\\\",{\\\"regex\\\":\\\"event_(.*)\\\"}],\\\"path\\\":[\\\"\\\\/events\\\\/\\\",\\\"\\\\/events\\\\/\\\",{\\\"regex\\\":\\\"\\\\\\\\\\\\/events\\\\\\\\\\\\/!(friends|create)\\\\\\\\\\\\/\\\"}],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_fe\\\",\\\"key\\\":[\\\"fe\\\"],\\\"path\\\":[\\\"\\\\/events\\\\/friends\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_2356318349\\\",\\\"key\\\":[\\\"app_2356318349\\\",\\\"ff\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",],\n    JSBNG__onafterload: [\"startMessagingNavCountUpdater(\\\"100\\\");\",],\n    JSBNG__content: {\n        pagelet_pinned_nav: \"\\u003Cdiv class=\\\"homeSideNav\\\" id=\\\"pinnedNav\\\"\\u003E\\u003Cdiv class=\\\"navHeader\\\"\\u003EFAVORITES\\u003C/div\\u003E\\u003Cdiv class=\\\"mts mbm droppableNav uiSideNavSection uiFutureSideNavSection\\\"\\u003E\\u003Cul class=\\\"uiSideNav\\\" role=\\\"navigation\\\" data-gt=\\\"&#123;&quot;nav_items_count&quot;:&quot;5&quot;,&quot;nav_section&quot;:&quot;pinnedNav&quot;&#125;\\\"\\u003E\\u003Cli class=\\\"sideNavItem stat_elem selectedItem open\\\" id=\\\"navItem_app_156203961126022\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix\\\" href=\\\"/?sk=welcome\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;156203961126022&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_14557j sx_b0986a\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EWelcome\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_4748854339\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Edit\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"/ajax/feed/edit_options_dialog.php\\\" rel=\\\"dialog\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EEdit\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix\\\" href=\\\"/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;4748854339&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_cgcm2h sx_b81b69\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003ENews Feed\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_217974574879787\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Remove from Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERemove from Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/messages/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;217974574879787&quot;,&quot;count&quot;:&quot;&quot;,&quot;rank&quot;:&quot;3&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_cgcm2h sx_6594cb\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EMessages\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cul\\u003E\\u003Cli id=\\\"navItem_other\\\"\\u003E\\u003Ca class=\\\"subitem clearfix\\\" href=\\\"/messages/other/\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"linkChild\\\"\\u003EOther\\u003C/span\\u003E&nbsp;\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_2344061033\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Remove from Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERemove from Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/events/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;2344061033&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;4&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_28f733\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EEvents\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cul\\u003E\\u003Cli id=\\\"navItem_fe\\\"\\u003E\\u003Ca class=\\\"subitem clearfix\\\" href=\\\"/events/friends/\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"linkChild\\\"\\u003EFriends&#039; Events\\u003C/span\\u003E&nbsp;\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_2356318349\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Remove from Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERemove from Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/?sk=ff\\\" title=\\\"Find Friends\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;2356318349&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;5&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_eqteur sx_c1cafe\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EFind Friends\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003Cdiv class=\\\"actionLinks stat_elem\\\"\\u003E\\u003Ca class=\\\"navEditDone\\\" href=\\\"#\\\" data-endpoint=\\\"/ajax/bookmark/edit/\\\"\\u003E\\u003Cspan class=\\\"navEdit\\\"\\u003EEdit\\u003C/span\\u003E\\u003Cspan class=\\\"navDone\\\"\\u003EDone\\u003C/span\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"loadingIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n    }\n});");
// 1552
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 2,\n    id: \"pagelet_bookmark_nav\",\n    is_last: true,\n    css: [\"6liCk\",\"kZ9Q2\",\"6x0ig\",],\n    js: [\"LayX0\",\"Vroh4\",\"poN6f\",\"jnsdD\",\"JR0hL\",],\n    requires: [\"pagelet_controller::home_side_future_nav\",],\n    JSBNG__onload: [\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"appsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_app_2305272732\\\",\\\"key\\\":[\\\"app_2305272732\\\",\\\"app_2305272732_2392950137\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_119960514742544\\\",\\\"key\\\":[\\\"app_119960514742544\\\",\\\"music\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_2347471856\\\",\\\"key\\\":[\\\"app_2347471856\\\",\\\"notes\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[{\\\"id\\\":\\\"navItem_notes_pages\\\",\\\"key\\\":[\\\"notes_pages\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/pages\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_drafts\\\",\\\"key\\\":[\\\"notes_drafts\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/drafts\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_tagged\\\",\\\"key\\\":[\\\"notes_tagged\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/tagged\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_notes_me\\\",\\\"key\\\":[\\\"notes_me\\\"],\\\"path\\\":[\\\"\\\\/notes\\\\/me\\\\/\\\"],\\\"type\\\":null,\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]},{\\\"id\\\":\\\"navItem_app_10150110253435258\\\",\\\"key\\\":[\\\"app_10150110253435258\\\",\\\"questions\\\",\\\"question\\\"],\\\"path\\\":[\\\"\\\\/questions\\\\/friends\\\\/\\\",{\\\"regex\\\":\\\"\\\\\\\\\\\\/questions\\\\\\\\\\\\/(\\\\\\\\w+)\\\\\\\\\\\\/\\\"}],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_app_2309869772\\\",\\\"key\\\":[\\\"app_2309869772\\\"],\\\"path\\\":[\\\"\\\\/\\\"],\\\"type\\\":\\\"apps\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"groupsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_app_230259100322928\\\",\\\"key\\\":[\\\"app_230259100322928\\\",\\\"create_group\\\"],\\\"path\\\":[\\\"\\\\/ajax\\\\/groups\\\\/create_get.php\\\"],\\\"type\\\":\\\"groups\\\",\\\"endpoint\\\":null,\\\"selected\\\":false,\\\"children\\\":[]}]);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"pagesNav\\\",\\\"editEndpoint\\\":null}, []);\",\"FutureSideNav.getInstance().initSection({\\\"id\\\":\\\"listsNav\\\",\\\"editEndpoint\\\":null}, [{\\\"id\\\":\\\"navItem_fl_196338550436560\\\",\\\"key\\\":[\\\"fl_196338550436560\\\"],\\\"path\\\":[\\\"\\\\/home.php\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]},{\\\"id\\\":\\\"navItem_fl_196338560436559\\\",\\\"key\\\":[\\\"fl_196338560436559\\\"],\\\"path\\\":[\\\"\\\\/home.php\\\"],\\\"type\\\":\\\"lists\\\",\\\"endpoint\\\":\\\"\\\\/ajax\\\\/home\\\\/generic.php\\\",\\\"selected\\\":false,\\\"children\\\":[]}]);\",],\n    JSBNG__content: {\n        pagelet_bookmark_nav: \"\\u003Cdiv\\u003E\\u003Cdiv class=\\\"homeSideNav\\\" id=\\\"listsNav\\\"\\u003E\\u003Cdiv class=\\\"navHeader\\\"\\u003E\\u003Ca href=\\\"/bookmarks/lists\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\"\\u003ELISTS\\u003C/div\\u003E\\u003Cspan class=\\\"mrm rfloat\\\"\\u003E\\u003Cdiv class=\\\"bookmarksNavSeeAll\\\"\\u003EMORE\\u003C/div\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cul class=\\\"uiSideNav mts mbm nonDroppableNav uiSideNavSection uiFutureSideNavSection\\\" role=\\\"navigation\\\" data-gt=\\\"&#123;&quot;nav_items_count&quot;:&quot;2&quot;,&quot;nav_section&quot;:&quot;listsNav&quot;&#125;\\\"\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_fl_196338550436560\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator hideSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem hideOption\\\" data-label=\\\"Hide\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" ajaxify=\\\"/ajax/bookmark/hide/?id=fl_196338550436560\\\" rel=\\\"async-post\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EHide\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/home.php?sk=fl_196338550436560\\\" title=\\\"Close Friends\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;196338550436560&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_7kwant sx_dfa161\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EClose Friends\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_fl_196338560436559\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator hideSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem hideOption\\\" data-label=\\\"Hide\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" ajaxify=\\\"/ajax/bookmark/hide/?id=fl_196338560436559\\\" rel=\\\"async-post\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EHide\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/home.php?sk=fl_196338560436559\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;196338560436559&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_7kwant sx_227950\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EFamily\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cdiv id=\\\"listsSeeAllLink\\\"\\u003E\\u003Ca ajaxify=\\\"/ajax/bookmark/seeall/nux\\\" rel=\\\"async-post\\\"\\u003ESee all lists...\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"homeSideNav\\\" id=\\\"pagesNav\\\"\\u003E\\u003Cdiv class=\\\"navHeader hidden_elem\\\"\\u003EPAGES\\u003C/div\\u003E\\u003Cul class=\\\"uiSideNav mts mbm nonDroppableNav uiSideNavSection uiFutureSideNavSection\\\" role=\\\"navigation\\\" data-gt=\\\"&#123;&quot;nav_items_count&quot;:&quot;0&quot;,&quot;nav_section&quot;:&quot;pagesNav&quot;&#125;\\\"\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"homeSideNav\\\" id=\\\"groupsNav\\\"\\u003E\\u003Cdiv class=\\\"navHeader\\\"\\u003EGROUPS\\u003C/div\\u003E\\u003Cul class=\\\"uiSideNav mts mbm nonDroppableNav uiSideNavSection uiFutureSideNavSection\\\" role=\\\"navigation\\\" data-gt=\\\"&#123;&quot;nav_items_count&quot;:&quot;1&quot;,&quot;nav_section&quot;:&quot;groupsNav&quot;&#125;\\\"\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_230259100322928\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/ajax/groups/create_get.php?ref=bookmarks\\\" title=\\\"Create Group...\\\" rel=\\\"dialog\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;230259100322928&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_cgcm2h sx_e03381\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003ECreate Group...\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"homeSideNav\\\" id=\\\"appsNav\\\"\\u003E\\u003Cdiv class=\\\"navHeader\\\"\\u003E\\u003Ca href=\\\"/bookmarks/apps\\\"\\u003E\\u003Cdiv class=\\\"clearfix\\\"\\u003E\\u003Cdiv class=\\\"lfloat\\\"\\u003EAPPS\\u003C/div\\u003E\\u003Cspan class=\\\"mrm rfloat\\\"\\u003E\\u003Cdiv class=\\\"bookmarksNavSeeAll\\\"\\u003EMORE\\u003C/div\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cul class=\\\"uiSideNav mts mbm nonDroppableNav uiSideNavSection uiFutureSideNavSection\\\" role=\\\"navigation\\\" data-gt=\\\"&#123;&quot;nav_items_count&quot;:&quot;5&quot;,&quot;nav_section&quot;:&quot;appsNav&quot;&#125;\\\"\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_2305272732\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/?sk=app_2305272732_2392950137\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;2305272732&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;1&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_50329a\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EPhotos\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_119960514742544\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/?sk=music\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;119960514742544&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;2&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_a59a42\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EMusic\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_2347471856\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/notes/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;2347471856&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;3&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_1c4089\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003ENotes\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cul\\u003E\\u003Cli id=\\\"navItem_notes_pages\\\"\\u003E\\u003Ca class=\\\"subitem clearfix\\\" href=\\\"/notes/pages/\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"linkChild\\\"\\u003EPages&#039; Notes\\u003C/span\\u003E&nbsp;\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli id=\\\"navItem_notes_drafts\\\"\\u003E\\u003Ca class=\\\"subitem clearfix\\\" href=\\\"/notes/drafts/\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"linkChild\\\"\\u003EMy Drafts\\u003C/span\\u003E&nbsp;\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli id=\\\"navItem_notes_tagged\\\"\\u003E\\u003Ca class=\\\"subitem clearfix\\\" href=\\\"/notes/tagged/\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"linkChild\\\"\\u003ENotes About Me\\u003C/span\\u003E&nbsp;\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli id=\\\"navItem_notes_me\\\"\\u003E\\u003Ca class=\\\"subitem clearfix\\\" href=\\\"/notes/me/\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"linkChild\\\"\\u003EMy Notes\\u003C/span\\u003E&nbsp;\\u003C/div\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_10150110253435258\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/questions/friends/\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;10150110253435258&quot;,&quot;count&quot;:&quot;0&quot;,&quot;rank&quot;:&quot;4&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_7kwant sx_07b943\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003EQuestions\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"sideNavItem stat_elem\\\" id=\\\"navItem_app_2309869772\\\"\\u003E\\u003Cdiv class=\\\"buttonWrap\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock mas bookmarksMenuButton hidden_elem uiSideNavEditButton\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem favorite\\\" data-label=\\\"Add to Favorites\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"0\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAdd to Favorites\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem rearrange\\\" data-label=\\\"Rearrange\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ERearrange\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ca class=\\\"item clearfix sortableItem\\\" href=\\\"/?sk=app_2309869772\\\" title=\\\"\\\" data-gt=\\\"&#123;&quot;bmid&quot;:&quot;2309869772&quot;,&quot;count&quot;:&quot;0&quot;,&quot;type&quot;:&quot;click2canvas&quot;,&quot;rank&quot;:&quot;5&quot;&#125;\\\"\\u003E\\u003Cdiv class=\\\"rfloat\\\"\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003Cspan class=\\\"count hidden_elem uiSideNavCount\\\"\\u003E\\u003Cspan class=\\\"countValue fss\\\"\\u003E0\\u003C/span\\u003E\\u003Cspan class=\\\"maxCountIndicator\\\"\\u003E\\u003C/span\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"grip\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\\u003Cdiv\\u003E\\u003Cspan class=\\\"imgWrap\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_599039\\\"\\u003E\\u003C/i\\u003E\\u003C/span\\u003E\\u003Cdiv class=\\\"linkWrap noCount\\\"\\u003ELinks\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/a\\u003E\\u003Cspan class=\\\"mover hidden_elem\\\"\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n    }\n});");
// 1598
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 3,\n    id: \"pagelet_sidebar\",\n    is_last: true,\n    css: [\"6liCk\",\"zMzHV\",\"8DGr1\",\"6x0ig\",],\n    resource_map: {\n        zMzHV: {\n            type: \"css\",\n            permanent: 1,\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/ym/r/PeSUzP6m_TQ.css\"\n        }\n    },\n    js: [\"LayX0\",\"Vroh4\",\"HKq5g\",\"Un380\",\"poN6f\",\"jnsdD\",\"JYRWp\",\"TLs0W\",],\n    jscc: \"JSCC.init({\\\"j4e93235b851695b368877201\\\":function(){return new ChatOrderedList($(\\\"upctjk_35\\\"));},\\\"j4e93235b851695b368877202\\\":function(){return new ChatTypeaheadDataSource({\\\"showOfflineUsers\\\":true});},\\\"j4e93235b851695b368877203\\\":function(){return new Typeahead(JSCC.get('j4e93235b851695b368877202'), {node_id: \\\"upctjk_36\\\", ctor: \\\"TypeaheadView\\\", options: {\\\"autoSelect\\\":true,\\\"renderer\\\":\\\"chat\\\"}}, {ctor: \\\"ChatTypeaheadCore\\\", options: {\\\"keepFocused\\\":false,\\\"resetOnSelect\\\":true,\\\"setValueOnSelect\\\":false}}, $(\\\"upctjk_37\\\"))},\\\"j4e93235b851695b368877204\\\":function(){return new ScrollableArea()},\\\"j4e93235b851695b368877205\\\":function(){return new ChatSidebarDropdown();},\\\"j4e93235b851695b368877206\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cli class=\\\\\\\"item\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"clearfix\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\" data-jsid=\\\\\\\"anchor\\\\\\\"\\u003E\\\\u003cimg class=\\\\\\\"pic\\\\\\\" src=\\\\\\\"\\\\/images\\\\/spacer.gif\\\\\\\" data-jsid=\\\\\\\"profile-photo\\\\\\\" \\\\/\\u003E\\\\u003cspan class=\\\\\\\"name\\\\\\\" data-jsid=\\\\\\\"name\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003ci class=\\\\\\\"status img sp_3zg6ta sx_823b1c\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\"));}});\",\n    JSBNG__onload: [\"ChatConfig.set({\\\"chat_client_tabs\\\":0,\\\"chat_save_client_tabs\\\":1,\\\"sidebar\\\":1,\\\"sidebar_online_friends\\\":1,\\\"tab_auto_close_enabled\\\":1,\\\"video.outbound_ring\\\":0,\\\"multichat\\\":1,\\\"group_chat.can_mute\\\":1,\\\"sidebar_ticker\\\":1,\\\"titan\\\":1,\\\"video.early_start_session\\\":0,\\\"video.deep_log\\\":0,\\\"video.small_log\\\":1,\\\"video.long_log\\\":0,\\\"video.short_runtime\\\":1,\\\"video.progress_bar\\\":0,\\\"chat_canary\\\":0,\\\"channel_disconnect_warning\\\":0,\\\"channel_disconnect_warning_internal\\\":0,\\\"24h_times\\\":false,\\\"available_sheet_min_tab_age_ms\\\":20000,\\\"sound_enabled\\\":true,\\\"typing_notifications\\\":true,\\\"ordered_list.available_target\\\":0.85,\\\"ordered_list.sort_alphabetical\\\":true,\\\"ordered_list.top_friends\\\":5,\\\"sidebar.min_friends\\\":25,\\\"sidebar.minimum_width\\\":1225,\\\"video.can_call\\\":true,\\\"video.can_be_called\\\":1,\\\"video.activate_seconds\\\":25,\\\"video.slow_login_ms\\\":2200,\\\"tab_auto_close_timeout_ms\\\":900000,\\\"tab_auto_close_timeout_variation_range_ms\\\":5000,\\\"tab_auto_close_min_tab_count\\\":0,\\\"chat_tab_user_status_update_min_interval_ms\\\":5000,\\\"chat_tab_user_status_update_variation_range_ms\\\":3000,\\\"group_chat_facepile_update_interval_ms\\\":60000,\\\"buddy_list_channel_down\\\":\\\"Channel Down\\\",\\\"channel_on_idle\\\":\\\"[FB only] Channel server is not responding.\\\",\\\"channel_poll_interval\\\":3000});\",\"window.ChatSidebar.init($(\\\"upctjk_34\\\"), JSCC.get('j4e93235b851695b368877201'), JSCC.get('j4e93235b851695b368877203'));\",\"JSCC.get('j4e93235b851695b368877204').init($(\\\"upctjk_38\\\"), {\\\"persistent\\\":true});\",\"JSCC.get('j4e93235b851695b368877205').init($(\\\"upctjk_39\\\"));\",\"OrderedFriendsList.init([\\\"1055580469\\\"]);\",\"JSCC.get('j4e93235b851695b368877201').init(JSCC.get('j4e93235b851695b368877206'));\",\"OrderedFriendsList.init([\\\"1055580469\\\"]);\",],\n    JSBNG__content: {\n        pagelet_sidebar: \"\\u003Cdiv class=\\\"fbChatSidebar hidden_elem\\\" id=\\\"upctjk_34\\\"\\u003E\\u003Cdiv class=\\\"fbChatSidebarBody\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableArea scrollableOrderedList fade\\\" style=\\\"width:180px;\\\" id=\\\"upctjk_38\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaWrap scrollable\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaBody\\\" style=\\\"width:180px;\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaContent\\\"\\u003E\\u003Cul class=\\\"fbChatOrderedList clearfix\\\" id=\\\"upctjk_35\\\"\\u003E\\u003Cli\\u003E\\u003Cdiv class=\\\"phs fcg\\\"\\u003ELoading...\\u003C/div\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"uiScrollableAreaTrack invisible_elem\\\"\\u003E\\u003Cdiv class=\\\"uiScrollableAreaGripper\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbChatTypeaheadView hidden_elem\\\" id=\\\"upctjk_36\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbChatSidebarMessage clearfix\\\"\\u003E\\u003Ci class=\\\"img sp_3zg6ta sx_823b1c\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"message fcg\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Ctable class=\\\"uiGrid fbChatSidebarFooter\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cdiv class=\\\"uiTypeahead uiClearableTypeahead fbChatTypeahead\\\" id=\\\"upctjk_37\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Clabel class=\\\"clear uiCloseButton\\\" for=\\\"upctjk_40\\\"\\u003E\\u003Cinput title=\\\"Remove\\\" onclick=\\\"var c = JSCC.get(&#039;j4e93235b851695b368877203&#039;).getCore(); c.reset(); c.getElement().focus(); \\\" type=\\\"button\\\" id=\\\"upctjk_40\\\" /\\u003E\\u003C/label\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"hiddenInput\\\" /\\u003E\\u003Cdiv class=\\\"innerWrap\\\"\\u003E\\u003Cinput type=\\\"text\\\" class=\\\"inputtext inputsearch textInput DOMControl_placeholder\\\" autocomplete=\\\"off\\\" placeholder=\\\"Search\\\" onfocus=\\\"return wait_for_load(this, event, function() &#123;JSCC.get(&#039;j4e93235b851695b368877203&#039;).init([&quot;chatTypeahead&quot;,&quot;buildBestAvailableNames&quot;,&quot;showLoadingIndicator&quot;]);;;&#125;);\\\" spellcheck=\\\"false\\\" value=\\\"Search\\\" title=\\\"Search\\\" /\\u003E\\u003C/div\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003Ctd\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock fbChatSidebarDropdown button uiSelectorBottomUp uiSelectorRight\\\" id=\\\"upctjk_39\\\" data-multiple=\\\"1\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem uiMenuItemCheckbox uiSelectorOption\\\" data-label=\\\"Available to Chat\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitemcheckbox\\\" tabindex=\\\"0\\\" aria-checked=\\\"false\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAvailable to Chat\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem uiMenuItemCheckbox uiSelectorOption checked\\\" data-label=\\\"Chat Sounds\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitemcheckbox\\\" tabindex=\\\"-1\\\" aria-checked=\\\"true\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EChat Sounds\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Limit Availability...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"/ajax/chat/fl_privacy.php\\\" rel=\\\"dialog\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ELimit Availability...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cselect multiple=\\\"1\\\"\\u003E\\u003Coption value=\\\"\\\" disabled=\\\"1\\\"\\u003E\\u003C/option\\u003E\\u003Coption value=\\\"visibility\\\"\\u003EAvailable to Chat\\u003C/option\\u003E\\u003Coption value=\\\"sound\\\" selected=\\\"1\\\"\\u003EChat Sounds\\u003C/option\\u003E\\u003C/select\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003Ctd\\u003E\\u003Ca class=\\\"uiTooltip toggle button\\\" onmouseout=\\\"this.blur();\\\" onclick=\\\"Chat.toggleSidebar();\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"uiTooltipWrap top right righttop\\\"\\u003E\\u003Cspan class=\\\"uiTooltipText uiTooltipNoWrap\\\"\\u003EHide sidebar\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003C/div\\u003E\"\n    }\n});");
// 1655
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 4,\n    id: \"pagelet_friends_online\",\n    css: [\"6liCk\",\"zMzHV\",\"6x0ig\",\"kZ9Q2\",],\n    js: [\"LayX0\",\"Vroh4\",\"poN6f\",\"HKq5g\",\"jnsdD\",\"Un380\",\"TLs0W\",],\n    jscc: \"JSCC.init({\\\"j4e93235b8182c4a065985001\\\":function(){return new ChatTypeaheadDataSource({\\\"maxResults\\\":10,\\\"persistOnRefresh\\\":false,\\\"showOfflineUsers\\\":true});},\\\"j4e93235b8182c4a065985002\\\":function(){return new Typeahead(JSCC.get('j4e93235b8182c4a065985001'), {node_id: \\\"upctjk_41\\\", ctor: \\\"TypeaheadView\\\", options: {\\\"autoSelect\\\":true,\\\"renderer\\\":\\\"chat\\\"}}, {ctor: \\\"ChatTypeaheadCore\\\", options: {\\\"keepFocused\\\":false,\\\"resetOnSelect\\\":true,\\\"setValueOnSelect\\\":false}}, $(\\\"upctjk_42\\\"))},\\\"j4e93235b8182c4a065985003\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cli class=\\\\\\\"uiFacepileItem uiListItem uiListHorizontalItemBorder uiListHorizontalItem chatOnline\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"uiTooltip link\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"anchor\\\\\\\"\\u003E\\\\u003cimg class=\\\\\\\"uiProfilePhoto uiProfilePhotoMedium img\\\\\\\" src=\\\\\\\"http:\\\\/\\\\/profile.ak.fbcdn.net\\\\/hprofile-ak-ash2\\\\/275624_100001812504199_1255023530_q.jpg\\\\\\\" alt=\\\\\\\"\\\\\\\" data-jsid=\\\\\\\"img\\\\\\\" \\\\/\\u003E\\\\u003cdiv class=\\\\\\\"chatStatus\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top left lefttop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EJavaScript TestEngineer\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\"));}});\",\n    JSBNG__onload: [\"OrderedFriendsList.init([\\\"1055580469\\\"]);\",\"require.ensure([\\\"ChatOnlineFriends\\\"], function(ChatOnlineFriends) {(new ChatOnlineFriends()).init(20, JSCC.get('j4e93235b8182c4a065985002'), $(\\\"chatFriendsOnline\\\"), $(\\\"upctjk_43\\\"), JSCC.get('j4e93235b8182c4a065985003'));})\",\"OrderedFriendsList.init([\\\"1055580469\\\"]);\",],\n    JSBNG__content: {\n        pagelet_friends_online: \"\\u003Cdiv id=\\\"chatFriendsOnline\\\" class=\\\"isOffline\\\"\\u003E\\u003Cdiv class=\\\"uiHeader uiHeaderTopBorder uiHeaderNav uiHeaderNavEmpty\\\" role=\\\"separator\\\"\\u003E\\u003Cdiv class=\\\"clearfix uiHeaderTop\\\"\\u003E\\u003Cdiv\\u003E\\u003Ch4 class=\\\"uiHeaderTitle\\\"\\u003E\\u003C/h4\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"pas\\\"\\u003E\\u003Ctable class=\\\"uiGrid mbs mrs typeaheadContainer hideIfOffline\\\" cellspacing=\\\"0\\\" cellpadding=\\\"0\\\"\\u003E\\u003Ctbody\\u003E\\u003Ctr\\u003E\\u003Ctd\\u003E\\u003Cdiv class=\\\"uiTypeahead uiClearableTypeahead fbChatTypeahead typeahead hideIfOffline\\\" id=\\\"upctjk_42\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Clabel class=\\\"clear uiCloseButton\\\" for=\\\"upctjk_45\\\"\\u003E\\u003Cinput title=\\\"Remove\\\" onclick=\\\"var c = JSCC.get(&#039;j4e93235b8182c4a065985002&#039;).getCore(); c.reset(); c.getElement().focus(); \\\" type=\\\"button\\\" id=\\\"upctjk_45\\\" /\\u003E\\u003C/label\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"hiddenInput\\\" /\\u003E\\u003Cdiv class=\\\"innerWrap\\\"\\u003E\\u003Cinput type=\\\"text\\\" class=\\\"inputtext inputsearch textInput DOMControl_placeholder\\\" autocomplete=\\\"off\\\" placeholder=\\\"Friends on Chat\\\" onfocus=\\\"return wait_for_load(this, event, function() &#123;JSCC.get(&#039;j4e93235b8182c4a065985002&#039;).init([&quot;chatTypeahead&quot;,&quot;buildBestAvailableNames&quot;,&quot;showLoadingIndicator&quot;]);;;&#125;);\\\" spellcheck=\\\"false\\\" value=\\\"Friends on Chat\\\" title=\\\"Friends on Chat\\\" /\\u003E\\u003C/div\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/td\\u003E\\u003Ctd\\u003E\\u003Clabel class=\\\"sidebarBtn uiButton uiButtonNoText\\\" for=\\\"upctjk_44\\\"\\u003E\\u003Ci class=\\\"mrs customimg img sp_3zg6ta sx_b3b6f9\\\"\\u003E\\u003C/i\\u003E\\u003Cinput value=\\\"\\\" title=\\\"Show Sidebar\\\" onclick=\\\"Chat.toggleSidebar();$E(event).kill();\\\" type=\\\"submit\\\" id=\\\"upctjk_44\\\" /\\u003E\\u003C/label\\u003E\\u003C/td\\u003E\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\\u003Cdiv class=\\\"uiFacepile uiFacepileMedium hideIfOffline fbFriendsOnlineFacepile\\\" id=\\\"upctjk_43\\\"\\u003E\\u003Cul class=\\\"uiList uiListHorizontal clearfix\\\"\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"UIImageBlock clearfix navigationLink showIfOffline\\\"\\u003E\\u003Ci class=\\\"UIImageBlock_Image UIImageBlock_ICON_Image img sp_cgcm2h sx_77cc05\\\"\\u003E\\u003C/i\\u003E\\u003Cdiv class=\\\"fbChatOfflineMessage UIImageBlock_Content UIImageBlock_ICON_Content fsm fwn fcg\\\"\\u003EYou are currently offline. To chat with your friends, \\u003Ca onclick=\\\"Chat.openBuddyList();$E(event).kill();\\\" href=\\\"#\\\"\\u003Ego online\\u003C/a\\u003E.\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbChatTypeaheadView hidden_elem\\\" id=\\\"upctjk_41\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n    }\n});");
// 1706
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 4,\n    id: \"fbRequestsList\",\n    css: [\"6liCk\",\"8DGr1\",],\n    js: [\"LayX0\",\"Vroh4\",],\n    JSBNG__onload: [\"window.presenceRequests.fromDom()\",],\n    JSBNG__content: {\n        fbRequestsList: \"\\u003Cdiv\\u003E\\u003Cdiv class=\\\"fbRequestList\\\"\\u003E\\u003Cul class=\\\"uiList pbm\\\"\\u003E\\u003Cli class=\\\"empty  uiListItem uiListLight uiListVerticalItemBorder\\\"\\u003ENo new requests\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"jewelFooter\\\"\\u003E\\u003Ca class=\\\"seeMore\\\" href=\\\"http://www.facebook.com/friends/edit/\\\"\\u003E\\u003Cspan\\u003ESee All Friends\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\"\n    }\n});");
// 1746
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 4,\n    id: \"pagelet_presence\",\n    css: [\"6liCk\",\"8DGr1\",\"6x0ig\",\"zMzHV\",],\n    bootloadable: {\n        VideoChatCore: [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",\"HKq5g\",\"jnsdD\",\"JYRWp\",\"oIqym\",\"TY5y5\",\"9l85X\",\"sHGOK\",\"8DGr1\",\"P5VoD\",\"5uO4k\",\"prt3e\",],\n        \"user-activity\": [\"LayX0\",\"Vroh4\",\"poN6f\",],\n        VideoChatViewCore: [\"LayX0\",\"Vroh4\",\"6liCk\",\"poN6f\",\"HKq5g\",\"jnsdD\",\"JYRWp\",\"5uO4k\",\"8DGr1\",\"P5VoD\",\"9l85X\",\"prt3e\",\"TY5y5\",],\n        sort: [\"TZhVy\",\"Vroh4\",\"LayX0\",]\n    },\n    resource_map: {\n        \"9l85X\": {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/ye/r/B9kkDS2WEUG.js\"\n        },\n        sHGOK: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yF/r/H2fvg8cA3Pa.js\"\n        },\n        prt3e: {\n            type: \"js\",\n            src: \"http://static.ak.fbcdn.net/rsrc.php/v1/yC/r/I3HaSiNsEMS.js\"\n        }\n    },\n    tplts: {\n        z9Omi9: [\"BeeperTemplate\",\"\\u003Cdiv id=\\\"BeeperBox\\\" class=\\\"UIBeeper hidden_elem\\\"\\u003E\\u003Cdiv class=\\\"UIBeeper_Full\\\"\\u003E\\u003Cdiv class=\\\"Beeps\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\",]\n    },\n    js: [\"LayX0\",\"Vroh4\",\"poN6f\",\"HKq5g\",\"jnsdD\",\"TLs0W\",\"Un380\",\"P5VoD\",\"JYRWp\",],\n    jscc: \"JSCC.init({\\\"j4e93235b8519a41208901241\\\":function(){return AvailableList;},\\\"j4e93235b8519a41208901242\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbChatMessage fsm\\\\\\\" data-jsid=\\\\\\\"message\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a41208901243\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"mhs mbs pts fbChatConvItem fbChatMessageGroup clearfix small\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"profileLink\\\\\\\" data-jsid=\\\\\\\"profileLink\\\\\\\"\\u003E\\\\u003cimg class=\\\\\\\"profilePhoto\\\\\\\" src=\\\\\\\"\\\\/images\\\\/spacer.gif\\\\\\\" data-jsid=\\\\\\\"profilePhoto\\\\\\\" title=\\\\\\\"You\\\\\\\" \\\\/\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"messages\\\\\\\" data-jsid=\\\\\\\"messages\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"metaInfoContainer fss fcg\\\\\\\"\\u003E\\\\u003cspan data-jsid=\\\\\\\"reportLinkWithDot\\\\\\\" class=\\\\\\\"hidden_elem\\\\\\\"\\u003E\\\\u003ca rel=\\\\\\\"dialog\\\\\\\" data-jsid=\\\\\\\"reportLink\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"fcg\\\\\\\"\\u003EReport\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E \\\\u00b7 \\\\u003c\\\\/span\\u003E\\\\u003cspan class=\\\\\\\"timestamp\\\\\\\" data-jsid=\\\\\\\"timestamp\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a41208901244\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"mhs mbs pts fbChatConvItem fbChatMessageGroup clearfix small\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"uiTooltip profileLink profileTooltipLink\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"profileLink\\\\\\\"\\u003E\\\\u003cimg class=\\\\\\\"profilePhoto\\\\\\\" src=\\\\\\\"\\\\/images\\\\/spacer.gif\\\\\\\" data-jsid=\\\\\\\"profilePhoto\\\\\\\" \\\\/\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap middle right rightmiddle\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EYou\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"messages\\\\\\\" data-jsid=\\\\\\\"messages\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"metaInfoContainer fss fcg\\\\\\\"\\u003E\\\\u003cspan data-jsid=\\\\\\\"reportLinkWithDot\\\\\\\" class=\\\\\\\"hidden_elem\\\\\\\"\\u003E\\\\u003ca rel=\\\\\\\"dialog\\\\\\\" data-jsid=\\\\\\\"reportLink\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"fcg\\\\\\\"\\u003EReport\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E \\\\u00b7 \\\\u003c\\\\/span\\u003E\\\\u003cspan class=\\\\\\\"timestamp\\\\\\\" data-jsid=\\\\\\\"timestamp\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a41208901245\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"mhs mbs pts fbChatConvItem fbChatMessageGroup clearfix small\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"uiTooltip profileLink profileTooltipLink\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"profileLink\\\\\\\"\\u003E\\\\u003cimg class=\\\\\\\"profilePhoto\\\\\\\" src=\\\\\\\"\\\\/images\\\\/spacer.gif\\\\\\\" data-jsid=\\\\\\\"profilePhoto\\\\\\\" \\\\/\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap middle right rightmiddle\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EYou\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"messages\\\\\\\" data-jsid=\\\\\\\"messages\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"metaInfoContainer fss fcg\\\\\\\"\\u003E\\\\u003cspan data-jsid=\\\\\\\"reportLinkWithDot\\\\\\\" class=\\\\\\\"hidden_elem\\\\\\\"\\u003E\\\\u003ca rel=\\\\\\\"dialog\\\\\\\" data-jsid=\\\\\\\"reportLink\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"fcg\\\\\\\"\\u003EReport\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E \\\\u00b7 \\\\u003c\\\\/span\\u003E\\\\u003cspan class=\\\\\\\"timestamp\\\\\\\" data-jsid=\\\\\\\"timestamp\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a41208901246\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbChatMessage errorMsg fsm fcg\\\\\\\" data-jsid=\\\\\\\"message\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a41208901247\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbChatMessage warningMsg fsm fcg\\\\\\\" data-jsid=\\\\\\\"message\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a41208901248\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003ca class=\\\\\\\"uiIconText\\\\\\\" style=\\\\\\\"padding-left: 12px;\\\\\\\"\\u003E\\\\u003ci class=\\\\\\\"img sp_cgcm2h sx_c0700e\\\\\\\" style=\\\\\\\"top: 1px;\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003cspan data-jsid=\\\\\\\"label\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\"));},\\\"j4e93235b8519a41208901249\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003ca class=\\\\\\\"uiIconText\\\\\\\" style=\\\\\\\"padding-left: 12px;\\\\\\\"\\u003E\\\\u003ci class=\\\\\\\"img sp_cgcm2h sx_037013\\\\\\\" style=\\\\\\\"top: 3px;\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003cspan data-jsid=\\\\\\\"label\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\"));},\\\"j4e93235b8519a412089012410\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbChatMessageSubject fsm fwb\\\\\\\" data-jsid=\\\\\\\"messageSubject\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012411\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"mhs mbs fbChatConvItem fbChatConvDateBreak fss fwb fcg\\\\\\\" data-jsid=\\\\\\\"date\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012412\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbNub fbDockChatTab user\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"fbNubButton\\\\\\\" data-jsid=\\\\\\\"fbDockChatTab\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"toggle\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbChatTab fbChatUserTab\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"funhouse rfloat\\\\\\\"\\u003E\\\\u003clabel class=\\\\\\\"close uiCloseButton\\\\\\\" for=\\\\\\\"upctjk_48\\\\\\\"\\u003E\\\\u003cinput title=\\\\\\\"Close\\\\\\\" data-jsid=\\\\\\\"closeButton\\\\\\\" type=\\\\\\\"button\\\\\\\" id=\\\\\\\"upctjk_48\\\\\\\" \\\\/\\u003E\\\\u003c\\\\/label\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"wrapWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"wrap\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"name fwb\\\\\\\" data-jsid=\\\\\\\"name\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cspan class=\\\\\\\"numMessages hidden_elem\\\\\\\" data-jsid=\\\\\\\"numMessages\\\\\\\"\\u003E0\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyout fbDockChatTabFlyout uiToggleFlyout\\\\\\\" data-jsid=\\\\\\\"chatWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutOuter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutInner\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbNubFlyoutTitlebar titlebar\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"mls rfloat\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"uiTooltip videoicon button\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"videoCallLink\\\\\\\" data-gt=\\\\\\\"&#123;&quot;videochat&quot;:&quot;call_clicked_chat_tab&quot;&#125;\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top center centertop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EStart a video call\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"uiSelector inlineBlock fbDockChatDropdown\\\\\\\" data-jsid=\\\\\\\"dropdown\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"wrap\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"button uiSelectorButton\\\\\\\" href=\\\\\\\"#\\\\\\\" role=\\\\\\\"button\\\\\\\" aria-haspopup=\\\\\\\"1\\\\\\\" rel=\\\\\\\"toggle\\\\\\\"\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"uiSelectorMenuWrapper uiToggleFlyout\\\\\\\"\\u003E\\\\u003cdiv role=\\\\\\\"menu\\\\\\\" class=\\\\\\\"uiMenu uiSelectorMenu\\\\\\\"\\u003E\\\\u003cul class=\\\\\\\"uiMenuInner\\\\\\\"\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"Add Friends to Chat...\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"0\\\\\\\" data-jsid=\\\\\\\"addFriendLink\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003EAdd Friends to Chat...\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuSeparator\\\\\\\"\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"See Full Conversation\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"-1\\\\\\\" data-jsid=\\\\\\\"conversationLink\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003ESee Full Conversation\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"Clear Window\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"-1\\\\\\\" data-jsid=\\\\\\\"clearWindowLink\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003EClear Window\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuSeparator\\\\\\\"\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"Report as Spam\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"-1\\\\\\\" data-jsid=\\\\\\\"reportSpamLink\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003EReport as Spam\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003c\\\\/ul\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003ca class=\\\\\\\"uiTooltip close button\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"titlebarCloseButton\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top center centertop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EPress Esc to close\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"titlebarLabel clearfix\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"titlebarTextWrapper\\\\\\\" data-jsid=\\\\\\\"titlebarTextWrapper\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"titlebarText\\\\\\\" data-jsid=\\\\\\\"titlebarText\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutHeader\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"sheetContainer\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"sheet hidden_elem\\\\\\\" data-jsid=\\\\\\\"sheet\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBody scrollable\\\\\\\" data-jsid=\\\\\\\"chatConv\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBodyContent\\\\\\\"\\u003E\\\\u003ctable class=\\\\\\\"uiGrid conversationContainer\\\\\\\" cellspacing=\\\\\\\"0\\\\\\\" cellpadding=\\\\\\\"0\\\\\\\"\\u003E\\\\u003ctbody\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vTop\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"conversation\\\\\\\" data-jsid=\\\\\\\"conversation\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vBot\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"pas typingIndicator fcg\\\\\\\" data-jsid=\\\\\\\"typingIndicator\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003c\\\\/tbody\\u003E\\\\u003c\\\\/table\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutFooter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"inputContainer\\\\\\\"\\u003E\\\\u003ctextarea class=\\\\\\\"uiTextareaAutogrow input\\\\\\\" data-jsid=\\\\\\\"input\\\\\\\" onfocus=\\\\\\\"return wait_for_load(this, event, function() &#123;if (!this._has_control) &#123;  new TextAreaControl(this).setAutogrow(true);  this._has_control = true; &#125; &#125;);\\\\\\\"\\u003E\\\\u003c\\\\/textarea\\u003E\\\\u003ci class=\\\\\\\"inputIcon img sp_cgcm2h sx_e513e2\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012413\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbNub fbDockChatTab group\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"fbNubButton\\\\\\\" data-jsid=\\\\\\\"fbDockChatTab\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"toggle\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbChatTab fbChatGroupTab\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"funhouse rfloat\\\\\\\"\\u003E\\\\u003clabel class=\\\\\\\"close uiCloseButton\\\\\\\" for=\\\\\\\"upctjk_49\\\\\\\"\\u003E\\\\u003cinput title=\\\\\\\"Close\\\\\\\" data-jsid=\\\\\\\"closeButton\\\\\\\" type=\\\\\\\"button\\\\\\\" id=\\\\\\\"upctjk_49\\\\\\\" \\\\/\\u003E\\\\u003c\\\\/label\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"wrapWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"wrap\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"name fwb\\\\\\\" data-jsid=\\\\\\\"name\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cspan class=\\\\\\\"numMessages hidden_elem\\\\\\\" data-jsid=\\\\\\\"numMessages\\\\\\\"\\u003E0\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyout fbDockChatTabFlyout uiToggleFlyout\\\\\\\" data-jsid=\\\\\\\"chatWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutOuter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutInner\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbNubFlyoutTitlebar titlebar\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"mls rfloat\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"uiSelector inlineBlock fbDockChatDropdown\\\\\\\" data-jsid=\\\\\\\"dropdown\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"wrap\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"button uiSelectorButton\\\\\\\" href=\\\\\\\"#\\\\\\\" role=\\\\\\\"button\\\\\\\" aria-haspopup=\\\\\\\"1\\\\\\\" rel=\\\\\\\"toggle\\\\\\\"\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"uiSelectorMenuWrapper uiToggleFlyout\\\\\\\"\\u003E\\\\u003cdiv role=\\\\\\\"menu\\\\\\\" class=\\\\\\\"uiMenu uiSelectorMenu\\\\\\\"\\u003E\\\\u003cul class=\\\\\\\"uiMenuInner\\\\\\\"\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"Hide Chat for this Group\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"0\\\\\\\" data-jsid=\\\\\\\"muteGroupLink\\\\\\\" href=\\\\\\\"\\\\/ajax\\\\/groups\\\\/membership\\\\/mute_group.php\\\\\\\" rel=\\\\\\\"async-post\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003EHide Chat for this Group\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003c\\\\/ul\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003ca class=\\\\\\\"uiTooltip close button\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"titlebarCloseButton\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top center centertop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EPress Esc to close\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"titlebarLabel clearfix\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"titlebarTextWrapper\\\\\\\" data-jsid=\\\\\\\"titlebarTextWrapper\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"titlebarText\\\\\\\" data-jsid=\\\\\\\"titlebarText\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutHeader\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"facepileHolder\\\\\\\" data-jsid=\\\\\\\"facepileHolder\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"sheetContainer\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"sheet hidden_elem\\\\\\\" data-jsid=\\\\\\\"sheet\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBody scrollable\\\\\\\" data-jsid=\\\\\\\"chatConv\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBodyContent\\\\\\\"\\u003E\\\\u003ctable class=\\\\\\\"uiGrid conversationContainer\\\\\\\" cellspacing=\\\\\\\"0\\\\\\\" cellpadding=\\\\\\\"0\\\\\\\"\\u003E\\\\u003ctbody\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vTop\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"conversation\\\\\\\" data-jsid=\\\\\\\"conversation\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vBot\\\\\\\"\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003c\\\\/tbody\\u003E\\\\u003c\\\\/table\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutFooter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"inputContainer\\\\\\\"\\u003E\\\\u003ctextarea class=\\\\\\\"uiTextareaAutogrow input\\\\\\\" data-jsid=\\\\\\\"input\\\\\\\" onfocus=\\\\\\\"return wait_for_load(this, event, function() &#123;if (!this._has_control) &#123;  new TextAreaControl(this).setAutogrow(true);  this._has_control = true; &#125; &#125;);\\\\\\\"\\u003E\\\\u003c\\\\/textarea\\u003E\\\\u003ci class=\\\\\\\"inputIcon img sp_cgcm2h sx_e513e2\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012414\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbNub fbDockChatTab livelisten\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"fbNubButton\\\\\\\" data-jsid=\\\\\\\"fbDockChatTab\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"toggle\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbChatTab fbChatLiveListenTab\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"funhouse rfloat\\\\\\\"\\u003E\\\\u003clabel class=\\\\\\\"close uiCloseButton\\\\\\\" for=\\\\\\\"upctjk_50\\\\\\\"\\u003E\\\\u003cinput title=\\\\\\\"Close\\\\\\\" data-jsid=\\\\\\\"closeButton\\\\\\\" type=\\\\\\\"button\\\\\\\" id=\\\\\\\"upctjk_50\\\\\\\" \\\\/\\u003E\\\\u003c\\\\/label\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"wrapWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"wrap\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"name fwb\\\\\\\" data-jsid=\\\\\\\"name\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cspan class=\\\\\\\"numMessages hidden_elem\\\\\\\" data-jsid=\\\\\\\"numMessages\\\\\\\"\\u003E0\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyout fbDockChatTabFlyout uiToggleFlyout\\\\\\\" data-jsid=\\\\\\\"chatWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutOuter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutInner\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbNubFlyoutTitlebar titlebar\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"mls rfloat\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"uiTooltip close button\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"titlebarCloseButton\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top center centertop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EPress Esc to close\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"titlebarLabel clearfix\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"titlebarTextWrapper\\\\\\\" data-jsid=\\\\\\\"titlebarTextWrapper\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"titlebarText\\\\\\\" data-jsid=\\\\\\\"titlebarText\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutHeader\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"facepileHolder\\\\\\\" data-jsid=\\\\\\\"facepileHolder\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"sheetContainer\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"sheet hidden_elem\\\\\\\" data-jsid=\\\\\\\"sheet\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBody scrollable\\\\\\\" data-jsid=\\\\\\\"chatConv\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBodyContent\\\\\\\"\\u003E\\\\u003ctable class=\\\\\\\"uiGrid conversationContainer\\\\\\\" cellspacing=\\\\\\\"0\\\\\\\" cellpadding=\\\\\\\"0\\\\\\\"\\u003E\\\\u003ctbody\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vTop\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"conversation\\\\\\\" data-jsid=\\\\\\\"conversation\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vBot\\\\\\\"\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003c\\\\/tbody\\u003E\\\\u003c\\\\/table\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutFooter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"inputContainer\\\\\\\"\\u003E\\\\u003ctextarea class=\\\\\\\"uiTextareaAutogrow input\\\\\\\" data-jsid=\\\\\\\"input\\\\\\\" onfocus=\\\\\\\"return wait_for_load(this, event, function() &#123;if (!this._has_control) &#123;  new TextAreaControl(this).setAutogrow(true);  this._has_control = true; &#125; &#125;);\\\\\\\"\\u003E\\\\u003c\\\\/textarea\\u003E\\\\u003ci class=\\\\\\\"inputIcon img sp_cgcm2h sx_e513e2\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012415\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"fbNub fbDockChatTab thread\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"uiTooltip fbNubButton\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" data-jsid=\\\\\\\"fbDockChatTab\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"toggle\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbChatTab fbChatThreadTab\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"funhouse rfloat\\\\\\\"\\u003E\\\\u003clabel class=\\\\\\\"close uiCloseButton\\\\\\\" for=\\\\\\\"upctjk_51\\\\\\\"\\u003E\\\\u003cinput title=\\\\\\\"Close\\\\\\\" data-jsid=\\\\\\\"closeButton\\\\\\\" type=\\\\\\\"button\\\\\\\" id=\\\\\\\"upctjk_51\\\\\\\" \\\\/\\u003E\\\\u003c\\\\/label\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"wrapWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"wrap\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"name fwb\\\\\\\" data-jsid=\\\\\\\"name\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cspan class=\\\\\\\"numMessages hidden_elem\\\\\\\" data-jsid=\\\\\\\"numMessages\\\\\\\"\\u003E0\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top center centertop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003ELoading...\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyout fbDockChatTabFlyout uiToggleFlyout\\\\\\\" data-jsid=\\\\\\\"chatWrapper\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutOuter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutInner\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"clearfix fbNubFlyoutTitlebar titlebar\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"mls rfloat\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"uiTooltip addToThread button\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"addToThreadLink\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top center centertop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EAdd more friends to chat\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"uiSelector inlineBlock fbDockChatDropdown\\\\\\\" data-jsid=\\\\\\\"dropdown\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"wrap\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"button uiSelectorButton\\\\\\\" href=\\\\\\\"#\\\\\\\" role=\\\\\\\"button\\\\\\\" aria-haspopup=\\\\\\\"1\\\\\\\" rel=\\\\\\\"toggle\\\\\\\"\\u003E\\\\u003c\\\\/a\\u003E\\\\u003cdiv class=\\\\\\\"uiSelectorMenuWrapper uiToggleFlyout\\\\\\\"\\u003E\\\\u003cdiv role=\\\\\\\"menu\\\\\\\" class=\\\\\\\"uiMenu uiSelectorMenu\\\\\\\"\\u003E\\\\u003cul class=\\\\\\\"uiMenuInner\\\\\\\"\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"See Full Conversation\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"0\\\\\\\" data-jsid=\\\\\\\"conversationLink\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003ESee Full Conversation\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"Add Friends to Chat...\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"-1\\\\\\\" data-jsid=\\\\\\\"addFriendLink\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003EAdd Friends to Chat...\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuSeparator\\\\\\\"\\u003E\\\\u003c\\\\/li\\u003E\\\\u003cli class=\\\\\\\"uiMenuItem\\\\\\\" data-label=\\\\\\\"Leave Conversation...\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"itemAnchor\\\\\\\" role=\\\\\\\"menuitem\\\\\\\" tabindex=\\\\\\\"-1\\\\\\\" data-jsid=\\\\\\\"unsubscribeLink\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"itemLabel fsm\\\\\\\"\\u003ELeave Conversation...\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\\u003c\\\\/ul\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003ca class=\\\\\\\"uiTooltip close button\\\\\\\" onmouseout=\\\\\\\"this.blur();\\\\\\\" href=\\\\\\\"#\\\\\\\" data-jsid=\\\\\\\"titlebarCloseButton\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipWrap top center centertop\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"uiTooltipText uiTooltipNoWrap\\\\\\\"\\u003EPress Esc to close\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"titlebarLabel clearfix\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"titlebarTextWrapper\\\\\\\" data-jsid=\\\\\\\"titlebarTextWrapper\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"titlebarText\\\\\\\" data-jsid=\\\\\\\"titlebarText\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutHeader\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"sheetContainer\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"sheet hidden_elem\\\\\\\" data-jsid=\\\\\\\"sheet\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBody scrollable\\\\\\\" data-jsid=\\\\\\\"chatConv\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutBodyContent\\\\\\\"\\u003E\\\\u003ctable class=\\\\\\\"uiGrid conversationContainer\\\\\\\" cellspacing=\\\\\\\"0\\\\\\\" cellpadding=\\\\\\\"0\\\\\\\"\\u003E\\\\u003ctbody\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vTop\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"conversation\\\\\\\" data-jsid=\\\\\\\"conversation\\\\\\\"\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003ctr\\u003E\\\\u003ctd class=\\\\\\\"vBot\\\\\\\"\\u003E\\\\u003c\\\\/td\\u003E\\\\u003c\\\\/tr\\u003E\\\\u003c\\\\/tbody\\u003E\\\\u003c\\\\/table\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"fbNubFlyoutFooter\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"inputContainer\\\\\\\"\\u003E\\\\u003ctextarea class=\\\\\\\"uiTextareaAutogrow input\\\\\\\" data-jsid=\\\\\\\"input\\\\\\\" onfocus=\\\\\\\"return wait_for_load(this, event, function() &#123;if (!this._has_control) &#123;  new TextAreaControl(this).setAutogrow(true);  this._has_control = true; &#125; &#125;);\\\\\\\"\\u003E\\\\u003c\\\\/textarea\\u003E\\\\u003ci class=\\\\\\\"inputIcon img sp_cgcm2h sx_e513e2\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012416\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"mhs mbs pts fbChatConvItem fbChatEventMsg clearfix\\\\\\\"\\u003E\\\\u003cdiv class=\\\\\\\"iconWrapper\\\\\\\"\\u003E\\\\u003ci class=\\\\\\\"eventIcon img sp_3zg6ta sx_823b1c\\\\\\\" data-jsid=\\\\\\\"icon\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003c\\\\/div\\u003E\\\\u003cdiv class=\\\\\\\"messageWrapper\\\\\\\"\\u003E\\\\u003cspan class=\\\\\\\"message fsm fcg\\\\\\\" data-jsid=\\\\\\\"message\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003cspan class=\\\\\\\"mls timestamp rfloat fss fcg\\\\\\\" data-jsid=\\\\\\\"timestamp\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012417\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cdiv class=\\\\\\\"UIImageBlock clearfix pas\\\\\\\"\\u003E\\\\u003ci class=\\\\\\\"sheet_img UIImageBlock_Image UIImageBlock_ICON_Image img sp_cgcm2h sx_6594cb\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003cspan class=\\\\\\\"UIImageBlock_Content UIImageBlock_ICON_Content fcg\\\\\\\" data-jsid=\\\\\\\"text\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003c\\\\/div\\u003E\\\"));},\\\"j4e93235b8519a412089012418\\\":function(){return new NubController();},\\\"j4e93235b8519a412089012419\\\":function(){return new BuddyListNub();},\\\"j4e93235b8519a412089012420\\\":function(){return new ChatOrderedList($(\\\"upctjk_52\\\"));},\\\"j4e93235b8519a412089012421\\\":function(){return new ChatTypeaheadDataSource({\\\"showOfflineUsers\\\":true});},\\\"j4e93235b8519a412089012422\\\":function(){return new Typeahead(JSCC.get('j4e93235b8519a412089012421'), {node_id: \\\"upctjk_53\\\", ctor: \\\"TypeaheadView\\\", options: {\\\"autoSelect\\\":true,\\\"renderer\\\":\\\"chat\\\"}}, {ctor: \\\"ChatTypeaheadCore\\\", options: {\\\"keepFocused\\\":false,\\\"resetOnSelect\\\":true,\\\"setValueOnSelect\\\":false}}, $(\\\"upctjk_54\\\"))},\\\"j4e93235b8519a412089012423\\\":function(){return new ChatSidebarDropdown();},\\\"j4e93235b8519a412089012424\\\":function(){return new XHPTemplate(HTML(\\\"\\\\u003cli class=\\\\\\\"item\\\\\\\"\\u003E\\\\u003ca class=\\\\\\\"clearfix\\\\\\\" href=\\\\\\\"#\\\\\\\" rel=\\\\\\\"ignore\\\\\\\" data-jsid=\\\\\\\"anchor\\\\\\\"\\u003E\\\\u003cimg class=\\\\\\\"pic\\\\\\\" src=\\\\\\\"\\\\/images\\\\/spacer.gif\\\\\\\" data-jsid=\\\\\\\"profile-photo\\\\\\\" \\\\/\\u003E\\\\u003cspan class=\\\\\\\"name\\\\\\\" data-jsid=\\\\\\\"name\\\\\\\"\\u003E\\\\u003c\\\\/span\\u003E\\\\u003ci class=\\\\\\\"status img sp_3zg6ta sx_823b1c\\\\\\\"\\u003E\\\\u003c\\\\/i\\u003E\\\\u003c\\\\/a\\u003E\\\\u003c\\\\/li\\u003E\\\"));}});\",\n    JSBNG__onload: [\"Dock.init($(\\\"upctjk_47\\\"));\",\"MusicButtonManager.init([\\\"music.song\\\"])\",\"window.presenceCookieManager = new CookieManager(2, true);\",\"window.channelManager = new ChannelManager($(\\\"upctjk_46\\\"), \\\"100001812504199\\\", 0, {\\\"MIN_RETRY_INTERVAL\\\":10000,\\\"MAX_RETRY_INTERVAL\\\":60000,\\\"PING_INTERVAL\\\":30000,\\\"HEARTBEAT_TIMEOUT\\\":45000,\\\"IFRAME_LOAD_TIMEOUT\\\":30000,\\\"CONN_MAX_LOG_INTERVAL\\\":15000,\\\"DOS_LIMIT\\\":120}, false);\",\"window.presence = new Presence(\\\"100001812504199\\\", \\\"JavaScript TestEngineer\\\", \\\"JavaScript\\\", \\\"\\\", 1318265692000, false, {\\\"UPDATE_GRANULARITY\\\":20,\\\"BUDDY_BASE_TIME\\\":40,\\\"BUDDY_MAX_TIME\\\":900,\\\"BUDDY_MIN_TIME\\\":30,\\\"BUDDY_COST_NEVER_SENT_MESSAGE\\\":900,\\\"BUDDY_COST_NO_LIST_CHANGE\\\":30,\\\"BUDDY_COST_NO_CHAT_TABS\\\":30,\\\"BUDDY_COST_CHAT_ACTIVITY\\\":180,\\\"BUDDY_COST_VIEW_ACTIVITY\\\":180,\\\"BUDDY_COST_PAGE_ACTIVITY\\\":180,\\\"BUDDY_MAX_ACTIVITY_MINS\\\":180,\\\"BUDDY_MAX_AVAIL_COOKIE\\\":20,\\\"BUDDY_VIEW_FETCH_WINDOW\\\":120,\\\"NOTIFICATIONS_PIGGYBACK_PERCENTAGE\\\":10,\\\"CHAT_UI_COOKIE_CACHE_WINDOW\\\":25,\\\"NOTIFICATIONS_CACHE_VERSION\\\":2,\\\"NOTIFICATIONS_UPDATE_MILLISECONDS\\\":480000});\",\"channelManager.addChannel(\\\"p_100001812504199\\\", -1, bind(presence, \\\"handleMsg\\\"), bind(presence, \\\"start\\\"), bind(presence, \\\"connectionShutdown\\\"), bind(presence, \\\"restart\\\"));\",\"channelManager.rebuild(6);presence.connectionShutdown(false);\",\"JSCC.get('j4e93235b8519a41208901241').init(0, false, {}, 100000, 300000, {}, 0, []);\",\"VideoChat.init();\",\"window.chatOptions = new ChatOptions(false, {\\\"compact_buddylist\\\":0,\\\"sticky_buddylist\\\":0,\\\"sound\\\":1,\\\"idle_cutoff\\\":30000,\\\"sidebar_mode\\\":1});\",\"chatOptions.load();\",\"window.ChatUserInfos = {\\\"100001812504199\\\":{\\\"name\\\":\\\"JavaScript TestEngineer\\\",\\\"firstName\\\":\\\"JavaScript\\\",\\\"vanity\\\":null,\\\"thumbSrc\\\":\\\"http:\\\\/\\\\/profile.ak.fbcdn.net\\\\/hprofile-ak-ash2\\\\/275624_100001812504199_1255023530_q.jpg\\\",\\\"gender\\\":2,\\\"type\\\":\\\"user\\\",\\\"exist\\\":true}};\",\"define(\\\"InitialChatUserInfos\\\", [], window.ChatUserInfos);\",\"var templates = {};templates[\\\"chat-msg\\\"]=JSCC.get('j4e93235b8519a41208901242');templates[\\\"chat-msg-group\\\"]=JSCC.get('j4e93235b8519a41208901243');templates[\\\"chat-msg-group-with-tooltip\\\"]=JSCC.get('j4e93235b8519a41208901244');templates[\\\"chat-msg-thread-with-tooltip\\\"]=JSCC.get('j4e93235b8519a41208901245');templates[\\\"chat-msg-error\\\"]=JSCC.get('j4e93235b8519a41208901246');templates[\\\"chat-msg-warning\\\"]=JSCC.get('j4e93235b8519a41208901247');templates[\\\"chat-msg-attachment\\\"]=JSCC.get('j4e93235b8519a41208901248');templates[\\\"chat-msg-forward\\\"]=JSCC.get('j4e93235b8519a41208901249');templates[\\\"chat-msg-subject\\\"]=JSCC.get('j4e93235b8519a412089012410');templates[\\\"chat-msg-date-break\\\"]=JSCC.get('j4e93235b8519a412089012411');templates[\\\"chat-tab\\\"]=JSCC.get('j4e93235b8519a412089012412');templates[\\\"chat-group-tab\\\"]=JSCC.get('j4e93235b8519a412089012413');templates[\\\"chat-livelisten-tab\\\"]=JSCC.get('j4e93235b8519a412089012414');templates[\\\"chat-thread-tab\\\"]=JSCC.get('j4e93235b8519a412089012415');templates[\\\"chat-msg-event\\\"]=JSCC.get('j4e93235b8519a412089012416');templates[\\\"chat-sheet-notice\\\"]=JSCC.get('j4e93235b8519a412089012417');window.chatDisplay = new ChatDisplayInterim({}, 0, [], \\\"\\\", {}, templates);\",\"chatDisplay.load();\",\"window.chatTabSlider = new ChatTabSlider();\",\"chatTabSlider.load();\",\"JSCC.get('j4e93235b8519a412089012418').init($(\\\"fbDockChatTabSlider\\\"));\",\"JSCC.get('j4e93235b8519a412089012419').init($(\\\"fbDockChatBuddylistNub\\\"), JSCC.get('j4e93235b8519a412089012420'), JSCC.get('j4e93235b8519a412089012422'));\",\"JSCC.get('j4e93235b8519a412089012423').init($(\\\"upctjk_55\\\"));\",\"OrderedFriendsList.init([\\\"1055580469\\\"]);\",\"JSCC.get('j4e93235b8519a412089012420').init(JSCC.get('j4e93235b8519a412089012424'));\",\"OrderedFriendsList.init([\\\"1055580469\\\"]);\",],\n    JSBNG__content: {\n        pagelet_presence: [\"\\u003Ciframe class=\\\"hidden_elem\\\" id=\\\"upctjk_46\\\"\\u003E\\u003C/iframe\\u003E\\u003Cdiv class=\\\"fbDockWrapper fbDockWrapperRight bb\\\" id=\\\"upctjk_47\\\"\\u003E\\u003Cdiv class=\\\"fbDock clearfix\\\"\\u003E\\u003Cdiv class=\\\"clearfix rNubContainer\\\"\\u003E\\u003Cdiv class=\\\"fbNubGroup clearfix offline\\\" id=\\\"fbDockChat\\\"\\u003E\\u003Cdiv class=\\\"fbNubGroup clearfix hide_on_popped_out\\\" id=\\\"fbDockChatTabSlider\\\"\\u003E\\u003Cdiv class=\\\"fbNub hidden_elem next\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"arrow\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"numTabs\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"numMessages\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubGroup clearfix\\\" id=\\\"fbDockChatTabsWrapper\\\"\\u003E\\u003Cdiv class=\\\"fbNubGroup clearfix\\\" id=\\\"fbDockChatTabs\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNub hidden_elem previous\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" href=\\\"#\\\"\\u003E\\u003Cspan class=\\\"numMessages\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"numTabs\\\"\\u003E\\u003C/span\\u003E\\u003Cspan class=\\\"arrow\\\"\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNub fbDockChatBuddyListNub hide_on_popped_out hide_on_presence_error\\\" id=\\\"fbDockChatBuddylistNub\\\"\\u003E\\u003Ca class=\\\"fbNubButton\\\" href=\\\"#\\\" rel=\\\"toggle\\\"\\u003E\\u003Ci class=\\\"icon img sp_3zg6ta sx_823b1c\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"label\\\"\\u003EChat (Offline)\\u003C/span\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"fbNubFlyout uiToggleFlyout\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutOuter\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutInner\\\"\\u003E\\u003Cdiv class=\\\"clearfix fbNubFlyoutTitlebar\\\"\\u003E\\u003Cdiv class=\\\"uiSelector inlineBlock fbChatSidebarDropdown button rfloat uiSelectorRight\\\" id=\\\"upctjk_55\\\" data-multiple=\\\"1\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Ca class=\\\"uiSelectorButton uiCloseButton\\\" title=\\\"\\\" href=\\\"#\\\" role=\\\"button\\\" aria-haspopup=\\\"1\\\" rel=\\\"toggle\\\"\\u003E\\u003C/a\\u003E\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\\u003Cdiv role=\\\"menu\\\" class=\\\"uiMenu uiSelectorMenu\\\"\\u003E\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\\u003Cli class=\\\"uiMenuItem uiMenuItemCheckbox uiSelectorOption\\\" data-label=\\\"Available to Chat\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitemcheckbox\\\" tabindex=\\\"0\\\" aria-checked=\\\"false\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EAvailable to Chat\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem uiMenuItemCheckbox uiSelectorOption checked\\\" data-label=\\\"Chat Sounds\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitemcheckbox\\\" tabindex=\\\"-1\\\" aria-checked=\\\"true\\\" href=\\\"#\\\" rel=\\\"ignore\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003EChat Sounds\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuSeparator\\\"\\u003E\\u003C/li\\u003E\\u003Cli class=\\\"uiMenuItem\\\" data-label=\\\"Limit Availability...\\\"\\u003E\\u003Ca class=\\\"itemAnchor\\\" role=\\\"menuitem\\\" tabindex=\\\"-1\\\" href=\\\"/ajax/chat/fl_privacy.php\\\" rel=\\\"dialog\\\"\\u003E\\u003Cspan class=\\\"itemLabel fsm\\\"\\u003ELimit Availability...\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cselect multiple=\\\"1\\\"\\u003E\\u003Coption value=\\\"\\\" disabled=\\\"1\\\"\\u003E\\u003C/option\\u003E\\u003Coption value=\\\"visibility\\\"\\u003EAvailable to Chat\\u003C/option\\u003E\\u003Coption value=\\\"sound\\\" selected=\\\"1\\\"\\u003EChat Sounds\\u003C/option\\u003E\\u003C/select\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"titlebarLabel clearfix\\\"\\u003E\\u003Cdiv class=\\\"titlebarTextWrapper\\\"\\u003EChat\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBody scrollable\\\"\\u003E\\u003Cdiv class=\\\"fbNubFlyoutBodyContent\\\"\\u003E\\u003Cul class=\\\"fbChatOrderedList clearfix\\\" id=\\\"upctjk_52\\\"\\u003E\\u003Cli\\u003E\\u003Cdiv class=\\\"phs fcg\\\"\\u003ELoading...\\u003C/div\\u003E\\u003C/li\\u003E\\u003C/ul\\u003E\\u003Cdiv class=\\\"fbChatTypeaheadView hidden_elem\\\" id=\\\"upctjk_53\\\"\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNubFlyoutFooter\\\"\\u003E\\u003Cdiv class=\\\"uiTypeahead uiClearableTypeahead fbChatTypeahead\\\" id=\\\"upctjk_54\\\"\\u003E\\u003Cdiv class=\\\"wrap\\\"\\u003E\\u003Clabel class=\\\"clear uiCloseButton\\\" for=\\\"upctjk_56\\\"\\u003E\\u003Cinput title=\\\"Remove\\\" onclick=\\\"var c = JSCC.get(&#039;j4e93235b8519a412089012422&#039;).getCore(); c.reset(); c.getElement().focus(); \\\" type=\\\"button\\\" id=\\\"upctjk_56\\\" /\\u003E\\u003C/label\\u003E\\u003Cinput type=\\\"hidden\\\" autocomplete=\\\"off\\\" class=\\\"hiddenInput\\\" /\\u003E\\u003Cdiv class=\\\"innerWrap\\\"\\u003E\\u003Cinput type=\\\"text\\\" class=\\\"inputtext inputsearch textInput DOMControl_placeholder\\\" autocomplete=\\\"off\\\" placeholder=\\\"Search\\\" onfocus=\\\"return wait_for_load(this, event, function() &#123;JSCC.get(&#039;j4e93235b8519a412089012422&#039;).init([&quot;chatTypeahead&quot;,&quot;buildBestAvailableNames&quot;,&quot;showLoadingIndicator&quot;]);;;&#125;);\\\" spellcheck=\\\"false\\\" value=\\\"Search\\\" title=\\\"Search\\\" /\\u003E\\u003C/div\\u003E\\u003Cimg class=\\\"uiLoadingIndicatorAsync img\\\" src=\\\"http://static.ak.fbcdn.net/rsrc.php/v1/yb/r/GsNJNwuI-UM.gif\\\" alt=\\\"\\\" width=\\\"16\\\" height=\\\"11\\\" /\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNub show_on_popped_out\\\" id=\\\"fbChatPopoutNub\\\"\\u003E\\u003Ca class=\\\"uiTooltip fbNubButton\\\" onmouseout=\\\"this.blur();\\\" onclick=\\\"presence.popin();\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"img sp_azqx0n sx_cc6642\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiTooltipWrap top right righttop\\\"\\u003E\\u003Cspan class=\\\"uiTooltipText uiTooltipNoWrap\\\"\\u003EPop In Chat\\u003C/span\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003Cdiv class=\\\"fbNub show_on_presence_error\\\" id=\\\"fbChatErrorNub\\\"\\u003E\\u003Ca class=\\\"uiTooltip fbNubButton\\\" onmouseout=\\\"this.blur();\\\" href=\\\"#\\\"\\u003E\\u003Ci class=\\\"img sp_azqx0n sx_d010c3\\\"\\u003E\\u003C/i\\u003E\\u003Cspan class=\\\"uiTooltipWrap top right righttop\\\"\\u003E\\u003Cspan class=\\\"uiTooltipText uiTooltipNoWrap\\\"\\u003E \\u003C/span\\u003E\\u003C/span\\u003E\\u003C/a\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E\\u003C/div\\u003E[[\\u003E tplt_0]]\",{\n            tplt_0: [\"z9Omi9\",[],]\n        },]\n    }\n});");
// 1790
geval("big_pipe.JSBNG__onPageletArrive({\n    phase: 4,\n    id: \"\",\n    is_last: true,\n    the_end: true,\n    css: [\"6liCk\",\"/V4PE\",\"kZ9Q2\",\"6x0ig\",],\n    js: [\"LayX0\",\"Vroh4\",\"poN6f\",\"jnsdD\",\"TLs0W\",\"JR0hL\",\"FmWj5\",],\n    JSBNG__onafterload: [\"new AsyncRequest().setURI(\\\"\\\\/ajax\\\\/httponly_cookies.php?dc=prn1c06\\\").setMethod(\\\"POST\\\").setData({keys: [1188362605]}).send();\",]\n});");
// 1837
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_154[0], o0,o10);
// undefined
o0 = null;
// undefined
o10 = null;
// 1845
JSBNG_Replay.sfb70ab12eee911300ccf01d20dbb588c58164ec7_2[0]();
// 1851
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[0](false);
// 2328
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[0](false);
// 2372
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[1](false);
// 2416
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[0](false);
// 2784
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[1](false);
// 2807
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[0](false);
// 3835
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[1](false);
// 3845
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_32[2](false);
// 3855
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"Vroh4\",]);\n}\n;\n;\nfunction object(b) {\n    var a = new Function();\n    a.prototype = b;\n    return new a();\n};\n;\nfunction is_scalar(a) {\n    return (/string|number|boolean/).test(typeof a);\n};\n;\nfunction keys(c) {\n    var b = [];\n    for (var a in c) {\n        b.push(a);\n    ;\n    };\n;\n    return b;\n};\n;\nfunction values(b) {\n    var c = [];\n    for (var a in b) {\n        c.push(b[a]);\n    ;\n    };\n;\n    return c;\n};\n;\nfunction count(c) {\n    var a = 0;\n    for (var b in c) {\n        a++;\n    ;\n    };\n;\n    return a;\n};\n;\nfunction are_equal(a, b) {\n    return ((JSON.stringify(a) == JSON.stringify(b)));\n};\n;\nfunction merge() {\n    var b = {\n    };\n    for (var a = 0; ((a < arguments.length)); a++) {\n        copy_properties(b, arguments[a]);\n    ;\n    };\n;\n    return b;\n};\n;\nObject.from = function(c, e) {\n    var d = {\n    };\n    var b = hasArrayNature(e);\n    if (((typeof e == \"undefined\"))) {\n        e = true;\n    }\n;\n;\n    for (var a = c.length; a--; ) {\n        d[c[a]] = ((b ? e[a] : e));\n    ;\n    };\n;\n    return d;\n};\nfunction coalesce() {\n    for (var a = 0; ((a < arguments.length)); ++a) {\n        if (((arguments[a] != null))) {\n            return arguments[a];\n        }\n    ;\n    ;\n    };\n;\n    return null;\n};\n;\n!function() {\n    function a(b) {\n        return ((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11), function() {\n            if (((this === window))) {\n                throw new TypeError();\n            }\n        ;\n        ;\n            return b.apply(this, arguments);\n        }));\n    };\n;\n    copy_properties(Array.prototype, {\n        map: function(c, b) {\n            if (((((this === window)) || ((typeof c != \"function\"))))) {\n                throw new TypeError();\n            }\n        ;\n        ;\n            var d;\n            var e = this.length;\n            var f = new Array(e);\n            for (d = 0; ((d < e)); ++d) {\n                if (((d in this))) {\n                    f[d] = c.call(b, this[d], d, this);\n                }\n            ;\n            ;\n            };\n        ;\n            return f;\n        },\n        forEach: function(c, b) {\n            this.map(c, b);\n            return this;\n        },\n        filter: function(c, b) {\n            c = ((c || function(h) {\n                return h;\n            }));\n            if (((((this === window)) || ((typeof c != \"function\"))))) {\n                throw new TypeError();\n            }\n        ;\n        ;\n            var d, g, e = this.length, f = [];\n            for (d = 0; ((d < e)); ++d) {\n                if (((d in this))) {\n                    g = this[d];\n                    if (c.call(b, g, d, this)) {\n                        f.push(g);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n            return f;\n        },\n        every: function(d, c) {\n            var b = this.filter(function() {\n                return 1;\n            });\n            return ((this.filter(d, c).length == b.length));\n        },\n        some: function(c, b) {\n            return ((this.filter(c, b).length > 0));\n        },\n        reduce: null,\n        reduceRight: null,\n        sort: a(Array.prototype.sort),\n        reverse: a(Array.prototype.reverse),\n        concat: a(Array.prototype.concat),\n        slice: a(Array.prototype.slice),\n        indexOf: a(((Array.prototype.indexOf || function(d, b) {\n            var c = this.length;\n            b |= 0;\n            if (((b < 0))) {\n                b += c;\n            }\n        ;\n        ;\n            for (; ((b < c)); b++) {\n                if (((((b in this)) && ((this[b] === d))))) {\n                    return b;\n                }\n            ;\n            ;\n            };\n        ;\n            return -1;\n        }))),\n        contains: function(b) {\n            return ((this.indexOf(b) != -1));\n        },\n        remove: function(c) {\n            var b = this.indexOf(c);\n            if (((b != -1))) {\n                this.splice(b, 1);\n            }\n        ;\n        ;\n        }\n    });\n    Array.prototype.each = Array.prototype.forEach;\n    Array.prototype.clone = Array.prototype.slice;\n}();\nfunction muffinize(d) {\n    var c = \"a\";\n    var b = \"d\";\n    var a = [c,b,].join(\"\");\n    return d.replace(/muffin/g, a);\n};\n;\nif (((typeof JSBNG__console == \"undefined\"))) {\n    JSBNG__console = {\n        log: bagofholding,\n        info: bagofholding,\n        warn: bagofholding,\n        error: bagofholding\n    };\n}\n;\n;\nwindow.Util = JSBNG__console;\nwindow.JSBNG__onloadRegister = function(a) {\n    ((window.loaded ? _runHook(a) : _addHook(\"JSBNG__onloadhooks\", a)));\n};\nfunction JSBNG__onafterloadRegister(a) {\n    ((window.afterloaded ? JSBNG__setTimeout(function() {\n        _runHook(a);\n    }, 0) : _addHook(\"JSBNG__onafterloadhooks\", a)));\n};\n;\nfunction _onloadHook() {\n    ((((!window.loaded && window.CavalryLogger)) && CavalryLogger.getInstance().setTimeStamp(\"t_prehooks\")));\n    _runHooks(\"JSBNG__onloadhooks\");\n    ((((!window.loaded && window.CavalryLogger)) && CavalryLogger.getInstance().setTimeStamp(\"t_hooks\")));\n    window.loaded = true;\n    Arbiter.inform(\"uipage_onload\", true, Arbiter.BEHAVIOR_STATE);\n};\n;\nfunction _onafterloadHook() {\n    _runHooks(\"JSBNG__onafterloadhooks\");\n    window.afterloaded = true;\n};\n;\nfunction _runHook(b) {\n    try {\n        return b();\n    } catch (a) {\n    \n    };\n;\n};\n;\nfunction _runHooks(b) {\n    var d = ((((b == \"JSBNG__onbeforeleavehooks\")) || ((b == \"JSBNG__onbeforeunloadhooks\"))));\n    var e = null;\n    do {\n        var a = window[b];\n        if (!d) {\n            window[b] = null;\n        }\n    ;\n    ;\n        if (!a) {\n            break;\n        }\n    ;\n    ;\n        for (var c = 0; ((c < a.length)); c++) {\n            if (d) {\n                e = ((e || _runHook(a[c])));\n            }\n             else _runHook(a[c]);\n        ;\n        ;\n        };\n    ;\n        if (d) {\n            break;\n        }\n    ;\n    ;\n    } while (window[b]);\n    if (((d && e))) {\n        return e;\n    }\n;\n;\n};\n;\nfunction keep_window_set_as_loaded() {\n    if (((window.loaded == false))) {\n        window.loaded = true;\n        _runHooks(\"JSBNG__onloadhooks\");\n    }\n;\n;\n    if (((window.afterloaded == false))) {\n        window.afterloaded = true;\n        _runHooks(\"JSBNG__onafterloadhooks\");\n    }\n;\n;\n};\n;\nArbiter.registerCallback(_onloadHook, [OnloadEvent.ONLOAD_DOMCONTENT_CALLBACK,InitialJSLoader.INITIAL_JS_READY,]);\nArbiter.registerCallback(_onafterloadHook, [OnloadEvent.ONLOAD_DOMCONTENT_CALLBACK,OnloadEvent.ONLOAD_CALLBACK,InitialJSLoader.INITIAL_JS_READY,]);\nArbiter.subscribe(OnloadEvent.ONBEFOREUNLOAD, function(b, a) {\n    a.warn = ((_runHooks(\"JSBNG__onbeforeleavehooks\") || _runHooks(\"JSBNG__onbeforeunloadhooks\")));\n    if (!a.warn) {\n        window.loaded = false;\n        window.afterloaded = false;\n    }\n;\n;\n}, Arbiter.SUBSCRIBE_NEW);\nArbiter.subscribe(OnloadEvent.ONUNLOAD, function(b, a) {\n    _runHooks(\"JSBNG__onunloadhooks\");\n}, Arbiter.SUBSCRIBE_NEW);\nvoid (0);\nfunction AsyncSignal(b, a) {\n    this.data = ((a || {\n    }));\n    if (((((window.Env && Env.tracking_domain)) && ((b.charAt(0) == \"/\"))))) {\n        b = ((Env.tracking_domain + b));\n    }\n;\n;\n    this.uri = b;\n    this.handler = null;\n};\n;\nAsyncSignal.prototype.setHandler = function(a) {\n    this.handler = a;\n    return this;\n};\nAsyncSignal.prototype.send = function() {\n    var c = this.handler, b = this.data, g = this.uri, f = [], d = new JSBNG__Image(), a = JSBNG__document.getElementById(\"post_form_id\");\n    b.asyncSignal = ((Math.floor(((Math.JSBNG__random() * 10000))) + 1));\n    if (a) {\n        b.post_form_id = a.value;\n    }\n;\n;\n    if (window.Env) {\n        b.__user = Env.user;\n        if (Env.fb_isb) {\n            b.fb_isb = Env.fb_isb;\n        }\n    ;\n    ;\n    }\n;\n;\n    for (var e in b) {\n        f.push(((((encodeURIComponent(e) + \"=\")) + encodeURIComponent(b[e]))));\n    ;\n    };\n;\n    if (((g.indexOf(\"?\") == -1))) {\n        g += \"?\";\n    }\n;\n;\n    g += f.join(\"&\");\n    if (c) {\n        d.JSBNG__onload = d.JSBNG__onerror = (function(i, h) {\n            return function() {\n                h(((i.height == 1)));\n            };\n        })(d, c);\n    }\n;\n;\n    d.src = g;\n    return this;\n};\nfunction setCookie(a, b, d, e) {\n    if (((env_get(\"no_cookies\") && ((a != \"tpa\"))))) {\n        return;\n    }\n;\n;\n    if (d) {\n        var f = new JSBNG__Date();\n        var c = new JSBNG__Date();\n        c.setTime(((f.getTime() + d)));\n    }\n;\n;\n    JSBNG__document.cookie = ((((((((((((((((a + \"=\")) + encodeURIComponent(b))) + \"; \")) + ((d ? ((((\"expires=\" + c.toGMTString())) + \"; \")) : \"\")))) + \"path=\")) + ((e || \"/\")))) + \"; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n};\n;\nfunction clearCookie(a) {\n    JSBNG__document.cookie = ((((((a + \"=; expires=Sat, 01 Jan 2000 00:00:00 GMT; \")) + \"path=/; domain=\")) + window.JSBNG__location.hostname.replace(/^.*(\\.facebook\\..*)$/i, \"$1\")));\n};\n;\nfunction getCookie(d) {\n    var e = ((d + \"=\"));\n    var b = JSBNG__document.cookie.split(\";\");\n    for (var c = 0; ((c < b.length)); c++) {\n        var a = b[c];\n        while (((a.charAt(0) == \" \"))) {\n            a = a.substring(1, a.length);\n        ;\n        };\n    ;\n        if (((a.indexOf(e) == 0))) {\n            return decodeURIComponent(a.substring(e.length, a.length));\n        }\n    ;\n    ;\n    };\n;\n    return null;\n};\n;\nfunction HTML(a) {\n    if (((a && a.__html))) {\n        a = a.__html;\n    }\n;\n;\n    if (!((this instanceof HTML))) {\n        if (((a instanceof HTML))) {\n            return a;\n        }\n    ;\n    ;\n        return new HTML(a);\n    }\n;\n;\n    this._content = a;\n    this._defer = false;\n    this._extra_action = \"\";\n    this._nodes = null;\n    this._inline_js = bagofholding;\n    this._ie_clone_bug = false;\n    return this;\n};\n;\nHTML.isHTML = function(a) {\n    return ((a && ((((a instanceof HTML)) || ((a.__html !== undefined))))));\n};\nHTML.replaceJSONWrapper = function(a) {\n    return ((((a && ((a.__html !== undefined)))) ? new HTML(a.__html) : a));\n};\ncopy_properties(HTML.prototype, {\n    toString: function() {\n        var a = ((this._content || \"\"));\n        if (this._extra_action) {\n            a += ((((((\"\\u003Cscript type=\\\"text/javascript\\\"\\u003E\" + this._extra_action)) + \"\\u003C/scr\")) + \"ipt\\u003E\"));\n        }\n    ;\n    ;\n        return a;\n    },\n    setAction: function(a) {\n        this._extra_action = a;\n        return this;\n    },\n    getAction: function() {\n        this._fillCache();\n        var a = function() {\n            this._inline_js();\n            eval_global(this._extra_action);\n        }.bind(this);\n        if (this.getDeferred()) {\n            return a.defer.bind(a);\n        }\n         else return a\n    ;\n    },\n    setDeferred: function(a) {\n        this._defer = !!a;\n        return this;\n    },\n    getDeferred: function() {\n        return this._defer;\n    },\n    getContent: function() {\n        return this._content;\n    },\n    getNodes: function() {\n        this._fillCache();\n        return this._nodes;\n    },\n    getRootNode: function() {\n        return this.getNodes()[0];\n    },\n    ieCloneBug: function() {\n        this._fillCache();\n        return this._ie_clone_bug;\n    },\n    _fillCache: function() {\n        if (((null !== this._nodes))) {\n            return;\n        }\n    ;\n    ;\n        var d = this._content;\n        if (!d) {\n            this._nodes = [];\n            return;\n        }\n    ;\n    ;\n        d = d.replace(/(<(\\w+)[^>]*?)\\/>/g, function(l, m, n) {\n            return ((n.match(/^(abbr|br|col|img|input|link|meta|param|hr|area|embed)$/i) ? l : ((((((m + \"\\u003E\\u003C/\")) + n)) + \"\\u003E\"))));\n        });\n        var h = d.trim().toLowerCase(), k = JSBNG__document.createElement(\"div\"), b = false;\n        var j = ((((((((((((((!h.indexOf(\"\\u003Copt\") && [1,\"\\u003Cselect multiple=\\\"multiple\\\" class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/select\\u003E\",])) || ((!h.indexOf(\"\\u003Cleg\") && [1,\"\\u003Cfieldset class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/fieldset\\u003E\",])))) || ((h.match(/^<(thead|tbody|tfoot|colg|cap)/) && [1,\"\\u003Ctable class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/table\\u003E\",])))) || ((!h.indexOf(\"\\u003Ctr\") && [2,\"\\u003Ctable\\u003E\\u003Ctbody class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/tbody\\u003E\\u003C/table\\u003E\",])))) || ((((!h.indexOf(\"\\u003Ctd\") || !h.indexOf(\"\\u003Cth\"))) && [3,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003Ctr class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/tr\\u003E\\u003C/tbody\\u003E\\u003C/table\\u003E\",])))) || ((!h.indexOf(\"\\u003Ccol\") && [2,\"\\u003Ctable\\u003E\\u003Ctbody\\u003E\\u003C/tbody\\u003E\\u003Ccolgroup class=\\\"__WRAPPER\\\"\\u003E\",\"\\u003C/colgroup\\u003E\\u003C/table\\u003E\",])))) || null));\n        if (((null === j))) {\n            k.className = \"__WRAPPER\";\n            if (ua.ie()) {\n                j = [0,\"\\u003Cspan style=\\\"display:none\\\"\\u003E&nbsp;\\u003C/span\\u003E\",\"\",];\n                b = true;\n            }\n             else j = [0,\"\",\"\",];\n        ;\n        ;\n        }\n    ;\n    ;\n        k.innerHTML = ((((j[1] + d)) + j[2]));\n        while (j[0]--) {\n            k = k.lastChild;\n        ;\n        };\n    ;\n        if (b) {\n            k.removeChild(k.firstChild);\n        }\n    ;\n    ;\n        ((k.className != \"__WRAPPER\"));\n        if (((((0 !== k.getElementsByTagName(\"option\").length)) || ((0 !== k.getElementsByTagName(\"object\").length))))) {\n            this._ie_clone_bug = true;\n        }\n    ;\n    ;\n        if (ua.ie()) {\n            var i;\n            if (((!h.indexOf(\"\\u003Ctable\") && ((-1 == h.indexOf(\"\\u003Ctbody\")))))) {\n                i = ((k.firstChild && k.firstChild.childNodes));\n            }\n             else if (((((j[1] == \"\\u003Ctable\\u003E\")) && ((-1 == h.indexOf(\"\\u003Ctbody\")))))) {\n                i = k.childNodes;\n            }\n             else i = [];\n            \n        ;\n        ;\n            for (var f = ((i.length - 1)); ((f >= 0)); --f) {\n                if (((((i[f].nodeName && ((i[f].nodeName.toLowerCase() == \"tbody\")))) && ((i[f].childNodes.length == 0))))) {\n                    i[f].parentNode.removeChild(i[f]);\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        var g = k.getElementsByTagName(\"script\");\n        var a = [];\n        for (var e = 0; ((e < g.length)); e++) {\n            if (g[e].src) {\n                a.push(Bootloader.requestResource.bind(Bootloader, \"js\", g[e].src));\n            }\n             else a.push(eval_global.bind(null, g[e].innerHTML));\n        ;\n        ;\n        };\n    ;\n        for (var e = ((g.length - 1)); ((e >= 0)); e--) {\n            g[e].parentNode.removeChild(g[e]);\n        ;\n        };\n    ;\n        var c = function() {\n            for (var l = 0; ((l < a.length)); l++) {\n                a[l]();\n            ;\n            };\n        ;\n        };\n        this._nodes = $A(k.childNodes);\n        this._inline_js = c;\n    }\n});\nvar DOM = {\n    JSBNG__find: function(a, c) {\n        var b = DOM.scry(a, c);\n        return b[0];\n    },\n    scry: function(j, v) {\n        if (!j) {\n            return [];\n        }\n    ;\n    ;\n        var w = v.split(\" \");\n        var d = [j,];\n        var i = ((j === JSBNG__document));\n        for (var m = 0; ((m < w.length)); m++) {\n            if (((d.length == 0))) {\n                break;\n            }\n        ;\n        ;\n            if (((w[m] == \"\"))) {\n                continue;\n            }\n        ;\n        ;\n            var u = w[m];\n            var s = [];\n            var zd = false;\n            if (((u.charAt(0) == \"^\"))) {\n                if (((m == 0))) {\n                    zd = true;\n                    u = u.slice(1);\n                }\n                 else return []\n            ;\n            }\n        ;\n        ;\n            u = u.replace(/\\./g, \" .\");\n            u = u.replace(/\\#/g, \" #\");\n            u = u.replace(/\\[/g, \" [\");\n            var z = u.split(\" \");\n            var za = ((z[0] || \"*\"));\n            var n = ((z[1] && ((z[1].charAt(0) == \"#\"))));\n            if (n) {\n                var h = ge(z[1].slice(1), true);\n                if (((h && ((((\"*\" == za)) || ((h.tagName.toLowerCase() == za))))))) {\n                    for (var q = 0; ((q < d.length)); q++) {\n                        if (((zd && DOM.contains(h, d[q])))) {\n                            s = [h,];\n                            break;\n                        }\n                         else if (((((JSBNG__document == d[q])) || DOM.contains(d[q], h)))) {\n                            s = [h,];\n                            break;\n                        }\n                        \n                    ;\n                    ;\n                    };\n                }\n            ;\n            ;\n            }\n             else {\n                var zc = [];\n                var c = d.length;\n                for (var o = 0; ((o < c)); o++) {\n                    if (zd) {\n                        var k = [];\n                        var g = d[o].parentNode;\n                        var a = ((za == \"*\"));\n                        while (DOM.isNode(g, DOM.NODE_TYPES.ELEMENT)) {\n                            if (((a || ((g.tagName.toLowerCase() == za))))) {\n                                k.push(g);\n                            }\n                        ;\n                        ;\n                            g = g.parentNode;\n                        };\n                    ;\n                    }\n                     else var k = d[o].getElementsByTagName(za)\n                ;\n                    var l = k.length;\n                    for (var r = 0; ((r < l)); r++) {\n                        zc.push(k[r]);\n                    ;\n                    };\n                ;\n                };\n            ;\n                for (var x = 1; ((x < z.length)); x++) {\n                    var y = z[x];\n                    var p = ((y.charAt(0) == \".\"));\n                    var e = y.substring(1);\n                    for (var o = 0; ((o < zc.length)); o++) {\n                        var zb = zc[o];\n                        if (!zb) {\n                            continue;\n                        }\n                    ;\n                    ;\n                        if (p) {\n                            if (!CSS.hasClass(zb, e)) {\n                                delete zc[o];\n                            }\n                        ;\n                        ;\n                            continue;\n                        }\n                         else {\n                            var f = y.slice(1, ((y.length - 1)));\n                            if (((f.indexOf(\"=\") == -1))) {\n                                if (((zb.getAttribute(f) === null))) {\n                                    delete zc[o];\n                                    continue;\n                                }\n                            ;\n                            ;\n                            }\n                             else {\n                                var t = f.split(\"=\");\n                                var b = t[0];\n                                var ze = t[1];\n                                ze = ze.slice(1, ((ze.length - 1)));\n                                if (((zb.getAttribute(b) != ze))) {\n                                    delete zc[o];\n                                    continue;\n                                }\n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                };\n            ;\n                for (var o = 0; ((o < zc.length)); o++) {\n                    if (zc[o]) {\n                        s.push(zc[o]);\n                        if (zd) {\n                            break;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            d = s;\n        };\n    ;\n        return d;\n    },\n    getText: (function() {\n        var a = JSBNG__document.createElement(\"div\"), b = ((((a.textContent != null)) ? \"textContent\" : \"innerText\"));\n        return function(c) {\n            if (!c) {\n                return \"\";\n            }\n             else if (DOM.isNode(c, DOM.NODE_TYPES.TEXT)) {\n                return c.data;\n            }\n             else return c[b]\n            \n        ;\n        };\n    })(),\n    JSBNG__getSelection: function() {\n        var b = window.JSBNG__getSelection, a = JSBNG__document.selection;\n        if (b) {\n            return ((b() + \"\"));\n        }\n         else if (a) {\n            return a.createRange().text;\n        }\n        \n    ;\n    ;\n        return null;\n    },\n    create: function(c, a, b) {\n        c = JSBNG__document.createElement(c);\n        if (a) {\n            a = copy_properties({\n            }, a);\n            if (a.style) {\n                copy_properties(c.style, a.style);\n                delete a.style;\n            }\n        ;\n        ;\n            for (var d in a) {\n                if (((d.toLowerCase().indexOf(\"JSBNG__on\") == 0))) {\n                    if (!((typeof a[d] != \"function\"))) {\n                        if (((window.JSBNG__Event && JSBNG__Event.listen))) {\n                            JSBNG__Event.listen(c, d.substr(2), a[d]);\n                        }\n                         else c[d] = a[d];\n                    ;\n                    }\n                ;\n                ;\n                    delete a[d];\n                }\n            ;\n            ;\n            };\n        ;\n            copy_properties(c, a);\n        }\n    ;\n    ;\n        if (((b != undefined))) {\n            DOM.setContent(c, b);\n        }\n    ;\n    ;\n        return c;\n    },\n    prependContent: function(c, b) {\n        if (!DOM.isNode(c)) {\n            throw new Error(\"DOM.prependContent: reference element is not a node\");\n        }\n    ;\n    ;\n        var a = function(d) {\n            if (c.firstChild) {\n                c.insertBefore(d, c.firstChild);\n            }\n             else c.appendChild(d);\n        ;\n        ;\n        };\n        return DOM._addContent(b, a, c);\n    },\n    insertAfter: function(c, b) {\n        if (((!DOM.isNode(c) || !c.parentNode))) {\n            throw new Error(\"DOM.insertAfter: reference element is not a node\");\n        }\n    ;\n    ;\n        var a = function(d) {\n            if (c.nextSibling) {\n                c.parentNode.insertBefore(d, c.nextSibling);\n            }\n             else c.parentNode.appendChild(d);\n        ;\n        ;\n        };\n        return DOM._addContent(b, a, c.parentNode);\n    },\n    insertBefore: function(b, c) {\n        if (((!DOM.isNode(c) || !c.parentNode))) {\n            throw new Error(((\"DOM.insertBefore: reference element is not a node or \" + \"does not have a parent.\")));\n        }\n    ;\n    ;\n        var a = function(d) {\n            c.parentNode.insertBefore(d, c);\n        };\n        return DOM._addContent(b, a, c.parentNode);\n    },\n    setContent: function(b, a) {\n        if (!DOM.isNode(b)) {\n            throw new Error(\"DOM.setContent: reference element is not a node\");\n        }\n    ;\n    ;\n        DOM.empty(b);\n        return DOM.appendContent(b, a);\n    },\n    appendContent: function(c, b) {\n        if (!DOM.isNode(c)) {\n            throw new Error(\"DOM.appendContent: reference element is not a node\");\n        }\n    ;\n    ;\n        var a = function(d) {\n            c.appendChild(d);\n        };\n        return DOM._addContent(b, a, c);\n    },\n    replace: function(c, b) {\n        if (((!DOM.isNode(c) || !c.parentNode))) {\n            throw new Error(((\"DOM.replace: reference element must be a node with a\" + \" parent\")));\n        }\n    ;\n    ;\n        var a = function(d) {\n            c.parentNode.replaceChild(d, c);\n        };\n        return DOM._addContent(b, a, c.parentNode);\n    },\n    remove: function(a) {\n        a = $(a);\n        if (a.parentNode) {\n            a.parentNode.removeChild(a);\n        }\n    ;\n    ;\n    },\n    empty: function(a) {\n        a = $(a);\n        while (a.firstChild) {\n            DOM.remove(a.firstChild);\n        ;\n        };\n    ;\n    },\n    contains: function(b, a) {\n        b = ge(b);\n        a = ge(a);\n        if (((!b || !a))) {\n            return false;\n        }\n         else if (((b === a))) {\n            return true;\n        }\n         else if (DOM.isNode(b, \"#text\")) {\n            return false;\n        }\n         else if (DOM.isNode(a, \"#text\")) {\n            return DOM.contains(b, a.parentNode);\n        }\n         else if (b.contains) {\n            return b.contains(a);\n        }\n         else if (b.compareDocumentPosition) {\n            return !!((b.compareDocumentPosition(a) & 16));\n        }\n         else return false\n        \n        \n        \n        \n        \n    ;\n    },\n    getRootElement: function() {\n        var a = null;\n        if (((window.Quickling && Quickling.isActive()))) {\n            a = ge(\"JSBNG__content\");\n        }\n    ;\n    ;\n        return ((a || JSBNG__document.body));\n    },\n    isNode: function(d, e) {\n        if (((typeof (JSBNG__Node) == \"undefined\"))) {\n            JSBNG__Node = null;\n        }\n    ;\n    ;\n        try {\n            if (((!d || !((((((JSBNG__Node != undefined)) && ((d instanceof JSBNG__Node)))) || d.nodeName))))) {\n                return false;\n            }\n        ;\n        ;\n        } catch (a) {\n            return false;\n        };\n    ;\n        if (((typeof (e) !== \"undefined\"))) {\n            e = $A(e).map(function(g) {\n                return ((g + \"\")).toUpperCase();\n            });\n            var c, f;\n            try {\n                c = new String(d.nodeName).toUpperCase();\n                f = d.nodeType;\n            } catch (a) {\n                return false;\n            };\n        ;\n            for (var b = 0; ((b < e.length)); b++) {\n                try {\n                    if (((((c == e[b])) || ((f == e[b]))))) {\n                        return true;\n                    }\n                ;\n                ;\n                } catch (a) {\n                \n                };\n            ;\n            };\n        ;\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    NODE_TYPES: {\n        ELEMENT: 1,\n        ATTRIBUTE: 2,\n        TEXT: 3,\n        CDATA_SECTION: 4,\n        ENTITY_REFERENCE: 5,\n        ENTITY: 6,\n        PROCESSING_INSTRUCTION: 7,\n        COMMENT: 8,\n        DOCUMENT: 9,\n        DOCUMENT_TYPE: 10,\n        DOCUMENT_FRAGMENT: 11,\n        NOTATION_NODE: 12\n    },\n    _addContent: function(d, a, m) {\n        d = HTML.replaceJSONWrapper(d);\n        if (((((((d instanceof HTML)) && ((-1 == d.toString().indexOf(((\"\\u003Cscr\" + \"ipt\"))))))) && ((\"\" == m.innerHTML))))) {\n            var g = ua.ie();\n            if (((!g || ((((g > 7)) && !DOM.isNode(m, [\"table\",\"tbody\",\"thead\",\"tfoot\",\"tr\",\"select\",\"fieldset\",])))))) {\n                var h = ((g ? \"\\u003Cem style=\\\"display:none;\\\"\\u003E&nbsp;\\u003C/em\\u003E\" : \"\"));\n                m.innerHTML = ((h + d));\n                ((g && m.removeChild(m.firstChild)));\n                return $A(m.childNodes);\n            }\n        ;\n        ;\n        }\n         else if (DOM.isNode(m, DOM.NODE_TYPES.TEXT)) {\n            m.data = d;\n            return [d,];\n        }\n        \n    ;\n    ;\n        var j, e = [], b = [];\n        var f = JSBNG__document.createDocumentFragment();\n        if (!((d instanceof Array))) {\n            d = [d,];\n        }\n    ;\n    ;\n        for (var i = 0; ((i < d.length)); i++) {\n            j = HTML.replaceJSONWrapper(d[i]);\n            if (((j instanceof HTML))) {\n                b.push(j.getAction());\n                var l = j.getNodes(), c;\n                for (var k = 0; ((k < l.length)); k++) {\n                    c = ((((ua.safari() || ((ua.ie() && j.ieCloneBug())))) ? l[k] : l[k].cloneNode(true)));\n                    e.push(c);\n                    f.appendChild(c);\n                };\n            ;\n            }\n             else if (is_scalar(j)) {\n                var n = JSBNG__document.createTextNode(j);\n                e.push(n);\n                f.appendChild(n);\n            }\n             else if (DOM.isNode(j)) {\n                e.push(j);\n                f.appendChild(j);\n            }\n             else if (!((j instanceof Array))) {\n                ((j !== null));\n            }\n            \n            \n            \n        ;\n        ;\n        };\n    ;\n        a(f);\n        for (var i = 0; ((i < b.length)); i++) {\n            b[i]();\n        ;\n        };\n    ;\n        return e;\n    }\n};\nfunction $N(c, a, b) {\n    if (((((((((typeof a != \"object\")) || DOM.isNode(a))) || ((a instanceof Array)))) || HTML.isHTML(a)))) {\n        b = a;\n        a = null;\n    }\n;\n;\n    return DOM.create(c, a, b);\n};\n;\nfunction URI(a) {\n    if (((a === window))) {\n        return;\n    }\n;\n;\n    if (((this === window))) {\n        return new URI(((a || window.JSBNG__location.href)));\n    }\n;\n;\n    this.parse(((a || \"\")));\n};\n;\ncopy_properties(URI, {\n    getRequestURI: function(a, b) {\n        a = ((((a === undefined)) || a));\n        if (((((a && window.PageTransitions)) && PageTransitions.isInitialized()))) {\n            return PageTransitions.getCurrentURI(!!b).getQualifiedURI();\n        }\n         else return new URI(window.JSBNG__location.href)\n    ;\n    },\n    getMostRecentURI: function() {\n        if (((window.PageTransitions && PageTransitions.isInitialized()))) {\n            return PageTransitions.getMostRecentURI().getQualifiedURI();\n        }\n         else return new URI(window.JSBNG__location.href)\n    ;\n    },\n    getNextURI: function() {\n        if (((window.PageTransitions && PageTransitions.isInitialized()))) {\n            return PageTransitions.getNextURI().getQualifiedURI();\n        }\n         else return new URI(window.JSBNG__location.href)\n    ;\n    },\n    expression: /(((\\w+):\\/\\/)([^\\/:]*)(:(\\d+))?)?([^#?]*)(\\?([^#]*))?(#(.*))?/,\n    arrayQueryExpression: /^(\\w+)((?:\\[\\w*\\])+)=?(.*)/,\n    explodeQuery: function(g) {\n        if (!g) {\n            return {\n            };\n        }\n    ;\n    ;\n        var h = {\n        };\n        g = g.replace(/%5B/gi, \"[\").replace(/%5D/gi, \"]\");\n        g = g.split(\"&\");\n        for (var b = 0, d = g.length; ((b < d)); b++) {\n            var e = g[b].match(URI.arrayQueryExpression);\n            if (!e) {\n                var j = g[b].split(\"=\");\n                h[URI.decodeComponent(j[0])] = ((((j[1] === undefined)) ? null : URI.decodeComponent(j[1])));\n            }\n             else {\n                var c = e[2].split(/\\]\\[|\\[|\\]/).slice(0, -1);\n                var f = e[1];\n                var k = URI.decodeComponent(((e[3] || \"\")));\n                c[0] = f;\n                var i = h;\n                for (var a = 0; ((a < ((c.length - 1)))); a++) {\n                    if (c[a]) {\n                        if (((i[c[a]] === undefined))) {\n                            if (((c[((a + 1))] && !c[((a + 1))].match(/\\d+$/)))) {\n                                i[c[a]] = {\n                                };\n                            }\n                             else i[c[a]] = [];\n                        ;\n                        }\n                    ;\n                    ;\n                        i = i[c[a]];\n                    }\n                     else {\n                        if (((c[((a + 1))] && !c[((a + 1))].match(/\\d+$/)))) {\n                            i.push({\n                            });\n                        }\n                         else i.push([]);\n                    ;\n                    ;\n                        i = i[((i.length - 1))];\n                    }\n                ;\n                ;\n                };\n            ;\n                if (((((i instanceof Array)) && ((c[((c.length - 1))] == \"\"))))) {\n                    i.push(k);\n                }\n                 else i[c[((c.length - 1))]] = k;\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return h;\n    },\n    implodeQuery: function(f, e, a) {\n        e = ((e || \"\"));\n        if (((a === undefined))) {\n            a = true;\n        }\n    ;\n    ;\n        var g = [];\n        if (((((f === null)) || ((f === undefined))))) {\n            g.push(((a ? URI.encodeComponent(e) : e)));\n        }\n         else if (((f instanceof Array))) {\n            for (var c = 0; ((c < f.length)); ++c) {\n                try {\n                    if (((f[c] !== undefined))) {\n                        g.push(URI.implodeQuery(f[c], ((e ? ((((((e + \"[\")) + c)) + \"]\")) : c))));\n                    }\n                ;\n                ;\n                } catch (b) {\n                \n                };\n            ;\n            };\n        ;\n        }\n         else if (((typeof (f) == \"object\"))) {\n            if (DOM.isNode(f)) {\n                g.push(\"{node}\");\n            }\n             else for (var d in f) {\n                try {\n                    if (((f[d] !== undefined))) {\n                        g.push(URI.implodeQuery(f[d], ((e ? ((((((e + \"[\")) + d)) + \"]\")) : d))));\n                    }\n                ;\n                ;\n                } catch (b) {\n                \n                };\n            ;\n            }\n        ;\n        ;\n        }\n         else if (a) {\n            g.push(((((URI.encodeComponent(e) + \"=\")) + URI.encodeComponent(f))));\n        }\n         else g.push(((((e + \"=\")) + f)));\n        \n        \n        \n    ;\n    ;\n        return g.join(\"&\");\n    },\n    encodeComponent: function(d) {\n        var c = String(d).split(/([\\[\\]])/);\n        for (var a = 0, b = c.length; ((a < b)); a += 2) {\n            c[a] = window.encodeURIComponent(c[a]);\n        ;\n        };\n    ;\n        return c.join(\"\");\n    },\n    decodeComponent: function(a) {\n        return window.decodeURIComponent(a.replace(/\\+/g, \" \"));\n    },\n    INVALID_DOMAIN: \"invalid.invalid\",\n    sanitizeDomain: function(a) {\n        var b = new RegExp(((((\"[\\\\x00-\\\\x2c\\\\x2f\\\\x3b-\\\\x40\\\\x5c\\\\x5e\\\\x60\\\\x7b-\\\\x7f\" + \"\\\\uFDD0-\\\\uFDEF\\\\uFFF0-\\\\uFFFF\")) + \"\\\\u2047\\\\u2048\\\\uFE56\\\\uFE5F\\\\uFF03\\\\uFF0F\\\\uFF1F]\")));\n        if (b.test(a)) {\n            return URI.INVALID_DOMAIN;\n        }\n         else return a\n    ;\n    }\n});\ncopy_properties(URI.prototype, {\n    parse: function(b) {\n        var a = b.toString().match(URI.expression);\n        copy_properties(this, {\n            protocol: ((a[3] || \"\")),\n            domain: URI.sanitizeDomain(((a[4] || \"\"))),\n            port: ((a[6] || \"\")),\n            path: ((a[7] || \"\")),\n            query_s: ((a[9] || \"\")),\n            fragment: ((a[11] || \"\"))\n        });\n        return this;\n    },\n    setProtocol: function(a) {\n        this.protocol = a;\n        return this;\n    },\n    getProtocol: function() {\n        return this.protocol;\n    },\n    setQueryData: function(a) {\n        this.query_s = URI.implodeQuery(a);\n        return this;\n    },\n    addQueryData: function(a) {\n        return this.setQueryData(copy_properties(this.getQueryData(), a));\n    },\n    removeQueryData: function(b) {\n        if (!((b instanceof Array))) {\n            b = [b,];\n        }\n    ;\n    ;\n        var d = this.getQueryData();\n        for (var a = 0, c = b.length; ((a < c)); ++a) {\n            delete d[b[a]];\n        ;\n        };\n    ;\n        return this.setQueryData(d);\n    },\n    getQueryData: function() {\n        return URI.explodeQuery(this.query_s);\n    },\n    setFragment: function(a) {\n        this.fragment = a;\n        return this;\n    },\n    getFragment: function() {\n        return this.fragment;\n    },\n    setDomain: function(a) {\n        this.domain = URI.sanitizeDomain(a);\n        return this;\n    },\n    getDomain: function() {\n        return this.domain;\n    },\n    setPort: function(a) {\n        this.port = a;\n        return this;\n    },\n    getPort: function() {\n        return this.port;\n    },\n    setPath: function(a) {\n        this.path = a;\n        return this;\n    },\n    getPath: function() {\n        return this.path.replace(/^\\/+/, \"/\");\n    },\n    isEmpty: function() {\n        return !((((((((((this.path || this.protocol)) || this.domain)) || this.port)) || this.query_s)) || this.fragment));\n    },\n    toString: function() {\n        var a = \"\";\n        ((this.protocol && (a += ((this.protocol + \"://\")))));\n        ((this.domain && (a += this.domain)));\n        ((this.port && (a += ((\":\" + this.port)))));\n        if (((this.domain && !this.path))) {\n            a += \"/\";\n        }\n    ;\n    ;\n        ((this.path && (a += this.path)));\n        ((this.query_s && (a += ((\"?\" + this.query_s)))));\n        ((this.fragment && (a += ((\"#\" + this.fragment)))));\n        return a;\n    },\n    valueOf: function() {\n        return this.toString();\n    },\n    isFacebookURI: function() {\n        if (!URI._facebookURIRegex) {\n            URI._facebookURIRegex = new RegExp(\"(^|\\\\.)facebook\\\\.com([^.]*)$\", \"i\");\n        }\n    ;\n    ;\n        return ((!this.domain || URI._facebookURIRegex.test(this.domain)));\n    },\n    isQuicklingEnabled: function() {\n        return ((((window.Quickling && Quickling.isActive())) && Quickling.isPageActive(this)));\n    },\n    getRegisteredDomain: function() {\n        if (!this.domain) {\n            return \"\";\n        }\n    ;\n    ;\n        if (!this.isFacebookURI()) {\n            return null;\n        }\n    ;\n    ;\n        var b = this.domain.split(\".\");\n        var a = b.indexOf(\"facebook\");\n        return b.slice(a).join(\".\");\n    },\n    getUnqualifiedURI: function() {\n        return new URI(this).setProtocol(null).setDomain(null).setPort(null);\n    },\n    getQualifiedURI: function() {\n        var b = new URI(this);\n        if (!b.getDomain()) {\n            var a = URI();\n            b.setProtocol(a.getProtocol()).setDomain(a.getDomain()).setPort(a.getPort());\n        }\n    ;\n    ;\n        return b;\n    },\n    isSameOrigin: function(a) {\n        var b = ((a || window.JSBNG__location.href));\n        if (!((b instanceof URI))) {\n            b = new URI(b.toString());\n        }\n    ;\n    ;\n        if (((this.getProtocol() && ((this.getProtocol() != b.getProtocol()))))) {\n            return false;\n        }\n    ;\n    ;\n        if (((this.getDomain() && ((this.getDomain() != b.getDomain()))))) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    go: function(a) {\n        goURI(this, a);\n    },\n    setSubdomain: function(b) {\n        var c = new URI(this).getQualifiedURI();\n        var a = c.getDomain().split(\".\");\n        if (((a.length <= 2))) {\n            a.unshift(b);\n        }\n         else a[0] = b;\n    ;\n    ;\n        return c.setDomain(a.join(\".\"));\n    },\n    getSubdomain: function() {\n        if (!this.getDomain()) {\n            return \"\";\n        }\n    ;\n    ;\n        var a = this.getDomain().split(\".\");\n        if (((a.length <= 2))) {\n            return \"\";\n        }\n         else return a[0]\n    ;\n    },\n    setSecure: function(a) {\n        return this.setProtocol(((a ? \"https\" : \"http\")));\n    },\n    isSecure: function() {\n        return ((this.getProtocol() == \"https\"));\n    }\n});\nfunction detect_broken_proxy_cache(d, a) {\n    var b = getCookie(a);\n    if (((((((b != d)) && ((b != null)))) && ((d != \"0\"))))) {\n        var c = {\n            c: \"si_detect_broken_proxy_cache\",\n            m: ((((((((a + \" \")) + d)) + \" \")) + b))\n        };\n        var e = new URI(\"/common/scribe_endpoint.php\").getQualifiedURI().toString();\n        new AsyncSignal(e, c).send();\n    }\n;\n;\n};\n;\nString.prototype.trim = function() {\n    if (((this == window))) {\n        return null;\n    }\n;\n;\n    return this.replace(/^\\s*|\\s*$/g, \"\");\n};\nfunction trim(b) {\n    try {\n        return String(b.toString()).trim();\n    } catch (a) {\n        return \"\";\n    };\n;\n};\n;\nString.prototype.startsWith = function(a) {\n    if (((this == window))) {\n        return null;\n    }\n;\n;\n    return ((this.substring(0, a.length) == a));\n};\nString.prototype.endsWith = function(a) {\n    if (((this == window))) {\n        return null;\n    }\n;\n;\n    return ((((this.length >= a.length)) && ((this.substring(((this.length - a.length))) == a))));\n};\nString.prototype.hash32 = function() {\n    var a = 2166136261;\n    for (var b = 0, c = this.length; ((b < c)); ++b) {\n        a = ((((a ^ this.charCodeAt(b))) * 16777619));\n    ;\n    };\n;\n    a += ((a << 13));\n    a ^= ((a >> 7));\n    a += ((a << 3));\n    a ^= ((a >> 17));\n    a += ((a << 5));\n    return ((((a | 0)) + 2147483648));\n};\nString.prototype.split = (function(a) {\n    return function(h, e) {\n        var b = \"\";\n        if (((((h === null)) || ((e === null))))) {\n            return [];\n        }\n         else if (((typeof h == \"string\"))) {\n            return a.call(this, h, e);\n        }\n         else if (((h === undefined))) {\n            return [this.toString(),];\n        }\n         else if (((h instanceof RegExp))) {\n            if (((!h._2 || !h._1))) {\n                b = h.toString().replace(/^[\\S\\s]+\\//, \"\");\n                if (!h._1) {\n                    if (!h.global) {\n                        h._1 = new RegExp(h.source, ((\"g\" + b)));\n                    }\n                     else h._1 = 1;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            separator1 = ((((h._1 === 1)) ? h : h._1));\n            var i = ((h._2 ? h._2 : h._2 = new RegExp(((((\"^\" + separator1.source)) + \"$\")), b)));\n            if (((((e === undefined)) || ((e < 0))))) {\n                e = false;\n            }\n             else {\n                e = Math.floor(e);\n                if (!e) {\n                    return [];\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var f, g = [], d = 0, c = 0;\n            while (((((e ? ((c++ <= e)) : true)) && (f = separator1.exec(this))))) {\n                if (((((f[0].length === 0)) && ((separator1.lastIndex > f.index))))) {\n                    separator1.lastIndex--;\n                }\n            ;\n            ;\n                if (((separator1.lastIndex > d))) {\n                    if (((f.length > 1))) {\n                        f[0].replace(i, function() {\n                            for (var j = 1; ((j < ((arguments.length - 2)))); j++) {\n                                if (((arguments[j] === undefined))) {\n                                    f[j] = undefined;\n                                }\n                            ;\n                            ;\n                            };\n                        ;\n                        });\n                    }\n                ;\n                ;\n                    g = g.concat(this.substring(d, f.index), ((((f.index === this.length)) ? [] : f.slice(1))));\n                    d = separator1.lastIndex;\n                }\n            ;\n            ;\n                if (((f[0].length === 0))) {\n                    separator1.lastIndex++;\n                }\n            ;\n            ;\n            };\n        ;\n            return ((((d === this.length)) ? ((separator1.test(\"\") ? g : g.concat(\"\"))) : ((e ? g : g.concat(this.substring(d))))));\n        }\n         else return a.call(this, h, e)\n        \n        \n        \n    ;\n    };\n})(String.prototype.split);\nadd_properties(\"CSS\", {\n    shown: function(a) {\n        return !CSS.hasClass(a, \"hidden_elem\");\n    },\n    toggle: function(a) {\n        CSS.conditionShow(a, !CSS.shown(a));\n    },\n    setClass: function(b, a) {\n        $(b).className = ((a || \"\"));\n        return b;\n    },\n    setStyle: function(a, b, c) {\n        switch (b) {\n          case \"opacity\":\n            a.style.opacity = c;\n            a.style.filter = ((((c !== \"\")) ? ((((\"alpha(opacity=\" + ((c * 100)))) + \")\")) : \"\"));\n            break;\n          case \"float\":\n            a.style.cssFloat = a.style.styleFloat = c;\n            break;\n          default:\n            b = b.replace(/-(.)/g, function(d, e) {\n                return e.toUpperCase();\n            });\n            a.style[b] = c;\n        };\n    ;\n        return a;\n    },\n    getStyle: function(b, d) {\n        b = $(b);\n        d = d.replace(/-(.)/g, function(e, f) {\n            return f.toUpperCase();\n        });\n        function c(e) {\n            return e.replace(/([A-Z])/g, \"-$1\").toLowerCase();\n        };\n    ;\n        if (window.JSBNG__getComputedStyle) {\n            var a = window.JSBNG__getComputedStyle(b, null);\n            if (a) {\n                return a.getPropertyValue(c(d));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((JSBNG__document.defaultView && JSBNG__document.defaultView.JSBNG__getComputedStyle))) {\n            var a = JSBNG__document.defaultView.JSBNG__getComputedStyle(b, null);\n            if (a) {\n                return a.getPropertyValue(c(d));\n            }\n        ;\n        ;\n            if (((d == \"display\"))) {\n                return \"none\";\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (b.currentStyle) {\n            return b.currentStyle[d];\n        }\n    ;\n    ;\n        return b.style[d];\n    },\n    getStyleFloat: function(a, b) {\n        return parseFloat(CSS.getStyle(a, b), 10);\n    },\n    getOpacity: function(a) {\n        a = $(a);\n        var b = CSS.getStyle(a, \"filter\");\n        var c = null;\n        if (((b && (c = /(\\d+(?:\\.\\d+)?)/.exec(b))))) {\n            return ((parseFloat(c.pop()) / 100));\n        }\n         else if (b = CSS.getStyle(a, \"opacity\")) {\n            return parseFloat(b);\n        }\n         else return 1\n        \n    ;\n    }\n});\nfunction intl_locale_is_rtl() {\n    return ((\"rtl\" == CSS.getStyle(JSBNG__document.body, \"direction\")));\n};\n;\nDataStore = ((window.DataStore || {\n    _storage: {\n    },\n    _elements: {\n    },\n    _tokenCounter: 1,\n    _NOT_IN_DOM_CONST: 1,\n    _getStorage: function(a) {\n        var b;\n        if (((typeof a == \"string\"))) {\n            b = ((\"str_\" + a));\n        }\n         else {\n            b = ((\"elem_\" + ((a.__FB_TOKEN || (a.__FB_TOKEN = [DataStore._tokenCounter++,])))[0]));\n            DataStore._elements[b] = a;\n        }\n    ;\n    ;\n        return ((DataStore._storage[b] || (DataStore._storage[b] = {\n        })));\n    },\n    _shouldDeleteData: function(a) {\n        if (!a.nodeName) {\n            return false;\n        }\n    ;\n    ;\n        try {\n            if (((null != a.offsetParent))) {\n                return false;\n            }\n        ;\n        ;\n        } catch (b) {\n        \n        };\n    ;\n        if (JSBNG__document.documentElement.contains) {\n            return !JSBNG__document.documentElement.contains(a);\n        }\n         else return ((JSBNG__document.documentElement.compareDocumentPosition(a) & DataStore._NOT_IN_DOM_CONST))\n    ;\n    },\n    set: function(c, b, d) {\n        var a = DataStore._getStorage(c);\n        a[b] = d;\n        return c;\n    },\n    get: function(e, d, c) {\n        var b = DataStore._getStorage(e), f = b[d];\n        if (((((typeof f === \"undefined\")) && e.getAttribute))) {\n            var a = e.getAttribute(((\"data-\" + d)));\n            f = ((((null === a)) ? undefined : a));\n        }\n    ;\n    ;\n        if (((((c !== undefined)) && ((f === undefined))))) {\n            f = b[d] = c;\n        }\n    ;\n    ;\n        return f;\n    },\n    remove: function(c, b) {\n        var a = DataStore._getStorage(c), d = a[b];\n        delete a[b];\n        return d;\n    },\n    cleanup: function() {\n        var b, a;\n        for (b in DataStore._elements) {\n            a = DataStore._elements[b];\n            if (DataStore._shouldDeleteData(a)) {\n                delete DataStore._storage[b];\n                delete DataStore._elements[b];\n            }\n        ;\n        ;\n        };\n    ;\n    }\n}));\nfunction DOMControl(a) {\n    this.root = $(a);\n    this.updating = false;\n    DataStore.set(a, \"DOMControl\", this);\n};\n;\nDOMControl.prototype = {\n    getRoot: function() {\n        return this.root;\n    },\n    beginUpdate: function() {\n        if (this.updating) {\n            return false;\n        }\n    ;\n    ;\n        this.updating = true;\n        return true;\n    },\n    endUpdate: function() {\n        this.updating = false;\n    },\n    update: function(a) {\n        if (!this.beginUpdate()) {\n            return this;\n        }\n    ;\n    ;\n        this.JSBNG__onupdate(a);\n        this.endUpdate();\n    },\n    JSBNG__onupdate: function(a) {\n    \n    }\n};\nDOMControl.getInstance = function(a) {\n    return DataStore.get(a, \"DOMControl\");\n};\nadd_properties(\"CSS\", {\n    supportsBorderRadius: function() {\n        var c = [\"KhtmlBorderRadius\",\"OBorderRadius\",\"MozBorderRadius\",\"WebkitBorderRadius\",\"msBorderRadius\",\"borderRadius\",];\n        var d = false, a = JSBNG__document.createElement(\"div\");\n        for (var b = c.length; ((b >= 0)); b--) {\n            if (d = ((a.style[c[b]] !== undefined))) {\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        CSS.supportsBorderRadius = bagof(d);\n        return d;\n    }\n});\nadd_properties(\"Input\", {\n    JSBNG__focus: function(a) {\n        try {\n            a.JSBNG__focus();\n        } catch (b) {\n        \n        };\n    ;\n    },\n    isEmpty: function(a) {\n        return ((!(/\\S/).test(((a.value || \"\"))) || CSS.hasClass(a, \"DOMControl_placeholder\")));\n    },\n    getValue: function(a) {\n        return ((Input.isEmpty(a) ? \"\" : a.value));\n    },\n    setValue: function(b, d) {\n        CSS.removeClass(b, \"DOMControl_placeholder\");\n        b.value = ((d || \"\"));\n        var c = b.getAttribute(\"maxlength\");\n        if (((c > 0))) {\n            Bootloader.loadComponents(\"maxlength-form-listener\", function() {\n                Input.enforceMaxLength(b, c);\n            });\n        }\n    ;\n    ;\n        var a = DOMControl.getInstance(b);\n        ((((a && a.resetHeight)) && a.resetHeight()));\n    },\n    setPlaceholder: function(a, b) {\n        a.setAttribute(\"title\", b);\n        a.setAttribute(\"placeholder\", b);\n        if (((a == JSBNG__document.activeElement))) {\n            return;\n        }\n    ;\n    ;\n        if (Input.isEmpty(a)) {\n            CSS.conditionClass(a, \"DOMControl_placeholder\", b);\n            a.value = ((b || \"\"));\n        }\n    ;\n    ;\n    },\n    reset: function(a) {\n        var b = ((((a !== JSBNG__document.activeElement)) ? ((a.getAttribute(\"placeholder\") || \"\")) : \"\"));\n        a.value = b;\n        CSS.conditionClass(a, \"DOMControl_placeholder\", b);\n        a.style.height = \"\";\n    },\n    setSubmitOnEnter: function(a, b) {\n        CSS.conditionClass(a, \"enter_submit\", b);\n    },\n    getSubmitOnEnter: function(a) {\n        return CSS.hasClass(a, \"enter_submit\");\n    }\n});\nJSBNG__Event.DATASTORE_KEY = \"Event.listeners\";\nif (!JSBNG__Event.prototype) {\n    JSBNG__Event.prototype = {\n    };\n}\n;\n;\nfunction $E(a) {\n    a = ((((a || window.JSBNG__event)) || {\n    }));\n    if (!a._inherits_from_prototype) {\n        for (var c in JSBNG__Event.prototype) {\n            try {\n                a[c] = JSBNG__Event.prototype[c];\n            } catch (b) {\n            \n            };\n        ;\n        };\n    }\n;\n;\n    return a;\n};\n;\n(function() {\n    copy_properties(JSBNG__Event.prototype, {\n        _inherits_from_prototype: true,\n        JSBNG__stop: function() {\n            this.cancelBubble = true;\n            ((this.stopPropagation && this.stopPropagation()));\n            return this;\n        },\n        prevent: function() {\n            this.returnValue = false;\n            ((this.preventDefault && this.preventDefault()));\n            return this;\n        },\n        kill: function() {\n            this.JSBNG__stop().prevent();\n            return false;\n        },\n        getTarget: function() {\n            var g = ((this.target || this.srcElement));\n            return ((g ? $(g) : null));\n        },\n        getRelatedTarget: function() {\n            var g = ((this.relatedTarget || ((((this.fromElement === this.srcElement)) ? this.toElement : this.fromElement))));\n            return ((g ? $(g) : null));\n        },\n        getModifiers: function() {\n            var g = {\n                control: !!this.ctrlKey,\n                shift: !!this.shiftKey,\n                alt: !!this.altKey,\n                meta: !!this.metaKey\n            };\n            g.access = ((ua.osx() ? g.control : g.alt));\n            g.any = ((((((g.control || g.shift)) || g.alt)) || g.meta));\n            return g;\n        }\n    });\n    copy_properties(JSBNG__Event, {\n        listen: function(h, q, j, n) {\n            if (((typeof h == \"string\"))) {\n                h = $(h);\n            }\n        ;\n        ;\n            if (((typeof n == \"undefined\"))) {\n                n = JSBNG__Event.Priority.NORMAL;\n            }\n        ;\n        ;\n            if (((typeof q == \"object\"))) {\n                var i = {\n                };\n                for (var p in q) {\n                    i[p] = JSBNG__Event.listen(h, p, q[p], n);\n                ;\n                };\n            ;\n                return i;\n            }\n        ;\n        ;\n            if (q.match(/^on/i)) {\n                throw new TypeError(((((\"Bad event name `\" + JSBNG__event)) + \"': use `click', not `onclick'.\")));\n            }\n        ;\n        ;\n            q = q.toLowerCase();\n            if (((((h.nodeName == \"LABEL\")) && ((q == \"click\"))))) {\n                var m = h.getElementsByTagName(\"input\");\n                h = ((((m.length == 1)) ? m[0] : h));\n            }\n        ;\n        ;\n            var k = DataStore.get(h, b, {\n            });\n            if (f[q]) {\n                var g = f[q];\n                q = g.base;\n                j = g.wrap(j);\n            }\n        ;\n        ;\n            a(h, q);\n            var r = k[q];\n            if (!((n in r))) {\n                r[n] = [];\n            }\n        ;\n        ;\n            var l = r[n].length, o = new EventHandlerRef(j, r[n], l);\n            r[n].push(o);\n            return o;\n        },\n        JSBNG__stop: function(g) {\n            return $E(g).JSBNG__stop();\n        },\n        prevent: function(g) {\n            return $E(g).prevent();\n        },\n        kill: function(g) {\n            return $E(g).kill();\n        },\n        getKeyCode: function(JSBNG__event) {\n            JSBNG__event = $E(JSBNG__event);\n            if (!JSBNG__event) {\n                return false;\n            }\n        ;\n        ;\n            switch (JSBNG__event.keyCode) {\n              case 63232:\n                return 38;\n              case 63233:\n                return 40;\n              case 63234:\n                return 37;\n              case 63235:\n                return 39;\n              case 63272:\n            \n              case 63273:\n            \n              case 63275:\n                return null;\n              case 63276:\n                return 33;\n              case 63277:\n                return 34;\n            };\n        ;\n            if (JSBNG__event.shiftKey) {\n                switch (JSBNG__event.keyCode) {\n                  case 33:\n                \n                  case 34:\n                \n                  case 37:\n                \n                  case 38:\n                \n                  case 39:\n                \n                  case 40:\n                    return null;\n                };\n            }\n        ;\n        ;\n            return JSBNG__event.keyCode;\n        },\n        getPriorities: function() {\n            if (!e) {\n                var g = values(JSBNG__Event.Priority);\n                g.sort(function(h, i) {\n                    return ((h - i));\n                });\n                e = g;\n            }\n        ;\n        ;\n            return e;\n        },\n        __fire: function(g, i, JSBNG__event) {\n            var h = JSBNG__Event.__getHandler(g, i);\n            if (h) {\n                return h($E(JSBNG__event));\n            }\n        ;\n        ;\n        },\n        __getHandler: function(g, h) {\n            return DataStore.get(g, ((JSBNG__Event.DATASTORE_KEY + h)));\n        }\n    });\n    var e = null, b = JSBNG__Event.DATASTORE_KEY;\n    var c = function(g) {\n        return function(h) {\n            if (!DOM.contains(this, h.getRelatedTarget())) {\n                return g.call(this, h);\n            }\n        ;\n        ;\n        };\n    };\n    var f = {\n        mouseenter: {\n            base: \"mouseover\",\n            wrap: c\n        },\n        mouseleave: {\n            base: \"mouseout\",\n            wrap: c\n        }\n    };\n    var a = function(g, m) {\n        var h = ((\"JSBNG__on\" + m));\n        var k = d.bind(g);\n        var j = DataStore.get(g, b);\n        if (((m in j))) {\n            return;\n        }\n    ;\n    ;\n        j[m] = {\n        };\n        if (g.JSBNG__addEventListener) {\n            g.JSBNG__addEventListener(m, k, false);\n        }\n         else if (g.JSBNG__attachEvent) {\n            g.JSBNG__attachEvent(h, k);\n        }\n        \n    ;\n    ;\n        DataStore.set(g, ((b + m)), k);\n        if (g[h]) {\n            var l = ((((g === JSBNG__document.documentElement)) ? JSBNG__Event.Priority._BUBBLE : JSBNG__Event.Priority.TRADITIONAL));\n            var i = g[h];\n            g[h] = null;\n            JSBNG__Event.listen(g, m, i, l);\n        }\n    ;\n    ;\n        if (((((g.nodeName === \"FORM\")) && ((m === \"submit\"))))) {\n            JSBNG__Event.listen(g, m, JSBNG__Event.__bubbleSubmit.curry(g), JSBNG__Event.Priority._BUBBLE);\n        }\n    ;\n    ;\n    };\n    var d = function(JSBNG__event) {\n        JSBNG__event = $E(JSBNG__event);\n        var n = JSBNG__event.type;\n        if (!DataStore.get(this, b)) {\n            throw new Error(\"Bad listenHandler context.\");\n        }\n    ;\n    ;\n        var o = DataStore.get(this, b)[n];\n        if (!o) {\n            throw new Error(((((\"No registered handlers for `\" + n)) + \"'.\")));\n        }\n    ;\n    ;\n        if (((n == \"click\"))) {\n            var i = Parent.byTag(JSBNG__event.getTarget(), \"a\");\n            var p = ((((i && i.ua)) || user_action(i, \"click\", JSBNG__event)));\n            if (window.ArbiterMonitor) {\n                ArbiterMonitor.initUA(p, [i,]);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var k = JSBNG__Event.getPriorities();\n        for (var j = 0; ((j < k.length)); j++) {\n            var l = k[j];\n            if (((l in o))) {\n                var g = o[l];\n                for (var h = 0; ((h < g.length)); h++) {\n                    if (!g[h]) {\n                        continue;\n                    }\n                ;\n                ;\n                    var m = g[h].fire(this, JSBNG__event);\n                    if (((m === false))) {\n                        return JSBNG__event.kill();\n                    }\n                     else if (JSBNG__event.cancelBubble) {\n                        JSBNG__event.JSBNG__stop();\n                    }\n                    \n                ;\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return JSBNG__event.returnValue;\n    };\n})();\nJSBNG__Event.Priority = {\n    URGENT: -20,\n    TRADITIONAL: -10,\n    NORMAL: 0,\n    _BUBBLE: 1000\n};\nfunction EventHandlerRef(b, a, c) {\n    this._handler = b;\n    this._container = a;\n    this._index = c;\n};\n;\nEventHandlerRef.prototype = {\n    remove: function() {\n        delete this._handler;\n        delete this._container[this._index];\n    },\n    fire: function(a, JSBNG__event) {\n        return this._handler.call(a, JSBNG__event);\n    }\n};\nfunction Vector2(b, c, a) {\n    copy_properties(this, {\n        x: parseFloat(b),\n        y: parseFloat(c),\n        domain: ((a || \"pure\"))\n    });\n};\n;\ncopy_properties(Vector2.prototype, {\n    toString: function() {\n        return ((((((((\"(\" + this.x)) + \", \")) + this.y)) + \")\"));\n    },\n    add: function(c, d) {\n        if (((arguments.length == 1))) {\n            if (((c.domain != \"pure\"))) {\n                c = c.convertTo(this.domain);\n            }\n        ;\n        ;\n            return this.add(c.x, c.y);\n        }\n    ;\n    ;\n        var a = parseFloat(c);\n        var b = parseFloat(d);\n        return new Vector2(((this.x + a)), ((this.y + b)), this.domain);\n    },\n    mul: function(a, b) {\n        if (((typeof (b) == \"undefined\"))) {\n            b = a;\n        }\n    ;\n    ;\n        return new Vector2(((this.x * a)), ((this.y * b)), this.domain);\n    },\n    sub: function(a, b) {\n        if (((arguments.length == 1))) {\n            return this.add(a.mul(-1));\n        }\n         else return this.add(-a, -b)\n    ;\n    },\n    distanceTo: function(a) {\n        return this.sub(a).magnitude();\n    },\n    magnitude: function() {\n        return Math.sqrt(((((this.x * this.x)) + ((this.y * this.y)))));\n    },\n    convertTo: function(a) {\n        if (((((((a != \"pure\")) && ((a != \"viewport\")))) && ((a != \"JSBNG__document\"))))) {\n            return new Vector2(0, 0);\n        }\n    ;\n    ;\n        if (((a == this.domain))) {\n            return new Vector2(this.x, this.y, this.domain);\n        }\n    ;\n    ;\n        if (((a == \"pure\"))) {\n            return new Vector2(this.x, this.y);\n        }\n    ;\n    ;\n        if (((this.domain == \"pure\"))) {\n            return new Vector2(0, 0);\n        }\n    ;\n    ;\n        var b = Vector2.getScrollPosition(\"JSBNG__document\");\n        var c = this.x, d = this.y;\n        if (((this.domain == \"JSBNG__document\"))) {\n            c -= b.x;\n            d -= b.y;\n        }\n         else {\n            c += b.x;\n            d += b.y;\n        }\n    ;\n    ;\n        return new Vector2(c, d, a);\n    },\n    setElementPosition: function(a) {\n        var b = this.convertTo(\"JSBNG__document\");\n        a.style.left = ((parseInt(b.x) + \"px\"));\n        a.style.JSBNG__top = ((parseInt(b.y) + \"px\"));\n        return this;\n    },\n    setElementDimensions: function(a) {\n        return this.setElementWidth(a).setElementHeight(a);\n    },\n    setElementWidth: function(a) {\n        a.style.width = ((parseInt(this.x, 10) + \"px\"));\n        return this;\n    },\n    setElementHeight: function(a) {\n        a.style.height = ((parseInt(this.y, 10) + \"px\"));\n        return this;\n    },\n    scrollElementBy: function(a) {\n        if (((a == JSBNG__document.body))) {\n            window.JSBNG__scrollBy(this.x, this.y);\n        }\n         else {\n            a.scrollLeft += this.x;\n            a.scrollTop += this.y;\n        }\n    ;\n    ;\n        return this;\n    }\n});\ncopy_properties(Vector2, {\n    getEventPosition: function(b, a) {\n        a = ((a || \"JSBNG__document\"));\n        b = $E(b);\n        var d = ((b.pageX || ((b.clientX + ((JSBNG__document.documentElement.scrollLeft || JSBNG__document.body.scrollLeft))))));\n        var e = ((b.pageY || ((b.clientY + ((JSBNG__document.documentElement.scrollTop || JSBNG__document.body.scrollTop))))));\n        var c = new Vector2(d, e, \"JSBNG__document\");\n        return c.convertTo(a);\n    },\n    getScrollPosition: function(a) {\n        a = ((a || \"JSBNG__document\"));\n        var b = ((JSBNG__document.body.scrollLeft || JSBNG__document.documentElement.scrollLeft));\n        var c = ((JSBNG__document.body.scrollTop || JSBNG__document.documentElement.scrollTop));\n        return new Vector2(b, c, \"JSBNG__document\").convertTo(a);\n    },\n    getElementPosition: function(c, b) {\n        b = ((b || \"JSBNG__document\"));\n        if (!c) {\n            return;\n        }\n    ;\n    ;\n        if (!((\"getBoundingClientRect\" in c))) {\n            return new Vector2(0, 0, \"JSBNG__document\");\n        }\n    ;\n    ;\n        var e = c.getBoundingClientRect(), a = JSBNG__document.documentElement, d = ((Math.round(e.left) - a.clientLeft)), f = ((Math.round(e.JSBNG__top) - a.clientTop));\n        return new Vector2(d, f, \"viewport\").convertTo(b);\n    },\n    getElementDimensions: function(a) {\n        return new Vector2(((a.offsetWidth || 0)), ((a.offsetHeight || 0)));\n    },\n    getViewportDimensions: function() {\n        var a = ((((((((window && window.JSBNG__innerWidth)) || ((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.clientWidth)))) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.clientWidth)))) || 0));\n        var b = ((((((((window && window.JSBNG__innerHeight)) || ((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.clientHeight)))) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.clientHeight)))) || 0));\n        return new Vector2(a, b, \"viewport\");\n    },\n    getDocumentDimensions: function() {\n        var a = ((((((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.scrollWidth)) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.scrollWidth)))) || 0));\n        var b = ((((((((JSBNG__document && JSBNG__document.documentElement)) && JSBNG__document.documentElement.scrollHeight)) || ((((JSBNG__document && JSBNG__document.body)) && JSBNG__document.body.scrollHeight)))) || 0));\n        return new Vector2(a, b, \"JSBNG__document\");\n    },\n    deserialize: function(b) {\n        var a = b.split(\",\");\n        return new Vector2(a[0], a[1]);\n    }\n});\nvar operaIgnoreScroll = {\n    table: true,\n    \"inline-table\": true,\n    inline: true\n};\nfunction elementX(a) {\n    return Vector2.getElementPosition(a, \"JSBNG__document\").x;\n};\n;\nfunction elementY(a) {\n    return Vector2.getElementPosition(a, \"JSBNG__document\").y;\n};\n;\nfunction animation(a) {\n    if (((a == undefined))) {\n        return;\n    }\n;\n;\n    if (((this == window))) {\n        return new animation(a);\n    }\n     else {\n        this.obj = a;\n        this._reset_state();\n        this.queue = [];\n        this.last_attr = null;\n    }\n;\n;\n};\n;\nanimation.resolution = 20;\nanimation.offset = 0;\nanimation.prototype._reset_state = function() {\n    this.state = {\n        attrs: {\n        },\n        duration: 500\n    };\n};\nanimation.prototype.JSBNG__stop = function() {\n    this._reset_state();\n    this.queue = [];\n    return this;\n};\nanimation.prototype._build_container = function() {\n    if (this.container_div) {\n        this._refresh_container();\n        return;\n    }\n;\n;\n    if (((this.obj.firstChild && this.obj.firstChild.__animation_refs))) {\n        this.container_div = this.obj.firstChild;\n        this.container_div.__animation_refs++;\n        this._refresh_container();\n        return;\n    }\n;\n;\n    var b = JSBNG__document.createElement(\"div\");\n    b.style.padding = \"0px\";\n    b.style.margin = \"0px\";\n    b.style.border = \"0px\";\n    b.__animation_refs = 1;\n    var a = this.obj.childNodes;\n    while (a.length) {\n        b.appendChild(a[0]);\n    ;\n    };\n;\n    this.obj.appendChild(b);\n    this._orig_overflow = this.obj.style.overflow;\n    this.obj.style.overflow = \"hidden\";\n    this.container_div = b;\n    this._refresh_container();\n};\nanimation.prototype._refresh_container = function() {\n    this.container_div.style.height = \"auto\";\n    this.container_div.style.width = \"auto\";\n    this.container_div.style.height = ((this.container_div.offsetHeight + \"px\"));\n    this.container_div.style.width = ((this.container_div.offsetWidth + \"px\"));\n};\nanimation.prototype._destroy_container = function() {\n    if (!this.container_div) {\n        return;\n    }\n;\n;\n    if (!--this.container_div.__animation_refs) {\n        var a = this.container_div.childNodes;\n        while (a.length) {\n            this.obj.appendChild(a[0]);\n        ;\n        };\n    ;\n        this.obj.removeChild(this.container_div);\n    }\n;\n;\n    this.container_div = null;\n    this.obj.style.overflow = this._orig_overflow;\n};\nanimation.ATTR_TO = 1;\nanimation.ATTR_BY = 2;\nanimation.ATTR_FROM = 3;\nanimation.prototype._attr = function(a, d, c) {\n    a = a.replace(/-[a-z]/gi, function(e) {\n        return e.substring(1).toUpperCase();\n    });\n    var b = false;\n    switch (a) {\n      case \"background\":\n        this._attr(\"backgroundColor\", d, c);\n        return this;\n      case \"margin\":\n        d = animation.parse_group(d);\n        this._attr(\"marginBottom\", d[0], c);\n        this._attr(\"marginLeft\", d[1], c);\n        this._attr(\"marginRight\", d[2], c);\n        this._attr(\"marginTop\", d[3], c);\n        return this;\n      case \"padding\":\n        d = animation.parse_group(d);\n        this._attr(\"paddingBottom\", d[0], c);\n        this._attr(\"paddingLeft\", d[1], c);\n        this._attr(\"paddingRight\", d[2], c);\n        this._attr(\"paddingTop\", d[3], c);\n        return this;\n      case \"backgroundColor\":\n    \n      case \"borderColor\":\n    \n      case \"color\":\n        d = animation.parse_color(d);\n        break;\n      case \"opacity\":\n        d = parseFloat(d, 10);\n        break;\n      case \"height\":\n    \n      case \"width\":\n        if (((d == \"auto\"))) {\n            b = true;\n        }\n         else d = parseInt(d, 10);\n    ;\n    ;\n        break;\n      case \"borderWidth\":\n    \n      case \"lineHeight\":\n    \n      case \"fontSize\":\n    \n      case \"marginBottom\":\n    \n      case \"marginLeft\":\n    \n      case \"marginRight\":\n    \n      case \"marginTop\":\n    \n      case \"paddingBottom\":\n    \n      case \"paddingLeft\":\n    \n      case \"paddingRight\":\n    \n      case \"paddingTop\":\n    \n      case \"bottom\":\n    \n      case \"left\":\n    \n      case \"right\":\n    \n      case \"JSBNG__top\":\n    \n      case \"scrollTop\":\n    \n      case \"scrollLeft\":\n        d = parseInt(d, 10);\n        break;\n      default:\n        throw new Error(((a + \" is not a supported attribute!\")));\n    };\n;\n    if (((this.state.attrs[a] === undefined))) {\n        this.state.attrs[a] = {\n        };\n    }\n;\n;\n    if (b) {\n        this.state.attrs[a].auto = true;\n    }\n;\n;\n    switch (c) {\n      case animation.ATTR_FROM:\n        this.state.attrs[a].start = d;\n        break;\n      case animation.ATTR_BY:\n        this.state.attrs[a].by = true;\n      case animation.ATTR_TO:\n        this.state.attrs[a].value = d;\n        break;\n    };\n;\n};\nanimation._get_box_width = function(c) {\n    var d = parseInt(CSS.getStyle(c, \"paddingLeft\"), 10), e = parseInt(CSS.getStyle(c, \"paddingRight\"), 10), a = parseInt(CSS.getStyle(c, \"borderLeftWidth\"), 10), b = parseInt(CSS.getStyle(c, \"borderRightWidth\"), 10);\n    return ((((((((c.offsetWidth - ((d ? d : 0)))) - ((e ? e : 0)))) - ((a ? a : 0)))) - ((b ? b : 0))));\n};\nanimation._get_box_height = function(c) {\n    var e = parseInt(CSS.getStyle(c, \"paddingTop\"), 10), d = parseInt(CSS.getStyle(c, \"paddingBottom\"), 10), a = parseInt(CSS.getStyle(c, \"borderTopWidth\"), 10), b = parseInt(CSS.getStyle(c, \"borderBottomWidth\"), 10);\n    return ((((((((c.offsetHeight - ((e ? e : 0)))) - ((d ? d : 0)))) - ((a ? a : 0)))) - ((b ? b : 0))));\n};\nanimation.prototype.to = function(a, b) {\n    if (((b === undefined))) {\n        this._attr(this.last_attr, a, animation.ATTR_TO);\n    }\n     else {\n        this._attr(a, b, animation.ATTR_TO);\n        this.last_attr = a;\n    }\n;\n;\n    return this;\n};\nanimation.prototype.by = function(a, b) {\n    if (((b === undefined))) {\n        this._attr(this.last_attr, a, animation.ATTR_BY);\n    }\n     else {\n        this._attr(a, b, animation.ATTR_BY);\n        this.last_attr = a;\n    }\n;\n;\n    return this;\n};\nanimation.prototype.from = function(a, b) {\n    if (((b === undefined))) {\n        this._attr(this.last_attr, a, animation.ATTR_FROM);\n    }\n     else {\n        this._attr(a, b, animation.ATTR_FROM);\n        this.last_attr = a;\n    }\n;\n;\n    return this;\n};\nanimation.prototype.duration = function(a) {\n    this.state.duration = ((a ? a : 0));\n    return this;\n};\nanimation.prototype.checkpoint = function(b, a) {\n    if (((b === undefined))) {\n        b = 1;\n    }\n;\n;\n    this.state.checkpoint = b;\n    this.queue.push(this.state);\n    this._reset_state();\n    this.state.checkpointcb = a;\n    return this;\n};\nanimation.prototype.blind = function() {\n    this.state.blind = true;\n    return this;\n};\nanimation.prototype.hide = function() {\n    this.state.hide = true;\n    return this;\n};\nanimation.prototype.show = function() {\n    this.state.show = true;\n    return this;\n};\nanimation.prototype.ease = function(a) {\n    this.state.ease = a;\n    return this;\n};\nanimation.prototype.go = function() {\n    var b = (new JSBNG__Date()).getTime();\n    this.queue.push(this.state);\n    for (var a = 0; ((a < this.queue.length)); a++) {\n        this.queue[a].start = ((b - animation.offset));\n        if (this.queue[a].checkpoint) {\n            b += ((this.queue[a].checkpoint * this.queue[a].duration));\n        }\n    ;\n    ;\n    };\n;\n    animation.push(this);\n    return this;\n};\nanimation.prototype._show = function() {\n    CSS.show(this.obj);\n};\nanimation.prototype._hide = function() {\n    CSS.hide(this.obj);\n};\nanimation.prototype._frame = function(m) {\n    var c = true;\n    var l = false;\n    var o = false;\n    var n;\n    function d(p) {\n        return ((JSBNG__document.documentElement[p] || JSBNG__document.body[p]));\n    };\n;\n    for (var e = 0; ((e < this.queue.length)); e++) {\n        var b = this.queue[e];\n        if (((b.start > m))) {\n            c = false;\n            continue;\n        }\n    ;\n    ;\n        if (b.checkpointcb) {\n            this._callback(b.checkpointcb, ((m - b.start)));\n            b.checkpointcb = null;\n        }\n    ;\n    ;\n        if (((b.started === undefined))) {\n            if (b.show) {\n                this._show();\n            }\n        ;\n        ;\n            for (var a in b.attrs) {\n                if (((b.attrs[a].start !== undefined))) {\n                    continue;\n                }\n            ;\n            ;\n                switch (a) {\n                  case \"backgroundColor\":\n                \n                  case \"borderColor\":\n                \n                  case \"color\":\n                    n = animation.parse_color(CSS.getStyle(this.obj, ((((a == \"borderColor\")) ? \"borderLeftColor\" : a))));\n                    if (b.attrs[a].by) {\n                        b.attrs[a].value[0] = Math.min(255, Math.max(0, ((b.attrs[a].value[0] + n[0]))));\n                        b.attrs[a].value[1] = Math.min(255, Math.max(0, ((b.attrs[a].value[1] + n[1]))));\n                        b.attrs[a].value[2] = Math.min(255, Math.max(0, ((b.attrs[a].value[2] + n[2]))));\n                    }\n                ;\n                ;\n                    break;\n                  case \"opacity\":\n                    n = CSS.getOpacity(this.obj);\n                    if (b.attrs[a].by) {\n                        b.attrs[a].value = Math.min(1, Math.max(0, ((b.attrs[a].value + n))));\n                    }\n                ;\n                ;\n                    break;\n                  case \"height\":\n                    n = animation._get_box_height(this.obj);\n                    if (b.attrs[a].by) {\n                        b.attrs[a].value += n;\n                    }\n                ;\n                ;\n                    break;\n                  case \"width\":\n                    n = animation._get_box_width(this.obj);\n                    if (b.attrs[a].by) {\n                        b.attrs[a].value += n;\n                    }\n                ;\n                ;\n                    break;\n                  case \"scrollLeft\":\n                \n                  case \"scrollTop\":\n                    n = ((((this.obj === JSBNG__document.body)) ? d(a) : this.obj[a]));\n                    if (b.attrs[a].by) {\n                        b.attrs[a].value += n;\n                    }\n                ;\n                ;\n                    b[((\"last\" + a))] = n;\n                    break;\n                  default:\n                    n = ((parseInt(CSS.getStyle(this.obj, a), 10) || 0));\n                    if (b.attrs[a].by) {\n                        b.attrs[a].value += n;\n                    }\n                ;\n                ;\n                    break;\n                };\n            ;\n                b.attrs[a].start = n;\n            };\n        ;\n            if (((((b.attrs.height && b.attrs.height.auto)) || ((b.attrs.width && b.attrs.width.auto))))) {\n                if (((ua.firefox() < 3))) {\n                    o = true;\n                }\n            ;\n            ;\n                this._destroy_container();\n                for (var a in {\n                    height: 1,\n                    width: 1,\n                    fontSize: 1,\n                    borderLeftWidth: 1,\n                    borderRightWidth: 1,\n                    borderTopWidth: 1,\n                    borderBottomWidth: 1,\n                    paddingLeft: 1,\n                    paddingRight: 1,\n                    paddingTop: 1,\n                    paddingBottom: 1\n                }) {\n                    if (b.attrs[a]) {\n                        this.obj.style[a] = ((b.attrs[a].value + ((((typeof b.attrs[a].value == \"number\")) ? \"px\" : \"\"))));\n                    }\n                ;\n                ;\n                };\n            ;\n                if (((b.attrs.height && b.attrs.height.auto))) {\n                    b.attrs.height.value = animation._get_box_height(this.obj);\n                }\n            ;\n            ;\n                if (((b.attrs.width && b.attrs.width.auto))) {\n                    b.attrs.width.value = animation._get_box_width(this.obj);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            b.started = true;\n            if (b.blind) {\n                this._build_container();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var i = ((((m - b.start)) / b.duration));\n        if (((i >= 1))) {\n            i = 1;\n            if (b.hide) {\n                this._hide();\n            }\n        ;\n        ;\n        }\n         else c = false;\n    ;\n    ;\n        var k = ((b.ease ? b.ease(i) : i));\n        if (((((!l && ((i != 1)))) && b.blind))) {\n            l = true;\n        }\n    ;\n    ;\n        if (((o && this.obj.parentNode))) {\n            var j = this.obj.parentNode;\n            var h = this.obj.nextSibling;\n            j.removeChild(this.obj);\n        }\n    ;\n    ;\n        for (var a in b.attrs) {\n            switch (a) {\n              case \"backgroundColor\":\n            \n              case \"borderColor\":\n            \n              case \"color\":\n                this.obj.style[a] = ((((((((((((\"rgb(\" + animation.calc_tween(k, b.attrs[a].start[0], b.attrs[a].value[0], true))) + \",\")) + animation.calc_tween(k, b.attrs[a].start[1], b.attrs[a].value[1], true))) + \",\")) + animation.calc_tween(k, b.attrs[a].start[2], b.attrs[a].value[2], true))) + \")\"));\n                break;\n              case \"opacity\":\n                CSS.setStyle(this.obj, \"opacity\", animation.calc_tween(k, b.attrs[a].start, b.attrs[a].value));\n                break;\n              case \"height\":\n            \n              case \"width\":\n                this.obj.style[a] = ((((((k == 1)) && b.attrs[a].auto)) ? \"auto\" : ((animation.calc_tween(k, b.attrs[a].start, b.attrs[a].value, true) + \"px\"))));\n                break;\n              case \"scrollLeft\":\n            \n              case \"scrollTop\":\n                var f = ((this.obj === JSBNG__document.body));\n                n = ((f ? d(a) : this.obj[a]));\n                if (((b[((\"last\" + a))] !== n))) {\n                    delete b.attrs[a];\n                }\n                 else {\n                    var g = animation.calc_tween(k, b.attrs[a].start, b.attrs[a].value, true);\n                    if (!f) {\n                        g = this.obj[a] = g;\n                    }\n                     else {\n                        if (((a == \"scrollLeft\"))) {\n                            window.JSBNG__scrollTo(g, d(\"scrollTop\"));\n                        }\n                         else window.JSBNG__scrollTo(d(\"scrollLeft\"), g);\n                    ;\n                    ;\n                        g = d(a);\n                    }\n                ;\n                ;\n                    b[((\"last\" + a))] = g;\n                }\n            ;\n            ;\n                break;\n              default:\n                this.obj.style[a] = ((animation.calc_tween(k, b.attrs[a].start, b.attrs[a].value, true) + \"px\"));\n                break;\n            };\n        ;\n        };\n    ;\n        if (((i == 1))) {\n            this.queue.splice(e--, 1);\n            this._callback(b.JSBNG__ondone, ((((m - b.start)) - b.duration)));\n        }\n    ;\n    ;\n    };\n;\n    if (o) {\n        j[((h ? \"insertBefore\" : \"appendChild\"))](this.obj, h);\n    }\n;\n;\n    if (((!l && this.container_div))) {\n        this._destroy_container();\n    }\n;\n;\n    return !c;\n};\nanimation.prototype.JSBNG__ondone = function(a) {\n    this.state.JSBNG__ondone = a;\n    return this;\n};\nanimation.prototype._callback = function(a, b) {\n    if (a) {\n        animation.offset = b;\n        a.call(this);\n        animation.offset = 0;\n    }\n;\n;\n};\nanimation.calc_tween = function(a, b, c, d) {\n    return ((d ? parseInt : parseFloat))(((((((c - b)) * a)) + b)), 10);\n};\nanimation.parse_color = function(a) {\n    var b = /^#([a-f0-9]{1,2})([a-f0-9]{1,2})([a-f0-9]{1,2})$/i.exec(a);\n    if (b) {\n        return [parseInt(((((b[1].length == 1)) ? ((b[1] + b[1])) : b[1])), 16),parseInt(((((b[2].length == 1)) ? ((b[2] + b[2])) : b[2])), 16),parseInt(((((b[3].length == 1)) ? ((b[3] + b[3])) : b[3])), 16),];\n    }\n     else {\n        var c = /^rgba? *\\(([0-9]+), *([0-9]+), *([0-9]+)(?:, *([0-9]+))?\\)$/.exec(a);\n        if (c) {\n            if (((c[4] === \"0\"))) {\n                return [255,255,255,];\n            }\n             else return [parseInt(c[1], 10),parseInt(c[2], 10),parseInt(c[3], 10),]\n        ;\n        }\n         else if (((a == \"transparent\"))) {\n            return [255,255,255,];\n        }\n         else throw \"Named color attributes are not supported.\"\n        \n    ;\n    }\n;\n;\n};\nanimation.parse_group = function(a) {\n    a = trim(a).split(/ +/);\n    if (((a.length == 4))) {\n        return a;\n    }\n     else if (((a.length == 3))) {\n        return [a[0],a[1],a[2],a[1],];\n    }\n     else if (((a.length == 2))) {\n        return [a[0],a[1],a[0],a[1],];\n    }\n     else return [a[0],a[0],a[0],a[0],]\n    \n    \n;\n};\nanimation.push = function(a) {\n    if (!animation.active) {\n        animation.active = [];\n    }\n;\n;\n    animation.active.push(a);\n    if (((animation.active.length === 1))) {\n        if (!animation.requestAnimationFrame) {\n            var b = ((((window.requestAnimationFrame || window.JSBNG__webkitRequestAnimationFrame)) || window.JSBNG__mozRequestAnimationFrame));\n            if (b) {\n                animation.requestAnimationFrame = b.bind(window);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (animation.requestAnimationFrame) {\n            animation.requestAnimationFrame(animation._animate);\n        }\n         else animation.timeout = JSBNG__setInterval(animation._animate, animation.resolution, false);\n    ;\n    ;\n    }\n;\n;\n    if (animation.requestAnimationFrame) {\n        animation._updateEndingTimer();\n    }\n;\n;\n    animation._animate(new JSBNG__Date().getTime(), true);\n};\nanimation._updateEndingTimer = function() {\n    if (!animation.requestAnimationFrame) {\n        throw new Error(\"Ending timer only valid with requestAnimationFrame\");\n    }\n;\n;\n    var d = 0;\n    for (var a = 0; ((a < animation.active.length)); a++) {\n        var f = animation.active[a];\n        for (var e = 0; ((e < f.queue.length)); e++) {\n            var b = ((f.queue[e].start + f.queue[e].duration));\n            if (((b > d))) {\n                d = b;\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n    if (animation.timeout) {\n        JSBNG__clearTimeout(animation.timeout);\n        delete animation.timeout;\n    }\n;\n;\n    var c = new JSBNG__Date().getTime();\n    if (((d > c))) {\n        animation.timeout = JSBNG__setTimeout(animation._animate.shield(), ((d - c)), false);\n    }\n;\n;\n};\nanimation._animate = function(d, c) {\n    d = ((d || new JSBNG__Date().getTime()));\n    for (var b = ((((c === true)) ? ((animation.active.length - 1)) : 0)); ((b < animation.active.length)); b++) {\n        try {\n            if (!animation.active[b]._frame(d)) {\n                animation.active.splice(b--, 1);\n            }\n        ;\n        ;\n        } catch (a) {\n            animation.active.splice(b--, 1);\n        };\n    ;\n    };\n;\n    if (((animation.active.length === 0))) {\n        if (animation.timeout) {\n            if (animation.requestAnimationFrame) {\n                JSBNG__clearTimeout(animation.timeout);\n            }\n             else JSBNG__clearInterval(animation.timeout);\n        ;\n        ;\n            delete animation.timeout;\n        }\n    ;\n    ;\n    }\n     else if (animation.requestAnimationFrame) {\n        animation.requestAnimationFrame(animation._animate);\n    }\n    \n;\n;\n};\nanimation.ease = {\n};\nanimation.ease.begin = function(a) {\n    return ((Math.sin(((((Math.PI / 2)) * ((a - 1))))) + 1));\n};\nanimation.ease.end = function(a) {\n    return Math.sin(((((45552 * Math.PI)) * a)));\n};\nanimation.ease.both = function(a) {\n    return ((((45607 * Math.sin(((Math.PI * ((a - 45630))))))) + 45635));\n};\nanimation.prependInsert = function(b, a) {\n    animation.insert(b, a, DOM.prependContent);\n};\nanimation.appendInsert = function(b, a) {\n    animation.insert(b, a, DOM.appendContent);\n};\nanimation.insert = function(c, a, b) {\n    CSS.setStyle(a, \"opacity\", 0);\n    b(c, a);\n    animation(a).from(\"opacity\", 0).to(\"opacity\", 1).duration(400).go();\n};\nvar Button = (function() {\n    var b = \"uiButtonDisabled\";\n    var a = \"uiButtonDepressed\";\n    var d = \"button:blocker\";\n    var c = \"href\";\n    function e(j, i) {\n        var h = DataStore.get(j, d);\n        if (i) {\n            if (h) {\n                h.remove();\n                DataStore.remove(j, d);\n            }\n        ;\n        ;\n        }\n         else if (!h) {\n            DataStore.set(j, d, JSBNG__Event.listen(j, \"click\", bagof(false), JSBNG__Event.Priority.URGENT));\n        }\n        \n    ;\n    ;\n    };\n;\n    function f(h) {\n        var i = Parent.byClass(h, \"uiButton\");\n        if (!i) {\n            throw new Error(\"invalid use case\");\n        }\n    ;\n    ;\n        return i;\n    };\n;\n    function g(h) {\n        return DOM.isNode(h, \"a\");\n    };\n;\n    return {\n        getInputElement: function(h) {\n            h = f(h);\n            if (g(h)) {\n                throw new Error(\"invalid use case\");\n            }\n        ;\n        ;\n            return DOM.JSBNG__find(h, \"input\");\n        },\n        isEnabled: function(h) {\n            return !CSS.hasClass(f(h), b);\n        },\n        setEnabled: function(k, h) {\n            k = f(k);\n            CSS.conditionClass(k, b, !h);\n            if (g(k)) {\n                var i = k.href;\n                var l = DataStore.get(k, c, \"#\");\n                if (h) {\n                    if (!i) {\n                        k.href = l;\n                    }\n                ;\n                ;\n                }\n                 else {\n                    if (((i && ((i !== l))))) {\n                        DataStore.set(k, c, i);\n                    }\n                ;\n                ;\n                    k.removeAttribute(\"href\");\n                }\n            ;\n            ;\n                e(k, h);\n            }\n             else {\n                var j = Button.getInputElement(k);\n                j.disabled = !h;\n                e(j, h);\n            }\n        ;\n        ;\n        },\n        setDepressed: function(i, h) {\n            CSS.conditionClass(f(i), a, h);\n        },\n        isDepressed: function(h) {\n            return CSS.hasClass(f(h), a);\n        },\n        setLabel: function(i, h) {\n            i = f(i);\n            if (g(i)) {\n                var j = DOM.JSBNG__find(i, \"span.uiButtonText\");\n                DOM.setContent(j, h);\n            }\n             else Button.getInputElement(i).value = h;\n        ;\n        ;\n            CSS.conditionClass(i, \"uiButtonNoText\", !h);\n        },\n        setIcon: function(i, h) {\n            if (!DOM.isNode(h)) {\n                return;\n            }\n        ;\n        ;\n            CSS.addClass(h, \"customimg\");\n            i = f(i);\n            var j = DOM.scry(i, \".img\")[0];\n            if (((j != h))) {\n                if (j) {\n                    DOM.replace(j, h);\n                }\n                 else DOM.prependContent(i, h);\n            ;\n            }\n        ;\n        ;\n        }\n    };\n})();\nfunction show() {\n    for (var b = 0; ((b < arguments.length)); b++) {\n        var a = ge(arguments[b]);\n        if (((a && a.style))) {\n            a.style.display = \"\";\n        }\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\nfunction hide() {\n    for (var b = 0; ((b < arguments.length)); b++) {\n        var a = ge(arguments[b]);\n        if (((a && a.style))) {\n            a.style.display = \"none\";\n        }\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\nfunction shown(a) {\n    a = ge(a);\n    return ((((a.style.display != \"none\")) && !((((a.style.display == \"\")) && ((a.offsetWidth == 0))))));\n};\n;\nfunction toggle() {\n    for (var b = 0; ((b < arguments.length)); b++) {\n        var a = $(arguments[b]);\n        a.style.display = ((((CSS.getStyle(a, \"display\") == \"block\")) ? \"none\" : \"block\"));\n    };\n;\n    return false;\n};\n;\nfunction toggleDisplayNone() {\n    for (var b = 0; ((b < arguments.length)); b++) {\n        var a = $(arguments[b]);\n        if (shown(a)) {\n            hide(a);\n        }\n         else show(a);\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\nvar KEYS = {\n    BACKSPACE: 8,\n    TAB: 9,\n    RETURN: 13,\n    ESC: 27,\n    SPACE: 32,\n    PAGE_UP: 33,\n    PAGE_DOWN: 34,\n    LEFT: 37,\n    UP: 38,\n    RIGHT: 39,\n    DOWN: 40,\n    DELETE: 46,\n    COMMA: 188\n};\nif (!this.JSON) {\n    this.JSON = function() {\n        function f(n) {\n            return ((((n < 10)) ? ((\"0\" + n)) : n));\n        };\n    ;\n        JSBNG__Date.prototype.toJSON = function() {\n            return ((((((((((((((((((((((this.getUTCFullYear() + \"-\")) + f(((this.getUTCMonth() + 1))))) + \"-\")) + f(this.getUTCDate()))) + \"T\")) + f(this.getUTCHours()))) + \":\")) + f(this.getUTCMinutes()))) + \":\")) + f(this.getUTCSeconds()))) + \"Z\"));\n        };\n        var m = {\n            \"\\u0008\": \"\\\\b\",\n            \"\\u0009\": \"\\\\t\",\n            \"\\u000a\": \"\\\\n\",\n            \"\\u000c\": \"\\\\f\",\n            \"\\u000d\": \"\\\\r\",\n            \"\\\"\": \"\\\\\\\"\",\n            \"\\\\\": \"\\\\\\\\\"\n        };\n        function stringify(value, whitelist) {\n            var a, i, k, l, v;\n            switch (typeof value) {\n              case \"string\":\n                return (((new RegExp(\"[\\u0000-\\u001f\\\\\\\\\\\"]\")).test(value) ? ((((\"\\\"\" + value.replace(/[\\x00-\\x1f\\\\\"]/g, function(a) {\n                    var c = m[a];\n                    if (c) {\n                        return c;\n                    }\n                ;\n                ;\n                    c = a.charCodeAt();\n                    return ((((\"\\\\u00\" + Math.floor(((c / 16))).toString(16))) + ((c % 16)).toString(16)));\n                }))) + \"\\\"\")) : ((((\"\\\"\" + value)) + \"\\\"\"))));\n              case \"number\":\n                return ((isFinite(value) ? String(value) : \"null\"));\n              case \"boolean\":\n                return String(value);\n              case \"null\":\n                return \"null\";\n              case \"object\":\n                if (!value) {\n                    return \"null\";\n                }\n            ;\n            ;\n                if (((\"nodeName\" in value))) {\n                    return null;\n                }\n            ;\n            ;\n                if (((typeof value.toJSON === \"function\"))) {\n                    return stringify(value.toJSON());\n                }\n            ;\n            ;\n                a = [];\n                if (((((typeof value.length === \"number\")) && !(propertyIsEnumerable(value, \"length\"))))) {\n                    l = value.length;\n                    for (i = 0; ((i < l)); i += 1) {\n                        a.push(((stringify(value[i], whitelist) || \"null\")));\n                    ;\n                    };\n                ;\n                    return ((((\"[\" + a.join(\",\"))) + \"]\"));\n                }\n            ;\n            ;\n                if (whitelist) {\n                    l = whitelist.length;\n                    for (i = 0; ((i < l)); i += 1) {\n                        k = whitelist[i];\n                        if (((typeof k === \"string\"))) {\n                            v = stringify(value[k], whitelist);\n                            if (v) {\n                                a.push(((((stringify(k) + \":\")) + v)));\n                            }\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n                 else for (k in value) {\n                    if (((typeof k === \"string\"))) {\n                        v = stringify(value[k], whitelist);\n                        if (v) {\n                            a.push(((((stringify(k) + \":\")) + v)));\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                return ((((\"{\" + a.join(\",\"))) + \"}\"));\n            };\n        ;\n        };\n    ;\n        return {\n            stringify: stringify,\n            parse: function(text, filter) {\n                var j;\n                function walk(k, v) {\n                    var i, n;\n                    if (((v && ((typeof v === \"object\"))))) {\n                        for (i in v) {\n                            if (Object.prototype.hasOwnProperty.apply(v, [i,])) {\n                                n = walk(i, v[i]);\n                                if (((n !== undefined))) {\n                                    v[i] = n;\n                                }\n                            ;\n                            ;\n                            }\n                        ;\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    return filter(k, v);\n                };\n            ;\n                if (((text && /^[\\],:{}\\s]*$/.test(text.replace(/\\\\./g, \"@\").replace(/\"[^\"\\\\\\n\\r]*\"|true|false|null|-?\\d+(?:\\.\\d*)?(:?[eE][+\\-]?\\d+)?/g, \"]\").replace(/(?:^|:|,)(?:\\s*\\[)+/g, \"\"))))) {\n                    j = eval(((((\"(\" + text)) + \")\")));\n                    return ((((typeof filter === \"function\")) ? walk(\"\", j) : j));\n                }\n            ;\n            ;\n                throw new SyntaxError(\"decodeJSON\");\n            }\n        };\n    }();\n}\n;\n;\nfunction propertyIsEnumerable(a, b) {\n    if (a.propertyIsEnumerable) {\n        return a.propertyIsEnumerable(b);\n    }\n;\n;\n    for (var c in a) {\n        if (((c == b))) {\n            return true;\n        }\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\nvar ErrorDialog = {\n    showAsyncError: function(b) {\n        try {\n            return ErrorDialog.show(b.getErrorSummary(), b.getErrorDescription());\n        } catch (a) {\n            JSBNG__alert(b);\n        };\n    ;\n    },\n    show: function(d, c, b, a) {\n        return (new Dialog()).setTitle(d).setBody(c).setButtons([Dialog.OK,]).setStackable(true).setModal(true).setHandler(((b || bagofholding))).setButtonsMessage(((a || \"\"))).show();\n    }\n};\nadd_properties(\"Form\", {\n    getInputs: function(a) {\n        a = ((a || JSBNG__document));\n        return [].concat($A(DOM.scry(a, \"input\")), $A(DOM.scry(a, \"select\")), $A(DOM.scry(a, \"textarea\")), $A(DOM.scry(a, \"button\")));\n    },\n    getSelectValue: function(a) {\n        return a.options[a.selectedIndex].value;\n    },\n    setSelectValue: function(b, c) {\n        for (var a = 0; ((a < b.options.length)); ++a) {\n            if (((b.options[a].value == c))) {\n                b.selectedIndex = a;\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    getRadioValue: function(b) {\n        for (var a = 0; ((a < b.length)); a++) {\n            if (b[a].checked) {\n                return b[a].value;\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    },\n    getElements: function(a) {\n        return $A(((((a.tagName == \"FORM\")) ? a.elements : Form.getInputs(a))));\n    },\n    getAttribute: function(b, a) {\n        return ((((b.getAttributeNode(a) || {\n        })).value || null));\n    },\n    setDisabled: function(b, a) {\n        Form.getElements(b).forEach(function(c) {\n            if (((c.disabled != undefined))) {\n                var d = DataStore.get(c, \"origDisabledState\");\n                if (a) {\n                    if (((d === undefined))) {\n                        DataStore.set(c, \"origDisabledState\", c.disabled);\n                    }\n                ;\n                ;\n                    c.disabled = a;\n                }\n                 else {\n                    if (((d !== true))) {\n                        c.disabled = false;\n                    }\n                ;\n                ;\n                    DataStore.remove(c, \"origDisabledState\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        });\n    },\n    bootstrap: function(d, e) {\n        var f = ((Form.getAttribute(d, \"method\") || \"GET\")).toUpperCase();\n        e = ((Parent.byTag(e, \"button\") || e));\n        var h = ((Parent.byClass(e, \"stat_elem\") || d));\n        if (CSS.hasClass(h, \"async_saving\")) {\n            return;\n        }\n    ;\n    ;\n        if (((e && ((((((e.form !== d)) || ((((e.nodeName != \"INPUT\")) && ((e.nodeName != \"BUTTON\")))))) || ((e.type != \"submit\"))))))) {\n            var i = DOM.scry(d, \".enter_submit_target\")[0];\n            var b = e;\n            ((i && (e = i)));\n        }\n    ;\n    ;\n        var c = Form.serialize(d, e);\n        Form.setDisabled(d, true);\n        var a = ((Form.getAttribute(d, \"ajaxify\") || Form.getAttribute(d, \"action\")));\n        trackReferrer(d, a);\n        var g = new AsyncRequest(a);\n        g.setData(c).setNectarModuleDataSafe(d).setReadOnly(((f == \"GET\"))).setMethod(f).setRelativeTo(d).setStatusElement(h).setFinallyHandler(Form.setDisabled.bind(null, d, false)).send();\n    },\n    serialize: function(b, c) {\n        var a = {\n        };\n        Form.getElements(b).forEach(function(d) {\n            if (((((d.JSBNG__name && !d.disabled)) && ((d.type != \"submit\"))))) {\n                if (((((((((((!d.type || ((((((d.type == \"radio\")) || ((d.type == \"checkbox\")))) && d.checked)))) || ((d.type == \"text\")))) || ((d.type == \"password\")))) || ((d.type == \"hidden\")))) || ((d.tagName == \"TEXTAREA\"))))) {\n                    var h;\n                    if (((d.JSBNG__name == \"post_form_id\"))) {\n                        h = Env.post_form_id;\n                    }\n                ;\n                ;\n                    Form._serializeHelper(a, d.JSBNG__name, ((h || Input.getValue(d))));\n                }\n                 else if (((d.tagName == \"SELECT\"))) {\n                    for (var e = 0, f = d.options.length; ((e < f)); ++e) {\n                        var g = d.options[e];\n                        if (g.selected) {\n                            Form._serializeHelper(a, d.JSBNG__name, g.value);\n                        }\n                    ;\n                    ;\n                    };\n                }\n                \n            ;\n            }\n        ;\n        ;\n        });\n        if (((((((((c && c.JSBNG__name)) && ((\"submit\" == c.type)))) && DOM.contains(b, c))) && DOM.isNode(c, [\"input\",\"button\",])))) {\n            Form._serializeHelper(a, c.JSBNG__name, c.value);\n        }\n    ;\n    ;\n        return Form._serializeFix(a);\n    },\n    _serializeHelper: function(a, d, e) {\n        var c = /([^\\]]+)\\[([^\\]]*)\\](.*)/.exec(d);\n        if (c) {\n            a[c[1]] = ((a[c[1]] || {\n            }));\n            if (((c[2] == \"\"))) {\n                var b = 0;\n                while (((a[c[1]][b] != undefined))) {\n                    b++;\n                ;\n                };\n            ;\n            }\n             else b = c[2];\n        ;\n        ;\n            if (((c[3] == \"\"))) {\n                a[c[1]][b] = e;\n            }\n             else Form._serializeHelper(a[c[1]], b.concat(c[3]), e);\n        ;\n        ;\n        }\n         else a[d] = e;\n    ;\n    ;\n    },\n    _serializeFix: function(a) {\n        var e = [];\n        for (var b in a) {\n            if (((a[b] instanceof Object))) {\n                a[b] = Form._serializeFix(a[b]);\n            }\n        ;\n        ;\n            e.push(b);\n        };\n    ;\n        if (((e.length > 0))) {\n            var d = 0, c = true;\n            e.sort().each(function(g) {\n                if (((g != d++))) {\n                    c = false;\n                }\n            ;\n            ;\n            });\n            if (c) {\n                var f = [];\n                e.each(function(g) {\n                    f[g] = a[g];\n                });\n                return f;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return a;\n    },\n    post: function(d, b, c) {\n        var a = JSBNG__document.createElement(\"form\");\n        a.action = d.toString();\n        a.method = \"POST\";\n        a.style.display = \"none\";\n        if (c) {\n            a.target = c;\n        }\n    ;\n    ;\n        if (ge(\"post_form_id\")) {\n            b.post_form_id = $(\"post_form_id\").value;\n        }\n    ;\n    ;\n        b.fb_dtsg = Env.fb_dtsg;\n        b.post_form_id_source = \"dynamic_post\";\n        Form.createHiddenInputs(b, a);\n        DOM.getRootElement().appendChild(a);\n        a.submit();\n        return false;\n    },\n    createHiddenInputs: function(g, a, d, f) {\n        d = ((d || {\n        }));\n        var c;\n        var h = URI.implodeQuery(g, \"\", false);\n        var i = h.split(\"&\");\n        for (var b = 0; ((b < i.length)); b++) {\n            if (i[b]) {\n                var j = i[b].split(\"=\");\n                var e = j[0];\n                var k = j[1];\n                if (((((e === undefined)) || ((k === undefined))))) {\n                    continue;\n                }\n            ;\n            ;\n                k = URI.decodeComponent(k);\n                if (((d[e] && f))) {\n                    d[e].value = k;\n                }\n                 else {\n                    c = $N(\"input\", {\n                        type: \"hidden\",\n                        JSBNG__name: e,\n                        value: k\n                    });\n                    d[e] = c;\n                    a.appendChild(c);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return d;\n    },\n    getFirstElement: function(b, g) {\n        g = ((g || [\"input[type=\\\"text\\\"]\",\"textarea\",\"input[type=\\\"password\\\"]\",\"input[type=\\\"button\\\"]\",\"input[type=\\\"submit\\\"]\",]));\n        var f = [];\n        for (var d = 0; ((d < g.length)); d++) {\n            f = DOM.scry(b, g[d]);\n            for (var c = 0; ((c < f.length)); c++) {\n                var e = f[c];\n                try {\n                    if (((((elementY(e) > 0)) && ((elementX(e) > 0))))) {\n                        return e;\n                    }\n                ;\n                ;\n                } catch (a) {\n                \n                };\n            ;\n            };\n        ;\n        };\n    ;\n        return null;\n    },\n    focusFirst: function(b) {\n        var a = Form.getFirstElement(b);\n        if (a) {\n            a.JSBNG__focus();\n            return true;\n        }\n    ;\n    ;\n        return false;\n    }\n});\nfunction Dialog(a) {\n    this._show_loading = true;\n    this._loading_was_shown = false;\n    this._auto_focus = true;\n    this._submit_on_enter = false;\n    this._fade_enabled = true;\n    this._onload_handlers = [];\n    this._top = 125;\n    this._uniqueID = ((\"dialog_\" + Dialog._globalCount++));\n    this._content = null;\n    this._obj = null;\n    this._popup = null;\n    this._overlay = null;\n    this._shim = null;\n    this._hidden_objects = [];\n    this._causal_elem = null;\n    this._previous_focus = null;\n    if (a) {\n        this._setFromModel(a);\n    }\n;\n;\n    Dialog._init();\n};\n;\nMetaprototype.makeFinal(Dialog);\ncopy_properties(Dialog, {\n    OK: {\n        JSBNG__name: \"ok\",\n        label: _tx(\"Okay\")\n    },\n    CANCEL: {\n        JSBNG__name: \"cancel\",\n        label: _tx(\"Cancel\"),\n        className: \"inputaux\"\n    },\n    CLOSE: {\n        JSBNG__name: \"close\",\n        label: _tx(\"Close\")\n    },\n    NEXT: {\n        JSBNG__name: \"next\",\n        label: _tx(\"Next\")\n    },\n    SAVE: {\n        JSBNG__name: \"save\",\n        label: _tx(\"Save\")\n    },\n    SUBMIT: {\n        JSBNG__name: \"submit\",\n        label: _tx(\"Submit\")\n    },\n    CONFIRM: {\n        JSBNG__name: \"JSBNG__confirm\",\n        label: _tx(\"Confirm\")\n    },\n    DELETE: {\n        JSBNG__name: \"delete\",\n        label: _tx(\"Delete\")\n    },\n    _globalCount: 0,\n    _bottoms: [0,],\n    max_bottom: 0,\n    _updateMaxBottom: function() {\n        Dialog.max_bottom = Math.max.apply(Math, Dialog._bottoms);\n    }\n});\ncopy_properties(Dialog, {\n    OK_AND_CANCEL: [Dialog.OK,Dialog.CANCEL,],\n    _STANDARD_BUTTONS: [Dialog.OK,Dialog.CANCEL,Dialog.CLOSE,Dialog.SAVE,Dialog.SUBMIT,Dialog.CONFIRM,Dialog.DELETE,],\n    SHOULD_HIDE_OBJECTS: !ua.windows(),\n    _useCSSBorders: ((CSS.supportsBorderRadius() || ((ua.ie() <= 6)))),\n    SIZE: {\n        WIDE: 555,\n        STANDARD: 445\n    },\n    _HALO_WIDTH: 10,\n    _BORDER_WIDTH: 1,\n    _PADDING_WIDTH: 10,\n    _PAGE_MARGIN: 40,\n    _stack: [],\n    newButton: function(e, d, b, c) {\n        var a = {\n            JSBNG__name: e,\n            label: d\n        };\n        if (b) {\n            a.className = b;\n        }\n    ;\n    ;\n        if (c) {\n            a.handler = c;\n        }\n    ;\n    ;\n        return a;\n    },\n    getCurrent: function() {\n        var a = Dialog._stack;\n        return ((a.length ? a[((a.length - 1))] : null));\n    },\n    bootstrap: function(i, a, f, d, e, c) {\n        a = ((a || {\n        }));\n        var j = ((c && ((c.rel == \"dialog-pipe\"))));\n        copy_properties(a, new URI(i).getQueryData());\n        d = ((d || ((f ? \"GET\" : \"POST\"))));\n        var h = ((Parent.byClass(c, \"stat_elem\") || c));\n        if (((h && CSS.hasClass(h, \"async_saving\")))) {\n            return false;\n        }\n    ;\n    ;\n        var g;\n        if (j) {\n            g = new AjaxPipeRequest();\n        }\n         else g = new AsyncRequest().setReadOnly(!!f).setMethod(d).setRelativeTo(c).setStatusElement(h);\n    ;\n    ;\n        g.setURI(i).setNectarModuleDataSafe(c).setData(a);\n        var b = new Dialog(e).setCausalElement(c).setAsync(g, j);\n        b.show();\n        return false;\n    },\n    _init: function() {\n        this._init = bagofholding;\n        JSBNG__onleaveRegister(Dialog._tearDown.shield(null, false));\n        Arbiter.subscribe(\"page_transition\", Dialog._tearDown.shield(null, true));\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", function(JSBNG__event) {\n            if (((((JSBNG__Event.getKeyCode(JSBNG__event) == KEYS.ESC)) && !JSBNG__event.getModifiers().any))) {\n                if (Dialog._escape()) {\n                    JSBNG__event.kill();\n                }\n            ;\n            ;\n            }\n             else if (((((JSBNG__Event.getKeyCode(JSBNG__event) == KEYS.RETURN)) && !JSBNG__event.getModifiers().any))) {\n                if (Dialog._enter()) {\n                    JSBNG__event.kill();\n                }\n            ;\n            }\n            \n        ;\n        ;\n        });\n        JSBNG__Event.listen(window, \"resize\", function(JSBNG__event) {\n            var a = Dialog.getCurrent();\n            ((a && a._resetDialogObj()));\n        });\n    },\n    _basicMutator: function(a) {\n        return function(b) {\n            this[a] = b;\n            this._dirty();\n            return this;\n        };\n    },\n    _findButton: function(a, c) {\n        if (a) {\n            for (var b = 0; ((b < a.length)); ++b) {\n                if (((a[b].JSBNG__name == c))) {\n                    return a[b];\n                }\n            ;\n            ;\n            };\n        }\n    ;\n    ;\n        return null;\n    },\n    _tearDown: function(b) {\n        var c = Dialog._stack.clone();\n        for (var a = ((c.length - 1)); ((a >= 0)); a--) {\n            if (!((b && c[a]._cross_transition))) {\n                c[a].hide();\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    _escape: function() {\n        var d = Dialog.getCurrent();\n        if (!d) {\n            return false;\n        }\n    ;\n    ;\n        var e = d._semi_modal;\n        var b = d._buttons;\n        if (((!b && !e))) {\n            return false;\n        }\n    ;\n    ;\n        if (((e && !b))) {\n            d.hide();\n            return true;\n        }\n    ;\n    ;\n        var a;\n        var c = Dialog._findButton(b, \"cancel\");\n        if (d._cancelHandler) {\n            d.cancel();\n            return true;\n        }\n         else if (c) {\n            a = c;\n        }\n         else if (((b.length == 1))) {\n            a = b[0];\n        }\n         else return false\n        \n        \n    ;\n        d._handleButton(a);\n        return true;\n    },\n    _enter: function() {\n        var b = Dialog.getCurrent();\n        if (((!b || !b._submit_on_enter))) {\n            return false;\n        }\n    ;\n    ;\n        if (((JSBNG__document.activeElement != b._frame))) {\n            return false;\n        }\n    ;\n    ;\n        var a = b._buttons;\n        if (!a) {\n            return false;\n        }\n    ;\n    ;\n        b._handleButton(a[0]);\n        return true;\n    },\n    call_or_eval: function(obj, func, args) {\n        if (!func) {\n            return undefined;\n        }\n    ;\n    ;\n        args = ((args || {\n        }));\n        if (((typeof (func) == \"string\"))) {\n            var params = keys(args).join(\", \");\n            func = eval(((((((((\"({f: function(\" + params)) + \") { \")) + func)) + \"}})\"))).f;\n        }\n    ;\n    ;\n        return func.apply(obj, values(args));\n    }\n});\ncopy_properties(Dialog.prototype, {\n    _cross_transition: false,\n    _fixed: false,\n    show: function() {\n        this._showing = true;\n        this._dirty();\n        return this;\n    },\n    showLoading: function() {\n        this._loading_was_shown = true;\n        this._renderDialog($N(\"div\", {\n            className: \"dialog_loading\"\n        }, _tx(\"Loading...\")));\n        return this;\n    },\n    hide: function(a) {\n        if (!this._showing) {\n            return this;\n        }\n    ;\n    ;\n        this._showing = false;\n        if (this._autohide_timeout) {\n            JSBNG__clearTimeout(this._autohide_timeout);\n            this._autohide_timeout = null;\n        }\n    ;\n    ;\n        if (((this._fade_enabled && ((Dialog._stack.length <= 1))))) {\n            this._fadeOut(a);\n        }\n         else this._hide(a);\n    ;\n    ;\n        return this;\n    },\n    cancel: function() {\n        if (((!this._cancelHandler || ((this._cancelHandler() !== false))))) {\n            this.hide();\n        }\n    ;\n    ;\n    },\n    getRoot: function() {\n        return this._obj;\n    },\n    getBody: function() {\n        return DOM.scry(this._obj, \"div.dialog_body\")[0];\n    },\n    getButtonElement: function(a) {\n        if (((typeof a == \"string\"))) {\n            a = Dialog._findButton(this._buttons, a);\n        }\n    ;\n    ;\n        if (((!a || !a.JSBNG__name))) {\n            return null;\n        }\n    ;\n    ;\n        var b = DOM.scry(this._popup, \"input\");\n        var c = function(d) {\n            return ((d.JSBNG__name == a.JSBNG__name));\n        };\n        return ((b.filter(c)[0] || null));\n    },\n    getContentNode: function() {\n        return DOM.JSBNG__find(this._content, \"div.dialog_content\");\n    },\n    getFormData: function() {\n        return Form.serialize(this.getContentNode());\n    },\n    setAllowCrossPageTransition: function(a) {\n        this._cross_transition = a;\n        return this;\n    },\n    setShowing: function() {\n        this.show();\n        return this;\n    },\n    setHiding: function() {\n        this.hide();\n        return this;\n    },\n    setTitle: Dialog._basicMutator(\"_title\"),\n    setBody: Dialog._basicMutator(\"_body\"),\n    setExtraData: Dialog._basicMutator(\"_extra_data\"),\n    setReturnData: Dialog._basicMutator(\"_return_data\"),\n    setShowLoading: Dialog._basicMutator(\"_show_loading\"),\n    setFullBleed: Dialog._basicMutator(\"_full_bleed\"),\n    setImmediateRendering: function(a) {\n        this._immediate_rendering = a;\n        return this;\n    },\n    setCausalElement: function(a) {\n        this._causal_elem = a;\n        return this;\n    },\n    setUserData: Dialog._basicMutator(\"_user_data\"),\n    getUserData: function() {\n        return this._user_data;\n    },\n    setAutohide: function(a) {\n        if (a) {\n            if (this._showing) {\n                this._autohide_timeout = JSBNG__setTimeout(this.hide.shield(this), a);\n            }\n             else this._autohide = a;\n        ;\n        ;\n        }\n         else {\n            this._autohide = null;\n            if (this._autohide_timeout) {\n                JSBNG__clearTimeout(this._autohide_timeout);\n                this._autohide_timeout = null;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return this;\n    },\n    setSummary: Dialog._basicMutator(\"_summary\"),\n    setButtons: function(a) {\n        var c;\n        if (!((a instanceof Array))) {\n            c = $A(arguments);\n        }\n         else c = a;\n    ;\n    ;\n        for (var d = 0; ((d < c.length)); ++d) {\n            if (((typeof c[d] == \"string\"))) {\n                var b = Dialog._findButton(Dialog._STANDARD_BUTTONS, c[d]);\n                c[d] = b;\n            }\n        ;\n        ;\n        };\n    ;\n        this._buttons = c;\n        this._updateButtons();\n        return this;\n    },\n    setButtonsMessage: Dialog._basicMutator(\"_buttons_message\"),\n    setClickButtonOnEnter: function(b, a) {\n        this._clickButtonOnEnter = a;\n        this._clickButtonOnEnterInputName = b;\n        return this;\n    },\n    setStackable: function(b, a) {\n        this._is_stackable = b;\n        this._shown_while_stacked = ((b && a));\n        return this;\n    },\n    setHandler: function(a) {\n        this._handler = a;\n        return this;\n    },\n    setCancelHandler: function(a) {\n        this._cancelHandler = Dialog.call_or_eval.bind(null, this, a);\n        return this;\n    },\n    setCloseHandler: function(a) {\n        this._close_handler = Dialog.call_or_eval.bind(null, this, a);\n        return this;\n    },\n    clearHandler: function() {\n        return this.setHandler(null);\n    },\n    setPostURI: function(b, a) {\n        if (((a === undefined))) {\n            a = true;\n        }\n    ;\n    ;\n        if (a) {\n            this.setHandler(this._submitForm.bind(this, \"POST\", b));\n        }\n         else this.setHandler(function() {\n            Form.post(b, this.getFormData());\n            this.hide();\n        }.bind(this));\n    ;\n    ;\n        return this;\n    },\n    setGetURI: function(a) {\n        this.setHandler(this._submitForm.bind(this, \"GET\", a));\n        return this;\n    },\n    setModal: function(a) {\n        this._modal = a;\n        return this;\n    },\n    setSemiModal: function(a) {\n        if (a) {\n            this.setModal(true);\n        }\n    ;\n    ;\n        this._semi_modal = a;\n        return this;\n    },\n    setWideDialog: Dialog._basicMutator(\"_wide_dialog\"),\n    setContentWidth: Dialog._basicMutator(\"_content_width\"),\n    setTitleLoading: function(b) {\n        if (((b === undefined))) {\n            b = true;\n        }\n    ;\n    ;\n        var a = DOM.JSBNG__find(this._popup, \"h2.dialog_title\");\n        if (a) {\n            CSS.conditionClass(a, \"loading\", b);\n        }\n    ;\n    ;\n        return this;\n    },\n    setSecure: Dialog._basicMutator(\"_secure\"),\n    setClassName: Dialog._basicMutator(\"_class_name\"),\n    setFadeEnabled: Dialog._basicMutator(\"_fade_enabled\"),\n    setFooter: Dialog._basicMutator(\"_footer\"),\n    setAutoFocus: Dialog._basicMutator(\"_auto_focus\"),\n    setTop: Dialog._basicMutator(\"_top\"),\n    setFixed: Dialog._basicMutator(\"_fixed\"),\n    JSBNG__onloadRegister: function(a) {\n        $A(a).forEach(function(b) {\n            if (((typeof b == \"string\"))) {\n                b = new Function(b);\n            }\n        ;\n        ;\n            this._onload_handlers.push(b.bind(this));\n        }.bind(this));\n        return this;\n    },\n    setAsyncURL: function(a) {\n        return this.setAsync(new AsyncRequest(a));\n    },\n    setAsync: function(a, i) {\n        var c = function(m) {\n            if (((this._async_request != a))) {\n                return;\n            }\n        ;\n        ;\n            this._async_request = null;\n            var l = m.getPayload();\n            var j = l;\n            var k = function() {\n                if (((typeof j == \"string\"))) {\n                    this.setBody(j);\n                }\n                 else this._setFromModel(j);\n            ;\n            ;\n                this._update(true);\n            }.bind(this);\n            if (i) {\n                j = l.dialog;\n                Bootloader.setResourceMap(l.resource_map);\n                Bootloader.loadResources(l.css, k);\n            }\n             else k();\n        ;\n        ;\n        }.bind(this);\n        var b = a.getData();\n        b.__d = 1;\n        a.setData(b);\n        var d = bind(this, \"hide\");\n        var h;\n        if (i) {\n            a.setFirstResponseHandler(c);\n            h = a.getAsyncRequest();\n        }\n         else {\n            var f = ((a.getHandler() || bagofholding));\n            a.setHandler(function(j) {\n                f(j);\n                c(j);\n            });\n            h = a;\n        }\n    ;\n    ;\n        var e = ((h.getErrorHandler() || bagofholding));\n        var g = ((h.getTransportErrorHandler() || bagofholding));\n        h.setAllowCrossPageTransition(this._cross_transition).setErrorHandler(function(j) {\n            d(true);\n            e(j);\n        }).setTransportErrorHandler(function(j) {\n            d(true);\n            g(j);\n        });\n        a.send();\n        this._async_request = a;\n        this._dirty();\n        return this;\n    },\n    _dirty: function() {\n        if (!this._is_dirty) {\n            this._is_dirty = true;\n            if (this._immediate_rendering) {\n                this._update();\n            }\n             else bind(this, \"_update\", false).defer();\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _format: function(a) {\n        if (((typeof a == \"string\"))) {\n            a = HTML(a);\n        }\n         else a = HTML.replaceJSONWrapper(a);\n    ;\n    ;\n        if (((a instanceof HTML))) {\n            a.setDeferred(true);\n        }\n    ;\n    ;\n        return a;\n    },\n    _update: function(d) {\n        if (((!this._is_dirty && ((d !== true))))) {\n            return;\n        }\n    ;\n    ;\n        this._is_dirty = false;\n        if (!this._showing) {\n            return;\n        }\n    ;\n    ;\n        if (((((this._autohide && !this._async_request)) && !this._autohide_timeout))) {\n            this._autohide_timeout = JSBNG__setTimeout(bind(this, \"hide\"), this._autohide);\n        }\n    ;\n    ;\n        if (((!this._async_request || !this._show_loading))) {\n            if (((this._loading_was_shown === true))) {\n                this._hide(true);\n                this._loading_was_shown = false;\n            }\n        ;\n        ;\n            var b = [];\n            if (this._summary) {\n                b.push($N(\"div\", {\n                    className: \"dialog_summary\"\n                }, this._format(this._summary)));\n            }\n        ;\n        ;\n            b.push($N(\"div\", {\n                className: \"dialog_body\"\n            }, this._format(this._body)));\n            var a = this._getButtonContent();\n            if (a.length) {\n                b.push($N(\"div\", {\n                    className: \"dialog_buttons clearfix\"\n                }, a));\n            }\n        ;\n        ;\n            if (this._footer) {\n                b.push($N(\"div\", {\n                    className: \"dialog_footer\"\n                }, this._format(this._footer)));\n            }\n        ;\n        ;\n            b = $N(\"div\", {\n                className: \"dialog_content\"\n            }, b);\n            if (this._title) {\n                var g = $N(\"span\", this._format(this._title));\n                var h = $N(\"h2\", {\n                    className: \"dialog_title\",\n                    id: ((\"title_\" + this._uniqueID))\n                }, g);\n                CSS.conditionClass(h, \"secure\", this._secure);\n                b = [h,b,];\n            }\n             else {\n                CSS.addClass(b, \"dialog_content_titleless\");\n                b = [b,];\n            }\n        ;\n        ;\n            this._renderDialog(b);\n            CSS.conditionClass(this.getRoot(), \"omitDialogFooter\", !a.length);\n            if (((((this._clickButtonOnEnterInputName && this._clickButtonOnEnter)) && ge(this._clickButtonOnEnterInputName)))) {\n                JSBNG__Event.listen(ge(this._clickButtonOnEnterInputName), \"keypress\", function(i) {\n                    if (((JSBNG__Event.getKeyCode(i) == KEYS.RETURN))) {\n                        this._handleButton(this._clickButtonOnEnter);\n                        i.kill();\n                    }\n                ;\n                ;\n                    return true;\n                }.bind(this));\n            }\n        ;\n        ;\n            for (var f = 0; ((f < this._onload_handlers.length)); ++f) {\n                try {\n                    this._onload_handlers[f]();\n                } catch (e) {\n                \n                };\n            ;\n            };\n        ;\n            this._onload_handlers = [];\n            this._previous_focus = JSBNG__document.activeElement;\n            Input.JSBNG__focus(this._frame);\n        }\n         else this.showLoading();\n    ;\n    ;\n        var c = ((2 * Dialog._BORDER_WIDTH));\n        if (Dialog._useCSSBorders) {\n            c += ((2 * Dialog._HALO_WIDTH));\n        }\n    ;\n    ;\n        if (this._content_width) {\n            c += this._content_width;\n            if (!this._full_bleed) {\n                c += ((2 * Dialog._PADDING_WIDTH));\n            }\n        ;\n        ;\n        }\n         else if (this._wide_dialog) {\n            c += Dialog.SIZE.WIDE;\n        }\n         else c += Dialog.SIZE.STANDARD;\n        \n    ;\n    ;\n        this._popup.style.width = ((c + \"px\"));\n    },\n    _updateButtons: function() {\n        if (!this._showing) {\n            return;\n        }\n    ;\n    ;\n        var b = this._getButtonContent();\n        var c = null;\n        if (!this.getRoot()) {\n            this._buildDialog();\n        }\n    ;\n    ;\n        CSS.conditionClass(this.getRoot(), \"omitDialogFooter\", !b.length);\n        if (b.length) {\n            c = $N(\"div\", {\n                className: \"dialog_buttons clearfix\"\n            }, b);\n        }\n    ;\n    ;\n        var d = ((DOM.scry(this._content, \"div.dialog_buttons\")[0] || null));\n        if (!d) {\n            if (!c) {\n                return;\n            }\n        ;\n        ;\n            var a = this.getBody();\n            if (a) {\n                DOM.insertAfter(a, c);\n            }\n        ;\n        ;\n        }\n         else if (c) {\n            DOM.replace(d, c);\n        }\n         else DOM.remove(d);\n        \n    ;\n    ;\n    },\n    _getButtonContent: function() {\n        var c = [];\n        if (((((this._buttons && ((this._buttons.length > 0)))) || this._buttons_message))) {\n            if (this._buttons_message) {\n                c.push($N(\"div\", {\n                    className: \"dialog_buttons_msg\"\n                }, this._format(this._buttons_message)));\n            }\n        ;\n        ;\n            if (this._buttons) {\n                for (var f = 0; ((f < this._buttons.length)); f++) {\n                    var b = this._buttons[f];\n                    var d = $N(\"input\", {\n                        type: \"button\",\n                        JSBNG__name: ((b.JSBNG__name || \"\")),\n                        value: b.label\n                    });\n                    var e = $N(\"label\", {\n                        className: \"uiButton uiButtonLarge uiButtonConfirm\"\n                    }, d);\n                    if (b.className) {\n                        b.className.split(/\\s+/).each(function(g) {\n                            CSS.addClass(e, g);\n                        });\n                        if (CSS.hasClass(e, \"inputaux\")) {\n                            CSS.removeClass(e, \"inputaux\");\n                            CSS.removeClass(e, \"uiButtonConfirm\");\n                        }\n                    ;\n                    ;\n                        if (CSS.hasClass(e, \"uiButtonSpecial\")) {\n                            CSS.removeClass(e, \"uiButtonConfirm\");\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                    if (b.icon) {\n                        DOM.prependContent(e, $N(\"img\", {\n                            src: b.icon,\n                            className: \"img mrs\"\n                        }));\n                    }\n                ;\n                ;\n                    if (b.disabled) {\n                        Button.setEnabled(e, false);\n                    }\n                ;\n                ;\n                    JSBNG__Event.listen(d, \"click\", this._handleButton.bind(this, b.JSBNG__name));\n                    for (var a in b) {\n                        if (((((a.indexOf(\"data-\") === 0)) && ((a.length > 5))))) {\n                            d.setAttribute(a, b[a]);\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    c.push(e);\n                };\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return c;\n    },\n    _renderDialog: function(b) {\n        if (!this._obj) {\n            this._buildDialog();\n        }\n    ;\n    ;\n        if (this._class_name) {\n            CSS.addClass(this._obj, this._class_name);\n        }\n    ;\n    ;\n        CSS.conditionClass(this._obj, \"full_bleed\", this._full_bleed);\n        if (((typeof b == \"string\"))) {\n            b = HTML(b).setDeferred(((this._immediate_rendering !== true)));\n        }\n    ;\n    ;\n        DOM.setContent(this._content, b);\n        this._showDialog();\n        this._submit_on_enter = false;\n        if (this._auto_focus) {\n            var c = Form.getFirstElement(this._content, [\"input[type=\\\"text\\\"]\",\"textarea\",\"input[type=\\\"password\\\"]\",]);\n            if (c) {\n                Form.focusFirst.bind(this, this._content).defer();\n            }\n             else this._submit_on_enter = true;\n        ;\n        ;\n        }\n    ;\n    ;\n        var a = ((Vector2.getElementDimensions(this._content).y + Vector2.getElementPosition(this._content).y));\n        Dialog._bottoms.push(a);\n        this._bottom = a;\n        Dialog._updateMaxBottom();\n        return this;\n    },\n    _buildDialog: function() {\n        this._obj = $N(\"div\", {\n            className: \"generic_dialog\",\n            id: this._uniqueID\n        });\n        this._obj.style.display = \"none\";\n        JSBNG__document.body.appendChild(this._obj);\n        if (!this._popup) {\n            this._popup = $N(\"div\", {\n                className: \"generic_dialog_popup\"\n            });\n        }\n    ;\n    ;\n        this._popup.style.left = this._popup.style.JSBNG__top = \"\";\n        this._obj.appendChild(this._popup);\n        if (((((ua.ie() < 7)) && !this._shim))) {\n            Bootloader.loadComponents(\"iframe-shim\", function() {\n                this._shim = new IframeShim(this._popup);\n            });\n        }\n    ;\n    ;\n        this._buildDialogContent();\n    },\n    _showDialog: function() {\n        if (this._modal) {\n            this._buildOverlay();\n        }\n         else if (this._overlay) {\n            DOM.remove(this._overlay);\n            this._overlay = null;\n        }\n        \n    ;\n    ;\n        if (((this._obj && this._obj.style.display))) {\n            this._obj.style.visibility = \"hidden\";\n            this._obj.style.display = \"\";\n            this.resetDialogPosition();\n            this._obj.style.visibility = \"\";\n            this._obj.dialog = this;\n        }\n         else this.resetDialogPosition();\n    ;\n    ;\n        JSBNG__clearInterval(this.active_hiding);\n        this.active_hiding = JSBNG__setInterval(this._activeResize.bind(this), 500);\n        Arbiter.inform(\"layer_shown\", {\n            type: \"Dialog\"\n        });\n        var c = Dialog._stack;\n        if (c.length) {\n            var a = c[((c.length - 1))];\n            if (((((a != this)) && ((!a._is_stackable || ((a._show_loading && a._loading_was_shown))))))) {\n                a._hide();\n            }\n             else if (((((((a == this)) && a._show_loading)) && a._loading_was_shown))) {\n                Arbiter.inform(\"layer_hidden\", {\n                    type: \"Dialog\"\n                });\n            }\n            \n        ;\n        ;\n            for (var b = ((c.length - 1)); ((b >= 0)); b--) {\n                if (((c[b] == this))) {\n                    c.splice(b, 1);\n                }\n                 else if (!c[b]._shown_while_stacked) {\n                    c[b]._hide(true);\n                }\n                \n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        c.push(this);\n        return this;\n    },\n    _updateShim: function() {\n        return ((this._shim && this._shim.show()));\n    },\n    _activeResize: function() {\n        if (((this.last_offset_height != this._content.offsetHeight))) {\n            this.last_offset_height = this._content.offsetHeight;\n            this._updateShim();\n        }\n    ;\n    ;\n    },\n    _buildDialogContent: function() {\n        CSS.addClass(this._obj, \"pop_dialog\");\n        if (intl_locale_is_rtl()) {\n            CSS.addClass(this._obj, \"pop_dialog_rtl\");\n        }\n    ;\n    ;\n        var a;\n        if (Dialog._useCSSBorders) {\n            a = ((((\"\\u003Cdiv class=\\\"pop_container_advanced\\\"\\u003E\" + \"\\u003Cdiv class=\\\"pop_content\\\" id=\\\"pop_content\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\"));\n        }\n         else a = ((((((((((((((((\"\\u003Cdiv class=\\\"pop_container\\\"\\u003E\" + \"\\u003Cdiv class=\\\"pop_verticalslab\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_horizontalslab\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_topleft\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_topright\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_bottomright\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_bottomleft\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003Cdiv class=\\\"pop_content pop_content_old\\\" id=\\\"pop_content\\\"\\u003E\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\"));\n    ;\n    ;\n        DOM.setContent(this._popup, HTML(a));\n        this._frame = DOM.JSBNG__find(this._popup, \"div.pop_content\");\n        this._content = this._frame;\n        this._frame.setAttribute(\"tabIndex\", \"0\");\n        this._frame.setAttribute(\"role\", \"alertdialog\");\n    },\n    _buildOverlay: function() {\n        if (this._overlay) {\n            return;\n        }\n    ;\n    ;\n        this._overlay = $N(\"div\", {\n            className: \"overlay\"\n        });\n        if (this._semi_modal) {\n            JSBNG__Event.listen(this._obj, \"click\", function(a) {\n                if (!DOM.contains(this._popup, JSBNG__event.getTarget())) {\n                    this.hide();\n                }\n            ;\n            ;\n            }.bind(this));\n        }\n    ;\n    ;\n        if (((ua.ie() < 7))) {\n            this._overlay.style.height = ((Vector2.getDocumentDimensions().y + \"px\"));\n        }\n    ;\n    ;\n        this._obj.insertBefore(this._overlay, this._obj.firstChild);\n    },\n    resetDialogPosition: function() {\n        if (!this._popup) {\n            return;\n        }\n    ;\n    ;\n        this._resetDialogObj();\n        this._updateShim();\n    },\n    _resetDialogObj: function() {\n        var a = DOM.JSBNG__find(this._popup, \"div.pop_content\");\n        var b = ((Vector2.getElementDimensions(a).y + ((2 * Dialog._HALO_WIDTH))));\n        var g = ((Vector2.getViewportDimensions().y - ((2 * Dialog._PAGE_MARGIN))));\n        var f = this._top;\n        var e = Vector2.getScrollPosition().y;\n        var c = ((g - b));\n        if (((c < 0))) {\n            f = Dialog._PAGE_MARGIN;\n        }\n         else if (((f > c))) {\n            f = ((Dialog._PAGE_MARGIN + ((Math.max(c, 0) / 2))));\n        }\n        \n    ;\n    ;\n        if (!this._fixed) {\n            f += e;\n        }\n    ;\n    ;\n        CSS.conditionClass(this._obj, \"generic_dialog_fixed\", this._fixed);\n        var d = ((this._fixed && ((c < 0))));\n        CSS.conditionClass(this._obj, \"generic_dialog_fixed_overflow\", d);\n        CSS.conditionClass(JSBNG__document.body, \"generic_dialog_overflow_mode\", d);\n        CSS.setStyle(this._popup, \"JSBNG__top\", ((f + \"px\")));\n        if (((this._fixed && ((((f - Vector2.getElementPosition(this._popup, \"viewport\").y)) > 1))))) {\n            f += e;\n            CSS.setStyle(this._popup, \"JSBNG__top\", ((f + \"px\")));\n        }\n    ;\n    ;\n    },\n    _fadeOut: function(b) {\n        if (!this._popup) {\n            return;\n        }\n    ;\n    ;\n        try {\n            animation(this._obj).duration(0).checkpoint().to(\"opacity\", 0).hide().duration(250).JSBNG__ondone(this._hide.bind(this, b)).go();\n        } catch (a) {\n            this._hide(b);\n        };\n    ;\n    },\n    _hide: function(d) {\n        if (this._obj) {\n            this._obj.style.display = \"none\";\n        }\n    ;\n    ;\n        this._updateShim();\n        if (this.timeout) {\n            JSBNG__clearTimeout(this.timeout);\n            this.timeout = null;\n        }\n    ;\n    ;\n        if (this._hidden_objects.length) {\n            for (var b = 0, c = this._hidden_objects.length; ((b < c)); b++) {\n                this._hidden_objects[b].style.visibility = \"\";\n            ;\n            };\n        ;\n            this._hidden_objects = [];\n        }\n    ;\n    ;\n        JSBNG__clearInterval(this.active_hiding);\n        if (this._bottom) {\n            var a = Dialog._bottoms;\n            a.splice(a.indexOf(this._bottom), 1);\n            Dialog._updateMaxBottom();\n        }\n    ;\n    ;\n        Arbiter.inform(\"layer_hidden\", {\n            type: \"Dialog\"\n        });\n        if (((((this._previous_focus && JSBNG__document.activeElement)) && DOM.contains(this._obj, JSBNG__document.activeElement)))) {\n            Input.JSBNG__focus(this._previous_focus);\n        }\n    ;\n    ;\n        if (d) {\n            return;\n        }\n    ;\n    ;\n        this.destroy();\n    },\n    destroy: function() {\n        if (Dialog._stack.length) {\n            var b = Dialog._stack;\n            for (var a = ((b.length - 1)); ((a >= 0)); a--) {\n                if (((b[a] == this))) {\n                    b.splice(a, 1);\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            if (b.length) {\n                b[((b.length - 1))]._showDialog();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (this._obj) {\n            DOM.remove(this._obj);\n            this._obj = null;\n            ((this._shim && this._shim.hide()));\n            this._shim = null;\n        }\n    ;\n    ;\n        if (this._close_handler) {\n            this._close_handler({\n                return_data: this._return_data\n            });\n        }\n    ;\n    ;\n    },\n    _handleButton: function(a) {\n        if (((typeof a == \"string\"))) {\n            a = Dialog._findButton(this._buttons, a);\n        }\n    ;\n    ;\n        var b = Dialog.call_or_eval(a, a.handler);\n        if (((b === false))) {\n            return;\n        }\n    ;\n    ;\n        if (((a.JSBNG__name == \"cancel\"))) {\n            this.cancel();\n        }\n         else if (((Dialog.call_or_eval(this, this._handler, {\n            button: a\n        }) !== false))) {\n            this.hide();\n        }\n        \n    ;\n    ;\n    },\n    _submitForm: function(d, e, b) {\n        var c = this.getFormData();\n        if (b) {\n            c[b.JSBNG__name] = b.label;\n        }\n    ;\n    ;\n        if (this._extra_data) {\n            copy_properties(c, this._extra_data);\n        }\n    ;\n    ;\n        var a = new AsyncRequest().setURI(e).setData(c).setMethod(d).setNectarModuleDataSafe(this._causal_elem).setReadOnly(((d == \"GET\")));\n        this.setAsync(a);\n        return false;\n    },\n    _setFromModel: function(c) {\n        var a = {\n        };\n        copy_properties(a, c);\n        if (a.immediateRendering) {\n            this.setImmediateRendering(a.immediateRendering);\n            delete a.immediateRendering;\n        }\n    ;\n    ;\n        for (var d in a) {\n            if (((d == \"JSBNG__onloadRegister\"))) {\n                this.JSBNG__onloadRegister(a[d]);\n                continue;\n            }\n        ;\n        ;\n            var b = this[((((\"set\" + d.substr(0, 1).toUpperCase())) + d.substr(1)))];\n            b.apply(this, $A(a[d]));\n        };\n    ;\n    },\n    _updateBottom: function() {\n        var a = ((Vector2.getElementDimensions(this._content).y + Vector2.getElementPosition(this._content).y));\n        Dialog._bottoms[((Dialog._bottoms.length - 1))] = a;\n        Dialog._updateMaxBottom();\n    }\n});\nfunction AsyncRequest(uri) {\n    var dispatchResponse = bind(this, function(asyncResponse) {\n        try {\n            this.clearStatusIndicator();\n            if (!this.isRelevant()) {\n                invokeErrorHandler(1010);\n                return;\n            }\n        ;\n        ;\n            if (((this.initialHandler(asyncResponse) !== false))) {\n                JSBNG__clearTimeout(this.timer);\n                ((asyncResponse.jscc && invoke_callbacks([asyncResponse.jscc,])));\n                if (this.handler) {\n                    try {\n                        var suppress_onload = this.handler(asyncResponse);\n                    } catch (exception) {\n                        ((asyncResponse.is_last && this.finallyHandler(asyncResponse)));\n                        throw exception;\n                    };\n                }\n            ;\n            ;\n                if (((suppress_onload !== AsyncRequest.suppressOnloadToken))) {\n                    var JSBNG__onload = asyncResponse.JSBNG__onload;\n                    if (JSBNG__onload) {\n                        for (var ii = 0; ((ii < JSBNG__onload.length)); ii++) {\n                            try {\n                                (new Function(JSBNG__onload[ii])).apply(this);\n                            } catch (exception) {\n                            \n                            };\n                        ;\n                        };\n                    }\n                ;\n                ;\n                    if (this.lid) {\n                        Arbiter.inform(\"tti_ajax\", {\n                            s: this.lid,\n                            d: [((this._sendTimeStamp || 0)),((((this._sendTimeStamp && this._responseTime)) ? ((this._responseTime - this._sendTimeStamp)) : 0)),]\n                        }, Arbiter.BEHAVIOR_EVENT);\n                    }\n                ;\n                ;\n                    var JSBNG__onafterload = asyncResponse.JSBNG__onafterload;\n                    if (JSBNG__onafterload) {\n                        for (var ii = 0; ((ii < JSBNG__onafterload.length)); ii++) {\n                            try {\n                                (new Function(JSBNG__onafterload[ii])).apply(this);\n                            } catch (exception) {\n                            \n                            };\n                        ;\n                        };\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                ((asyncResponse.is_last && this.finallyHandler(asyncResponse)));\n            }\n        ;\n        ;\n        } catch (exception) {\n        \n        };\n    ;\n    });\n    var dispatchErrorResponse = bind(this, function(asyncResponse, isTransport) {\n        try {\n            this.clearStatusIndicator();\n            var async_error = asyncResponse.getError();\n            if (this._sendTimeStamp) {\n                var _duration = (((+new JSBNG__Date()) - this._sendTimeStamp));\n                var xfb_ip = ((this._xFbServer || \"-\"));\n                asyncResponse.logError(\"async_error\", {\n                    duration: _duration,\n                    xfb_ip: xfb_ip\n                });\n            }\n             else asyncResponse.logError(\"async_error\");\n        ;\n        ;\n            if ((((!this.isRelevant()) || ((async_error === 1010))))) {\n                return;\n            }\n        ;\n        ;\n            if (((((((((async_error == 1357008)) || ((async_error == 1357007)))) || ((async_error == 1442002)))) || ((async_error == 1357001))))) {\n                var is_confirmation = false;\n                if (((((async_error == 1357008)) || ((async_error == 1357007))))) {\n                    is_confirmation = true;\n                }\n            ;\n            ;\n                var payload = asyncResponse.getPayload();\n                this._displayServerDialog(payload.__dialog, is_confirmation);\n            }\n             else if (((this.initialHandler(asyncResponse) !== false))) {\n                JSBNG__clearTimeout(this.timer);\n                try {\n                    if (isTransport) {\n                        this.transportErrorHandler(asyncResponse);\n                    }\n                     else this.errorHandler(asyncResponse);\n                ;\n                ;\n                } catch (exception) {\n                    this.finallyHandler(asyncResponse);\n                    throw exception;\n                };\n            ;\n                this.finallyHandler(asyncResponse);\n            }\n            \n        ;\n        ;\n        } catch (exception) {\n        \n        };\n    ;\n    });\n    var _interpretTransportResponse = bind(this, function() {\n        if (this.getOption(\"suppressEvaluation\")) {\n            var r = new AsyncResponse(this, this.transport);\n            return {\n                asyncResponse: r\n            };\n        }\n    ;\n    ;\n        var _sendError = function(p, error_code, str) {\n            if (!window.send_error_signal) {\n                return;\n            }\n        ;\n        ;\n            if (this._xFbServer) {\n                error_code = ((\"1008_\" + error_code));\n            }\n             else error_code = ((\"1012_\" + error_code));\n        ;\n        ;\n            send_error_signal(\"async_xport_resp\", ((((((((((((((((error_code + \":\")) + ((this._xFbServer || \"-\")))) + \":\")) + p.getURI())) + \":\")) + str.length)) + \":\")) + str.substr(0, 1600))));\n        };\n        var shield = \"for (;;);\";\n        var shieldlen = shield.length;\n        var text = this.transport.responseText;\n        if (((text.length <= shieldlen))) {\n            _sendError(this, \"empty\", text);\n            return {\n                transportError: ((\"Response too short on async to \" + this.getURI()))\n            };\n        }\n    ;\n    ;\n        var offset = 0;\n        while (((((text.charAt(offset) == \" \")) || ((text.charAt(offset) == \"\\u000a\"))))) {\n            offset++;\n        ;\n        };\n    ;\n        ((offset && ((text.substring(offset, ((offset + shieldlen))) == shield))));\n        var safeResponse = text.substring(((offset + shieldlen)));\n        try {\n            var response = eval(((((\"(\" + safeResponse)) + \")\")));\n        } catch (exception) {\n            _sendError(this, \"excep\", text);\n            return {\n                transportError: ((\"eval() failed on async to \" + this.getURI()))\n            };\n        };\n    ;\n        return interpretResponse(response);\n    });\n    var interpretResponse = bind(this, function(response) {\n        if (response.redirect) {\n            return {\n                redirect: response.redirect\n            };\n        }\n    ;\n    ;\n        var r = new AsyncResponse(this);\n        if (((response.__ar != 1))) {\n            r.payload = response;\n        }\n         else {\n            copy_properties(r, response);\n            if (response.tplts) {\n                if (window.DynaTemplate) {\n                    DynaTemplate.registerTemplates(response.tplts);\n                }\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return {\n            asyncResponse: r\n        };\n    });\n    var invokeResponseHandler = bind(this, function(interp) {\n        if (((typeof (interp.redirect) != \"undefined\"))) {\n            (function() {\n                this.setURI(interp.redirect).send();\n            }).bind(this).defer();\n            return;\n        }\n    ;\n    ;\n        if (((((this.handler || this.errorHandler)) || this.transportErrorHandler))) {\n            if (((typeof (interp.asyncResponse) != \"undefined\"))) {\n                var r = interp.asyncResponse;\n                if (!this.isRelevant()) {\n                    invokeErrorHandler(1010);\n                    return;\n                }\n            ;\n            ;\n                if (r.inlinejs) {\n                    eval_global(r.inlinejs);\n                }\n            ;\n            ;\n                if (r.lid) {\n                    this._responseTime = (+new JSBNG__Date());\n                    if (window.CavalryLogger) {\n                        this.cavalry = CavalryLogger.getInstance(r.lid);\n                    }\n                ;\n                ;\n                    this.lid = r.lid;\n                }\n            ;\n            ;\n                if (((r.getError() && !r.getErrorIsWarning()))) {\n                    var fn = dispatchErrorResponse;\n                }\n                 else var fn = dispatchResponse\n            ;\n                Bootloader.setResourceMap(r.resource_map);\n                if (r.bootloadable) {\n                    Bootloader.enableBootload(r.bootloadable);\n                }\n            ;\n            ;\n                fn = fn.shield(null, r);\n                fn = fn.defer.bind(fn);\n                var is_transitional = false;\n                if (this.preBootloadHandler) {\n                    is_transitional = this.preBootloadHandler(r);\n                }\n            ;\n            ;\n                r.css = ((r.css || []));\n                r.js = ((r.js || []));\n                Bootloader.loadResources(r.css.concat(r.js), fn, is_transitional, this.getURI());\n            }\n             else if (((typeof (interp.transportError) != \"undefined\"))) {\n                if (this._xFbServer) {\n                    invokeErrorHandler(1008);\n                }\n                 else invokeErrorHandler(1012);\n            ;\n            ;\n            }\n             else invokeErrorHandler(1007);\n            \n        ;\n        }\n    ;\n    ;\n    });\n    var invokeErrorHandler = bind(this, function(explicitError) {\n        try {\n            if (((!window.loaded && !this.getOption(\"handleErrorAfterUnload\")))) {\n                return;\n            }\n        ;\n        ;\n        } catch (ex) {\n            return;\n        };\n    ;\n        var r = new AsyncResponse(this);\n        var err;\n        try {\n            err = ((((explicitError || this.transport.JSBNG__status)) || 1004));\n        } catch (ex) {\n            err = 1005;\n        };\n    ;\n        if (this._requestAborted) {\n            err = 1011;\n        }\n    ;\n    ;\n        try {\n            if (((this.responseText == \"\"))) {\n                err = 1002;\n            }\n        ;\n        ;\n        } catch (ignore) {\n        \n        };\n    ;\n        if (this.transportErrorHandler) {\n            var desc, summary;\n            var silent = true;\n            if (((false === JSBNG__navigator.JSBNG__onLine))) {\n                summary = _tx(\"No Network Connection\");\n                desc = _tx(\"Your browser appears to be offline. Please check your internet connection and try again.\");\n                err = 1006;\n            }\n             else if (((((err >= 300)) && ((err <= 399))))) {\n                summary = _tx(\"Redirection\");\n                desc = _tx(\"Your access to Facebook was redirected or blocked by a third party at this time, please contact your ISP or reload. \");\n                redir_url = this.transport.getResponseHeader(\"Location\");\n                if (redir_url) {\n                    goURI(redir_url, true);\n                }\n            ;\n            ;\n                silent = true;\n            }\n             else {\n                summary = _tx(\"Oops!\");\n                desc = _tx(\"Something went wrong. We're working on getting this fixed as soon as we can. You may be able to try again.\");\n            }\n            \n        ;\n        ;\n            !this.getOption(\"suppressErrorAlerts\");\n            copy_properties(r, {\n                error: err,\n                errorSummary: summary,\n                errorDescription: desc,\n                silentError: silent\n            });\n            dispatchErrorResponse(r, true);\n        }\n    ;\n    ;\n    });\n    var handleResponse = function(response) {\n        var asyncResponse = this.interpretResponse(response);\n        this.invokeResponseHandler(asyncResponse);\n    };\n    var JSBNG__onStateChange = function() {\n        try {\n            if (((this.transport.readyState == 4))) {\n                AsyncRequest._inflightPurge();\n                try {\n                    if (((((typeof (this.transport.getResponseHeader) != \"undefined\")) && this.transport.getResponseHeader(\"X-FB-Server\")))) {\n                        this._xFbServer = this.transport.getResponseHeader(\"X-FB-Server\");\n                    }\n                ;\n                ;\n                } catch (ex) {\n                \n                };\n            ;\n                if (((((this.transport.JSBNG__status >= 200)) && ((this.transport.JSBNG__status < 300))))) {\n                    invokeResponseHandler(_interpretTransportResponse());\n                }\n                 else if (((ua.safari() && ((typeof (this.transport.JSBNG__status) == \"undefined\"))))) {\n                    invokeErrorHandler(1002);\n                }\n                 else if (((((((window.Env && window.Env.retry_ajax_on_network_error)) && ((this.transport.JSBNG__status in {\n                    0: 1,\n                    12029: 1,\n                    12030: 1,\n                    12031: 1,\n                    12152: 1\n                })))) && ((this.remainingRetries > 0))))) {\n                    --this.remainingRetries;\n                    delete this.transport;\n                    this.send(true);\n                    return;\n                }\n                 else invokeErrorHandler();\n                \n                \n            ;\n            ;\n                if (((this.getOption(\"asynchronous\") !== false))) {\n                    delete this.transport;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        } catch (exception) {\n            try {\n                if (!window.loaded) {\n                    return;\n                }\n            ;\n            ;\n            } catch (ex) {\n                return;\n            };\n        ;\n            delete this.transport;\n            if (((this.remainingRetries > 0))) {\n                --this.remainingRetries;\n                this.send(true);\n            }\n             else {\n                !this.getOption(\"suppressErrorAlerts\");\n                if (window.send_error_signal) {\n                    send_error_signal(\"async_xport_resp\", ((((((((((\"1007:\" + ((this._xFbServer || \"-\")))) + \":\")) + this.getURI())) + \":\")) + exception.message)));\n                }\n            ;\n            ;\n                invokeErrorHandler(1007);\n            }\n        ;\n        ;\n        };\n    ;\n    };\n    var JSBNG__onJSONPResponse = function(data, more_chunked_response) {\n        var is_first = ((this.is_first === undefined));\n        this.is_first = is_first;\n        if (((this.transportIframe && !more_chunked_response))) {\n            if (this.cavalry) {\n                this.cavalry.collectBrowserTiming(this.transportIframe.contentWindow);\n            }\n        ;\n        ;\n            (function(x) {\n                JSBNG__document.body.removeChild(x);\n            }).bind(null, this.transportIframe).defer();\n        }\n    ;\n    ;\n        if (((((ua.ie() >= 9)) && window.JSON))) {\n            data = window.JSON.parse(window.JSON.stringify(data));\n        }\n    ;\n    ;\n        var r = this.interpretResponse(data);\n        r.asyncResponse.is_first = is_first;\n        r.asyncResponse.is_last = !more_chunked_response;\n        this.invokeResponseHandler(r);\n        return more_chunked_response;\n    };\n    copy_properties(this, {\n        JSBNG__onstatechange: JSBNG__onStateChange,\n        JSBNG__onjsonpresponse: JSBNG__onJSONPResponse,\n        invokeResponseHandler: invokeResponseHandler,\n        interpretResponse: interpretResponse,\n        handleResponse: handleResponse,\n        transport: null,\n        method: \"POST\",\n        uri: \"\",\n        timeout: null,\n        timer: null,\n        initialHandler: bagofholding,\n        handler: null,\n        errorHandler: null,\n        transportErrorHandler: null,\n        timeoutHandler: null,\n        finallyHandler: bagofholding,\n        serverDialogCancelHandler: bagofholding,\n        relativeTo: null,\n        statusElement: null,\n        statusClass: \"\",\n        data: {\n        },\n        context: {\n        },\n        readOnly: false,\n        writeRequiredParams: [\"post_form_id\",],\n        remainingRetries: 0,\n        option: {\n            asynchronous: true,\n            suppressErrorHandlerWarning: false,\n            suppressEvaluation: false,\n            suppressErrorAlerts: false,\n            retries: 0,\n            jsonp: false,\n            bundle: false,\n            useIframeTransport: false,\n            tfbEndpoint: true,\n            handleErrorAfterUnload: false\n        },\n        userActionID: \"-\"\n    });\n    this.errorHandler = AsyncResponse.defaultErrorHandler;\n    this.transportErrorHandler = bind(this, \"errorHandler\");\n    if (((uri != undefined))) {\n        this.setURI(uri);\n    }\n;\n;\n    return this;\n};\n;\nArbiter.subscribe(\"page_transition\", function(b, a) {\n    AsyncRequest._id_threshold = a.id;\n});\ncopy_properties(AsyncRequest, {\n    receiveJSONPResponse: function(b, a, c) {\n        if (this._JSONPReceivers[b]) {\n            if (!this._JSONPReceivers[b](a, c)) {\n                delete this._JSONPReceivers[b];\n            }\n        ;\n        ;\n        }\n         else if (((window.send_error_signal && !c))) {\n            var d = ((((a.payload && a.payload.uri)) || \"\"));\n            send_error_signal(\"js_timeout_and_exception\", ((((((\"00002:WrongSessionID:error:\" + b)) + \":\")) + d)));\n        }\n        \n    ;\n    ;\n    },\n    _bundleRequest: function(b) {\n        if (((b.getOption(\"jsonp\") || b.getOption(\"useIframeTransport\")))) {\n            b.setOption(\"bundle\", false);\n            return false;\n        }\n         else if (!b.uri.isFacebookURI()) {\n            b.setOption(\"bundle\", false);\n            return false;\n        }\n         else if (!b.getOption(\"asynchronous\")) {\n            b.setOption(\"bundle\", false);\n            return false;\n        }\n        \n        \n    ;\n    ;\n        var a = b.uri.getPath();\n        if (!AsyncRequest._bundleTimer) {\n            AsyncRequest._bundleTimer = JSBNG__setTimeout(function() {\n                AsyncRequest._sendBundledRequests();\n            }, 0);\n        }\n    ;\n    ;\n        AsyncRequest._allBundledRequests.push([a,b,]);\n        return true;\n    },\n    _sendBundledRequests: function() {\n        JSBNG__clearTimeout(AsyncRequest._bundleTimer);\n        AsyncRequest._bundleTimer = null;\n        var a = AsyncRequest._allBundledRequests;\n        AsyncRequest._allBundledRequests = [];\n        if (((a.length == 1))) {\n            var e = a[0][1];\n            e.setOption(\"bundle\", false).send();\n            return e;\n        }\n    ;\n    ;\n        if (((a.length === 0))) {\n            return null;\n        }\n    ;\n    ;\n        var b = [];\n        for (var c = 0; ((c < a.length)); c++) {\n            b.push([a[c][0],URI.implodeQuery(a[c][1].data),]);\n        ;\n        };\n    ;\n        var d = {\n            data: b\n        };\n        var e = new AsyncRequest();\n        e.setURI(\"/ajax/proxy.php\").setData(d).setMethod(\"POST\").setInitialHandler(bagof(true)).setAllowCrossPageTransition(true).setHandler(function(j) {\n            var i = j.getPayload();\n            var l = i.responses;\n            if (((l.length != a.length))) {\n                return;\n            }\n             else for (var g = 0; ((g < a.length)); g++) {\n                var h = a[g][0];\n                var k = a[g][1];\n                k.id = this.id;\n                if (((l[g][0] != h))) {\n                    k.invokeResponseHandler({\n                        transportError: ((\"Wrong response order in bundled request to \" + h))\n                    });\n                    continue;\n                }\n            ;\n            ;\n                var f = k.interpretResponse(l[g][1]);\n                k.invokeResponseHandler(f);\n            }\n        ;\n        ;\n        }).setTransportErrorHandler(function(k) {\n            var i = [];\n            var g = {\n                transportError: k.errorDescription\n            };\n            for (var f = 0; ((f < a.length)); f++) {\n                var h = a[f][0];\n                var j = a[f][1];\n                i.push(h);\n                j.id = this.id;\n                j.invokeResponseHandler(g);\n            };\n        ;\n        }).send();\n        return e;\n    },\n    bootstrap: function(c, b, d) {\n        var e = \"GET\";\n        var f = true;\n        var a = {\n        };\n        if (((d || ((b && ((((b.rel == \"async-post\")) || ((b.getAttribute && ((b.getAttribute(\"forcemethod\") == \"post\"))))))))))) {\n            e = \"POST\";\n            f = false;\n            if (c) {\n                c = URI(c);\n                a = c.getQueryData();\n                c.setQueryData({\n                });\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var g = ((Parent.byClass(b, \"stat_elem\") || b));\n        if (((g && CSS.hasClass(g, \"async_saving\")))) {\n            return false;\n        }\n    ;\n    ;\n        new AsyncRequest(c).setReadOnly(f).setMethod(e).setData(a).setNectarModuleDataSafe(b).setStatusElement(g).setRelativeTo(b).send();\n        return false;\n    },\n    post: function(b, a) {\n        new AsyncRequest(b).setReadOnly(false).setMethod(\"POST\").setData(a).send();\n        return false;\n    },\n    getLastId: function() {\n        return AsyncRequest._last_id;\n    },\n    _JSONPReceivers: {\n    },\n    _allBundledRequests: [],\n    _bundleTimer: null,\n    suppressOnloadToken: {\n    },\n    _last_id: 2,\n    _id_threshold: 2,\n    _inflight: [],\n    _inflightAdd: bagofholding,\n    _inflightPurge: bagofholding,\n    _inflightEnable: function() {\n        if (ua.ie()) {\n            copy_properties(AsyncRequest, {\n                _inflightAdd: function(a) {\n                    this._inflight.push(a);\n                },\n                _inflightPurge: function() {\n                    AsyncRequest._inflight = AsyncRequest._inflight.filter(function(a) {\n                        return ((a.transport && ((a.transport.readyState < 4))));\n                    });\n                }\n            });\n            JSBNG__onunloadRegister(function() {\n                AsyncRequest._inflight.each(function(a) {\n                    if (((a.transport && ((a.transport.readyState < 4))))) {\n                        a.transport.abort();\n                        delete a.transport;\n                    }\n                ;\n                ;\n                });\n            });\n        }\n    ;\n    ;\n    }\n});\ncopy_properties(AsyncRequest.prototype, {\n    setMethod: function(a) {\n        this.method = a.toString().toUpperCase();\n        return this;\n    },\n    getMethod: function() {\n        return this.method;\n    },\n    setData: function(a) {\n        this.data = a;\n        return this;\n    },\n    getData: function() {\n        return this.data;\n    },\n    setContextData: function(b, c, a) {\n        a = ((((a === undefined)) ? true : a));\n        if (a) {\n            this.context[((\"_log_\" + b))] = c;\n        }\n    ;\n    ;\n        return this;\n    },\n    _setUserActionID: function() {\n        this.userActionID = ((((((((window.EagleEye && EagleEye.getSessionID())) || \"-\")) + \"/\")) + ((((window.ArbiterMonitor && ArbiterMonitor.getUE())) || \"-\"))));\n    },\n    setURI: function(b) {\n        var c = URI(b);\n        if (((this.getOption(\"useIframeTransport\") && !c.isFacebookURI()))) {\n            return this;\n        }\n    ;\n    ;\n        if (((((!this.getOption(\"jsonp\") && !this.getOption(\"useIframeTransport\"))) && !c.isSameOrigin()))) {\n            return this;\n        }\n    ;\n    ;\n        this._setUserActionID();\n        if (((!b || c.isEmpty()))) {\n            if (((window.send_error_signal && window.get_error_stack))) {\n                var a = {\n                    err_code: 1013,\n                    vip: \"-\",\n                    duration: 0,\n                    xfb_ip: \"-\",\n                    path: window.JSBNG__location.href,\n                    aid: this.userActionID\n                };\n                send_error_signal(\"async_error\", JSON.stringify(a));\n                send_error_signal(\"async_xport_stack\", ((((((\"1013:\" + window.JSBNG__location.href)) + \"::\")) + get_error_stack())));\n            }\n        ;\n        ;\n            return this;\n        }\n    ;\n    ;\n        this.uri = c;\n        return this;\n    },\n    getURI: function() {\n        return this.uri.toString();\n    },\n    setInitialHandler: function(a) {\n        this.initialHandler = a;\n        return this;\n    },\n    setHandler: function(a) {\n        if (!((typeof (a) != \"function\"))) {\n            this.handler = a;\n        }\n    ;\n    ;\n        return this;\n    },\n    getHandler: function() {\n        return this.handler;\n    },\n    setErrorHandler: function(a) {\n        if (!((typeof (a) != \"function\"))) {\n            this.errorHandler = a;\n        }\n    ;\n    ;\n        return this;\n    },\n    setTransportErrorHandler: function(a) {\n        this.transportErrorHandler = a;\n        return this;\n    },\n    getErrorHandler: function() {\n        return this.errorHandler;\n    },\n    getTransportErrorHandler: function() {\n        return this.transportErrorHandler;\n    },\n    setTimeoutHandler: function(b, a) {\n        if (!((typeof (a) != \"function\"))) {\n            this.timeout = b;\n            this.timeoutHandler = a;\n        }\n    ;\n    ;\n        return this;\n    },\n    resetTimeout: function(b) {\n        if (!((this.timeoutHandler === null))) {\n            if (((b === null))) {\n                this.timeout = null;\n                JSBNG__clearTimeout(this.timer);\n                this.timer = null;\n            }\n             else {\n                var a = !this._allowCrossPageTransition;\n                this.timeout = b;\n                JSBNG__clearTimeout(this.timer);\n                this.timer = this._handleTimeout.bind(this).defer(this.timeout, a);\n            }\n        ;\n        }\n    ;\n    ;\n        return this;\n    },\n    _handleTimeout: function() {\n        this.abandon();\n        this.timeoutHandler(this);\n    },\n    setNewSerial: function() {\n        this.id = ++AsyncRequest._last_id;\n        return this;\n    },\n    setFinallyHandler: function(a) {\n        this.finallyHandler = a;\n        return this;\n    },\n    setServerDialogCancelHandler: function(a) {\n        this.serverDialogCancelHandler = a;\n        return this;\n    },\n    setPreBootloadHandler: function(a) {\n        this.preBootloadHandler = a;\n        return this;\n    },\n    setReadOnly: function(a) {\n        if (!((typeof (a) != \"boolean\"))) {\n            this.readOnly = a;\n        }\n    ;\n    ;\n        return this;\n    },\n    setFBMLForm: function() {\n        this.writeRequiredParams = [\"fb_sig\",];\n        return this;\n    },\n    getReadOnly: function() {\n        return this.readOnly;\n    },\n    setRelativeTo: function(a) {\n        this.relativeTo = a;\n        return this;\n    },\n    getRelativeTo: function() {\n        return this.relativeTo;\n    },\n    setStatusClass: function(a) {\n        this.statusClass = a;\n        return this;\n    },\n    setStatusElement: function(a) {\n        this.statusElement = a;\n        return this;\n    },\n    getStatusElement: function() {\n        return ge(this.statusElement);\n    },\n    isRelevant: function() {\n        if (this._allowCrossPageTransition) {\n            return true;\n        }\n    ;\n    ;\n        if (!this.id) {\n            return true;\n        }\n    ;\n    ;\n        return ((this.id > AsyncRequest._id_threshold));\n    },\n    clearStatusIndicator: function() {\n        var a = this.getStatusElement();\n        if (a) {\n            CSS.removeClass(a, \"async_saving\");\n            CSS.removeClass(a, this.statusClass);\n        }\n    ;\n    ;\n    },\n    addStatusIndicator: function() {\n        var a = this.getStatusElement();\n        if (a) {\n            CSS.addClass(a, \"async_saving\");\n            CSS.addClass(a, this.statusClass);\n        }\n    ;\n    ;\n    },\n    specifiesWriteRequiredParams: function() {\n        return this.writeRequiredParams.every(function(a) {\n            this.data[a] = ((((this.data[a] || Env[a])) || ((ge(a) || {\n            })).value));\n            if (((this.data[a] !== undefined))) {\n                return true;\n            }\n        ;\n        ;\n            return false;\n        }, this);\n    },\n    setOption: function(a, b) {\n        if (((typeof (this.option[a]) != \"undefined\"))) {\n            this.option[a] = b;\n        }\n    ;\n    ;\n        return this;\n    },\n    getOption: function(a) {\n        ((typeof (this.option[a]) == \"undefined\"));\n        return this.option[a];\n    },\n    abort: function() {\n        if (this.transport) {\n            var a = this.getTransportErrorHandler();\n            this.setOption(\"suppressErrorAlerts\", true);\n            this.setTransportErrorHandler(bagofholding);\n            this._requestAborted = 1;\n            this.transport.abort();\n            this.setTransportErrorHandler(a);\n        }\n    ;\n    ;\n    },\n    abandon: function() {\n        JSBNG__clearTimeout(this.timer);\n        this.setOption(\"suppressErrorAlerts\", true).setHandler(bagofholding).setErrorHandler(bagofholding).setTransportErrorHandler(bagofholding);\n        if (this.transport) {\n            this._requestAborted = 1;\n            this.transport.abort();\n        }\n    ;\n    ;\n    },\n    setNectarData: function(a) {\n        if (a) {\n            if (((this.data.nctr === undefined))) {\n                this.data.nctr = {\n                };\n            }\n        ;\n        ;\n            copy_properties(this.data.nctr, a);\n        }\n    ;\n    ;\n        return this;\n    },\n    setNectarModuleDataSafe: function(a) {\n        if (this.setNectarModuleData) {\n            this.setNectarModuleData(a);\n        }\n    ;\n    ;\n        return this;\n    },\n    setNectarImpressionIdSafe: function() {\n        if (this.setNectarImpressionId) {\n            this.setNectarImpressionId();\n        }\n    ;\n    ;\n        return this;\n    },\n    setAllowCrossPageTransition: function(a) {\n        this._allowCrossPageTransition = !!a;\n        if (this.timer) {\n            this.resetTimeout(this.timeout);\n        }\n    ;\n    ;\n        return this;\n    },\n    send: function(c) {\n        c = ((c || false));\n        if (!this.uri) {\n            return false;\n        }\n    ;\n    ;\n        ((!this.errorHandler && !this.getOption(\"suppressErrorHandlerWarning\")));\n        if (((this.getOption(\"jsonp\") && ((this.method != \"GET\"))))) {\n            this.setMethod(\"GET\");\n        }\n    ;\n    ;\n        if (((this.getOption(\"useIframeTransport\") && ((this.method != \"GET\"))))) {\n            this.setMethod(\"GET\");\n        }\n    ;\n    ;\n        ((((this.timeoutHandler !== null)) && ((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\")))));\n        if (!this.getReadOnly()) {\n            this.specifiesWriteRequiredParams();\n            if (((this.method != \"POST\"))) {\n                return false;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((((this.method == \"POST\")) && this.getOption(\"tfbEndpoint\")))) {\n            this.data.fb_dtsg = Env.fb_dtsg;\n            this.data.lsd = getCookie(\"lsd\");\n        }\n    ;\n    ;\n        if (((!is_empty(this.context) && this.getOption(\"tfbEndpoint\")))) {\n            copy_properties(this.data, this.context);\n            this.data.ajax_log = 1;\n        }\n    ;\n    ;\n        if (((((((!this.getReadOnly() && this.getOption(\"tfbEndpoint\"))) && ((this.method == \"POST\")))) && ((this.data.post_form_id_source === undefined))))) {\n            this.data.post_form_id_source = \"AsyncRequest\";\n        }\n    ;\n    ;\n        if (window.Env) {\n            this.data.__user = Env.user;\n        }\n    ;\n    ;\n        this._setUserActionID();\n        if (((this.getOption(\"bundle\") && AsyncRequest._bundleRequest(this)))) {\n            return true;\n        }\n    ;\n    ;\n        this.setNewSerial();\n        if (this.getOption(\"tfbEndpoint\")) {\n            this.uri.addQueryData({\n                __a: 1\n            });\n            if (Env.fb_isb) {\n                this.uri.addQueryData({\n                    fb_isb: Env.fb_isb\n                });\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this.finallyHandler = async_callback(this.finallyHandler, \"final\");\n        var h, d;\n        if (((this.method == \"GET\"))) {\n            h = this.uri.addQueryData(this.data).toString();\n            d = \"\";\n        }\n         else {\n            h = this.uri.toString();\n            d = URI.implodeQuery(this.data);\n        }\n    ;\n    ;\n        if (((this.getOption(\"jsonp\") || this.getOption(\"useIframeTransport\")))) {\n            h = this.uri.addQueryData({\n                __a: this.id\n            }).toString();\n            AsyncRequest._JSONPReceivers[this.id] = async_callback(bind(this, \"JSBNG__onjsonpresponse\"), \"json\");\n            if (this.getOption(\"jsonp\")) {\n                (function() {\n                    JSBNG__document.body.appendChild($N(\"script\", {\n                        src: h,\n                        type: \"text/javascript\"\n                    }));\n                }).bind(this).defer();\n            }\n             else {\n                var e = {\n                    position: \"absolute\",\n                    JSBNG__top: \"-9999999px\",\n                    width: \"80px\",\n                    height: \"80px\"\n                };\n                this.transportIframe = $N(\"div\", {\n                    src: \"javascript:''\",\n                    style: e\n                });\n                JSBNG__document.body.appendChild(this.transportIframe);\n                this.transportIframe.src = h;\n            }\n        ;\n        ;\n            return true;\n        }\n    ;\n    ;\n        if (this.transport) {\n            return false;\n        }\n    ;\n    ;\n        var g = null;\n        try {\n            g = new JSBNG__XMLHttpRequest();\n        } catch (b) {\n        \n        };\n    ;\n        if (!g) {\n            try {\n                g = new ActiveXObject(\"Msxml2.XMLHTTP\");\n            } catch (b) {\n            \n            };\n        }\n    ;\n    ;\n        if (!g) {\n            try {\n                g = new ActiveXObject(\"Microsoft.XMLHTTP\");\n            } catch (b) {\n            \n            };\n        }\n    ;\n    ;\n        if (!g) {\n            return false;\n        }\n    ;\n    ;\n        g.JSBNG__onreadystatechange = async_callback(bind(this, \"JSBNG__onstatechange\"), \"xhr\");\n        if (!c) {\n            this.remainingRetries = this.getOption(\"retries\");\n        }\n    ;\n    ;\n        if (((window.send_error_signal || window.ArbiterMonitor))) {\n            this._sendTimeStamp = ((this._sendTimeStamp || (+new JSBNG__Date())));\n        }\n    ;\n    ;\n        this.transport = g;\n        try {\n            this.transport.open(this.method, h, this.getOption(\"asynchronous\"));\n        } catch (a) {\n            return false;\n        };\n    ;\n        var f = env_get(\"svn_rev\");\n        if (f) {\n            this.transport.setRequestHeader(\"X-SVN-Rev\", String(f));\n        }\n    ;\n    ;\n        if (((this.method == \"POST\"))) {\n            this.transport.setRequestHeader(\"Content-Type\", \"application/x-www-form-urlencoded\");\n        }\n    ;\n    ;\n        this.addStatusIndicator();\n        this.transport.send(d);\n        if (((this.timeout !== null))) {\n            this.resetTimeout(this.timeout);\n        }\n    ;\n    ;\n        AsyncRequest._inflightAdd(this);\n        return true;\n    },\n    _displayServerDialog: function(c, b) {\n        var a = new Dialog(c);\n        if (b) {\n            a.setHandler(this._displayConfirmationHandler.bind(this, a));\n        }\n    ;\n    ;\n        a.setCancelHandler(function() {\n            this.serverDialogCancelHandler.apply(this, arguments);\n            this.finallyHandler.apply(this, arguments);\n        }.bind(this)).setCloseHandler(this.finallyHandler.bind(this)).show();\n    },\n    _displayConfirmationHandler: function(a) {\n        this.data.confirmed = 1;\n        copy_properties(this.data, a.getFormData());\n        this.send();\n    }\n});\nfunction AsyncResponse(b, a) {\n    copy_properties(this, {\n        error: 0,\n        errorSummary: null,\n        errorDescription: null,\n        JSBNG__onload: null,\n        replay: false,\n        payload: ((a || null)),\n        request: ((b || null)),\n        silentError: false,\n        is_last: true\n    });\n    return this;\n};\n;\ncopy_properties(AsyncResponse, {\n    defaultErrorHandler: function(b) {\n        try {\n            if (!b.silentError) {\n                AsyncResponse.verboseErrorHandler(b);\n            }\n             else b.logErrorByGroup(\"silent\", 10);\n        ;\n        ;\n        } catch (a) {\n            JSBNG__alert(b);\n        };\n    ;\n    },\n    verboseErrorHandler: function(b) {\n        try {\n            var summary = b.getErrorSummary();\n            var desc = b.getErrorDescription();\n            b.logErrorByGroup(\"popup\", 10);\n            if (((b.silentError && ((desc == \"\"))))) {\n                desc = _tx(\"Something went wrong. We're working on getting this fixed as soon as we can. You may be able to try again.\");\n            }\n        ;\n        ;\n            ErrorDialog.show(summary, desc);\n        } catch (a) {\n            JSBNG__alert(b);\n        };\n    ;\n    }\n});\ncopy_properties(AsyncResponse.prototype, {\n    getRequest: function() {\n        return this.request;\n    },\n    getPayload: function() {\n        return this.payload;\n    },\n    getError: function() {\n        return this.error;\n    },\n    getErrorSummary: function() {\n        return this.errorSummary;\n    },\n    setErrorSummary: function(a) {\n        a = ((((a === undefined)) ? null : a));\n        this.errorSummary = a;\n        return this;\n    },\n    getErrorDescription: function() {\n        return this.errorDescription;\n    },\n    getErrorIsWarning: function() {\n        return this.errorIsWarning;\n    },\n    logError: function(a, c) {\n        if (window.send_error_signal) {\n            var b = {\n                err_code: this.error,\n                vip: ((env_get(\"vip\") || \"-\"))\n            };\n            if (((c !== undefined))) {\n                b.duration = c.duration;\n                b.xfb_ip = c.xfb_ip;\n            }\n        ;\n        ;\n            var d = this.request.getURI();\n            b.path = ((d || \"-\"));\n            b.aid = this.request.userActionID;\n            if (((d && ((d.indexOf(\"scribe_endpoint.php\") != -1))))) {\n                a = \"async_error_double\";\n            }\n        ;\n        ;\n            send_error_signal(a, JSON.stringify(b));\n        }\n    ;\n    ;\n    },\n    logErrorByGroup: function(b, a) {\n        if (((Math.floor(((Math.JSBNG__random() * a))) == 0))) {\n            if (((((this.error == 1357010)) || ((this.error < 15000))))) {\n                this.logError(((\"async_error_oops_\" + b)));\n            }\n             else this.logError(((\"async_error_logic_\" + b)));\n        ;\n        }\n    ;\n    ;\n    }\n});\nfunction UntrustedLink(a, d, b, c) {\n    this.dom = a;\n    this.url = a.href;\n    this.hash = d;\n    this.func_get_params = ((c || function() {\n        return {\n        };\n    }));\n    JSBNG__Event.listen(this.dom, \"click\", this.JSBNG__onclick.bind(this));\n    JSBNG__Event.listen(this.dom, \"mousedown\", this.JSBNG__onmousedown.bind(this));\n    JSBNG__Event.listen(this.dom, \"mouseup\", this.JSBNG__onmouseup.bind(this));\n    JSBNG__Event.listen(this.dom, \"mouseout\", this.JSBNG__onmouseout.bind(this));\n    this.JSBNG__onmousedown($E(b));\n};\n;\nUntrustedLink.bootstrap = function(a, d, b, c) {\n    if (a.__untrusted) {\n        return;\n    }\n;\n;\n    a.__untrusted = true;\n    new UntrustedLink(a, d, b, c);\n};\nUntrustedLink.prototype.getRewrittenURI = function() {\n    var a = copy_properties({\n        u: this.url,\n        h: this.hash\n    }, this.func_get_params(this.dom));\n    var b = new URI(\"/l.php\");\n    return b.setQueryData(a).setSubdomain(\"www\").setProtocol(\"http\");\n};\nUntrustedLink.prototype.JSBNG__onclick = function() {\n    (function() {\n        this.dom.href = this.url;\n    }).bind(this).defer(100);\n    this.dom.href = this.getRewrittenURI();\n};\nUntrustedLink.prototype.JSBNG__onmousedown = function(a) {\n    if (((a.button == 2))) {\n        this.dom.href = this.getRewrittenURI();\n    }\n;\n;\n};\nUntrustedLink.prototype.JSBNG__onmouseup = function() {\n    this.dom.href = this.getRewrittenURI();\n};\nUntrustedLink.prototype.JSBNG__onmouseout = function() {\n    this.dom.href = this.url;\n};\nfunction ElementController() {\n    this.handlers = [[],[],];\n};\n;\ncopy_properties(ElementController, {\n    ALL: 1,\n    TARGETS: 2,\n    MODIFIERS: 4,\n    BUTTONS: 8\n});\nElementController.prototype = {\n    initialize: function() {\n        this.initialize = bagofholding;\n        JSBNG__onloadRegister(this.register.bind(this));\n    },\n    handle: function(e, JSBNG__event, a) {\n        a = ((a || bagof(true)));\n        var b = this.handlers[0].concat(this.handlers[1]);\n        for (var c = 0, d = b.length; ((c < d)); c++) {\n            if (((a(b[c].filters, e, JSBNG__event) && ((b[c].callback(e, JSBNG__event) === false))))) {\n                return JSBNG__event.kill();\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    _registerHandler: function(b, a, c, d) {\n        this.initialize();\n        b[((d ? \"unshift\" : \"push\"))]({\n            callback: a,\n            filters: ((c || 0))\n        });\n    },\n    registerHandler: function(a, b, c) {\n        this._registerHandler(this.handlers[0], a, b, c);\n    },\n    registerFallbackHandler: function(a, b, c) {\n        this._registerHandler(this.handlers[1], a, b, c);\n    }\n};\nvar LinkController = new ElementController();\ncopy_properties(LinkController, {\n    key: \"LinkControllerHandler\",\n    register: function() {\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"mousedown\", this.handler.bind(this));\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", this.handler.bind(this));\n    },\n    handler: function(JSBNG__event) {\n        var b = Parent.byTag(JSBNG__event.getTarget(), \"a\");\n        var a = ((b && b.getAttribute(\"href\", 2)));\n        if (((((((!a || b.rel)) || !this.usesWebProtocol(a))) || DataStore.get(b, this.key)))) {\n            return;\n        }\n    ;\n    ;\n        DataStore.set(b, this.key, JSBNG__Event.listen(b, \"click\", function(JSBNG__event) {\n            if (((a.charAt(((a.length - 1))) == \"#\"))) {\n                JSBNG__event.prevent();\n                return;\n            }\n        ;\n        ;\n            trackReferrer(b, a);\n            this.handle(b, JSBNG__event, this.filter);\n        }.bind(this)));\n    },\n    filter: function(a, b, JSBNG__event) {\n        if (((a & ElementController.ALL))) {\n            return true;\n        }\n    ;\n    ;\n        if (((((((!((a & ElementController.TARGETS)) && b.target)) || ((!((a & ElementController.MODIFIERS)) && JSBNG__event.getModifiers().any)))) || ((((!((a & ElementController.BUTTONS)) && ((ua.safari() >= 525)))) && ((JSBNG__event.which != 1))))))) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    usesWebProtocol: function(a) {\n        var b = a.match(/^(\\w+):/);\n        return ((!b || b[1].match(/^http/i)));\n    }\n});\nvar FormController = new ElementController();\ncopy_properties(FormController, {\n    register: function() {\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"submit\", this.handler.bind(this));\n    },\n    handler: function(JSBNG__event) {\n        var a = JSBNG__event.getTarget();\n        if (((a.getAttributeNode(\"rel\") || {\n        })).value) {\n            return;\n        }\n    ;\n    ;\n        var b = user_action(a, \"form\", JSBNG__event);\n        if (window.ArbiterMonitor) {\n            ArbiterMonitor.initUA(b, [a,]);\n        }\n    ;\n    ;\n        return this.handle(a, JSBNG__event);\n    }\n});\nfunction JSBNG__Rect(e, d, a, c, b) {\n    if (((this === window))) {\n        if (((e instanceof JSBNG__Rect))) {\n            return e;\n        }\n    ;\n    ;\n        if (((e instanceof Vector2))) {\n            return new JSBNG__Rect(e.y, e.x, e.y, e.x, e.domain);\n        }\n    ;\n    ;\n        return JSBNG__Rect.getElementBounds($(e));\n    }\n;\n;\n    copy_properties(this, {\n        t: e,\n        r: d,\n        b: a,\n        l: c,\n        domain: ((b || \"pure\"))\n    });\n};\n;\ncopy_properties(JSBNG__Rect.prototype, {\n    w: function() {\n        return ((this.r - this.l));\n    },\n    h: function() {\n        return ((this.b - this.t));\n    },\n    toString: function() {\n        return ((((((((((((((((\"((\" + this.l)) + \", \")) + this.t)) + \"), (\")) + this.r)) + \", \")) + this.b)) + \"))\"));\n    },\n    contains: function(b) {\n        b = JSBNG__Rect(b).convertTo(this.domain);\n        var a = this;\n        return ((((((((a.l <= b.l)) && ((a.r >= b.r)))) && ((a.t <= b.t)))) && ((a.b >= b.b))));\n    },\n    add: function(c, d) {\n        if (((arguments.length == 1))) {\n            if (((c.domain != \"pure\"))) {\n                c = c.convertTo(this.domain);\n            }\n        ;\n        ;\n            return this.add(c.x, c.y);\n        }\n    ;\n    ;\n        var a = parseFloat(c);\n        var b = parseFloat(d);\n        return new JSBNG__Rect(((this.t + b)), ((this.r + a)), ((this.b + b)), ((this.l + a)), this.domain);\n    },\n    sub: function(a, b) {\n        if (((arguments.length == 1))) {\n            return this.add(a.mul(-1));\n        }\n         else return this.add(-a, -b)\n    ;\n    },\n    boundWithin: function(a) {\n        var b = 0, c = 0;\n        if (((this.l < a.l))) {\n            b = ((a.l - this.l));\n        }\n         else if (((this.r > a.r))) {\n            b = ((a.r - this.r));\n        }\n        \n    ;\n    ;\n        if (((this.t < a.t))) {\n            c = ((a.t - this.t));\n        }\n         else if (((this.b > a.b))) {\n            c = ((a.b - this.b));\n        }\n        \n    ;\n    ;\n        return this.add(b, c);\n    },\n    getCenter: function() {\n        return new Vector2(((this.l + ((this.w() / 2)))), ((this.t + ((this.h() / 2)))), this.domain);\n    },\n    getPositionVector: function() {\n        return new Vector2(this.l, this.t, this.domain);\n    },\n    getDimensionVector: function() {\n        return new Vector2(this.w(), this.h(), \"pure\");\n    },\n    convertTo: function(a) {\n        if (((this.domain == a))) {\n            return this;\n        }\n    ;\n    ;\n        if (((a == \"pure\"))) {\n            return new JSBNG__Rect(this.t, this.r, this.b, this.l, \"pure\");\n        }\n    ;\n    ;\n        if (((this.domain == \"pure\"))) {\n            return new JSBNG__Rect(0, 0, 0, 0);\n        }\n    ;\n    ;\n        var b = new Vector2(this.l, this.t, this.domain).convertTo(a);\n        return new JSBNG__Rect(b.y, ((b.x + this.w())), ((b.y + this.h())), b.x, a);\n    }\n});\ncopy_properties(JSBNG__Rect, {\n    deserialize: function(b) {\n        var a = b.split(\":\");\n        return new JSBNG__Rect(a[1], a[2], a[3], a[0]);\n    },\n    newFromVectors: function(b, a) {\n        return new JSBNG__Rect(b.y, ((b.x + a.x)), ((b.y + a.y)), b.x, b.domain);\n    },\n    getElementBounds: function(a) {\n        return JSBNG__Rect.newFromVectors(Vector2.getElementPosition(a), Vector2.getElementDimensions(a));\n    },\n    getViewportBounds: function() {\n        return JSBNG__Rect.newFromVectors(Vector2.getScrollPosition(), Vector2.getViewportDimensions());\n    },\n    minimumBoundingBox: function(d) {\n        var a = new JSBNG__Rect(Math.min(), Math.max(), Math.max(), Math.min());\n        var c;\n        for (var b = 0; ((b < d.length)); b++) {\n            c = d[b];\n            a.t = Math.min(a.t, c.t);\n            a.r = Math.max(a.r, c.r);\n            a.b = Math.max(a.b, c.b);\n            a.l = Math.min(a.l, c.l);\n        };\n    ;\n        return a;\n    }\n});\nJSBNG__onloadRegister(function() {\n    copy_properties(AsyncRequest.prototype, {\n        setNectarModuleData: function(c) {\n            if (((this.method == \"POST\"))) {\n                var d = Env.module;\n                if (((c && ((d === undefined))))) {\n                    var b = {\n                        fbpage_fan_confirm: 1\n                    };\n                    var e = null;\n                    for (var a = c; ((a && ((a != JSBNG__document.body)))); a = a.parentNode) {\n                        if (((!a.id || ((typeof a.id !== \"string\"))))) {\n                            continue;\n                        }\n                    ;\n                    ;\n                        if (a.id.startsWith(\"pagelet_\")) {\n                            d = a.id;\n                            break;\n                        }\n                    ;\n                    ;\n                        if (((!e && b[a.id]))) {\n                            e = a.id;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((((d === undefined)) && e))) {\n                        d = e;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                if (((d !== undefined))) {\n                    if (((this.data.nctr === undefined))) {\n                        this.data.nctr = {\n                        };\n                    }\n                ;\n                ;\n                    this.data.nctr._mod = d;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        setNectarImpressionId: function() {\n            if (((this.method == \"POST\"))) {\n                var a = env_get(\"impid\");\n                if (((a !== undefined))) {\n                    if (((this.data.nctr === undefined))) {\n                        this.data.nctr = {\n                        };\n                    }\n                ;\n                ;\n                    this.data.nctr._impid = a;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    });\n});\nif (((window == window.JSBNG__top))) {\n    !function() {\n        var a = function() {\n            var b = 0;\n            return function() {\n                if (!b) {\n                    b = 1;\n                    JSBNG__setTimeout(((window.top.JSBNG_Replay.push)((window.top.JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_505), function() {\n                        b = 0;\n                        var c = Vector2.getViewportDimensions();\n                        setCookie(\"wd\", ((((c.x + \"x\")) + c.y)));\n                        if (((window.AsyncSignal && ((Math.JSBNG__random() < 100866))))) {\n                            new AsyncSignal(\"/ajax/dimension_context.php\", {\n                                x: c.x,\n                                y: c.y\n                            }).send();\n                        }\n                    ;\n                    ;\n                    })), 100);\n                }\n            ;\n            ;\n            };\n        }();\n        JSBNG__onloadRegister(a);\n        JSBNG__onloadRegister(function() {\n            JSBNG__Event.listen(window, \"resize\", a);\n        });\n        JSBNG__onloadRegister(function() {\n            JSBNG__Event.listen(window, \"JSBNG__focus\", a);\n        });\n    }();\n}\n;\n;\n(function() {\n    function a(d, f, c, b) {\n        var e;\n        return function() {\n            var g = arguments;\n            var h = this;\n            var i = function() {\n                e = null;\n                d.apply(h, g);\n            };\n            ((c && JSBNG__clearTimeout(e)));\n            if (((c || !e))) {\n                e = JSBNG__setTimeout(i, f, b);\n            }\n        ;\n        ;\n        };\n    };\n;\n    window.debounce = function(c, d, b) {\n        return a(c, d, true, b);\n    };\n    window.throttle = function(c, d, b) {\n        return a(c, d, false, b);\n    };\n})();\nfunction defer_until(c, b, g, a, h) {\n    var e = b();\n    if (e) {\n        c(e);\n        return null;\n    }\n;\n;\n    var f = new JSBNG__Date().getTime();\n    var d = JSBNG__setInterval(function() {\n        e = b();\n        if (!e) {\n            if (((!g || ((g < ((new JSBNG__Date() - f))))))) {\n                return;\n            }\n        ;\n        ;\n            ((h && h()));\n        }\n    ;\n    ;\n        JSBNG__clearInterval(d);\n        c(e);\n    }, 20, a);\n    return d;\n};\n;\nJSBNG__onloadRegister(function() {\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"keyup\", function(JSBNG__event) {\n        var c = JSBNG__event.getTarget();\n        if (!DOM.isNode(c, [\"input\",\"textarea\",])) {\n            return;\n        }\n    ;\n    ;\n        if (((DOM.isNode(c, [\"input\",]) && ((c.type == \"password\"))))) {\n            return;\n        }\n    ;\n    ;\n        if (c.getAttribute(\"data-prevent-auto-flip\")) {\n            return;\n        }\n    ;\n    ;\n        var f = Input.getValue(c);\n        var b = ((c.style && c.style.direction));\n        if (!b) {\n            for (var d = 0; ((d < f.length)); d++) {\n                var a = f.charCodeAt(d);\n                if (((a >= 48))) {\n                    var e = ((((a >= 1470)) && ((a <= 1920))));\n                    CSS.setStyle(c, \"direction\", ((e ? \"rtl\" : \"ltr\")));\n                    return;\n                }\n            ;\n            ;\n            };\n        ;\n        }\n         else if (((f.length === 0))) {\n            CSS.setStyle(c, \"direction\", \"\");\n        }\n        \n    ;\n    ;\n    });\n});\nJSBNG__onloadRegister(function() {\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"submit\", function(b) {\n        var a = b.getTarget().getElementsByTagName(\"*\");\n        for (var c = 0; ((c < a.length)); c++) {\n            if (((a[c].getAttribute(\"placeholder\") && Input.isEmpty(a[c])))) {\n                Input.setValue(a[c], \"\");\n            }\n        ;\n        ;\n        };\n    ;\n    });\n});\nvar LiveTimer = {\n    restart: function(a) {\n        this.serverTime = a;\n        this.localStartTime = ((new JSBNG__Date().getTime() / 1000));\n        this.updateTimeStamps();\n    },\n    updateTimeStamps: function() {\n        LiveTimer.timestamps = DOM.scry(JSBNG__document.body, \"abbr.livetimestamp\");\n        LiveTimer.startLoop(20000);\n    },\n    addTimeStamps: function(a) {\n        if (((!a || !LiveTimer.timestamps))) {\n            return;\n        }\n    ;\n    ;\n        var c = DOM.scry(a, \"abbr.livetimestamp\");\n        for (var b = 0; ((b < c.length)); ++b) {\n            LiveTimer.timestamps.push(c[b]);\n        ;\n        };\n    ;\n        LiveTimer.startLoop(0);\n    },\n    startLoop: function(a) {\n        this.JSBNG__stop();\n        this.timeout = JSBNG__setTimeout(function() {\n            LiveTimer.loop();\n        }, a);\n    },\n    JSBNG__stop: function() {\n        JSBNG__clearTimeout(this.timeout);\n    },\n    updateNode: function(a, b) {\n        LiveTimer.updateNode = ((((ua.ie() < 7)) ? function(c, d) {\n            c.nextSibling.nodeValue = d;\n        } : function(c, d) {\n            c.firstChild.nodeValue = d;\n        }));\n        LiveTimer.updateNode(a, b);\n    },\n    loop: function(d) {\n        if (d) {\n            LiveTimer.updateTimeStamps();\n        }\n    ;\n    ;\n        var c = Math.floor(((((new JSBNG__Date().getTime() / 1000)) - LiveTimer.localStartTime)));\n        var a = -1;\n        ((LiveTimer.timestamps && LiveTimer.timestamps.each(function(g) {\n            var f = ((+new JSBNG__Date(g.getAttribute(\"data-date\")) / 1000));\n            var e = LiveTimer.renderRelativeTime(((LiveTimer.serverTime + c)), f);\n            if (e.text) {\n                LiveTimer.updateNode(g, e.text);\n            }\n        ;\n        ;\n            if (((((e.next != -1)) && ((((e.next < a)) || ((a == -1))))))) {\n                a = e.next;\n            }\n        ;\n        ;\n        })));\n        if (((a != -1))) {\n            var b = Math.max(20000, ((a * 1000)));\n            LiveTimer.timeout = JSBNG__setTimeout(function() {\n                LiveTimer.loop();\n            }, b);\n        }\n    ;\n    ;\n    },\n    renderRelativeTime: function(c, d) {\n        var e = {\n            text: \"\",\n            next: -1\n        };\n        if (((((((c - d)) > ((12 * 3600)))) || ((new JSBNG__Date(((c * 1000))).getDay() != new JSBNG__Date(((d * 1000))).getDay()))))) {\n            return e;\n        }\n    ;\n    ;\n        var f = ((c - d)), b = Math.floor(((f / 60))), a = Math.floor(((b / 60)));\n        if (((b < 1))) {\n            e.text = _tx(\"a few seconds ago\");\n            e.next = ((60 - ((f % 60))));\n            return e;\n        }\n    ;\n    ;\n        if (((a < 1))) {\n            if (((b == 1))) {\n                e.text = _tx(\"about a minute ago\");\n            }\n             else e.text = _tx(\"{number} minutes ago\", {\n                number: b\n            });\n        ;\n        ;\n            e.next = ((60 - ((f % 60))));\n            return e;\n        }\n    ;\n    ;\n        if (((a != 11))) {\n            e.next = ((3600 - ((f % 3600))));\n        }\n    ;\n    ;\n        if (((a == 1))) {\n            e.text = _tx(\"about an hour ago\");\n            return e;\n        }\n    ;\n    ;\n        e.text = _tx(\"{number} hours ago\", {\n            number: a\n        });\n        return e;\n    }\n};\nJSBNG__onloadRegister(function() {\n    add_properties(\"__behaviors\", {\n    });\n    if (__behaviors.TinyViewport) {\n        return;\n    }\n;\n;\n    __behaviors.TinyViewport = true;\n    var a = JSBNG__document.documentElement;\n    var b = debounce(function() {\n        CSS.conditionClass(a, \"tinyViewport\", ((((a.clientHeight < 400)) || ((a.clientWidth < a.scrollWidth)))));\n    });\n    JSBNG__Event.listen(window, \"resize\", b);\n    b();\n});");
// 4016
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[0], o6,o22);
// undefined
o6 = null;
// 4075
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"JR0hL\",]);\n}\n;\n;\nvar NewHigh = {\n    reset: function() {\n        this.initialized = false;\n    },\n    ensureInitialized: function() {\n        if (this.initialized) {\n            return;\n        }\n    ;\n    ;\n        this.button = DOM.scry(JSBNG__document.body, \"a.stream_header_button\")[0];\n        this.composer = DOM.scry(JSBNG__document.body, \"div.UIComposer\")[0];\n        this.buttonArea = DOM.scry(this.composer, \"div.UIComposer_ButtonArea\")[0];\n        this.initialized = true;\n    },\n    showComposer: function(a) {\n        this.ensureInitialized();\n        if (this.composer) {\n            CSS.show(this.composer);\n            UIComposer.focusInstance(this.composer.id);\n            var b = UIComposer.getInstance(this.composer.id);\n            ((b && b.loadAttachment(parseInt(a, 10))));\n        }\n    ;\n    ;\n        ((this.button && CSS.hide(this.button)));\n    },\n    hideComposer: function(b) {\n        this.ensureInitialized();\n        if (this.composer) {\n            var a = UIComposer.getInstance(this.composer.id);\n            if (!b) {\n                ((((a && a.initialized)) && a.JSBNG__blur()));\n                CSS.hide(this.composer);\n                ((this.button && CSS.show(this.button)));\n            }\n             else {\n                ((((a && a.initialized)) && a.loadAttachment(0)));\n                CSS.show(this.composer);\n                ((this.buttonArea && CSS.hide(this.buttonArea)));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    }\n};\nvar Base64 = (function() {\n    var c = \"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\";\n    function d(e) {\n        e = ((((((e.charCodeAt(0) << 16)) | ((e.charCodeAt(1) << 8)))) | e.charCodeAt(2)));\n        return String.fromCharCode(c.charCodeAt(((e >>> 18))), c.charCodeAt(((((e >>> 12)) & 63))), c.charCodeAt(((((e >>> 6)) & 63))), c.charCodeAt(((e & 63))));\n    };\n;\n    var a = ((((\"\\u003E___?456789:;\\u003C=_______\" + \"\\u0000\\u0001\\u0002\\u0003\\u0004\\u0005\\u0006\\u0007\\u0008\\u0009\\u000a\\u000b\\u000c\\u000d\\u000e\\u000f\\u0010\\u0011\\u0012\\u0013\\u0014\\u0015\\u0016\\u0017\\u0018\\u0019\")) + \"______\\u001a\\u001b\\u001c\\u001d\\u001e\\u001f !\\\"#$%&'()*+,-./0123\"));\n    function b(e) {\n        e = ((((((((a.charCodeAt(((e.charCodeAt(0) - 43))) << 18)) | ((a.charCodeAt(((e.charCodeAt(1) - 43))) << 12)))) | ((a.charCodeAt(((e.charCodeAt(2) - 43))) << 6)))) | a.charCodeAt(((e.charCodeAt(3) - 43)))));\n        return String.fromCharCode(((e >>> 16)), ((((e >>> 8)) & 255)), ((e & 255)));\n    };\n;\n    return {\n        encode: function(f) {\n            f = unescape(encodeURI(f));\n            var e = ((((f.length + 2)) % 3));\n            f = ((f + \"\\u0000\\u0000\".slice(e))).replace(/[\\s\\S]{3}/g, d);\n            return ((f.slice(0, ((((f.length + e)) - 2))) + \"==\".slice(e)));\n        },\n        decode: function(g) {\n            g = g.replace(/[^A-Za-z0-9+\\/]/g, \"\");\n            var f = ((((g.length + 3)) & 3));\n            g = ((g + \"AAA\".slice(f))).replace(/..../g, b);\n            g = g.slice(0, ((((g.length + f)) - 3)));\n            try {\n                return decodeURIComponent(escape(g));\n            } catch (e) {\n                throw new Error(\"Not valid UTF-8\");\n            };\n        ;\n        },\n        encodeObject: function(e) {\n            return Base64.encode(JSON.stringify(e));\n        },\n        decodeObject: function(e) {\n            return JSON.parse(Base64.decode(e));\n        },\n        encodeNums: function(e) {\n            return String.fromCharCode.apply(String, e.map(function(f) {\n                return c.charCodeAt(((((((f | -((f > 63)))) & -((f > 0)))) & 63)));\n            }));\n        }\n    };\n})();\nfunction FutureHomeSideNav() {\n    this.parent.construct(this);\n};\n;\nClass.extend(FutureHomeSideNav, \"FutureSideNav\");\nFutureHomeSideNav.prototype = {\n    init: function() {\n        this.parent.init.apply(this, arguments);\n        this.ajaxPipe = true;\n        this.seeAllEndpoint = \"/ajax/home/generic.php\";\n        this.typeSections = {\n            favorites: \"pinnedNav\",\n            apps: \"appsNav\",\n            groups: \"groupsNav\",\n            pages: \"pagesNav\",\n            lists: \"listsNav\",\n            connect_apps: \"connectNav\"\n        };\n        this.switchingFromTitanFixedFrame = false;\n        this._arbiterSubscriptions.push(Arbiter.subscribe(\"titan_fixed_frame_changed\", this.handleFixedFrameChanged.bind(this)), Arbiter.subscribe(NavigationMessage.NAVIGATION_FAVORITE_UPDATE, this.updateFavorite.bind(this)), Arbiter.subscribe(NavigationMessage.NAVIGATION_FIRST_RESPONSE, this.navigationFirstResponse.bind(this)));\n        this._ensureHover(\"homeSideNav\");\n    },\n    initMoreLink: function(a) {\n        this._eventHandlers.push(JSBNG__Event.listen(a, \"click\", this._showMoreSections.bind(this, a)));\n    },\n    _showMoreSections: function(b) {\n        var a = DOM.scry(this.root, \"div.belowThreshold\");\n        CSS.hide(b);\n        a.forEach(function(c) {\n            CSS.removeClass(c, \"belowThreshold\");\n        });\n    },\n    handleFixedFrameChanged: function(c, a) {\n        if (a) {\n            var b = function(d, e) {\n                UIPagelet.loadFromEndpoint(d, e, {\n                    fixed_frame: a,\n                    selected_key: \"inbox\"\n                });\n            };\n            b(\"PinnedNavigationPagelet\", \"pagelet_pinned_nav\");\n            b(\"BookmarkNavigationPagelet\", \"pagelet_bookmark_nav\");\n        }\n         else this.switchingFromTitanFixedFrame = true;\n    ;\n    ;\n    },\n    handlePageTransition: function(a) {\n        if (this.switchingFromTitanFixedFrame) {\n            this.switchingFromTitanFixedFrame = false;\n            return false;\n        }\n         else return this.parent.handlePageTransition(a)\n    ;\n    },\n    _initSection: function(a) {\n        var d = this.parent._initSection(a);\n        for (var e in this.typeSections) {\n            var c = this.typeSections[e];\n            if (((d.id == c))) {\n                var b = DOM.scry(d.node, \"div.navHeader\")[0];\n                if (b) {\n                    var f = ((((\"/bookmarks/(\" + e)) + \")(/)?\"));\n                    d.seeall = this._initItem({\n                        node: b,\n                        id: d.id,\n                        endpoint: this.seeAllEndpoint,\n                        key: [\"bookmarks\",],\n                        path: [{\n                            regex: f\n                        },]\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return d;\n    },\n    _constructItem: function(a, b) {\n        return new FutureHomeSideNavItem(a, b);\n    },\n    _constructSection: function(a) {\n        return new FutureHomeSideNavSection(a);\n    },\n    getSection: function(a) {\n        return ((this.typeSections[a] && this.sections[this.typeSections[a]]));\n    },\n    _getItemForKey: function(a) {\n        var b = this.parent._getItemForKey(\"nf\");\n        if (((b && b.matchKey(a)))) {\n            return b;\n        }\n         else return this.parent._getItemForKey(a)\n    ;\n    },\n    _isCurrentPath: function(a) {\n        return ((((a.getDomain() === this.uri.getDomain())) && ((((a.getPath() === \"/\")) || ((a.getPath() === \"/home.php\"))))));\n    },\n    _handleMenuClick: function(c, a, b, JSBNG__event) {\n        if (CSS.hasClass(b, \"favorite\")) {\n            Arbiter.inform(NavigationMessage.NAVIGATION_FAVORITE_UPDATE, {\n                key: a.numericKey,\n                favorite: !c.equals(this.getSection(\"favorites\"))\n            });\n        }\n         else this.parent._handleMenuClick(c, a, b, JSBNG__event);\n    ;\n    ;\n    },\n    removeItemByKey: function(a) {\n        Arbiter.inform(NavigationMessage.NAVIGATION_ITEM_REMOVED, a);\n        this.parent.removeItemByKey(a);\n    },\n    toggleItemByKey: function(b, d) {\n        var c = this.getNodeForKey(b);\n        if (!d) {\n            Arbiter.inform(NavigationMessage.NAVIGATION_ITEM_HIDDEN, b);\n            ((c && CSS.hide(c)));\n            var a = this._getItemForKey(b);\n            this.getSection(a.type).refresh();\n        }\n         else ((c && CSS.show(c)));\n    ;\n    ;\n    },\n    removeItem: function(a) {\n        var b = this.getSection(a.type);\n        this.parent.removeItem(a);\n        b.refresh();\n    },\n    updateFavorite: function(g, b) {\n        var f = this._findItem(function(h) {\n            return ((h.matchKey(b.key) && h.canFavorite()));\n        });\n        var d = this.getSection(\"favorites\");\n        var a = bagofholding;\n        var c = ((b.favorite ? d.addEndpoint : d.removeEndpoint));\n        if (!f) {\n            if (b.favorite) {\n                a = function() {\n                    UIPagelet.loadFromEndpoint(\"PinnedNavigationPagelet\", \"pagelet_pinned_nav\");\n                };\n            }\n             else a = function() {\n                UIPagelet.loadFromEndpoint(\"BookmarkNavigationPagelet\", \"pagelet_bookmark_nav\");\n            };\n        ;\n        ;\n        }\n         else {\n            var e = this.getSection(f.type);\n            if (b.favorite) {\n                CSS.show(f.node);\n                this.moveItem(d, f);\n                f.showFavorite();\n            }\n             else {\n                this.moveItem(e, f);\n                f.hideFavorite();\n            }\n        ;\n        ;\n            e.refresh();\n            d.refresh();\n            b.key = f.numericKey;\n        }\n    ;\n    ;\n        new AsyncRequest().setURI(c).setData({\n            id: b.key\n        }).setHandler(a).send();\n    },\n    _doPageTransition: function(a, c) {\n        this._unloadStreams();\n        var b = this.parent._doPageTransition(a, c);\n        if (((b && ((((a.type == \"groups\")) || ((a.type == \"lists\"))))))) {\n            a.setCount(0);\n        }\n    ;\n    ;\n        return b;\n    },\n    _unloadStreams: function() {\n        var a = ((UIIntentionalStream && UIIntentionalStream.instances));\n        var b = [\"nile\",\"global\",\"friends\",\"blade\",];\n        ((a && b.forEach(function(c) {\n            ((a[c] && a[c].unload()));\n        })));\n    },\n    navigationFirstResponse: function() {\n        this.setSelected(this.loading);\n    }\n};\nfunction FutureHomeSideNavSection(a) {\n    this.parent.construct(this, a);\n    this.editEndpoint = \"/ajax/bookmark/edit/\";\n    this.addEndpoint = \"/ajax/bookmark/add/\";\n    this.removeEndpoint = \"/ajax/bookmark/delete/\";\n};\n;\nClass.extend(FutureHomeSideNavSection, \"FutureSideNavSection\");\nFutureHomeSideNavSection.prototype = {\n    refresh: function() {\n        var b = DOM.scry(this.node, \"li.sideNavItem\");\n        var a = DOM.scry(this.node, \"div.actionLinks\");\n        var c = ((b.length && !CSS.hasClass(b[0], \"hidden_elem\")));\n        CSS.conditionShow(DOM.JSBNG__find(this.node, \"div.navHeader\"), c);\n        ((a.length && CSS.conditionShow(a[0], c)));\n    }\n};\nfunction FutureHomeSideNavItem(a, b) {\n    this.parent.construct(this, a, b);\n};\n;\nClass.extend(FutureHomeSideNavItem, \"FutureSideNavItem\");\nFutureHomeSideNavItem.prototype = {\n    canFavorite: function() {\n        return !!this._getFavoriteLabel();\n    },\n    showFavorite: function() {\n        DOM.setContent(this._getFavoriteLabel(), _tx(\"Remove from Favorites\"));\n    },\n    hideFavorite: function() {\n        DOM.setContent(this._getFavoriteLabel(), _tx(\"Add to Favorites\"));\n    },\n    _getFavoriteLabel: function() {\n        return DOM.scry(this.node, \"li.favorite span.itemLabel\")[0];\n    }\n};\nvar UIIntentionalStreamMessage = {\n    INITIALIZE_COMPLETE: \"UIIntentionalStream/initializeComplete\",\n    SET_AUTO_INSERT: \"UIIntentionalStream/setAutoInsert\",\n    UPDATE_STREAM: \"UIIntentionalStreamRefresh/updateStream\",\n    REFRESH_STREAM: \"UIIntentionalStreamRefresh/refreshStream\",\n    UPDATE_AUTOREFRESH_CONFIG: \"UIIntentionalStream/updateAutoRefreshConfig\",\n    UPDATE_HTML_CONTENT: \"UIIntentionalStream/updateHtmlContent\",\n    UPDATE_LAST_REFRESH_TIME: \"UIIntentionalStream/updateLastRefreshTime\",\n    INSERT_STORIES: \"UIIntentionalStream/updateLastRefreshTime\"\n};\nfunction HomeAdFirstRightColumnController() {\n\n};\n;\nHomeAdFirstRightColumnController.prototype = {\n    init: function(a) {\n        copy_properties(this, {\n            _enableSidebar: a.enableSidebar,\n            _tickerHeightOffset: 200,\n            contentCol: $(\"contentCol\"),\n            blueBar: $(\"blueBar\"),\n            _tickerMaxHeight: ((a.tickerMaxHeight || 500)),\n            _listeners: [],\n            _subscriptions: []\n        });\n        this._topOffset = 0;\n        this.PADDING_TICKER_TO_TOP = 5;\n        this.PADDING_RHC_TO_BOTTOM = 60;\n        this._sidebarIsHidden = true;\n        this._listeners.push(JSBNG__Event.listen(window, \"resize\", this.handleResize.bind(this)));\n        this._blueBarHeight = Vector2.getElementDimensions(this.blueBar).y;\n        this.reloadRightCol();\n        this._initSubscriptions();\n        JSBNG__onunloadRegister(this.cleanup.bind(this));\n        this._listeners.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", this._handleScroll.bind(this)));\n        if (!CSS.hasClass(JSBNG__document.documentElement, \"sidebarMode\")) {\n            this._onSidebarHide();\n        }\n         else if (this._enableSidebar) {\n            this._onSidebarShow();\n        }\n        \n    ;\n    ;\n        this.handleResize();\n    },\n    _initSubscriptions: function() {\n        this._subscriptions = [Arbiter.subscribe(\"Ticker/storiesInserted\", this.handleResize.bind(this)),Arbiter.subscribe(\"concierge/load\", this.handleResize.bind(this)),Arbiter.subscribe(UIIntentionalStreamMessage.INSERT_STORIES, this.handleResize.bind(this)),];\n        if (this._enableSidebar) {\n            this._subscriptions.push(Arbiter.subscribe(\"sidebar/hide\", this._onSidebarHide.bind(this)));\n            this._subscriptions.push(Arbiter.subscribe(\"sidebar/show\", this._onSidebarShow.bind(this)));\n        }\n    ;\n    ;\n    },\n    _onNavHandler: function(c, a) {\n        var b = a.params.key;\n        if (((((b != \"lf\")) && ((b != \"h\"))))) {\n            this.cleanup();\n        }\n    ;\n    ;\n    },\n    reloadRightCol: function() {\n        this.fixedScrollingContainer = ge(\"fixed_scrolling_container\");\n        this.fixedScrollingWrapper = DOM.scry(this.fixedScrollingContainer, \".fixed_scrolling_wrapper\")[0];\n        this.tickerPagelet = ge(\"pagelet_rhc_ticker\");\n        this.tickerContainer = DOM.scry(this.tickerPagelet, \".ticker_container\")[0];\n        this.tickerStream = DOM.scry(this.tickerPagelet, \".ticker_stream\")[0];\n        return ((this.tickerContainer && this.tickerStream));\n    },\n    cleanup: function() {\n        this._subscriptions.each(Arbiter.unsubscribe);\n        this._subscriptions = [];\n        this._listeners.each(function(a) {\n            a.remove();\n        });\n        this._listeners = [];\n    },\n    _handleScroll: function() {\n        if (((!this._sidebarIsHidden || !this.tickerStream))) {\n            return;\n        }\n    ;\n    ;\n        this._topOffset = ((this.PADDING_TICKER_TO_TOP + this._blueBarHeight));\n        var b = CSS.hasClass(JSBNG__document.documentElement, \"tinyViewport\");\n        var c = Vector2.getElementPosition(this.fixedScrollingContainer, \"viewport\").y;\n        var a = ((!b && ((c < this._topOffset))));\n        if (((a !== CSS.hasClass(this.fixedScrollingWrapper, \"fixed_elem\")))) {\n            this._setFixedRightCol(a);\n        }\n    ;\n    ;\n    },\n    _setFixedRightCol: function(a) {\n        var c = ((a ? ((this._topOffset + \"px\")) : \"\"));\n        CSS.setStyle(this.fixedScrollingWrapper, \"JSBNG__top\", c);\n        CSS.conditionClass(this.fixedScrollingWrapper, \"fixed_elem\", a);\n        var b = ((a ? \"Ticker/fixed\" : \"Ticker/unfixed\"));\n        Arbiter.inform(b);\n    },\n    handleResize: function() {\n        if (((((!this._sidebarIsHidden || !this.tickerStream)) || CSS.hasClass(JSBNG__document.documentElement, \"tinyViewport\")))) {\n            return;\n        }\n    ;\n    ;\n        this._handleScroll();\n        var e = Vector2.getViewportDimensions().y;\n        var b = ((Vector2.getElementDimensions(this.fixedScrollingWrapper).y - Vector2.getElementDimensions(this.tickerContainer).y));\n        var a = ((((((e - this._topOffset)) - b)) - this.PADDING_RHC_TO_BOTTOM));\n        var d = Vector2.getElementDimensions(this.tickerStream).y;\n        var c = Math.min(a, d, this._tickerMaxHeight);\n        CSS.setStyle(this.tickerContainer, \"height\", ((c + \"px\")));\n    },\n    _onSidebarHide: function() {\n        this._sidebarIsHidden = true;\n        var a = function() {\n            if (this.reloadRightCol()) {\n                this.handleResize();\n            }\n        ;\n        ;\n        };\n        TickerController.show(this.tickerPagelet, a.bind(this));\n    },\n    _onSidebarShow: function() {\n        this._sidebarIsHidden = false;\n        this._setFixedRightCol(false);\n        TickerController.hide(this.tickerPagelet);\n    }\n};\nvar HomeNavController = {\n    init: function() {\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"nav_update_counts\"), this._updateCounts.bind(this));\n    },\n    updateCounts: function(b) {\n        for (var a = 0; ((a < b.length)); a++) {\n            Arbiter.inform(NavigationMessage.NAVIGATION_COUNT_UPDATE, b[a]);\n        ;\n        };\n    ;\n    },\n    expandGroups: function() {\n        var a = ge(\"groupSideNavWrapper\");\n        if (a) {\n            CSS.addClass(a, \"expandedMode\");\n            CSS.hide(DOM.JSBNG__find($(\"moreGroupsLink\"), \".count\"));\n            new AsyncRequest(\"/ajax/groups/navigation/more_link/more_link.php\").setMethod(\"post\").setReadOnly(false).send();\n        }\n    ;\n    ;\n    },\n    collapseGroups: function() {\n        var a = ge(\"groupSideNavWrapper\");\n        if (a) {\n            CSS.removeClass(a, \"expandedMode\");\n        }\n    ;\n    ;\n    },\n    expandApps: function() {\n        var a = ge(\"bookmarks_menu\");\n        if (a) {\n            CSS.addClass(a, \"expandedMode\");\n        }\n    ;\n    ;\n    },\n    collapseApps: function() {\n        var a = ge(\"bookmarks_menu\");\n        if (a) {\n            CSS.removeClass(a, \"expandedMode\");\n        }\n    ;\n    ;\n    },\n    _lastSeenKey: null,\n    resetGroupsAndApps: function(a) {\n        a = ((a || null));\n        if (((((!a || !a.selected_key)) || ((a.selected_key != this._lastSeenKey))))) {\n            this.collapseGroups();\n            this.collapseApps();\n            if (ge(\"groupSideNavWrapper\")) {\n                UIPagelet.loadFromEndpoint(\"GroupsNavigationPagelet\", \"pagelet_groups_nav\", a);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this._lastSeenKey = ((((a && a.selected_key)) ? a.selected_key : null));\n    },\n    addSection: function(a, c, b, d) {\n        if (window.SideNav) {\n            SideNav.getInstance().addEndpoints(a);\n            SideNav.getInstance().updateCloseButtons(c, b);\n            SideNav.getInstance().addToURLMap(((d || {\n            })));\n        }\n    ;\n    ;\n    },\n    _groupIDs: [],\n    initGroupCounts: function(a, b) {\n        this._groupIDs = a;\n        if (((a && ((a.length > 0))))) {\n            Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"group_nav_update\"), this._updateGroupCounts.bind(this));\n        }\n    ;\n    ;\n    },\n    _refreshGroupCounts: function(a) {\n        new AsyncRequest().setURI(\"/ajax/groups/navigation/update_counts/update_counts.php\").setData({\n            group_ids: a,\n            nav_group_ids: this._groupIDs\n        }).setMethod(\"post\").send();\n    },\n    _updateGroupCounts: function(JSBNG__event, a) {\n        this._refreshGroupCounts([a.obj.group_id,]);\n    },\n    _updateCounts: function(JSBNG__event, a) {\n        this.updateCounts(a.obj.items);\n    }\n};\nfunction HomeTickerFirstRightColumnController() {\n\n};\n;\nHomeTickerFirstRightColumnController.prototype = {\n    _isFixed: false,\n    _forcedStatic: false,\n    init: function(a) {\n        copy_properties(this, {\n            _enableSidebar: a.enableSidebar,\n            contentCol: $(\"contentCol\"),\n            blueBar: $(\"blueBar\"),\n            _tickerMaxHeight: ((a.tickerMaxHeight || 425)),\n            _tickerMinHeight: ((a.tickerMinHeight || 225)),\n            _tickerAbsMinHeight: ((a.tickerAbsMinHeight || 120)),\n            _listeners: [],\n            _subscriptions: []\n        });\n        this._listeners.push(JSBNG__Event.listen(window, \"resize\", throttle(this.handleResize.bind(this))));\n        this.blueBarHeight = Vector2.getElementDimensions(this.blueBar).y;\n        this.reloadRightCol();\n        this._initSubscriptions();\n        JSBNG__onunloadRegister(this.cleanup.bind(this));\n        this._listeners.push(JSBNG__Event.listen(window, \"JSBNG__scroll\", throttle(this._handleScroll.bind(this))));\n        if (!CSS.hasClass(JSBNG__document.documentElement, \"sidebarMode\")) {\n            this._onSidebarHide();\n        }\n         else if (this._enableSidebar) {\n            this._onSidebarShow();\n        }\n        \n    ;\n    ;\n        this.handleResize();\n    },\n    _initSubscriptions: function() {\n        this._subscriptions = [Arbiter.subscribe(\"Ticker/storiesInserted\", this.handleResize.bind(this)),Arbiter.subscribe(\"concierge/load\", this.handleResize.bind(this)),Arbiter.subscribe(UIIntentionalStreamMessage.INSERT_STORIES, this.handleResize.bind(this)),];\n        if (this._enableSidebar) {\n            this._subscriptions.push(Arbiter.subscribe(\"sidebar/hide\", this._onSidebarHide.bind(this)));\n            this._subscriptions.push(Arbiter.subscribe(\"sidebar/show\", this._onSidebarShow.bind(this)));\n        }\n    ;\n    ;\n    },\n    reloadRightCol: function() {\n        this.rightColumn = DOM.scry(ge(\"rightCol\"), \"div.home_right_column\")[0];\n        this.rightColumnWrapper = DOM.JSBNG__find(this.rightColumn, \"div.rightColumnWrapper\");\n        this.egoPagelet = ge(\"pagelet_ego_pane\");\n        this.tickerPagelet = ge(\"pagelet_rhc_ticker\");\n        this.tickerContainer = DOM.scry(this.tickerPagelet, \".ticker_container\")[0];\n        this.tickerStream = DOM.scry(this.tickerPagelet, \".ticker_stream\")[0];\n        return ((this.tickerContainer && this.tickerStream));\n    },\n    cleanup: function() {\n        this._subscriptions.each(Arbiter.unsubscribe);\n        this._subscriptions = [];\n        this._listeners.each(function(a) {\n            a.remove();\n        });\n        this._listeners = [];\n    },\n    _handleScroll: function() {\n        if (((this._forcedStatic || !this.tickerStream))) {\n            return;\n        }\n    ;\n    ;\n        this._topOffset = ((this.blueBarHeight + Vector2.getElementPosition(this.blueBar, \"viewport\").y));\n        var b = this._topOffset;\n        var c = Vector2.getElementPosition(this.rightColumn, \"viewport\").y;\n        var a = ((c <= b));\n        if (((a !== this._isFixed))) {\n            this._setFixed(a);\n        }\n    ;\n    ;\n    },\n    _setFixed: function(a) {\n        this._isFixed = a;\n        var c = ((a ? ((this._topOffset + \"px\")) : \"\"));\n        CSS.setStyle(this.rightColumnWrapper, \"JSBNG__top\", c);\n        CSS.conditionClass(this.rightColumnWrapper, \"fixed_elem\", a);\n        var b = ((a ? \"Ticker/fixed\" : \"Ticker/unfixed\"));\n        Arbiter.inform(b);\n    },\n    handleResize: function() {\n        if (((((!this._sidebarIsHidden || !this.tickerStream)) || CSS.hasClass(JSBNG__document.documentElement, \"tinyViewport\")))) {\n            return;\n        }\n    ;\n    ;\n        this._handleScroll();\n        var i = Vector2.getViewportDimensions().y;\n        var c = 40;\n        var d = 61;\n        var g = ((Vector2.getElementDimensions(this.rightColumnWrapper).y - Vector2.getElementDimensions(this.tickerContainer).y));\n        var h = Vector2.getElementDimensions(this.tickerStream).y;\n        var b = ((((((((i - g)) - c)) - this._topOffset)) - d));\n        var a = this._tickerAbsMinHeight;\n        var f = this._tickerMinHeight;\n        this._forcedStatic = false;\n        if (((b < a))) {\n            this._forcedStatic = true;\n            this._setFixed(false);\n            b = a;\n        }\n         else if (((b < f))) {\n            if (((b > ((f - d))))) {\n                b = f;\n            }\n             else b += d;\n        ;\n        }\n        \n    ;\n    ;\n        var e = Math.min(b, h, this._tickerMaxHeight);\n        CSS.setStyle(this.tickerContainer, \"height\", ((e + \"px\")));\n    },\n    _onSidebarHide: function() {\n        this._sidebarIsHidden = true;\n        var a = function() {\n            if (this.reloadRightCol()) {\n                this._forcedStatic = false;\n                this._handleScroll();\n                this.handleResize();\n            }\n        ;\n        ;\n        };\n        TickerController.show(this.tickerPagelet, a.bind(this));\n    },\n    _onSidebarShow: function() {\n        this._sidebarIsHidden = false;\n        this._forcedStatic = true;\n        this._setFixed(false);\n        TickerController.hide(this.tickerPagelet);\n    }\n};\nfunction UIIntentionalStream(j, e, h, i, c, m, n, d, g, b, f, a, k, l) {\n    if (!j) {\n        throw new Error(\"UIIntentionalStream instantiated with no root.\");\n    }\n;\n;\n    copy_properties(this, {\n        id: j.id,\n        root: j,\n        instanceName: e,\n        newest: h,\n        oldest: i,\n        oldestMR: i,\n        firstLoadIDs: d,\n        shouldShowHidden: false,\n        defaultFilter: c,\n        currentFilterKey: b,\n        sourceType: m,\n        streamStoryCount: n,\n        maxUnseenStoryCount: g,\n        lastSeenTime: f,\n        hasPendingRefresh: false,\n        pauseAutoInsert: false,\n        unseenStoryCount: 0,\n        streamHeader: ge(\"pagelet_stream_header\"),\n        error: DOM.scry(j, \"div.UIIntentionalStream_Error\")[0],\n        pager: DOM.scry(j, \"div.uiMorePager\")[0],\n        filterNullState: DOM.scry(j, \"div.friendListFilterNullState\")[0],\n        streamContent: DOM.JSBNG__find(j, \".UIIntentionalStream_Content\"),\n        requestNum: 0,\n        scrollLoadCount: 1,\n        maxScrollLoadCount: 1,\n        boulderFeed: a,\n        scrollPosition: k,\n        lastViewStateID: 0,\n        shouldRenderCount: l,\n        scrollListener: null,\n        conowingoCount: 0,\n        headerCounts: {\n        },\n        collapseHeaderOnMove: false\n    });\n    this.setUpStreamHeader();\n    if (((this.streamStoryCount > 0))) {\n        this.updateLiveFeedCount(this.streamStoryCount);\n    }\n;\n;\n    JSBNG__onleaveRegister(this.unload.bind(this));\n    if (!UIIntentionalStream.instances) {\n        UIIntentionalStream.instances = {\n        };\n    }\n;\n;\n    UIIntentionalStream.instances[e] = this;\n    UIIntentionalStream.instance = this;\n    this.setupAutoInsert();\n    this.setupSubscriptions();\n    this.highlightsBlockData = {\n    };\n    Arbiter.inform(UIIntentionalStreamMessage.INITIALIZE_COMPLETE, {\n    }, Arbiter.BEHAVIOR_PERSISTENT);\n};\n;\nUIIntentionalStream.prototype.subscribeToComposerPublish = function() {\n    this.subscriptions.push(Arbiter.subscribe(\"composer/publish\", function(JSBNG__event, a) {\n        if (a.streamStory) {\n            this.addComposerContent(a.streamStory, 500);\n        }\n    ;\n    ;\n    }.bind(this)));\n};\nUIIntentionalStream.prototype.setupSubscriptions = function() {\n    this.subscriptions = [];\n    this.subscribeToComposerPublish();\n    this.subscriptions.push(Arbiter.subscribe(UIIntentionalStreamMessage.UPDATE_STREAM, this.updateStream.bind(this)));\n    this.subscriptions.push(Arbiter.subscribe(UIIntentionalStreamMessage.REFRESH_STREAM, this.refreshStream.bind(this)));\n    if (this.boulderFeed) {\n        this.scrollListener = JSBNG__Event.listen(window, \"JSBNG__scroll\", this.checkScroll.bind(this));\n        this.checkScroll();\n    }\n;\n;\n};\nUIIntentionalStream.prototype.tearDownSubscriptions = function() {\n    if (!this.subscriptions) {\n        return;\n    }\n;\n;\n    this.subscriptions.forEach(Arbiter.unsubscribe);\n    this.subscriptions = null;\n    if (this.scrollListener) {\n        this.scrollListener.remove();\n        this.scrollListener = null;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.unload = function() {\n    this.tearDownSubscriptions();\n    UIIntentionalStream.instance = null;\n    UIIntentionalStream.instances[this.instanceName] = null;\n    this.clearScrollLoader(true);\n    window.disableScrollLoad = null;\n    ((UIIntentionalStreamRefresh.instance && UIIntentionalStreamRefresh.instance.unload()));\n};\nUIIntentionalStream.getInstance = function(a) {\n    return UIIntentionalStream.instances[a];\n};\nUIIntentionalStream.prototype._getUpdateInsertType = function() {\n    if (((this.isOnNewHighlights() && ((!this.boulderFeed || this.shouldRenderCount))))) {\n        return UIIntentionalStream.REFRESH_COUNT;\n    }\n;\n;\n    return UIIntentionalStream.REFRESH_PREPEND;\n};\nUIIntentionalStream.prototype.updateStream = function(a) {\n    if (((((((a != UIIntentionalStreamMessage.UPDATE_STREAM)) || this.hasPendingRefresh)) || this.isAutoRefreshPaused()))) {\n        return;\n    }\n;\n;\n    this.loadNewer({\n        showLoader: false,\n        ignoreSelf: true,\n        insertType: this._getUpdateInsertType()\n    });\n};\nUIIntentionalStream.prototype.clearScrollLoader = function(a) {\n    if (this.currentScrollListener) {\n        this.currentScrollListener.remove();\n        this.currentScrollListener = null;\n    }\n;\n;\n    if (((a || ((this.scrollLoadCount >= this.maxScrollLoadCount))))) {\n        window.disableScrollLoad = true;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.loadOlderPosts = function(b) {\n    var a = {\n        filter: this.getCurrentFilterKey(),\n        oldest: this.oldest,\n        oldestMR: this.oldestMR,\n        last_seen_time: this.lastSeenTime,\n        scroll_count: this.scrollLoadCount,\n        scroll_position: this.scrollPosition,\n        last_viewstate_id: this.lastViewStateID,\n        position_data: this.highlightsBlockData\n    };\n    a = merge(a, b);\n    this.loadWithParams(a);\n};\nUIIntentionalStream.prototype.loadWithParams = function(a) {\n    var b = DOM.scry(this.root, \"div.fbStreamPager.hasMorePosts\")[0];\n    if (b) {\n        if (CSS.hasClass(b, \"async_saving\")) {\n            return;\n        }\n    ;\n    ;\n        CSS.addClass(b, \"async_saving\");\n    }\n;\n;\n    UIPagelet.loadFromEndpoint(\"/pagelet/home/morestories.php\", \"home_stream\", a, {\n        usePipe: true,\n        append: true\n    });\n};\nUIIntentionalStream.prototype.setScrollLoadCount = function(a) {\n    this.maxScrollLoadCount = a;\n};\nUIIntentionalStream.prototype.loadMoreOnScroll = function(b, a, c) {\n    if (window.disableScrollLoad) {\n        return;\n    }\n;\n;\n    var e = function() {\n        if (window.disableScrollLoad) {\n            return;\n        }\n    ;\n    ;\n        if (window.ArbiterMonitor) {\n            var h = user_action(null, \"JSBNG__scroll\", null, \"FORCE\", {\n                gt: {\n                    ua_id: \"stream:scroll:auto\"\n                }\n            });\n            ArbiterMonitor.initUA(h);\n        }\n    ;\n    ;\n        var g = {\n            delay_load_count: a\n        };\n        if (((((((this.scrollLoadCount == 1)) && this.firstLoadIDs)) && ((this.firstLoadIDs.length > 0))))) {\n            g = merge(g, {\n                first_load_ids: this.firstLoadIDs,\n                show_hidden: this.shouldShowHidden,\n                query_time: c\n            });\n        }\n    ;\n    ;\n        this.loadOlderPosts(g);\n    }.bind(this);\n    var f = DOM.scry(this.root, \"ul.uiStream li.genericStreamStory\");\n    if (!f.length) {\n        return;\n    }\n;\n;\n    var d = f[((((f.length - b)) - 1))];\n    if (d) {\n        this.currentScrollListener = new OnVisible(d, e, null, 0, {\n            detect_speed: ((this.scrollLoadCount > 1))\n        });\n    }\n     else e();\n;\n;\n};\nUIIntentionalStream.prototype.updateTimeRange = function(a, b) {\n    if (((!this.newest || ((this.newest < a))))) {\n        this.newest = a;\n    }\n;\n;\n    if (((!this.oldest || ((b && ((b < this.oldest))))))) {\n        this.oldest = b;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.updateOldestMR = function(a) {\n    if (((!this.oldestMR || ((a < this.oldestMR))))) {\n        this.oldestMR = a;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.getID = function() {\n    return this.id;\n};\nUIIntentionalStream.prototype.getCurrentFilterKey = function() {\n    if (this.currentFilterKey) {\n        return this.currentFilterKey;\n    }\n;\n;\n    var a = this.getCurrentParams();\n    if (((a && a.filter))) {\n        this.currentFilterKey = a.filter;\n    }\n     else if (this.defaultFilter) {\n        this.currentFilterKey = this.defaultFilter;\n    }\n    \n;\n;\n    return this.currentFilterKey;\n};\nUIIntentionalStream.prototype.resetFilterKey = function(a) {\n    this.currentFilterKey = a;\n};\nUIIntentionalStream.prototype.loadOlder = function(a) {\n    a = ((a || {\n    }));\n    if (!this.oldest) {\n        return;\n    }\n;\n;\n    var b = this.getCurrentParams();\n    b.oldest = this.oldest;\n    this.refresh(UIIntentionalStream.REFRESH_APPEND, b, a);\n    return this;\n};\nUIIntentionalStream.prototype.loadNewer = function(b) {\n    if (!this.newest) {\n        return;\n    }\n;\n;\n    b = ((b || {\n    }));\n    var a = this.getCurrentParams();\n    a.newest = this.newest;\n    if (b.ignoreSelf) {\n        a.ignore_self = true;\n    }\n;\n;\n    a.load_newer = true;\n    var c = coalesce(b.insertType, UIIntentionalStream.REFRESH_PREPEND);\n    this.refresh(c, a, b);\n    return this;\n};\nUIIntentionalStream.prototype.expandRecentStories = function() {\n    if (!this.shouldRenderCount) {\n        return;\n    }\n;\n;\n    this.shouldRenderCount = false;\n    var c = DOM.JSBNG__find($(\"pagelet_home_stream\"), \"ul.fbStreamRecentStoriesContainer\");\n    var b = this.removeHeader();\n    CSS.addClass(c.firstChild, \"uiStreamFirstStory\");\n    DOM.prependContent(c, b);\n    var a = this.getCurrentParams();\n    a.newest = this.newest;\n    a.active_mode = true;\n    var e = bagofholding;\n    var d = DOM.JSBNG__find($(\"pagelet_home_stream\"), \"div.fbStreamRecentStoriesPager\");\n    CSS.addClass(d, \"async_saving\");\n    if (((this.conowingoCount == ((c.childNodes.length - 1))))) {\n        e = function() {\n            CSS.hide(d);\n            this.shiftPrefetchStories();\n        }.bind(this);\n    }\n     else if (((this.conowingoCount > 20))) {\n        a.replace_pager = true;\n    }\n    \n;\n;\n    this.slideIn(c, e);\n    this.refresh(UIIntentionalStream.REFRESH_BUBBLE, a, {\n    });\n};\nUIIntentionalStream.prototype.showRecentStoriesPager = function(a) {\n    animation(a).from(\"opacity\", 0).to(\"opacity\", 1).show().JSBNG__ondone(function() {\n        Arbiter.inform(\"reflow\");\n    }).go();\n};\nUIIntentionalStream.prototype.slideIn = function(b, a) {\n    var f = b.parentNode;\n    var d = $N(\"div\", {\n        style: {\n            marginTop: \"-10000px\"\n        }\n    }, b);\n    var e = $N(\"div\", {\n        style: {\n            overflow: \"hidden\"\n        }\n    }, d);\n    CSS.setStyle(d, \"opacity\", 0);\n    CSS.show(b);\n    DOM.prependContent(f, e);\n    var c = Vector2.getElementDimensions(d).y;\n    CSS.setStyle(d, \"marginTop\", ((((\"-\" + c)) + \"px\")));\n    animation(d).to(\"marginTop\", 0).ease(animation.ease.both).checkpoint(24223).to(\"opacity\", 1).JSBNG__ondone(function() {\n        DOM.replace(e, b);\n        a();\n    }).go();\n};\nUIIntentionalStream.prototype.shiftPrefetchStories = function() {\n    var a = DOM.JSBNG__find($(\"pagelet_home_stream\"), \"ul.fbStreamRecentStoriesContainer\");\n    DOM.prependContent(this.streamContent, $A(a.childNodes));\n    Arbiter.inform(\"reflow\");\n};\nUIIntentionalStream.prototype.checkScroll = function() {\n    if (((this.scrollListener && ((Vector2.getScrollPosition().y > 0))))) {\n        var a = ge(\"highlight_header\");\n        new AsyncSignal(\"ajax/feed/scroll_detect.php\", {\n            hasHeader: !!a\n        }).send();\n        this.scrollListener.remove();\n        this.scrollListener = null;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.getCurrentParams = function() {\n    var a = {\n    };\n    var b = URI.getMostRecentURI().getQueryData();\n    if (b.sk) {\n        b.filter = b.sk;\n    }\n;\n;\n    var c = this.getValidParams();\n    if (c) {\n        c.forEach(function(d) {\n            a[d] = b[d];\n        });\n    }\n     else a = b;\n;\n;\n    return a;\n};\nUIIntentionalStream.prototype.setHomeFilter = function(a) {\n    this._homeFilter = a;\n};\nUIIntentionalStream.prototype.setHomeFilterLoading = function(a) {\n    if (this._homeFilter) {\n        this._homeFilter.setLoading(a);\n    }\n;\n;\n};\nUIIntentionalStream.prototype.updateBlockData = function(a) {\n    this.highlightsBlockData = a;\n};\nUIIntentionalStream.prototype.setConowingoCount = function(a) {\n    this.conowingoCount = a;\n};\nUIIntentionalStream.prototype.updateRecentStoryCount = function(b) {\n    this.conowingoCount = b;\n    if (((this.conowingoCount && this.boulderFeed))) {\n        var c = DOM.JSBNG__find($(\"pagelet_home_stream\"), \"div.fbStreamRecentStoriesPager\");\n        var d = DOM.JSBNG__find(c, \"span.fbStreamRecentStoriesText\");\n        var a;\n        if (((this.conowingoCount == 1))) {\n            a = _tx(\"SEE {count} NEW STORY\", {\n                count: b\n            });\n        }\n         else if (((b <= 100))) {\n            a = _tx(\"SEE {count} NEW STORIES\", {\n                count: b\n            });\n        }\n         else a = _tx(\"SEE 100+ NEW STORIES\");\n        \n    ;\n    ;\n        d.innerText = a;\n        if (CSS.hasClass(c, \"hidden_elem\")) {\n            this.showRecentStoriesPager(c);\n        }\n    ;\n    ;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.updateRenderedStories = function(b) {\n    if (((this.boulderFeed && this.shouldRenderCount))) {\n        var a = DOM.JSBNG__find($(\"pagelet_home_stream\"), \"ul.fbStreamRecentStoriesContainer\");\n        DOM.setContent(a, HTML(b));\n    }\n;\n;\n};\nUIIntentionalStream.prototype.scrollToOrLoadRecentStories = function() {\n    if (this.scrollToRecentStories()) {\n        new AsyncSignal(\"ajax/feed/scroll_link.php\", {\n        }).send();\n    }\n     else {\n        DOMScroll.JSBNG__scrollTo(ge(\"pagelet_stream_pager\"));\n        this.loadOlderPosts({\n            impatient_mode: true,\n            max_stories: 10\n        });\n    }\n;\n;\n};\nUIIntentionalStream.prototype.scrollToRecentStories = function() {\n    var a = ge(\"recent_header\");\n    if (a) {\n        CSS.removeClass(a, \"uiStreamHeaderHideLink\");\n        DOMScroll.JSBNG__scrollTo(a, true, false, ((Vector2.getViewportDimensions().y - 50)));\n        return true;\n    }\n     else return false\n;\n};\nUIIntentionalStream.prototype.scrollToTopStories = function() {\n    DOMScroll.JSBNG__scrollTo(ge(\"highlight_header\"), true, true);\n};\nUIIntentionalStream.prototype.refresh = function(j, a, f) {\n    Arbiter.inform(UIIntentionalStreamMessage.UPDATE_LAST_REFRESH_TIME);\n    this.currentFilterKey = a.filter;\n    if (((a.filter == UIIntentionalStream.FEED_FILTER_KEY_DUAL_NEWS_FEED))) {\n        this.currentFilterKey = this.defaultFilter;\n    }\n     else if (((((a.filter == UIIntentionalStream.FEED_FILTER_KEY_NEW_HIGHLIGHTS)) || ((a.filter === UIIntentionalStream.FEED_FILTER_KEY_NEWS_FEED))))) {\n        this.defaultFilter = this.currentFilterKey;\n    }\n    \n;\n;\n    f = ((f || {\n    }));\n    var h = ++this.requestNum;\n    var i = coalesce(f.showLoader, true);\n    var e = this.instanceName;\n    var d = function(k) {\n        UIIntentionalStream.getInstance(e).handleResponse(h, j, k, f);\n    };\n    var b = function(k) {\n        UIIntentionalStream.getInstance(e).handleError(h, j, k, f);\n    };\n    var c = function(k) {\n        UIIntentionalStream.getInstance(e).handleFinally(j, a.filter, k);\n    };\n    if (!(a.request_type = j)) {\n        a.request_type = \"none\";\n    }\n;\n;\n    if (a.filter) {\n        f.show_hidden = ((a.show_hidden ? a.show_hidden : false));\n    }\n     else f.show_hidden = this.shouldShowHidden;\n;\n;\n    a = copy_properties(this.getCurrentParams(), a);\n    this.hasPendingRefresh = true;\n    var g;\n    if (((((j == UIIntentionalStream.REFRESH_APPEND)) && i))) {\n        g = this.pager;\n    }\n;\n;\n    new AsyncRequest().setURI(this.getEndpoint()).setReadOnly(true).setOption(\"retries\", 0).setMethod(this.getRefreshMethod()).setData(a).setHandler(d).setStatusElement(g).setErrorHandler(b).setFinallyHandler(c).send();\n    if (((j == UIIntentionalStream.REFRESH_TRANSITION))) {\n        hide(this.pager);\n        this.clearScrollLoader(true);\n        this.oldest = this.newest = null;\n    }\n;\n;\n    if (i) {\n        this.setHomeFilterLoading(true);\n    }\n;\n;\n};\nUIIntentionalStream.prototype.addComposerContent = function(a, b) {\n    if (((this.boulderFeed && this.isOnNewsFeedFilter()))) {\n        CSS.addClass(a, \"uiStreamBoulderHighlight\");\n    }\n     else CSS.removeClass(a, \"uiStreamBoulderStyle\");\n;\n;\n    this.addContentPrepend(a, b);\n};\nUIIntentionalStream.prototype.addContentPrepend = function(a, b) {\n    if (a.length) {\n        $A(a).reverse().forEach(function(h) {\n            this.addContentPrepend(h, b);\n        }.bind(this));\n        return;\n    }\n;\n;\n    var d;\n    var f = Vector2.getScrollPosition().y;\n    var c = Vector2.getElementPosition(this.streamContent).y;\n    var g = ((this.scrollOnPrepend && ((f >= c))));\n    if (g) {\n        var e = function(h) {\n            var i = DOM.JSBNG__find(h, \"^li.uiStreamStory\");\n            if (!i) {\n                return;\n            }\n        ;\n        ;\n            DataStore.set(i, \"origHeight\", i.offsetHeight);\n            JSBNG__Event.listen(h, \"load\", function() {\n                var j = DataStore.get(i, \"origHeight\");\n                if (((i.offsetHeight != j))) {\n                    window.JSBNG__scrollBy(0, ((i.offsetHeight - j)));\n                    DataStore.set(i, \"origHeight\", i.offsetHeight);\n                }\n            ;\n            ;\n            });\n        };\n        d = animation.insert.curry(this.streamContent, a, (function(i, h) {\n            this.prependAfterHeader(h);\n            Arbiter.inform(\"reflow\");\n            window.JSBNG__scrollBy(0, h.offsetHeight);\n            DOM.scry(h, \"img\").forEach(e);\n        }).bind(this));\n    }\n     else d = (function() {\n        CSS.setStyle(a, \"opacity\", 0);\n        this.prependAfterHeader(a);\n        Arbiter.inform(\"reflow\");\n        animation(a).from(\"opacity\", 0).to(\"opacity\", 1).duration(400).go();\n    }).bind(this);\n;\n;\n    if (b) {\n        JSBNG__setTimeout(d, b);\n    }\n     else d();\n;\n;\n};\nUIIntentionalStream.prototype.prependAfterHeader = function(b) {\n    var a = this.removeHeader();\n    if (a) {\n        DOM.prependContent(this.streamContent, a);\n        CSS.addClass(b, \"uiStreamFirstStory\");\n        DOM.insertAfter(a, b);\n    }\n     else DOM.prependContent(this.streamContent, b);\n;\n;\n};\nUIIntentionalStream.prototype.removeHeader = function() {\n    var a = ge(\"stream_movable_header\");\n    if (a) {\n        if (((a.parentNode != this.streamContent))) {\n            return null;\n        }\n    ;\n    ;\n        var b = a.nextSibling;\n        CSS.removeClass(b, \"uiStreamFirstStory\");\n        DOM.remove(a);\n        CSS.show(a);\n        if (this.collapseHeaderOnMove) {\n            CSS.addClass(a, \"uiStreamHeaderCollapsed\");\n        }\n    ;\n    ;\n    }\n;\n;\n    return a;\n};\nUIIntentionalStream.prototype.setCollapseHeaderOnMove = function(a) {\n    this.collapseHeaderOnMove = a;\n    this.updateHeaderCounts(this.headerCounts);\n};\nUIIntentionalStream.prototype.updateHeaderCounts = function(a) {\n    this.headerCounts = a;\n    var d = a.highlight;\n    var h = a.recent;\n    if (this.collapseHeaderOnMove) {\n        if (((d > 1))) {\n            var g = DOM.scry(this.streamContent, \"#stream_movable_header .uiStreamHeaderText\");\n            if (((g.length == 1))) {\n                var b = {\n                    total: ((d + h)),\n                    highlight: d\n                };\n                var c = _tx(\"{total} RECENT STORIES, {highlight} MARKED AS TOP\", b);\n                g[0].innerHTML = c;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    }\n     else {\n        if (d) {\n            var e = DOM.scry(this.streamContent, \"#highlight_header .uiStreamHeaderTextLeft\");\n            if (((e.length == 1))) {\n                var f;\n                if (((d == 1))) {\n                    f = _tx(\"NEW TOP STORY\", {\n                        count: d\n                    });\n                }\n                 else if (((d < 20))) {\n                    f = _tx(\"TOP STORIES SINCE YOUR LAST VISIT ({count})\", {\n                        count: d\n                    });\n                }\n                 else f = _tx(\"TOP STORIES SINCE YOUR LAST VISIT (20+)\");\n                \n            ;\n            ;\n                e[0].innerHTML = f;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (h) {\n            var i = DOM.scry(this.streamContent, \"#highlight_header .uiStreamHeaderTextRight\");\n            if (((i.length == 1))) {\n                var j;\n                if (((h == 1))) {\n                    j = _tx(\"{count} MORE RECENT STORY\", {\n                        count: h\n                    });\n                }\n                 else if (((h < 100))) {\n                    j = _tx(\"{count} MORE RECENT STORIES\", {\n                        count: h\n                    });\n                }\n                 else j = _tx(\"100+ MORE RECENT STORIES\");\n                \n            ;\n            ;\n                i[0].innerHTML = j;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.addContentAppend = function(a) {\n    DOM.appendContent(this.streamContent, a);\n};\nUIIntentionalStream.getStoriesByAssoc = function(a) {\n    return DOM.scry(UIIntentionalStream.instance.root, ((\"div.aid_\" + a)));\n};\nUIIntentionalStream.prototype.handleResponse = function(d, g, e, b) {\n    b = ((b || {\n    }));\n    var c = e.getPayload();\n    ((this.filterNullState && DOM.remove(this.filterNullState)));\n    if (is_empty(c)) {\n        return;\n    }\n;\n;\n    if (((c.streamHeader && this.streamHeader))) {\n        DOM.setContent(this.streamHeader, HTML(c.streamHeader));\n        if (this.isOnNewsFeedFilter()) {\n            this.setUpStreamHeader();\n        }\n    ;\n    ;\n        NewHigh.reset();\n    }\n;\n;\n    if (c.autoRefreshConfig) {\n        Arbiter.inform(UIIntentionalStreamMessage.UPDATE_AUTOREFRESH_CONFIG, c.autoRefreshConfig);\n    }\n;\n;\n    this.setHomeFilterLoading(false);\n    if (((g == UIIntentionalStream.REFRESH_EXPAND))) {\n        var f = DOM.JSBNG__find($(b.expandStoryID), \"div.UIIntentionalStory_CollapsedStories\");\n        CSS.hide(f);\n        CSS.removeClass(f, \"UIIntentionalStory_CollapsedStoriesLoading\");\n    }\n;\n;\n    if (this.error) {\n        hide(this.error);\n    }\n;\n;\n    if (((d != this.requestNum))) {\n        return;\n    }\n;\n;\n    if (((\"show_hidden\" in b))) {\n        this.shouldShowHidden = b.show_hidden;\n    }\n;\n;\n    if (((((\"newestStoryTime\" in c)) && ((c.newestStoryTime > this.newest))))) {\n        this.newest = c.newestStoryTime;\n    }\n;\n;\n    if (((((\"oldestStoryTime\" in c)) && ((!this.oldest || ((c.oldestStoryTime < this.oldest))))))) {\n        this.oldest = c.oldestStoryTime;\n    }\n;\n;\n    if (((\"streamStoryCount\" in c))) {\n        this.updateLiveFeedCount(c.streamStoryCount);\n    }\n;\n;\n    if (!c.html) {\n        if (((g == UIIntentionalStream.REFRESH_BUBBLE))) {\n            this.shiftPrefetchStories();\n        }\n    ;\n    ;\n    }\n     else {\n        var a = HTML(c.html).getNodes();\n        switch (g) {\n          case UIIntentionalStream.REFRESH_COUNT:\n            if (((((this.boulderFeed && this.shouldRenderCount)) && c.conowingoCount))) {\n                this.updateRecentStoryCount(c.conowingoCount);\n                if (((\"conowingoHTML\" in c))) {\n                    this.updateRenderedStories(c.conowingoHTML);\n                }\n            ;\n            ;\n            }\n             else if (((c.storyCount && !this.boulderFeed))) {\n                this.updateLiveFeedCount(c.storyCount, true);\n            }\n            \n        ;\n        ;\n            break;\n          case UIIntentionalStream.REFRESH_BUBBLE:\n            if (c.replaceCurrentStories) {\n                DOM.empty(this.streamContent);\n                this.scrollPosition = c.scrollPosition;\n                this.lastViewStateID = c.lastViewStateID;\n                this.oldest = c.oldest;\n                this.highlightsBlockData = {\n                    is_highlight: false,\n                    highlight_blocks: 0,\n                    nonhighlight_blocks: 1,\n                    past_session_break: false\n                };\n            }\n        ;\n        ;\n            this.addContentPrepend(a);\n            this.shiftPrefetchStories();\n            break;\n          case UIIntentionalStream.REFRESH_PREPEND:\n            this.addContentPrepend(a);\n            break;\n          case UIIntentionalStream.REFRESH_APPEND:\n            this.addContentAppend(a);\n            this.clearScrollLoader(true);\n            break;\n          case UIIntentionalStream.REFRESH_TRANSITION:\n            DOM.setContent(this.streamContent, a);\n            if (!b.noScroll) {\n                DOMScroll.JSBNG__scrollTo(new Vector2(0, 0, \"JSBNG__document\"), false);\n            }\n        ;\n        ;\n            break;\n          case UIIntentionalStream.REFRESH_EXPAND:\n            DOM.insertAfter($(b.expandStoryID), a);\n            break;\n          case UIIntentionalStream.DELAYED_STREAM:\n            this.addContentAppend(a);\n            break;\n        };\n    ;\n        Arbiter.inform(UIIntentionalStreamMessage.UPDATE_HTML_CONTENT);\n    }\n;\n;\n};\nUIIntentionalStream.prototype.updateLiveFeedCount = function(c, b) {\n    var d = ((((this.unseenStoryCount == 0)) || !b));\n    if (b) {\n        this.unseenStoryCount += c;\n    }\n     else this.unseenStoryCount = c;\n;\n;\n    if (((((this.unseenStoryCount > 0)) && this.liveFeedCount))) {\n        var a = \"\";\n        if (((this.unseenStoryCount > this.maxUnseenStoryCount))) {\n            a = ((this.maxUnseenStoryCount + \"+\"));\n        }\n         else a = this.unseenStoryCount.toString();\n    ;\n    ;\n        DOM.setContent(this.liveFeedCount, HTML(a));\n        if (d) {\n            CSS.show(this.liveFeedBubble);\n        }\n    ;\n    ;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.handleError = function(c, f, d, b) {\n    if (((c != this.requestNum))) {\n        return;\n    }\n;\n;\n    this.setHomeFilterLoading(false);\n    var a = d.getError();\n    if (((a == 1357001))) {\n        AsyncResponse.defaultErrorHandler(d);\n    }\n;\n;\n    if (((f == UIIntentionalStream.REFRESH_EXPAND))) {\n        var e = DOM.JSBNG__find($(b.expandStoryID), \"div.UIIntentionalStory_CollapsedStories\");\n        CSS.removeClass(e, \"UIIntentionalStory_CollapsedStoriesLoading\");\n    }\n;\n;\n    if (((((!b.delayLoadCount && ((f != UIIntentionalStream.REFRESH_PREPEND)))) && this.error))) {\n        CSS.setStyle(this.error, \"display\", \"block\");\n    }\n;\n;\n};\nUIIntentionalStream.prototype.handleFinally = function(b, a) {\n    if (((b == UIIntentionalStream.REFRESH_TRANSITION))) {\n        PageTransitions.transitionComplete();\n        Arbiter.inform(NavigationMessage.NAVIGATION_COMPLETED);\n    }\n;\n;\n    this.hasPendingRefresh = false;\n};\nUIIntentionalStream.prototype.getValidParams = function() {\n    return UIIntentionalStream.VALID_PARAMS;\n};\nUIIntentionalStream.prototype.getEndpoint = function() {\n    return UIIntentionalStream.ENDPOINT;\n};\nUIIntentionalStream.prototype.getRefreshMethod = function() {\n    return UIIntentionalStream.REFRESH_METHOD;\n};\nUIIntentionalStream.prototype.isOnNewHighlights = function() {\n    var a = this.getCurrentFilterKey();\n    return ((((a == UIIntentionalStream.FEED_FILTER_KEY_NEW_HIGHLIGHTS)) || ((((a == UIIntentionalStream.FEED_FILTER_KEY_DUAL_NEWS_FEED)) && ((this.defaultFilter == UIIntentionalStream.FEED_FILTER_KEY_NEW_HIGHLIGHTS))))));\n};\nUIIntentionalStream.prototype.isLiveStreamBox = function() {\n    var a = this.getCurrentFilterKey();\n    return ((a && ((a.indexOf(UIIntentionalStream.FEED_FILTER_KEY_LIVE_STREAM_BOX) == 0))));\n};\nUIIntentionalStream.prototype.isOnNewsFeedFilter = function() {\n    var a = this.getCurrentFilterKey();\n    return ((((((a == UIIntentionalStream.FEED_FILTER_KEY_NEWS_FEED)) || ((a == UIIntentionalStream.FEED_FILTER_KEY_NEW_HIGHLIGHTS)))) || ((a == UIIntentionalStream.FEED_FILTER_KEY_DUAL_NEWS_FEED))));\n};\nUIIntentionalStream.prototype.setupAutoInsert = function() {\n    Arbiter.subscribe(UIIntentionalStreamMessage.SET_AUTO_INSERT, UIIntentionalStream.setAutoInsert);\n};\nUIIntentionalStream.setAutoInsert = function(b, a) {\n    if (((b != UIIntentionalStreamMessage.SET_AUTO_INSERT))) {\n        return;\n    }\n;\n;\n    var c = UIIntentionalStream.instance;\n    if (c) {\n        c.pauseAutoInsert = a.pause;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.isAutoRefreshPaused = function() {\n    if (((this.isOnNewHighlights() || this.isLiveStreamBox()))) {\n        return false;\n    }\n;\n;\n    return this.pauseAutoInsert;\n};\nUIIntentionalStream.prototype.setUpStreamHeader = function() {\n    if (!this.streamHeader) {\n        return;\n    }\n;\n;\n    this.liveFeedBubble = DOM.scry(this.streamHeader, \"span.uiBubbleCount\")[0];\n    if (!this.liveFeedBubble) {\n        return;\n    }\n;\n;\n    this.liveFeedCount = DOM.scry(this.liveFeedBubble, \"span.number\")[0];\n    if (!this.maxUnseenStoryCount) {\n        this.maxUnseenStoryCount = UIIntentionalStream.MAX_UNSEEN_STORY_COUNT;\n    }\n;\n;\n};\nUIIntentionalStream.prototype.refreshStream = function(e, a) {\n    if (((e != UIIntentionalStreamMessage.REFRESH_STREAM))) {\n        return;\n    }\n;\n;\n    var c = this.getCurrentFilterKey();\n    if (((this.isOnNewsFeedFilter() && a.shouldOverride))) {\n        c = UIIntentionalStream.FEED_FILTER_KEY_NEW_HIGHLIGHTS;\n    }\n;\n;\n    var f = ((c == UIIntentionalStream.FEED_FILTER_KEY_NEW_HIGHLIGHTS));\n    var b = {\n        filter: c\n    };\n    if (f) {\n        b.pending = f;\n    }\n;\n;\n    var d = {\n        filter: c\n    };\n    ((a.noScroll && (d.noScroll = 1)));\n    this.refresh(UIIntentionalStream.REFRESH_TRANSITION, b, d);\n};\ncopy_properties(UIIntentionalStream, {\n    ANIMATION_DURATION: 300,\n    REFRESH_METHOD: \"GET\",\n    REFRESH_TRANSITION: 1,\n    REFRESH_PREPEND: 2,\n    REFRESH_APPEND: 3,\n    REFRESH_COUNT: 4,\n    REFRESH_EXPAND: 5,\n    DELAYED_STREAM: 6,\n    REFRESH_BUBBLE: 7,\n    FEED_FILTER_KEY_FEED_STORY_SUMMARY: \"fssum\",\n    FEED_FILTER_KEY_NEW_HIGHLIGHTS: \"h\",\n    FEED_FILTER_KEY_NEWS_FEED: \"lf\",\n    FEED_FILTER_KEY_DUAL_NEWS_FEED: \"nf\",\n    FEED_FILTER_KEY_LIVE_STREAM_BOX: \"pub\",\n    VALID_PARAMS: [\"filter\",\"show_hidden\",],\n    ENDPOINT: \"/ajax/intent.php\",\n    MAX_UNSEEN_STORY_COUNT: 300\n});\nfunction UIIntentionalStreamRefresh(a, b) {\n    copy_properties(this, {\n        isAutoRefreshing: false,\n        lastRefresh: new JSBNG__Date().getTime()\n    });\n    UIIntentionalStreamRefresh.instance = this;\n    this.setAutoRefreshConfig(a);\n    this.updateConfigHandler = Arbiter.subscribe(UIIntentionalStreamMessage.UPDATE_AUTOREFRESH_CONFIG, this.updateAutoRefreshConfig.bind(this));\n    this.updateRefreshTimeHandler = Arbiter.subscribe(UIIntentionalStreamMessage.UPDATE_LAST_REFRESH_TIME, this.updateLastRefreshTime.bind(this));\n    JSBNG__onleaveRegister(this.unload.bind(this));\n    this.userActivity();\n    this.uaToken = UserActivity.subscribe(this.userActivity.bind(this));\n    this.autoRefreshInterval = JSBNG__setInterval(this.checkAutoPageRefresh.bind(this), this.checkAutoRefreshTimeInterval);\n    this.activeRefreshInterval = JSBNG__setInterval(this.checkActiveRefresh.bind(this), this.checkActiveRefreshTimeInterval);\n    this.enableAutoRefresh(b);\n    Arbiter.subscribe(UIIntentionalStreamMessage.UPDATE_STREAM, LiveTimer.loop.bind(LiveTimer, true));\n    Arbiter.subscribe(UIIntentionalStreamMessage.REFRESH_STREAM, LiveTimer.loop.bind(LiveTimer, true));\n    if (this.usePresence) {\n        UIIntentionalStreamRefresh.presenceRegister();\n    }\n;\n;\n};\n;\ncopy_properties(UIIntentionalStreamRefresh, {\n    _presenceInit: false,\n    DISABLE_AUTOREFRESH_TIME: ((((4 * 60)) * 1000)),\n    CHECK_AUTOREFRESH_INTERVAL: ((((5 * 60)) * 1000)),\n    AUTOREFRESH_INACTIVE_TIME: ((((30 * 60)) * 1000)),\n    HIGHLIGHTS_OVERRIDE_TIME: ((((360 * 60)) * 1000)),\n    CHECK_ACTIVE_REFRESH_TIME: ((((5 * 60)) * 1000)),\n    ACTIVE_REFRESH_TIME: ((30 * 1000))\n});\nUIIntentionalStreamRefresh.presenceRegister = function() {\n    if (UIIntentionalStreamRefresh._presenceInit) {\n        return true;\n    }\n;\n;\n    Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"feedpub\"), UIIntentionalStreamRefresh.handleNewStoryMessage);\n    UIIntentionalStreamRefresh._presenceInit = true;\n};\nUIIntentionalStreamRefresh.prototype.updateAutoRefreshConfig = function(b, a) {\n    if (((b == UIIntentionalStreamMessage.UPDATE_AUTOREFRESH_CONFIG))) {\n        this.setAutoRefreshConfig(a);\n    }\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.updateLastRefreshTime = function(a) {\n    if (((a == UIIntentionalStreamMessage.UPDATE_LAST_REFRESH_TIME))) {\n        this.lastRefresh = new JSBNG__Date().getTime();\n    }\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.setAutoRefreshConfig = function(a) {\n    a = ((a || {\n    }));\n    var b = ((((((24 * 60)) * 60)) * 1000));\n    if (!this.storyInterval) {\n        this.storyInterval = coalesce(a.story_interval, null);\n    }\n;\n;\n    this.allowAutoRefresh = coalesce(a.allow_auto_refresh, false);\n    this.inactiveThreshold = coalesce(a.inactive_threshold, 0);\n    this.activeRefreshTime = coalesce(a.fast_refresh_rate, b);\n    this.inactiveRefreshTime = coalesce(a.slow_refresh_rate, b);\n    this.allowPolling = coalesce(a.allow_polling, false);\n    this.refreshFactor = coalesce(a.refresh_factor, 10);\n    this.minRefreshInterval = coalesce(a.min_refresh_interval, ((60 * 1000)));\n    this.usePresence = coalesce(a.use_presence, false);\n    this.activeRefresh = coalesce(a.active_refresh, false);\n    this.checkActiveRefreshTimeInterval = coalesce(a.check_active_refresh_interval, UIIntentionalStreamRefresh.CHECK_ACTIVE_REFRESH_TIME);\n    this.activeRefreshTimeInterval = coalesce(a.active_refresh_interval, UIIntentionalStreamRefresh.ACTIVE_REFRESH_TIME);\n    this.disableAutoRefreshTime = coalesce(a.disable_autorefresh_time, UIIntentionalStreamRefresh.DISABLE_AUTOREFRESH_TIME);\n    this.checkAutoRefreshTimeInterval = coalesce(a.check_autorefresh_time_interval, UIIntentionalStreamRefresh.CHECK_AUTOREFRESH_INTERVAL);\n    this.autoRefreshInactiveTime = coalesce(a.autorefresh_inactive_time, UIIntentionalStreamRefresh.AUTOREFRESH_INACTIVE_TIME);\n    this.highlightsOverrideTime = coalesce(a.highlights_override_time, UIIntentionalStreamRefresh.HIGHLIGHTS_OVERRIDE_TIME);\n    return this;\n};\nUIIntentionalStreamRefresh.prototype.unload = function() {\n    this.enableAutoRefresh(false);\n    this.cleanupRefreshInterval();\n    UserActivity.unsubscribe(this.uaToken);\n    ((this.updateConfigHandler && Arbiter.unsubscribe(this.updateConfigHandler)));\n    ((this.updateRefreshTimeHandler && Arbiter.unsubscribe(this.updateRefreshTimeHandler)));\n};\nUIIntentionalStreamRefresh.prototype.userActivity = function() {\n    var a = this.isInactive();\n    this.lastActivity = (new JSBNG__Date().getTime());\n    this.isAutoRefreshing = true;\n    if (((a && this.canAutoRefresh()))) {\n        this.runAutoRefresh();\n    }\n;\n;\n    return true;\n};\nUIIntentionalStreamRefresh.prototype.isInactive = function() {\n    return ((this.getMSSinceLastActivity() > this.inactiveThreshold));\n};\nUIIntentionalStreamRefresh.prototype.getMSSinceLastActivity = function() {\n    return (((new JSBNG__Date().getTime()) - this.lastActivity));\n};\nUIIntentionalStreamRefresh.prototype.getMSSinceLastRefresh = function() {\n    return (((new JSBNG__Date().getTime()) - this.lastRefresh));\n};\nUIIntentionalStreamRefresh.prototype.getRefreshInterval = function() {\n    if (this.isInactive()) {\n        return this.inactiveRefreshTime;\n    }\n     else if (((this.storyInterval != null))) {\n        var a = ((this.storyInterval * this.refreshFactor));\n        return Math.max(a, this.activeRefreshTime);\n    }\n     else return this.activeRefreshTime\n    \n;\n};\nUIIntentionalStreamRefresh.prototype.canAutoRefresh = function() {\n    return ((this.isAutoRefreshing && this.allowAutoRefresh));\n};\nUIIntentionalStreamRefresh.handleNewStoryMessage = function(b, a) {\n    if (((b != PresenceMessage.getArbiterMessageType(\"feedpub\")))) {\n        return;\n    }\n;\n;\n    Arbiter.inform(UIIntentionalStreamMessage.UPDATE_STREAM);\n};\nUIIntentionalStreamRefresh.prototype.cancelUpdate = function() {\n    if (this.updateTask) {\n        JSBNG__clearTimeout(this.updateTask);\n        this.updateTask = null;\n    }\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.runUpdatePoll = function() {\n    this.updateTask = null;\n    if (this.canAutoRefresh()) {\n        this.runAutoRefresh();\n    }\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.runAutoRefresh = function() {\n    var a = 50;\n    if (((this.getMSSinceLastRefresh() >= ((this.minRefreshInterval - a))))) {\n        Arbiter.inform(UIIntentionalStreamMessage.UPDATE_STREAM);\n    }\n;\n;\n    this.schedulePoll(this.getRefreshInterval());\n};\nUIIntentionalStreamRefresh.prototype.schedulePoll = function(a) {\n    this.cancelUpdate();\n    if (this.allowPolling) {\n        this.updateTask = JSBNG__setTimeout(this.runUpdatePoll.bind(this), a);\n    }\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.enableAutoRefresh = function(b, c) {\n    this.isAutoRefreshing = b;\n    if (b) {\n        var a = ((c ? 0 : this.getRefreshInterval()));\n        this.schedulePoll(a);\n    }\n     else this.cancelUpdate();\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.checkAutoPageRefresh = function() {\n    if (!this.allowAutoRefresh) {\n        return;\n    }\n;\n;\n    if (((this.isAutoRefreshing && ((this.getMSSinceLastActivity() > this.disableAutoRefreshTime))))) {\n        this.isAutoRefreshing = false;\n    }\n;\n;\n    if (((this.getMSSinceLastRefresh() < this.autoRefreshInactiveTime))) {\n        return;\n    }\n;\n;\n    var a = this.getMSSinceLastActivity();\n    if (((a > this.autoRefreshInactiveTime))) {\n        var b = ((a > this.highlightsOverrideTime));\n        Arbiter.inform(UIIntentionalStreamMessage.REFRESH_STREAM, {\n            shouldOverride: b\n        });\n    }\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.checkActiveRefresh = function() {\n    if (!this.allowAutoRefresh) {\n        return;\n    }\n;\n;\n    if (((this.getMSSinceLastRefresh() < this.activeRefreshTimeInterval))) {\n        return;\n    }\n;\n;\n    if (((this.getMSSinceLastActivity() < this.activeRefreshTimeInterval))) {\n        Arbiter.inform(UIIntentionalStreamMessage.UPDATE_STREAM);\n    }\n;\n;\n};\nUIIntentionalStreamRefresh.prototype.cleanupRefreshInterval = function() {\n    if (this.autoRefreshInterval) {\n        JSBNG__clearInterval(this.autoRefreshInterval);\n        this.autoRefreshInterval = null;\n    }\n;\n;\n};\nfunction tz_calculate(f) {\n    var a = new JSBNG__Date();\n    var b = ((a.getTimezoneOffset() / 30));\n    var e = ((a.getTime() / 1000));\n    var d = Math.round(((((f - e)) / 1800)));\n    var c = ((Math.round(((b + d))) % 48));\n    if (((c == 0))) {\n        return 0;\n    }\n     else if (((c > 24))) {\n        c -= ((Math.ceil(((c / 48))) * 48));\n    }\n     else if (((c < -28))) {\n        c += ((Math.ceil(((c / -48))) * 48));\n    }\n    \n    \n;\n;\n    return ((c * 30));\n};\n;\nfunction tz_autoset(d, c) {\n    if (((!d || ((undefined == c))))) {\n        return;\n    }\n;\n;\n    if (window.tz_autoset.calculated) {\n        return;\n    }\n;\n;\n    window.tz_autoset.calculated = true;\n    var b = -tz_calculate(d);\n    if (((b != c))) {\n        var a = \"/ajax/autoset_timezone_ajax.php\";\n        new AsyncRequest().setURI(a).setData({\n            gmt_off: b\n        }).setErrorHandler(bagofholding).setTransportErrorHandler(bagofholding).setOption(\"suppressErrorAlerts\", true).send();\n    }\n;\n;\n};\n;\nwindow.__UIControllerRegistry = ((window.__UIControllerRegistry || {\n}));");
// 4124
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[4], o11,o22);
// undefined
o11 = null;
// 4151
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"VlW5K\",]);\n}\n;\n;\nfunction ContextualDialog(b) {\n    var a = new Dialog();\n    copy_properties(a, ContextualDialog.prototype);\n    a._setFromModel(b);\n    return a;\n};\n;\nContextualDialog.prototype = {\n    setContext: function(a) {\n        this._context = a;\n        this._dirty();\n        return this;\n    },\n    _buildDialogContent: function() {\n        Bootloader.loadComponents(\"contextual-dialog-css\", function() {\n            CSS.addClass(this._obj, \"contextual_dialog\");\n            this._content = this._frame = $N(\"div\", {\n                className: \"contextual_dialog_content\"\n            });\n            this._arrow = $N(\"div\", {\n                className: \"arrow\"\n            });\n            DOM.setContent(this._popup, [this._content,this._arrow,]);\n        }.bind(this));\n    },\n    _resetDialogObj: function() {\n        if (!this._context) {\n            return;\n        }\n    ;\n    ;\n        var g = Vector2.getElementPosition(this._context);\n        var k = this._context.offsetWidth, h = this._context.offsetHeight;\n        var l = g.x, m = ((g.y + h));\n        var i = Vector2.getViewportDimensions().x;\n        var j = Vector2.getScrollPosition().x;\n        var e = Vector2.getDocumentDimensions().x;\n        var d = Vector2.getElementDimensions(this._popup).x;\n        var f = 0;\n        var c;\n        if (((k < 64))) {\n            c = ((l + ((k / 2))));\n        }\n         else c = ((l + 32));\n    ;\n    ;\n        if (((((e > 0)) && ((e < d))))) {\n            f = -l;\n        }\n         else {\n            if (((((i > 0)) && ((((l + d)) > ((j + i))))))) {\n                f = ((((((j + i)) - d)) - l));\n                if (((((l + f)) < j))) {\n                    f = ((j - l));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((((e > 0)) && ((((l + d)) > e))))) {\n                f = ((((e - d)) - l));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        l += f;\n        if (((((c - l)) < 32))) {\n            l = ((c - 32));\n            if (((l < 0))) {\n                l = 0;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var b = Vector2.getElementDimensions(this._arrow).x;\n        var a = ((((c - l)) - ((b / 2))));\n        if (((a < 0))) {\n            a = 0;\n        }\n    ;\n    ;\n        if (((a > ((d - 32))))) {\n            a = ((d - 32));\n        }\n    ;\n    ;\n        CSS.setStyle(this._arrow, \"marginLeft\", ((a + \"px\")));\n        new Vector2(l, m, \"JSBNG__document\").setElementPosition(this._popup);\n    },\n    _renderDialog: function(a) {\n        if (((window != JSBNG__top))) {\n            this._auto_focus = false;\n        }\n    ;\n    ;\n        Dialog.prototype._renderDialog.call(this, a);\n    }\n};\nfunction captchaRefresh(d, e, f, a, b) {\n    var c = {\n        new_captcha_type: d,\n        id: f,\n        t_auth_token: a\n    };\n    c.skipped_captcha_data = $(\"captcha_persist_data\").value;\n    if (e) {\n        c.registration_page = true;\n    }\n;\n;\n    new AsyncRequest().setURI(\"/captcha/refresh_ajax.php\").setMethod(\"GET\").setReadOnly(true).setData(c).setStatusElement(\"captcha_throbber\").setHandler(function(i) {\n        var g = ge(\"captcha\");\n        var h = ge(\"captcha_error_msg\");\n        if (g) {\n            DOM.setContent(g, HTML(i.getPayload().captcha));\n        }\n    ;\n    ;\n        if (((b && h))) {\n            hide(h);\n        }\n    ;\n    ;\n    }).send();\n};\n;\nfunction tfbcaptcha_whats_this(a) {\n    new ContextualDialog().setContext(a).setTitle(_tx(\"Security Check\")).setBody(((((\"\\u003Cdiv class=\\\"tfbcaptcha_whats_this_popup\\\"\\u003E\" + _tx(\"This is a standard security test that we use to prevent spammers from creating fake accounts and spamming users.\"))) + \"\\u003C/div\\u003E\"))).setButtons(Dialog.OK).show();\n};\n;");
// 4152
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[6], o13,o22);
// undefined
o13 = null;
// 4179
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"jnsdD\",]);\n}\n;\n;\nPresenceMessage = {\n    STARTED: \"presence/started\",\n    SHUTDOWN: \"presence/shutdown\",\n    RESTARTED: \"presence/restarted\",\n    WINDOW_RESIZED: \"presence/window-resized\",\n    TAB_CLOSED: \"presence/tab-closed\",\n    TAB_OPENED: \"presence/tab-opened\",\n    PRESENCE_UPDATER_READY: \"presence/updater-ready\",\n    getAppMessageType: function(a, b) {\n        return ((((((\"presence/app_message:\" + a)) + \":\")) + b));\n    },\n    getArbiterMessageType: function(a) {\n        return ((\"presence/message:\" + a));\n    }\n};\nDcode = function() {\n    var a, d = {\n    }, b = {\n        _: \"%\",\n        A: \"%2\",\n        B: \"000\",\n        C: \"%7d\",\n        D: \"%7b%22\",\n        E: \"%2c%22\",\n        F: \"%22%3a\",\n        G: \"%2c%22ut%22%3a1\",\n        H: \"%2c%22bls%22%3a\",\n        I: \"%2c%22n%22%3a%22%\",\n        J: \"%22%3a%7b%22i%22%3a0%7d\",\n        K: \"%2c%22pt%22%3a0%2c%22vis%22%3a\",\n        L: \"%2c%22ch%22%3a%7b%22h%22%3a%22\",\n        M: \"%7b%22v%22%3a2%2c%22time%22%3a1\",\n        N: \".channel%22%2c%22sub%22%3a%5b\",\n        O: \"%2c%22sb%22%3a1%2c%22t%22%3a%5b\",\n        P: \"%2c%22ud%22%3a100%2c%22lc%22%3a0\",\n        Q: \"%5d%2c%22f%22%3anull%2c%22uct%22%3a\",\n        R: \".channel%22%2c%22sub%22%3a%5b1%5d\",\n        S: \"%22%2c%22m%22%3a0%7d%2c%7b%22i%22%3a\",\n        T: \"%2c%22blc%22%3a1%2c%22snd%22%3a1%2c%22ct%22%3a\",\n        U: \"%2c%22blc%22%3a0%2c%22snd%22%3a1%2c%22ct%22%3a\",\n        V: \"%2c%22blc%22%3a0%2c%22snd%22%3a0%2c%22ct%22%3a\",\n        W: \"%2c%22s%22%3a0%2c%22blo%22%3a0%7d%2c%22bl%22%3a%7b%22ac%22%3a\",\n        X: \"%2c%22ri%22%3a0%7d%2c%22state%22%3a%7b%22p%22%3a0%2c%22ut%22%3a1\",\n        Y: \"%2c%22pt%22%3a0%2c%22vis%22%3a1%2c%22bls%22%3a0%2c%22blc%22%3a0%2c%22snd%22%3a1%2c%22ct%22%3a\",\n        Z: \"%2c%22sb%22%3a1%2c%22t%22%3a%5b%5d%2c%22f%22%3anull%2c%22uct%22%3a0%2c%22s%22%3a0%2c%22blo%22%3a0%7d%2c%22bl%22%3a%7b%22ac%22%3a\"\n    };\n    function c() {\n        var f = [];\n        for (var e in b) {\n            d[b[e]] = e;\n            f.push(b[e]);\n        };\n    ;\n        f.reverse();\n        a = new RegExp(f.join(\"|\"), \"g\");\n    };\n;\n    return {\n        encode: function(e) {\n            c();\n            return encodeURIComponent(e).replace(/([_A-Z])|%../g, function(g, f) {\n                return ((f ? ((\"%\" + f.charCodeAt(0).toString(16))) : g));\n            }).toLowerCase().replace(a, function(f) {\n                return d[f];\n            });\n        },\n        decode: function(e) {\n            return decodeURIComponent(e.replace(/[_A-Z]/g, function(f) {\n                return b[f];\n            }));\n        }\n    };\n}();\nDcode_deprecated = function() {\n    var a, d = {\n    }, b = {\n        _: \"%\",\n        A: \"%22%3a\",\n        B: \"%2c%22\",\n        C: \"%2c%22sb%22%3a1%2c%22t%22%3a%7b%7d%2c%22f%22%3anull%2c%22uct%22%3a0%2c%22s%22%3a0%7d%2c%22bl%22%3a%7b%22ac%22%3a\",\n        D: \"%7b%22\",\n        E: \"%2c%22pt%22%3a0%2c%22vis%22%3a1%2c%22bls%22%3a0%2c%22blc%22%3a0%2c%22snd%22%3a1%2c%22blo%22%3a0%2c%22bvt%22%3a\",\n        F: \"ri%22%3a0%7d%2c%22state%22%3a%7b%22p%22%3a0%2c%22ut%22%3a1\",\n        G: \"%2c%22ch%22%3a%7b%22h%22%3a%22channel\",\n        H: \"%22%2c%22p%22%3a80%2c%22sub%22%3a%5b\",\n        I: \"%7d%7d\",\n        J: \"%7b%22v%22%3a2%2c%22time%22%3a1\",\n        K: \"%2c%22lc%22%3a1%2c%22cvr%22%3a%7b%22r%22%3a1%2c%22ts%22%3a1\",\n        L: \"%5d%2c%22p%5f\",\n        M: \"%22%3a0%2c%22\",\n        N: \"%22%3a%7b%22i%22%3a0%2c%22all%46lids%22%3a%5bnull%5d\",\n        O: \"0000\",\n        P: \"%22%3a1\",\n        Q: \"%7d\",\n        R: \"%2c%22pt%22%3a0%2c%22vis%22%3a0%2c%22bls%22%3a0%2c%22blc%22%3a0%2c%22snd%22%3a1%2c%22blo%22%3a0%2c%22bvt%22%3a0%2c%22ct%22%3a0%2c%22sb%22%3a1%2c%22t%22%3a%7b%7d%2c%22f%22%3anull%2c%22uct%22%3a0%2c%22s%22%3a0%7d%2c2bl%22%3a%7b%22ac%22%3a0%2c%22ut\",\n        S: \"%22%3a%7b%22ol%22%3a%2d1%2c%22exp%22%3a1\",\n        T: \"fl%22%3a%5b%22%2d1%22%5d%2c%22all%46lids%22%3a%5b%22%2d1%22%5d\",\n        U: \"ud%22%3a900%2c%22lc%22%3a0%2c%22cvr%22%3a%7b\",\n        V: \"%2c%22ut%22%3a1\",\n        W: \"%2c%22pt%22%3a0%2c%22vis%22%3a1%2c%22bls\",\n        X: \"%2c%22lc%22%3a1%2c%22cvr%22%3a%7b%22r%22%3a0%2e\",\n        Y: \"%22%3a%7b%22n%22%3a%22%\",\n        Z: \"%2c%22ud%22%3a\"\n    };\n    function c() {\n        var f = [];\n        for (var e in b) {\n            d[b[e]] = e;\n            f.push(b[e]);\n        };\n    ;\n        f.reverse();\n        a = new RegExp(f.join(\"|\"), \"g\");\n    };\n;\n    return {\n        encode: function(e) {\n            c();\n            return encodeURIComponent(e).replace(/([_A-Z])|%../g, function(g, f) {\n                return ((f ? ((\"%\" + f.charCodeAt(0).toString(16))) : g));\n            }).toLowerCase().replace(a, function(f) {\n                return d[f];\n            });\n        },\n        decode: function(e) {\n            return decodeURIComponent(e.replace(/[_A-Z]/g, function(f) {\n                return b[f];\n            }));\n        }\n    };\n}();\nfunction CookieManager(b, a) {\n    this.version = b;\n    this.cookieName = \"presence\";\n    this.dictEncode = a;\n    this.storers = {\n    };\n    Arbiter.inform(\"presence-cookie-manager/initialized\", this, Arbiter.BEHAVIOR_PERSISTENT);\n};\n;\nCookieManager.prototype = {\n    register: function(b, a) {\n        this.storers[b] = a;\n    },\n    store: function() {\n        var a = this._getCookie();\n        if (((((a && a.v)) && ((this.version < a.v))))) {\n            presence.versionShutdown();\n            return;\n        }\n    ;\n    ;\n        var b = {\n            v: this.version,\n            time: parseInt(((presence.getTime() * 4022)))\n        };\n        for (var d in this.storers) {\n            b[d] = this.storers[d]();\n        ;\n        };\n    ;\n        var c = JSON.stringify(b);\n        if (this.dictEncode) {\n            c = ((\"E\" + Dcode.encode(c)));\n        }\n    ;\n    ;\n        if (presence.hasUserCookie(false)) {\n            setCookie(this.cookieName, c, null);\n        }\n    ;\n    ;\n    },\n    clear: function() {\n        clearCookie(this.cookieName);\n    },\n    _getCookie: function() {\n        try {\n            var data = getCookie(this.cookieName);\n            if (((this.lastD === data))) {\n                return this.lastV;\n            }\n             else {\n                this.lastD = data;\n                this.lastV = null;\n            }\n        ;\n        ;\n            if (((data && ((data.charAt(0) == \"E\"))))) {\n                data = Dcode.decode(data.substring(1));\n            }\n             else if (((data && ((data.charAt(0) == \"D\"))))) {\n                data = Dcode_deprecated.decode(data.substring(1));\n            }\n            \n        ;\n        ;\n            if (data) {\n                this.lastV = JSON.parse(data);\n                return this.lastV;\n            }\n        ;\n        ;\n        } catch (a) {\n        \n        };\n    ;\n        return null;\n    },\n    getSubCookie: function(b) {\n        var a = this._getCookie();\n        if (!a) {\n            return null;\n        }\n    ;\n    ;\n        return a[b];\n    },\n    setCheckUserCookie: function(a) {\n        this.requireUserCookie = a;\n    }\n};");
// 4182
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[2], o8,o22);
// undefined
o8 = null;
// 4209
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"FmWj5\",]);\n}\n;\n;\nfunction TickerCache(a, b) {\n    this._controller = a;\n    this._cacheKey = b;\n    this._numStoriesToKeep = 15;\n    this._subscriptions = [Arbiter.subscribe(\"Ticker/storiesInserted\", this.update.bind(this)),Arbiter.subscribe(\"Ticker/resized\", this.update.bind(this)),Arbiter.subscribe(\"Ticker/afterInsert\", this.update.bind(this)),Arbiter.subscribe(\"Ticker/animateOut\", this.update.bind(this)),Arbiter.subscribe(\"Ticker/cacheHit\", this.poll.bind(this)),];\n};\n;\ncopy_properties(TickerCache.prototype, {\n    poll: function() {\n        this._controller.update({\n            cache_update: 1\n        });\n    },\n    loadData: function() {\n        if (((PageletCache && this._cacheKey))) {\n            return PageletCache.fetchData(this._cacheKey);\n        }\n    ;\n    ;\n    },\n    update: function() {\n        if (((PageletCache && this._cacheKey))) {\n            var b = function(e) {\n                var g = DOM.scry(e, \"div.fbFeedTickerStory\");\n                if (((g.length > this._numStoriesToKeep))) {\n                    g.slice(this._numStoriesToKeep).each(DOM.remove);\n                }\n            ;\n            ;\n                var c = [\"tickerStoryActive\",\"tickerStorySelected\",\"tickerStoryFetching\",];\n                g.each(function(h) {\n                    c.each(function(i) {\n                        CSS.removeClass(h, i);\n                    });\n                });\n                CSS.removeClass(e, \"tickerChildSelected\");\n                var f = DOM.scry(e, \"div.uiScrollableAreaTrack\")[0];\n                ((f && CSS.setStyle(f, \"opacity\", 0)));\n                var d = DOM.scry(e, \"div.fbFeedTicker\")[0];\n                if (d) {\n                    CSS.setStyle(d, \"JSBNG__top\", \"\");\n                    CSS.removeClass(d, \"fixed_elem\");\n                }\n            ;\n            ;\n            }.bind(this);\n            var a = function(c) {\n                c.newest = this._controller.getNewest();\n            }.bind(this);\n            PageletCache.snapShot(this._cacheKey, a, b);\n        }\n    ;\n    ;\n    },\n    cleanup: function() {\n        this._subscriptions.each(Arbiter.unsubscribe);\n    }\n});\nfunction TickerController() {\n\n};\n;\n!function() {\n    var c = 1;\n    var b = 2;\n    var a = 3;\n    var d = 4;\n    copy_properties(TickerController, {\n        _instances: {\n        },\n        _placeholders: {\n        },\n        _logPositionChange: false,\n        getInstance: function(e) {\n            var f = Parent.byClass($(e), \"fbFeedTicker\");\n            return ((f ? TickerController._instances[f.id] : null));\n        },\n        isLoaded: function(e) {\n            var f = TickerController._placeholders[e.id];\n            return ((!f || ((f.JSBNG__status == a))));\n        },\n        show: function(g, e) {\n            e = ((e || bagofholding));\n            for (var f in TickerController._instances) {\n                var i = ge(f);\n                if (((!i || ((i.parentNode.id == g.id))))) {\n                    continue;\n                }\n            ;\n            ;\n                TickerController.hide(i.parentNode);\n            };\n        ;\n            TickerController._doPositionChange(g);\n            CSS.show(g);\n            var h = TickerController._placeholders[g.id];\n            if (((h && ((h.JSBNG__status == c))))) {\n                TickerController._fetchTickerForPlaceholder(g, e);\n            }\n             else {\n                TickerController._placeholders[g.id] = {\n                    JSBNG__status: d,\n                    callback: e\n                };\n                e();\n            }\n        ;\n        ;\n        },\n        _doPositionChange: function(e) {\n            if (((!TickerController._logPositionChange || CSS.shown(e)))) {\n                return;\n            }\n        ;\n        ;\n            new AsyncSignal(\"/common/ods_endpoint.php\", {\n                k: ((\"ticker.render.switch.\" + e.id))\n            }).send();\n        },\n        hide: function(e) {\n            CSS.hide(e);\n        },\n        hideStoriesByClass: function(e) {\n            for (var f in TickerController._instances) {\n                DOM.scry($(f), e).forEach(CSS.hide);\n            ;\n            };\n        ;\n        },\n        hideStory: function(e) {\n            var f = ((e && TickerController.getInstance(e)));\n            ((f && f.hideStory(e)));\n        },\n        undoHideStory: function(e) {\n            var f = ((e && TickerController.getInstance(e)));\n            ((f && f.undoHideStory(e)));\n        },\n        _fetchTickerForPlaceholder: function(g, e) {\n            var f = {\n                handler: function() {\n                    TickerController._placeholders[g.id].JSBNG__status = a;\n                    e();\n                }\n            };\n            UIPagelet.loadFromEndpoint(\"TickerPagelet\", g.id, TickerController._placeholders[g.id].pageletData, f);\n            TickerController._placeholders[g.id].JSBNG__status = b;\n        },\n        registerStoryDialog: function(g, e) {\n            var f = ge(g);\n            if (!f) {\n                f = ge(((\"ticker_\" + g)));\n            }\n        ;\n        ;\n            Arbiter.subscribe(\"ticker/init\", function() {\n                var h = ((f && TickerController.getInstance(f)));\n                ((h && h.registerStoryDialog(f, e)));\n            }, Arbiter.SUBSCRIBE_ALL);\n        },\n        registerPlaceholder: function(g, f) {\n            var e = TickerController._placeholders[g];\n            TickerController._placeholders[g] = {\n                JSBNG__status: c,\n                pageletData: f\n            };\n            if (((e && ((e.JSBNG__status == d))))) {\n                TickerController.show($(g));\n                e.callback();\n            }\n        ;\n        ;\n        }\n    });\n}();\nTickerController.prototype = {\n    ADS_IDLE_MS: 300000,\n    FLYOUT_MAX_HEIGHT: 450,\n    FLYOUT_OFFSET_THRESHOLD: 20,\n    FLYOUT_COMMENT_OFFSET: 15,\n    FLYOUT_VIEWPORT_PADDING: 75,\n    FLYOUT_TARGET_HEIGHT_OFFSET: 25,\n    init: function(d, e, a) {\n        TickerController._instances[d.id] = this;\n        this._root = d;\n        this._content = DOM.JSBNG__find(d, \".ticker_stream\");\n        this._stories = DOM.JSBNG__find(this._root, \".tickerActivityStories\");\n        this._scrollableArea = e;\n        this._container = DOM.JSBNG__find(d, \"div.uiScrollableAreaWrap\");\n        this._storyIDs = [];\n        this._objectIDs = [];\n        this._fetchedStories = {\n        };\n        this._removedStoryIDs = [];\n        var b = +new JSBNG__Date();\n        this._lastUpdate = b;\n        this._lastPull = b;\n        this._lastInsert = ((b + a.firstCustomStoryDelay));\n        this._lastCustomStory = 0;\n        this._pollOnly = false;\n        this._needNonCustomStoryNum = 0;\n        this._autoloadStoryIndex = 1;\n        this._scrollTopThreshold = 100;\n        this._scrollTopPrompt = DOM.JSBNG__find(this._root, \".scrollTopPrompt\");\n        this._scrollTopPromptVisible = false;\n        this._maxStoriesToKeep = 50;\n        this._minStoriesToKeep = 25;\n        this._tickerInSidebarMode = !!Parent.byClass(this._root, \"fbChatSidebar\");\n        var c = $N(\"div\", {\n            className: \"hidden_elem\"\n        });\n        this._storyQueue = c;\n        DOM.appendContent(this._root, c);\n        this._initObjectIDs();\n        this._initPageletCache(a);\n        this._initConfig(a);\n        this._resetMorePager();\n        this._initListeners();\n        this._initSubscriptions();\n        Arbiter.inform(\"ticker/init\", this, Arbiter.BEHAVIOR_PERSISTENT);\n        this._poll();\n        if (this._prefetchAfterLoad) {\n            this._fetchStories(this._getAllStories().slice(0, 5));\n        }\n    ;\n    ;\n    },\n    _initPageletCache: function(a) {\n        if (((window.PageletCache && a.cacheKey))) {\n            this._cache = new TickerCache(this, a.cacheKey);\n            copy_properties(a, this._cache.loadData());\n        }\n    ;\n    ;\n    },\n    _initConfig: function(a) {\n        copy_properties(this, {\n            _newest: a.newest,\n            _page_newest: a.newest,\n            _timeout: a.timeout,\n            _heartbeatTimeout: Math.max(15000, a.heartbeatTimeout),\n            _pullTimeout: Math.max(30000, a.pullTimeout),\n            _insertTimeout: a.insertTimeout,\n            _friendCount: a.friendCount,\n            _maxQueueLength: a.maxQueueLength,\n            _filters: a.filters,\n            _heartbeatEndpoint: a.heartbeatEndpoint,\n            _maxCustomQueueLength: a.maxCustomQueueLength,\n            _customStoryInsertTimeout: Math.max(5000, a.customStoryInsertTimeout),\n            _nonCustomToCustomStoryRatio: a.nonCustomToCustomStoryRatio,\n            _minForceUpdateInterval: Math.max(a.insertTimeout, a.minForceUpdateInterval),\n            _popupOnHover: a.popupOnHover,\n            _priorityAppId: a.priorityAppId,\n            _prefetchOnHover: a.prefetchStoriesOnHover,\n            _dark: a.dark,\n            _userIdleTimeout: a.userIdleTimeout,\n            _pollOnly: a.pollOnly,\n            _tickerDebug: a.tickerDebug,\n            _tickerSource: a.tickerSource,\n            _prefetchAfterLoad: a.prefetchAfterLoad,\n            _cacheKey: a.cacheKey\n        });\n        this._queueCustomStories(a.customStories);\n    },\n    _initListeners: function() {\n        this._listeners = JSBNG__Event.listen(this._root, {\n            click: this._handleClick.bind(this),\n            keydown: this._handleKeydown.bind(this),\n            mouseout: this._handleMouseout.bind(this),\n            mouseover: this._handleMouseover.bind(this),\n            mousedown: this._tickerDeClicker.bind(this)\n        });\n        this._listeners.JSBNG__scroll = JSBNG__Event.listen(this._container, \"JSBNG__scroll\", this._handleScroll.bind(this));\n        this._initInfiniteScrollListener.bind(this).defer();\n    },\n    _initSubscriptions: function() {\n        JSBNG__onleaveRegister(this._cleanup.bind(this));\n        this._subscriptions = [Arbiter.subscribe(NavigationMessage.NAVIGATION_BEGIN, this._onNavHandler.bind(this)),Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"ticker_update\"), this._handleTickerPush.bind(this)),Arbiter.subscribe(\"composer/publish\", this._handleComposerPublish.bind(this)),Arbiter.subscribe(\"Ticker/storiesInserted\", this._handleStoriesInserted.bind(this)),Arbiter.subscribe(\"Ticker/fixed\", this._setFixed.bind(this, true)),Arbiter.subscribe(\"Ticker/unfixed\", this._setFixed.bind(this, false)),Arbiter.subscribe(\"Ticker/resized\", this._checkInfiniteScroll.bind(this)),Arbiter.subscribe(UFIOptimistic.COMMENT_SEND_EVENT, this._scrollDialogToBottom.bind(this)),Arbiter.subscribe(\"Ticker/chatOpened\", this._handleChatOpened.bind(this)),];\n    },\n    _handleClick: function(JSBNG__event) {\n        var c = JSBNG__event.getTarget();\n        if (this._getButtonFromNode(c)) {\n            this._handleActionButton(JSBNG__event);\n            return;\n        }\n    ;\n    ;\n        var b = this._getStoryFromNode(c);\n        var a = Parent.byClass(c, \"tickerStoryAllowClick\");\n        if (((((!b || ((b == this._selectedStory)))) || a))) {\n            return;\n        }\n    ;\n    ;\n        if (this._storyIsHidden(b)) {\n            return;\n        }\n    ;\n    ;\n        if (((((b == this._activeStory)) && !this._selectedStory))) {\n            this._selecting = true;\n        }\n    ;\n    ;\n        this._clearNux();\n        this._logUserAction(c, \"click\", JSBNG__event);\n        if (!this._storyCanOpenDialog(b)) {\n            this._openStoryExternally(b, JSBNG__event);\n            return;\n        }\n    ;\n    ;\n        this._activateStory(b);\n        this._selectStory(b);\n        if (b.getAttribute(\"data-story-unselectable\")) {\n            this._deactivateStory(b);\n        }\n    ;\n    ;\n    },\n    _handleMouseover: function(JSBNG__event) {\n        JSBNG__event.kill();\n        this._setLocked(true);\n        var c = JSBNG__event.getTarget();\n        var b = this._getOpenableStory(c);\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        if (((this._prefetchOnHover || this._popupOnHover))) {\n            this._fetchStory(b);\n        }\n    ;\n    ;\n        if (this._selectedStory) {\n            return;\n        }\n    ;\n    ;\n        if (this._popupOnHover) {\n            this._clearHoverTimeouts();\n            var a = ((this._activeStory ? 75 : 1000));\n            this._hoverShowTimeout = this._setTimeout(function() {\n                this._activateStory(b);\n                this._logUserAction(c, \"mouseover\", JSBNG__event);\n            }.bind(this), a);\n        }\n    ;\n    ;\n    },\n    _handleMouseout: function(JSBNG__event) {\n        var c = JSBNG__event.getTarget();\n        this._setLocked(false);\n        if (((c == this._getStoryFromNode(c)))) {\n            var b = DOM.scry(c.parentNode, \".openToggler\");\n            for (var a = 0; ((a < b.length)); a++) {\n                Selector.toggle(b[a]);\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        this._scheduleHide();\n    },\n    _handleKeydown: function(JSBNG__event) {\n        this._tickerDeClicker(JSBNG__event);\n        var b = this._activeStory;\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        var a = JSBNG__Event.getKeyCode(JSBNG__event);\n        switch (a) {\n          case KEYS.UP:\n            b = b.previousSibling;\n            break;\n          case KEYS.DOWN:\n            b = b.nextSibling;\n            break;\n          case KEYS.ESC:\n            this._deactivateStory(true);\n            return;\n          default:\n            return;\n        };\n    ;\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__event.kill();\n        this._activateStory(b);\n        this._selectStory(b);\n    },\n    _handleScroll: function() {\n        ((!this._preventScrollDismiss && this._deactivateStory(true)));\n        this._checkInfiniteScroll();\n        if (!this._scrollLogged) {\n            this._scrollLogged = true;\n            var b = this._stories.childNodes.length;\n            var c = this._stories.getAttribute(\"data-gt\");\n            var a = {\n                ticker_scroll: 1,\n                number_stories: b,\n                source: c\n            };\n            report_data(\"JSBNG__scroll\", {\n                gt: a\n            });\n        }\n    ;\n    ;\n    },\n    _handleStoriesInserted: function() {\n        this._initInfiniteScrollListener();\n        this._scrollableArea.adjustGripper();\n    },\n    _handleActionButton: function(JSBNG__event) {\n        var d = JSBNG__event.getTarget();\n        var a = this._getButtonFromNode(d);\n        var c = this._getOpenableStory(d);\n        var b = this._getStoryDialog(c);\n        if (b) {\n            var e = b.subscribe(\"beforehide\", function() {\n                b.unsubscribe(e);\n                return false;\n            });\n        }\n    ;\n    ;\n    },\n    _handleScrollToTopClick: function() {\n        this._scrollToTop(this._poll.bind(this));\n    },\n    _scrollToTop: function(a) {\n        animation(this._container).to(\"scrollTop\", 0).ease(animation.ease.end).JSBNG__ondone(a).go();\n    },\n    _clearHoverTimeouts: function() {\n        JSBNG__clearTimeout(this._hoverShowTimeout);\n        JSBNG__clearTimeout(this._hoverHideTimeout);\n    },\n    _getAllStories: function() {\n        return DOM.scry(this._root, \"div.fbFeedTickerStory\");\n    },\n    _getQueuedStories: function() {\n        return DOM.scry(this._storyQueue, \".fbFeedTickerStory.queuedStory\");\n    },\n    _getQueuedCustomStories: function() {\n        return DOM.scry(this._storyQueue, \".fbFeedTickerStory.customStory\");\n    },\n    _getButtonFromNode: function(a) {\n        return ((Parent.byClass(a, \"tickerInlineOverlay\") || Parent.byClass(a, \"tickerInlineOverlayLinkWrap\")));\n    },\n    _getStoryFromNode: function(a) {\n        return Parent.byClass(a, \"fbFeedTickerStory\");\n    },\n    _getOpenableStory: function(a) {\n        var b = this._getStoryFromNode(a);\n        return ((this._storyCanOpenDialog(b) ? b : null));\n    },\n    _getStoryDialog: function(a) {\n        return ((((window.ContextualDialogX && ContextualDialogX.getInstance(a))) || null));\n    },\n    _getStoryDialogEndpoint: function(a) {\n        return ((((((a && ((a.getAttribute(\"data-rel\") == \"async\")))) && a.getAttribute(\"data-ajaxify\"))) || null));\n    },\n    _storyCanOpenDialog: function(a) {\n        return ((!!this._getStoryDialogEndpoint(a) && !this._storyIsHidden(a)));\n    },\n    _storyIsHidden: function(a) {\n        return CSS.hasClass(a, \"tickerStoryHidden\");\n    },\n    hideStory: function(a) {\n        this._deactivateStory();\n        CSS.addClass(a, \"tickerStoryHidden\");\n        CSS.removeClass(a, \"tickerStoryClickable\");\n    },\n    undoHideStory: function(a) {\n        CSS.addClass(a, \"tickerStoryClickable\");\n        CSS.removeClass(a, \"tickerStoryHidden\");\n    },\n    _scheduleHide: function() {\n        if (((this._popupOnHover && !this._selectedStory))) {\n            this._clearHoverTimeouts();\n            this._hoverHideTimeout = this._setTimeout(this._deactivateStory.bind(this), 100);\n        }\n    ;\n    ;\n    },\n    _setScrollTopPromptVisible: function(a) {\n        this._scrollTopPromptVisible = a;\n        CSS.conditionShow(this._scrollTopPrompt, a);\n        if (((a && !this._listeners.scrollTop))) {\n            this._listeners.scrollTop = JSBNG__Event.listen(this._scrollTopPrompt, {\n                click: this._handleScrollToTopClick.bind(this)\n            });\n        }\n         else if (((!a && this._listeners.scrollTop))) {\n            this._listeners.scrollTop.click.remove();\n            this._listeners.scrollTop = null;\n        }\n        \n    ;\n    ;\n    },\n    _isUserIdle: function() {\n        return !UserActivity.isActive(this._userIdleTimeout);\n    },\n    _schedulePoll: function() {\n        JSBNG__clearTimeout(this._pollToken);\n        this._pollToken = this._setTimeout(this._poll.bind(this), this._timeout);\n    },\n    _poll: function() {\n        this._debug(\"poll\");\n        if (!this._isTickerVisible()) {\n            this._debug(\"not polling: ticker not visible\");\n            return;\n        }\n    ;\n    ;\n        if (this._isUserIdle()) {\n            this._debug(\"not polling: idle\");\n            return UserActivity.subscribeOnce(this._poll.bind(this));\n        }\n    ;\n    ;\n        var e = ((!this._isScrolledToTop() && this._getQueuedStories().length));\n        this._setScrollTopPromptVisible(e);\n        var d = +new JSBNG__Date();\n        var j = ((d - this._lastInsert));\n        if (((((j < this._insertTimeout)) || this._isLocked()))) {\n            return this._schedulePoll();\n        }\n    ;\n    ;\n        var g = this._getQueuedStories();\n        var a = this._getQueuedCustomStories();\n        var i = ((g.length > 0));\n        var h = ((((a.length > 0)) && ((((this._needNonCustomStoryNum === 0)) || ((!i && ((((d - this._lastCustomStory)) > this._customStoryInsertTimeout))))))));\n        if (h) {\n            this._insertStory(a.shift());\n            this._lastCustomStory = d;\n            this._needNonCustomStoryNum = this._nonCustomToCustomStoryRatio;\n            this._debug(\"not polling: should insert custom story\");\n            return this._schedulePoll();\n        }\n    ;\n    ;\n        if (i) {\n            this._insertStory(g.shift());\n            this._needNonCustomStoryNum--;\n            if (((this._needNonCustomStoryNum < 0))) {\n                this._needNonCustomStoryNum = 0;\n            }\n        ;\n        ;\n            this._debug(\"not polling: should insert story\");\n            return this._schedulePoll();\n        }\n    ;\n    ;\n        var b = ((((((((((a.length === 0)) && ((this._needNonCustomStoryNum === 0)))) && ((this._nonCustomToCustomStoryRatio > 0)))) && UserActivity.isActive(this.ADS_IDLE_MS))) && ((((d - this._lastUpdate)) > this._minForceUpdateInterval))));\n        var c = ((((d - this._lastUpdate)) > this._heartbeatTimeout));\n        if (((b || c))) {\n            var f = false;\n            if (((c && !this._pollOnly))) {\n                f = ((((d - this._lastPull)) > this._pullTimeout));\n            }\n        ;\n        ;\n            this._debug(\"polling for new stories\");\n            this.update({\n                heartbeat: c,\n                pull: f,\n                fullpoll: this._pollOnly,\n                needcustomstory: b\n            });\n            return;\n        }\n    ;\n    ;\n        this._schedulePoll();\n    },\n    update: function(b) {\n        var a = {\n            newest: ((((b.fullpoll || b.cache_update)) ? this._newest : this._page_newest)),\n            storyids: this._storyIDs,\n            friendcount: this._friendCount,\n            priorityappid: this._priorityAppId,\n            filters: JSON.stringify(this._filters)\n        };\n        copy_properties(a, b);\n        new AsyncRequest().setURI(this._heartbeatEndpoint).setReadOnly(true).setOption(\"retries\", 0).setData(a).setHandler(this._handleResponse.bind(this)).setFinallyHandler(this._poll.bind(this)).setAllowCrossPageTransition(true).send();\n        this._lastUpdate = +new JSBNG__Date();\n        if (a.pull) {\n            this._lastPull = this._lastUpdate;\n        }\n    ;\n    ;\n        this._storyIDs = [];\n    },\n    _insertStory: function(b, a) {\n        if (this._dark) {\n            return;\n        }\n    ;\n    ;\n        this._lastInsert = +new JSBNG__Date();\n        ((window.LiveTimer && LiveTimer.addTimeStamps(b)));\n        if (((a !== false))) {\n            if (this._isScrolledToTop()) {\n                this._scrollToTop(this._animateStoryIn.bind(this, b));\n            }\n             else this._animateStoryIn(b);\n        ;\n        ;\n        }\n         else DOM.prependContent(this._stories, b);\n    ;\n    ;\n        this._removeOldStories();\n    },\n    _removeOldStories: function() {\n        var b = this._getAllStories();\n        if (((b.length <= this._maxStoriesToKeep))) {\n            return;\n        }\n    ;\n    ;\n        var a = this._minStoriesToKeep;\n        b.slice(a).each(DOM.remove);\n        this._resetMorePager();\n    },\n    _resetMorePager: function() {\n        var b = this._getAllStories();\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        var c = b[((b.length - 1))].getAttribute(\"data-ticker-timestamp\");\n        var a = DOM.scry(this._root, \".tickerMorePager a\")[0];\n        if (!a) {\n            return;\n        }\n    ;\n    ;\n        var d = new URI(a.getAttribute(\"ajaxify\"));\n        d.addQueryData({\n            oldest: c\n        });\n        a.setAttribute(\"ajaxify\", d);\n    },\n    _setLocked: function(a) {\n        this._locked = a;\n    },\n    _isLocked: function() {\n        return !!((((this._scrollTopPromptVisible || this._locked)) || this._activeStory));\n    },\n    informAndRemoveStory: function(a, d, e) {\n        var b = this._getStoryFromNode(a);\n        var c = b.getAttribute(\"data-story-key\");\n        DOM.setContent(b, d);\n        CSS.addClass(b, \"highlightedStory\");\n        this._setTimeout(this.removeStory.bind(this, c), ((e || 6000)));\n    },\n    _getStoryByStoryKey: function(b) {\n        var c = this._getAllStories();\n        for (var a = 0; ((a < c.length)); a++) {\n            var d = c[a];\n            if (((d.getAttribute(\"data-story-key\") == b))) {\n                return d;\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    },\n    removeStory: function(c) {\n        this._removedStoryIDs[c] = true;\n        var b = this._getStoryByStoryKey(c);\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        if (((b == this._activeStory))) {\n            this._deactivateStory();\n        }\n    ;\n    ;\n        var a = this._getStoryDialog(b);\n        ((a && a.destroy()));\n        this._animateStoryOut(b);\n    },\n    _isScrolledToTop: function() {\n        return ((this._container.scrollTop <= this._scrollTopThreshold));\n    },\n    _animateStoryIn: function(b) {\n        var c = $N(\"div\", {\n            style: {\n                marginTop: \"-1000px\"\n            }\n        }, b);\n        CSS.setStyle(c, \"opacity\", 0);\n        DOM.prependContent(this._stories, c);\n        var a = Vector2.getElementDimensions(c).y;\n        CSS.setStyle(c, \"marginTop\", ((((\"-\" + a)) + \"px\")));\n        animation(c).to(\"marginTop\", 0).ease(animation.ease.end).checkpoint(15613).to(\"opacity\", 1).JSBNG__ondone(function() {\n            DOM.replace(c, b);\n            this._afterInsert(b);\n        }.bind(this)).go();\n    },\n    _animateStoryOut: function(a) {\n        var b = $N(\"div\", {\n            style: {\n                overflow: \"hidden\",\n                position: \"relative\"\n            }\n        });\n        DOM.insertBefore(b, a);\n        DOM.appendContent(b, a);\n        animation(b).to(\"JSBNG__top\", 20).to(\"height\", 0).to(\"opacity\", 0).ease(animation.ease.end).JSBNG__ondone(function() {\n            DOM.remove.curry(b);\n            Arbiter.inform(\"Ticker/animateOut\");\n        }.bind(this)).go();\n    },\n    _afterInsert: function(a) {\n        Arbiter.inform(\"Ticker/afterInsert\");\n        if (((((a.firstChild && a.firstChild.firstChild)) && a.firstChild.firstChild.id))) {\n            Arbiter.inform(((\"tickerad_\" + a.firstChild.firstChild.id)));\n        }\n    ;\n    ;\n    },\n    setFilters: function(a) {\n        this._filters = a;\n    },\n    setCurrentAppId: function(a) {\n        this._priorityAppId = a;\n    },\n    _canShowStory: function(a) {\n        if (((this._filters && a))) {\n            for (var b in a) {\n                var c = a[b];\n                if (((((b in this._filters)) && !((c in this._filters[b]))))) {\n                    return false;\n                }\n            ;\n            ;\n            };\n        }\n    ;\n    ;\n        return true;\n    },\n    _handleTickerPush: function(e, a) {\n        if (this._isUserIdle()) {\n            this._debug(\"discarding story: user is idle\");\n            return;\n        }\n    ;\n    ;\n        var c = a.obj;\n        if (c.delete_id) {\n            this.removeStory(c.delete_id);\n            return;\n        }\n    ;\n    ;\n        var b = c.story_xhp;\n        if (!b) {\n            this._debug(\"discarding story: no markup\");\n            return;\n        }\n    ;\n    ;\n        this._newest = c.story_time;\n        if (!this._canShowStory(a.obj.filter_data)) {\n            this._debug(\"discarding story: not meant for this ticker\");\n            return;\n        }\n    ;\n    ;\n        var d = HTML(b).getRootNode();\n        this.queueStory(d, c.flyout_js_cmds);\n    },\n    _handleComposerPublish: function(b, a) {\n        ((a.tickerMarkup && this._insertStory(a.tickerMarkup)));\n    },\n    _clearNux: function() {\n        var a = DOM.scry(JSBNG__document.body, \"div.tickerNUXContainer\");\n        if (a.length) {\n            a.each(function(c) {\n                var b = ContextualDialogX.getInstance(c);\n                ((b && b.hide()));\n            });\n            new AsyncRequest().setURI(\"/ajax/feed/ticker/nux.php\").send();\n        }\n    ;\n    ;\n        this._clearNux = bagofholding;\n    },\n    _logRender: function() {\n        if (this._loggedRender) {\n            return;\n        }\n    ;\n    ;\n        var a = this._tickerInSidebarMode;\n        if (((a || Parent.byClass(this._content, \"home_right_column\")))) {\n            new AsyncSignal(\"/ajax/log_ticker_render.php\", {\n                sidebar_mode: a\n            }).send();\n            this._loggedRender = true;\n        }\n    ;\n    ;\n    },\n    _isTickerVisible: function() {\n        var a = DOM.contains(JSBNG__document.body, this._content);\n        ((a && this._logRender()));\n        return a;\n    },\n    _handleResponse: function(d) {\n        var c = d.getPayload();\n        if (c.newest) {\n            this._newest = this._page_newest = c.newest;\n        }\n    ;\n    ;\n        if (c.JSBNG__content) {\n            if (c.cache_update) {\n                var f = HTML(c.JSBNG__content).getRootNode();\n                var e = DOM.scry(f, \"div.fbFeedTickerStory\");\n                for (var b = 0; ((b < e.length)); b++) {\n                    if (this.dedupeStory(e[b])) {\n                        e[b].parentNode.removeChild(e[b]);\n                    }\n                ;\n                ;\n                };\n            ;\n                this._insertStory(f);\n            }\n             else if (((c.JSBNG__content instanceof Array))) {\n                for (var a = 0; ((a < c.JSBNG__content.length)); a++) {\n                    this.queueStoryMarkup(c.JSBNG__content[a]);\n                ;\n                };\n            ;\n            }\n             else this.queueStoryMarkup(c.JSBNG__content);\n            \n        ;\n        }\n    ;\n    ;\n        if (c.custom_stories) {\n            this._queueCustomStories(c.custom_stories);\n        }\n    ;\n    ;\n    },\n    queueStoryMarkup: function(a) {\n        var b = HTML(a).getRootNode();\n        this.queueStory(b);\n    },\n    dedupeStory: function(c) {\n        var b = c.getAttribute(\"data-story-key\");\n        var a = ((b && ((!!this._objectIDs[b] || !!this._removedStoryIDs[b]))));\n        if (a) {\n            this._debug(\"discarding story: duplicated object id\");\n        }\n    ;\n    ;\n        ((b && (this._objectIDs[b] = true)));\n        return a;\n    },\n    queueStory: function(d, a) {\n        if (this._dark) {\n            return;\n        }\n    ;\n    ;\n        if (this.dedupeStory(d)) {\n            return;\n        }\n    ;\n    ;\n        CSS.addClass(d, \"queuedStory\");\n        DOM.appendContent(this._storyQueue, d);\n        var b = ((a && a.length));\n        if (b) {\n            a.each(function(e) {\n                new Function(e).apply();\n            });\n        }\n    ;\n    ;\n        d.setAttribute(\"id\", ((((d.id + \"_\")) + this._root.id)));\n        var c = this._getQueuedStories();\n        c.slice(0, -this._maxQueueLength).each(DOM.remove);\n        if (b) {\n            this._fetchedStories[d.id] = true;\n        }\n    ;\n    ;\n    },\n    _queueCustomStories: function(b) {\n        while (b.length) {\n            var c = b.shift();\n            c = HTML(c).getRootNode();\n            var d = c.getAttribute(\"data-story-key\");\n            if (this._removedStoryIDs[d]) {\n                return;\n            }\n        ;\n        ;\n            CSS.addClass(c, \"customStory\");\n            DOM.appendContent(this._storyQueue, c);\n        };\n    ;\n        var a = this._getQueuedCustomStories();\n        a.slice(0, -this._maxQueueLength).each(DOM.remove);\n    },\n    _cleanup: function() {\n        TickerController._placeholders.pagelet_rhc_ticker = null;\n        if (!Parent.byClass(this._content, \"hasRightCol\")) {\n            return;\n        }\n    ;\n    ;\n        this._objectIDs = [];\n        this._subscriptions.each(Arbiter.unsubscribe);\n        for (var a in this._listeners) {\n            this._listeners[a].remove();\n        ;\n        };\n    ;\n        JSBNG__clearTimeout(this._pollToken);\n        this._pollToken = null;\n        this._cleanupInputFocusListener();\n        this._cleanupContentResizeListener();\n        ((this._cache && this._cache.cleanup()));\n    },\n    _onNavHandler: function(c, a) {\n        var b = a.params.key;\n        if (((((b != \"lf\")) && ((b != \"h\"))))) {\n            this._cleanup();\n        }\n    ;\n    ;\n    },\n    registerStoryDialog: function(b, a) {\n        this._fetchedStories[b.id] = true;\n        a.setContext(b);\n        a.subscribe(\"hide\", this._deactivateStory.bind(this, true));\n        a.subscribe(\"success\", this._focusStory.bind(this, b));\n        a.subscribe(\"beforehide\", function() {\n            if (this._selecting) {\n                this._selecting = false;\n                return false;\n            }\n        ;\n        ;\n        }.bind(this));\n        if (this._popupOnHover) {\n            a.subscribe(\"mouseenter\", this._clearHoverTimeouts.bind(this));\n            a.subscribe(\"mouseleave\", this._scheduleHide.bind(this));\n            a.subscribe(\"show\", function() {\n                this._highlightDialogScrollbar.bind(this, a).defer();\n                var c = JSBNG__Event.listen(a.getContent(), \"click\", function() {\n                    this._selectStory(b);\n                    c.remove();\n                }.bind(this));\n            }.bind(this));\n        }\n    ;\n    ;\n        if (((b == this._activeStory))) {\n            this._openDialog(a);\n        }\n    ;\n    ;\n    },\n    _highlightDialogScrollbar: function(b) {\n        var c = DOM.scry(b.getContent(), \".uiScrollableArea\")[0];\n        var a = ((c && ScrollableArea.getInstance(c)));\n        ((a && a.adjustGripper().showScrollbar(false)));\n    },\n    _openStoryExternally: function(c, JSBNG__event) {\n        var a = c.getAttribute(\"data-ajaxify\");\n        if (!a) {\n            return;\n        }\n    ;\n    ;\n        var b = ((((JSBNG__event.which != 1)) || JSBNG__event.getModifiers().any));\n        ((b ? window.open(a, \"_blank\") : goURI(a)));\n    },\n    _focusStory: function(a) {\n        JSBNG__clearTimeout(this._scrollDismissal);\n        this._preventScrollDismiss = true;\n        this._scrollDismissal = this._setTimeout(function() {\n            this._preventScrollDismiss = false;\n        }.bind(this), 100);\n        a.JSBNG__focus();\n    },\n    _selectStory: function(a) {\n        this._selectedStory = a;\n        CSS.addClass(a, \"tickerStorySelected\");\n        CSS.addClass(this._root, \"tickerChildSelected\");\n    },\n    _activateStory: function(b) {\n        this._clearHoverTimeouts();\n        if (((((b == this._activeStory)) || !this._storyCanOpenDialog(b)))) {\n            return;\n        }\n    ;\n    ;\n        this._deactivateStory();\n        this._focusStory(b);\n        this._activeStory = b;\n        CSS.addClass(b, \"tickerStoryActive\");\n        ((window.Toggler && Toggler.hide()));\n        var a = this._getStoryDialog(b);\n        if (a) {\n            this._openDialog(a);\n            return;\n        }\n    ;\n    ;\n        this._fetchStory(b);\n    },\n    _deactivateStory: function(a) {\n        if (this._dialog) {\n            this._dialog.setFadeOnHide(((a === true))).hide();\n        }\n    ;\n    ;\n        if (this._activeStory) {\n            CSS.removeClass(this._activeStory, \"tickerStoryActive\");\n            CSS.removeClass(this._activeStory, \"tickerStorySelected\");\n            CSS.removeClass(this._root, \"tickerChildSelected\");\n        }\n    ;\n    ;\n        this._dialog = this._selectedStory = this._activeStory = null;\n        this._cleanupInputFocusListener();\n        this._cleanupContentResizeListener();\n    },\n    _logUserAction: function(a, b, JSBNG__event) {\n        user_action(a, b, JSBNG__event, \"FORCE\", null);\n    },\n    _fetchStory: function(d) {\n        JSBNG__clearTimeout(this._fetchToken);\n        var c = [];\n        var a = this._getAllStories();\n        var b = a.indexOf(d);\n        [-2,-1,0,1,2,].each(function(f) {\n            var e = a[((b + f))];\n            ((e && c.push(e)));\n        }, this);\n        this._fetchToken = JSBNG__setTimeout(this._fetchStories.bind(this, c), 100);\n    },\n    _fetchStories: function(c) {\n        var a = [];\n        var d;\n        var b = function(e) {\n            JSBNG__clearTimeout(d);\n            c.each(function(f) {\n                CSS.conditionClass(f, \"tickerStoryFetching\", e);\n            });\n        };\n        c = c.filter(function(f) {\n            if (((f.id in this._fetchedStories))) {\n                return false;\n            }\n        ;\n        ;\n            this._fetchedStories[f.id] = true;\n            var e = this._getStoryDialogEndpoint(f);\n            var g = URI(e).getQueryData();\n            if (((!e || !g))) {\n                return false;\n            }\n        ;\n        ;\n            g.uniq_id = f.getAttribute(\"id\");\n            g.referrer = this._tickerSource;\n            a.push(g);\n            return true;\n        }, this);\n        if (!a.length) {\n            return;\n        }\n    ;\n    ;\n        d = this._setTimeout(b.curry(true), 500);\n        new AsyncRequest(\"/ajax/feed/ticker/multi_story\").setFinallyHandler(b.curry(false)).setErrorHandler(bagofholding).setData({\n            stories: a\n        }).setAllowCrossPageTransition(this._tickerInSidebarMode).send();\n    },\n    _tickerDeClicker: function(JSBNG__event) {\n        var d = JSBNG__event.getTarget();\n        var b = Parent.byTag(d, \"a\");\n        var c = this._getStoryFromNode(d);\n        var a = this._getButtonFromNode(d);\n        if (((((((((((c && b)) && !a)) && CSS.hasClass(c, \"tickerStoryClickable\"))) && !CSS.hasClass(b, \"tickerStoryAllowClick\"))) && !this._storyIsHidden(c)))) {\n            b.setAttribute(\"rel\", \"ignore\");\n            b.removeAttribute(\"JSBNG__onclick\");\n            b.removeAttribute(\"ajaxify\");\n            b.removeAttribute(\"href\");\n        }\n    ;\n    ;\n    },\n    _initInfiniteScrollListener: function() {\n        var b = this._getAllStories();\n        var a = Math.max(0, ((b.length - this._autoloadStoryIndex)));\n        this._infiniteScrollStory = b[a];\n        this._checkInfiniteScroll();\n    },\n    _checkInfiniteScroll: function() {\n        if (this._infiniteScrollStory) {\n            var a = Vector2.getElementPosition(this._infiniteScrollStory).y;\n            var c = ((Vector2.getElementPosition(this._container).y + Vector2.getElementDimensions(this._container).y));\n            if (((a < c))) {\n                var b = DOM.scry(this._root, \".tickerMorePager a\")[0];\n                ((b && AsyncRequest.bootstrap(b.getAttribute(\"ajaxify\"), b)));\n                this._infiniteScrollStory = null;\n                this._autoloadStoryIndex = 5;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _setFixed: function(b) {\n        if (!this._selectedStory) {\n            return;\n        }\n    ;\n    ;\n        var a = this._getStoryDialog(this._selectedStory);\n        if (a) {\n            a.setFixed(b);\n            a.updatePosition();\n        }\n    ;\n    ;\n    },\n    _setTimeout: function(b, a) {\n        return JSBNG__setTimeout(b, a, !this._tickerInSidebarMode);\n    },\n    _scrollDialogToBottom: function() {\n        var a = ((this._dialog && this._dialog.getContent()));\n        var c = ((a && DOM.scry(a, \".uiScrollableAreaWrap\")[0]));\n        var b = ((c && ScrollableArea.getInstance(c)));\n        ((b && b.scrollToBottom()));\n    },\n    _openDialog: function(a) {\n        this._dialog = a.show();\n        this._updateDialogPosition();\n        this._writeSwfFrame(a);\n        this._initCommentFocusListener.bind(this).defer();\n        this._initContentResizeListener.bind(this).defer();\n        this._stupidIE7VideoResizeHack(a);\n    },\n    _stupidIE7VideoResizeHack: function(a) {\n        if (((ua.ie() === 7))) {\n            var b = DOM.scry(a.getContent(), \".uiVideoThumb .img\");\n            b.each(function(c) {\n                CSS.setStyle(c, \"width\", \"\");\n            });\n        }\n    ;\n    ;\n    },\n    _updateDialogPosition: function() {\n        var a = ((this._tickerInSidebarMode || !!Parent.byClass(this._root, \"fixed_elem\")));\n        this._dialog.setFixed(a);\n        this._adjustFlyoutContentHeight();\n        this._dialog.updatePosition();\n    },\n    _writeSwfFrame: function(b) {\n        var a = ((this._dialog && this._dialog.getContent()));\n        var e = DOM.scry(a, \".swfObject\")[0];\n        if (!e) {\n            return;\n        }\n    ;\n    ;\n        var d = e.getAttribute(\"data-swfid\");\n        if (((d && window[d]))) {\n            var c = window[d];\n            c.write(e);\n        }\n    ;\n    ;\n    },\n    _initCommentFocusListener: function() {\n        var a = ((this._dialog && this._dialog.getContent()));\n        var b = ((a && DOM.scry(a, \".tickerDialogFooter textarea\")[0]));\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        this._listeners.inputFocus = JSBNG__Event.listen(b, \"JSBNG__focus\", this._scrollDialogToBottom.bind(this));\n    },\n    _cleanupInputFocusListener: function() {\n        if (this._listeners.inputFocus) {\n            this._listeners.inputFocus.remove();\n            this._listeners.inputFocus = null;\n        }\n    ;\n    ;\n    },\n    _initContentResizeListener: function() {\n        var a = ((this._dialog && this._dialog.getContent()));\n        if (!a) {\n            return;\n        }\n    ;\n    ;\n        this._listeners.contentResize = JSBNG__Event.listen(a, \"click\", function() {\n            this._dialog.updatePosition.bind(this._dialog).defer();\n        }.bind(this));\n    },\n    _cleanupContentResizeListener: function() {\n        if (this._listeners.contentResize) {\n            this._listeners.contentResize.remove();\n            this._listeners.contentResize = null;\n        }\n    ;\n    ;\n    },\n    _adjustFlyoutContentHeight: function() {\n        var e = ((this._dialog && this._dialog.getContent()));\n        var i = ((e && DOM.scry(e, \".uiScrollableAreaWrap\")[0]));\n        if (!i) {\n            return;\n        }\n    ;\n    ;\n        var j = Vector2.getElementDimensions(i);\n        var d = Vector2.getElementPosition(i);\n        var l = DOM.scry(i, \".uiUfi .uiUfiComment\");\n        var f = ((Vector2.getViewportDimensions().y - this.FLYOUT_VIEWPORT_PADDING));\n        var h = Math.min(this.FLYOUT_MAX_HEIGHT, f);\n        var k = ((h - this.FLYOUT_TARGET_HEIGHT_OFFSET));\n        for (var g = 0; ((g < l.length)); g++) {\n            var a = l[g];\n            var c = Vector2.getElementPosition(a);\n            var b = ((c.y - d.y));\n            if (((Math.abs(((b - k))) <= this.FLYOUT_OFFSET_THRESHOLD))) {\n                k = ((b + this.FLYOUT_COMMENT_OFFSET));\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        if (((j.y > k))) {\n            CSS.setStyle(i, \"height\", ((k + \"px\")));\n            CSS.setStyle(i, \"max-height\", null);\n        }\n         else {\n            CSS.setStyle(i, \"max-height\", ((h + \"px\")));\n            CSS.setStyle(i, \"height\", null);\n        }\n    ;\n    ;\n    },\n    _initObjectIDs: function() {\n        stories = this._getAllStories();\n        for (var b = 0; ((b < stories.length)); ++b) {\n            var a = stories[b].getAttribute(\"data-story-key\");\n            ((a && (this._objectIDs[a] = true)));\n        };\n    ;\n    },\n    _handleChatOpened: function() {\n        this._deactivateStory(true);\n    },\n    _debug: function(a) {\n        ((this._tickerDebug && JSBNG__console.log(\"ticker: \", a)));\n    },\n    getNewest: function() {\n        return this._newest;\n    }\n};");
// 4213
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[5], o12,o22);
// undefined
o12 = null;
// 4240
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"TLs0W\",]);\n}\n;\n;\nvar NotificationCounter = (function() {\n    var a = {\n        messages: 0,\n        notifications: 0,\n        requests: 0\n    };\n    return {\n        init: function(b) {\n            Arbiter.subscribe(\"update_title\", this._handleUpdate.bind(this));\n            Arbiter.subscribe(\"jewel/count-updated\", this._handleCountUpdate.bind(this));\n            this.counterInFront = b;\n        },\n        getCount: function() {\n            var c = 0;\n            for (var d in a) {\n                var b = Number(a[d]);\n                if (((((typeof a[d] == \"string\")) && isNaN(b)))) {\n                    return a[d];\n                }\n            ;\n            ;\n                if (((isNaN(b) || ((b < 0))))) {\n                    JSLogger.create(\"jewels\").error(\"bad_count\", {\n                        jewel: d,\n                        count: a[d]\n                    });\n                    continue;\n                }\n            ;\n            ;\n                c += b;\n            };\n        ;\n            return c;\n        },\n        updateTitle: function() {\n            var b = DocumentTitle.get();\n            var c = this.getCount();\n            if (c) {\n                if (this.counterInFront) {\n                    b = ((((((\"(\" + c)) + \") \")) + b));\n                }\n                 else b = ((((((b + \" (\")) + c)) + \")\"));\n            ;\n            }\n        ;\n        ;\n            DocumentTitle.set(b, true);\n        },\n        _handleCountUpdate: function(c, b) {\n            a[b.jewel] = b.count;\n            this.updateTitle();\n        },\n        _handleUpdate: function(c, b) {\n            this.updateTitle();\n        }\n    };\n})();\nfunction RenderManager(a) {\n    copy_properties(this, {\n        _isDirty: false,\n        _obj: a\n    });\n};\n;\ncopy_properties(RenderManager.prototype, {\n    dirty: function() {\n        if (!this._isDirty) {\n            this._isDirty = true;\n            bind(this, this.doPaint).defer();\n        }\n    ;\n    ;\n    },\n    doPaint: function() {\n        this._isDirty = false;\n        this._obj.paint();\n    }\n});\nfunction CounterDisplay(a, g, h, e, d, b) {\n    copy_properties(this, {\n        _name: a,\n        _valueNode: $(g),\n        _wrapperNode: (($(h) || null)),\n        _statusClass: d,\n        _rm: new RenderManager(this),\n        _arbiterSubscription: null,\n        _count: 0\n    });\n    var c = this._valueNode.firstChild;\n    if (c) {\n        var f = parseInt(c.nodeValue, 10);\n        if (!isNaN(f)) {\n            this._count = f;\n        }\n    ;\n    ;\n    }\n;\n;\n    this._statusNode = ((e ? $(e) : null));\n    this._subscribeAll();\n    CounterDisplay.instances.push(this);\n    if (!b) {\n        JSBNG__onleaveRegister(this._destroy.bind(this), true);\n    }\n;\n;\n};\n;\ncopy_properties(CounterDisplay, {\n    EVENT_TYPE_ADJUST: \"CounterDisplay/adjust\",\n    EVENT_TYPE_UPDATE: \"CounterDisplay/update\",\n    instances: [],\n    adjustCount: function(a, b) {\n        Arbiter.inform(((((CounterDisplay.EVENT_TYPE_ADJUST + \"/\")) + a)), b);\n    },\n    setCount: function(a, b) {\n        Arbiter.inform(((((CounterDisplay.EVENT_TYPE_UPDATE + \"/\")) + a)), b);\n    }\n});\nClass.mixin(CounterDisplay, {\n    _destroy: function() {\n        delete this._valueNode;\n        delete this._wrapperNode;\n        if (this._arbiterSubscription) {\n            Arbiter.unsubscribe(this._arbiterSubscription);\n            delete this._arbiterSubscription;\n        }\n    ;\n    ;\n        CounterDisplay.instances.remove(this);\n    },\n    adjustCount: function(a) {\n        this._count = Math.max(0, ((this._count + a)));\n        this._rm.dirty();\n        return this;\n    },\n    setCount: function(a) {\n        this._count = Math.max(0, a);\n        this._rm.dirty();\n        return this;\n    },\n    paint: function() {\n        DOM.setContent(this._valueNode, this._count);\n        this._toggleNodes();\n    },\n    _toggleNodes: function() {\n        if (this._wrapperNode) {\n            CSS.conditionClass(this._wrapperNode, \"hidden_elem\", ((this._count <= 0)));\n        }\n    ;\n    ;\n        if (((this._statusClass && this._statusNode))) {\n            CSS.conditionClass(this._statusNode, this._statusClass, ((this._count > 0)));\n        }\n    ;\n    ;\n    },\n    _subscribeAll: function() {\n        var a = [((((CounterDisplay.EVENT_TYPE_ADJUST + \"/\")) + this._name)),((((CounterDisplay.EVENT_TYPE_UPDATE + \"/\")) + this._name)),];\n        this._arbiterSubscription = Arbiter.subscribe(a, this._onInform.bind(this), Arbiter.SUBSCRIBE_NEW);\n    },\n    _onInform: function(a, b) {\n        b = parseInt(b);\n        if (isNaN(b)) {\n            return;\n        }\n    ;\n    ;\n        if (((a.indexOf(CounterDisplay.EVENT_TYPE_ADJUST) != -1))) {\n            this.adjustCount(b);\n        }\n         else if (((a.indexOf(CounterDisplay.EVENT_TYPE_UPDATE) != -1))) {\n            this.setCount(b);\n        }\n         else return\n        \n    ;\n        return;\n    }\n});\nfunction MenubarMessageController(b, a) {\n\n};\n;\ncopy_properties(MenubarMessageController, {\n    ensureInitialized: function(c, b, a) {\n        if (((MenubarMessageController.initialized || !ge(b)))) {\n            return false;\n        }\n    ;\n    ;\n        var d = new MenubarMessageController(c, b);\n        MenubarMessageController.instance = d;\n        d.ensureInitialized(c, b, a);\n        MenubarMessageController.initialized = true;\n    }\n});\ncopy_properties(MenubarMessageController.prototype, {\n    ensureInitialized: function(d, c, a, b) {\n        this.menu = ge(c);\n        this.fetchOnHover = b;\n        var e = [((CounterDisplay.EVENT_TYPE_ADJUST + \"/messages_unread\")),((CounterDisplay.EVENT_TYPE_UPDATE + \"/messages_unread\")),];\n        Arbiter.subscribe(e, this.JSBNG__onCounterUpdate.bind(this), Arbiter.SUBSCRIBE_NEW);\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"messages_seen\"), function() {\n            Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"messages\",\n                count: 0\n            }, Arbiter.BEHAVIOR_STATE);\n        });\n        this._dirty = a;\n        if (b) {\n            this.mouseOverListener = JSBNG__Event.listen($(d), \"mouseover\", this.doRefetch.bind(this));\n        }\n    ;\n    ;\n    },\n    doRefetch: function() {\n        if (this._dirty) {\n            this._dirty = false;\n            this._fetch();\n        }\n    ;\n    ;\n    },\n    _fetch: function() {\n        new AsyncRequest().setURI(\"/ajax/gigaboxx/endpoint/ListThreads.php\").setMethod(\"GET\").setReadOnly(true).setHandler(this.JSBNG__onFetchComplete.bind(this)).setData({\n            folder: \"[fb]messages\",\n            start: 0,\n            limit: 5,\n            previews: true\n        }).send();\n    },\n    JSBNG__onFetchComplete: function(a) {\n        if (this.menu) {\n            DOM.setContent(this.menu, HTML(a.payload));\n        }\n    ;\n    ;\n    },\n    JSBNG__onCounterUpdate: function() {\n        this._dirty = true;\n    },\n    markSeen: function(a) {\n        new AsyncSignal(\"/ajax/gigaboxx/endpoint/UpdateLastSeenTime.php\", {\n            folder: a\n        }).send();\n    }\n});\nfunction JewelX() {\n\n};\n;\n(function() {\n    var b = {\n    };\n    function a() {\n        a = bagofholding;\n        Arbiter.subscribe(\"jewel/count-updated\", function(d, e) {\n            var f = b[e.jewel];\n            ((f && f.update(e)));\n        });\n        Arbiter.subscribe(\"jewel/count-initial\", function(d, e) {\n            var f = b[e.jewel];\n            ((f && f.setInitial(e.count)));\n        });\n        Arbiter.subscribe(\"jewel/reset\", function(d, e) {\n            var f = b[e.jewel];\n            ((f && f.reset()));\n        });\n        var c = null;\n        JSBNG__Event.listen(window, \"resize\", function(JSBNG__event) {\n            JSBNG__clearTimeout(c);\n            c = Arbiter.inform.bind(Arbiter, \"jewel/resize\", JSBNG__event).defer(100, false);\n        });\n    };\n;\n    Class.mixin(JewelX, \"Arbiter\", {\n        init: function(c, d) {\n            b[c] = this;\n            this.JSBNG__name = c;\n            this.root = d;\n            this.countNew = 0;\n            this.initialCount = 0;\n            Toggler.listen([\"show\",\"hide\",], this.root, function(f) {\n                var e = ((f === \"show\"));\n                ((e && this._logFirstClick()));\n                ((this.hasNew() && this.markSeen()));\n                this.reset();\n                this.inform(((e ? \"opened\" : \"JSBNG__closed\")));\n                Arbiter.inform(((e ? \"layer_shown\" : \"layer_hidden\")), {\n                    type: \"Jewel\"\n                });\n            }.bind(this));\n            a();\n        },\n        getRoot: function() {\n            return this.root;\n        },\n        hasNew: function() {\n            return CSS.hasClass(this.root, \"hasNew\");\n        },\n        isOpen: function() {\n            return CSS.hasClass(this.root, \"openToggler\");\n        },\n        reset: function() {\n            CSS.removeClass(this.root, \"hasNew\");\n        },\n        setContent: function(d) {\n            var c = DOM.JSBNG__find(this.root, \"ul.jewelItemList\");\n            DOM.setContent(c, HTML(d));\n        },\n        update: function(d) {\n            this.countNew = d.count;\n            var c = DOM.JSBNG__find(this.root, \"span.jewelCount span\");\n            DOM.setContent(c, this.countNew);\n            var e = ((isNaN(this.countNew) || ((this.countNew > 0))));\n            CSS.conditionClass(this.root, \"hasNew\", e);\n            this.inform(\"updated\", d);\n        },\n        setInitial: function(c) {\n            this.initialCount = c;\n        },\n        markSeen: function() {\n            Arbiter.inform(\"jewel/count-updated\", {\n                jewel: this.JSBNG__name,\n                count: 0\n            }, Arbiter.BEHAVIOR_STATE);\n            this.inform(\"marked-seen\");\n        },\n        _logFirstClick: function() {\n            this._logFirstClick = bagofholding;\n            report_data(\"jewel_click\", {\n                gt: {\n                    count: this.countNew,\n                    initial: this.initialCount,\n                    jewel: this.JSBNG__name\n                }\n            });\n        }\n    });\n})();\nfunction MessagesJewel() {\n\n};\n;\nMessagesJewel.prototype = {\n    init: function(c, b) {\n        this.jewel = c;\n        this.jewelFlyoutCase = ge(\"jewelFlyoutContainer\");\n        this.jewelFlyout = ge(\"fbMessagesFlyout\");\n        this.newCountSpan = ge(\"newMessageCount\");\n        this.folder = b;\n        var a = ge(\"messagesMarkReadButton\");\n        if (a) {\n            JSBNG__Event.listen(a, \"click\", this._markRead.shield(this, true));\n        }\n    ;\n    ;\n        this.jewel.subscribe(\"marked-seen\", this._markSeenCallback.shield(this));\n        this.jewel.subscribe(\"updated\", this._updateCount.bind(this));\n        this.jewel.subscribe(\"opened\", this._overflowHandler.bind(this));\n        Arbiter.subscribe(\"jewel/resize\", this._overflowHandler.bind(this));\n        Arbiter.subscribe(\"jewel/messages/fetched\", this._overflowHandler.bind(this));\n    },\n    _markRead: function(a, b) {\n        Arbiter.inform(\"jewel/count-updated\", {\n            jewel: \"messages\",\n            count: 0\n        });\n    },\n    _markSeenCallback: function(a, b) {\n        MenubarMessageController.instance.markSeen(this.folder);\n    },\n    _updateCount: function(a, b) {\n        this.countNew = b.count;\n        CSS.conditionClass(this.jewelFlyout, \"beeperUnread\", ((this.countNew > 0)));\n        CSS.conditionClass(this.jewelFlyoutCase, \"showMessages\", ((this.countNew > 0)));\n        if (this.newCountSpan) {\n            var c = ((((this.countNew == 1)) ? _tx(\"{num} NEW MESSAGE\", {\n                num: this.countNew\n            }) : _tx(\"{num} NEW MESSAGES\", {\n                num: this.countNew\n            })));\n            DOM.setContent(this.newCountSpan, c);\n        }\n    ;\n    ;\n    },\n    _overflowHandler: function() {\n        ((window.Unibeeper && Unibeeper.hideOverflow(DOM.scry($(\"fbMessagesItemList\"), \"li\"), DOM.JSBNG__find(this.jewelFlyout, \".jewelFooter\"))));\n    }\n};\nfunction RequestsJewel() {\n\n};\n;\nRequestsJewel.prototype = {\n    init: function(d, c, b) {\n        this.countNew = 0;\n        this.jewel = d;\n        this.jewelFlyoutCase = ge(\"jewelFlyoutContainer\");\n        this.jewelFlyout = ge(\"fbRequestsFlyout\");\n        this.newCountSpan = ge(\"newRequestCount\");\n        this.folder = c;\n        this.doNewMarkRead = b;\n        this._requestList = {\n        };\n        this._requestCount = 0;\n        var a = ge(\"requestsMarkReadButton\");\n        if (a) {\n            JSBNG__Event.listen(a, \"click\", this._markRead.shield(this));\n        }\n    ;\n    ;\n        this.jewel.subscribe(\"marked-seen\", this._markSeenCallback.shield(this));\n        this.jewel.subscribe(\"JSBNG__closed\", this._clearNewItems.shield(this));\n        this.jewel.subscribe(\"updated\", this._updateCount.bind(this));\n        this.jewel.subscribe(\"opened\", this._overflowHandler.bind(this));\n        Arbiter.subscribe(\"jewel/resize\", this._overflowHandler.bind(this));\n        ((window.Unibeeper && Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"jewel/requests/handled\"), this._removeRequest.bind(this))));\n        LinkController.registerHandler(this._handleLink.bind(this), ElementController.ALL);\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"jewel/requests/add\"), this._addRequest.bind(this));\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"jewel/requests/remove_old\"), this._removeOldRequest.bind(this));\n        JSBNG__Event.listen(this.jewelFlyout, \"submit\", function(e) {\n            var f = Parent.byClass(e.getTarget(), \"objectListItem\");\n            if (f) {\n                CSS.removeClass(f, \"jewelItemNew\");\n                CSS.addClass(f, \"jewelItemResponded\");\n            }\n        ;\n        ;\n        }.bind(this));\n        return this;\n    },\n    fromDom: function() {\n        DOM.scry(this.jewelFlyout, \".jewelItemList li.objectListItem\").each(function(c) {\n            var b = c.getAttribute(\"id\");\n            var a = ((b && parseInt(this._parseID(b).requester, 10)));\n            if (((a && !isNaN(a)))) {\n                this._requestList[a] = b;\n                ++this._requestCount;\n            }\n        ;\n        ;\n        }.bind(this));\n        this._conditionShowEmptyMessage();\n    },\n    _parseID: function(a) {\n        var b = a.match(/^(\\d+)_(\\d+)/);\n        return (((b) ? {\n            requester: b[1],\n            type: b[2]\n        } : undefined));\n    },\n    _handleLink: function(b, JSBNG__event) {\n        var c = Parent.byClass(b, \"jewelItemNew\");\n        if (((((c && Parent.byClass(c, \"fbRequestList\"))) && Parent.byClass(c, \"beeperEnabled\")))) {\n            var a = this._parseID(c.id);\n            ((a && this._markSeenCallback(a.requester, a.type)));\n            Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            });\n            CSS.removeClass(c, \"jewelItemNew\");\n        }\n    ;\n    ;\n        return true;\n    },\n    _addRequest: function(a, b) {\n        if (((!b || this._requestList[b.obj.from]))) {\n            return;\n        }\n    ;\n    ;\n        var c = DOM.JSBNG__find(this.jewelFlyout, \".jewelItemList\");\n        elem = DOM.prependContent(c, b.obj.markup)[0];\n        CSS.hide(DOM.JSBNG__find(c, \"img.loadingIndicator\"));\n        var d = {\n            jewel: \"requests\",\n            count: ++this.countNew\n        };\n        Arbiter.inform(\"jewel/count-updated\", d);\n        this._requestList[b.obj.from] = elem.id;\n        ++this._requestCount;\n        this._conditionShowEmptyMessage();\n    },\n    _removeOldRequest: function(a, b) {\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        var d = this._requestList[b.obj.from];\n        var c = ((d && ge(d)));\n        if (c) {\n            ((CSS.hasClass(c, \"jewelItemNew\") && Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            })));\n            if (!CSS.hasClass(c, \"jewelItemResponded\")) {\n                DOM.remove(c);\n                delete this._requestList[d];\n                --this._requestCount;\n                this._conditionShowEmptyMessage();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _markRead: function() {\n        this.jewel.markSeen();\n        this._clearNewItems();\n    },\n    _markSeenCallback: function(b, c) {\n        new AsyncSignal(\"/ajax/gigaboxx/endpoint/UpdateLastSeenTime.php\", {\n            folder: this.folder\n        }).send();\n        var a = ((((((typeof b != \"undefined\")) && ((typeof c != \"undefined\")))) ? {\n            requester: b,\n            type: c\n        } : {\n        }));\n        ((this.doNewMarkRead && new AsyncSignal(\"/ajax/requests/mark_read/\", a).send()));\n    },\n    _removeRequest: function(a, b) {\n        var c = b.obj.item_id;\n        if (c) {\n            var d = ge(c);\n            var e = ((d && CSS.hasClass(d, \"jewelItemNew\")));\n            ((d ? DOM.remove(d) : false));\n            ((e && Arbiter.inform(\"jewel/count-updated\", {\n                jewel: \"requests\",\n                count: --this.countNew\n            })));\n        }\n    ;\n    ;\n    },\n    _clearNewItems: function(a, b) {\n        DOM.scry(this.jewel.root, \"li.jewelItemNew\").each(function(c) {\n            CSS.removeClass(c, \"jewelItemNew\");\n        });\n    },\n    _updateCount: function(a, b) {\n        this.countNew = b.count;\n        CSS.conditionClass(this.jewelFlyout, \"beeperUnread\", ((this.countNew > 0)));\n        CSS.conditionClass(this.jewelFlyoutCase, \"showRequests\", ((this.countNew > 0)));\n        if (this.newCountSpan) {\n            var c = ((((this.countNew == 1)) ? _tx(\"{num} NEW REQUEST\", {\n                num: this.countNew\n            }) : _tx(\"{num} NEW REQUESTS\", {\n                num: this.countNew\n            })));\n            DOM.setContent(this.newCountSpan, c);\n        }\n    ;\n    ;\n    },\n    _conditionShowEmptyMessage: function() {\n        DOM.scry(this.jewelFlyout, \"li.empty\").each(function(a) {\n            CSS.conditionShow(a, ((this._requestCount <= 0)));\n        }.bind(this));\n    },\n    _overflowHandler: function() {\n        ((window.Unibeeper && Unibeeper.hideOverflow(DOM.scry($(\"fbRequestsList\"), \"li\"), DOM.JSBNG__find(this.jewelFlyout, \".jewelFooter\"))));\n    }\n};\nfunction DoublyLinkedListMap() {\n    this._head = null;\n    this._tail = null;\n    this._nodes = {\n    };\n};\n;\nDoublyLinkedListMap.prototype = {\n    get: function(a) {\n        return ((this._nodes[a] ? this._nodes[a].data : null));\n    },\n    _insert: function(c, a, f, b) {\n        ((((f && !this._nodes[f])) && (f = null)));\n        var d = ((((f && this._nodes[f])) || ((b ? this._head : this._tail)))), e = {\n            data: a,\n            key: c,\n            next: null,\n            prev: null\n        };\n        if (d) {\n            this.remove(c);\n            if (b) {\n                e.prev = d.prev;\n                ((d.prev && (d.prev.next = e)));\n                d.prev = e;\n                e.next = d;\n            }\n             else {\n                e.next = d.next;\n                ((d.next && (d.next.prev = e)));\n                d.next = e;\n                e.prev = d;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        ((((e.prev === null)) && (this._head = e)));\n        ((((e.next === null)) && (this._tail = e)));\n        this._nodes[c] = e;\n        return this;\n    },\n    insertBefore: function(b, a, c) {\n        return this._insert(b, a, c, true);\n    },\n    insertAfter: function(b, a, c) {\n        return this._insert(b, a, c, false);\n    },\n    prepend: function(b, a) {\n        return this.insertBefore(b, a, ((this._head && this._head.key)));\n    },\n    append: function(b, a) {\n        return this.insertAfter(b, a, ((this._tail && this._tail.key)));\n    },\n    remove: function(b) {\n        var a = this._nodes[b];\n        if (a) {\n            var c = a.next, d = a.prev;\n            ((c && (c.prev = d)));\n            ((d && (d.next = c)));\n            ((((this._head === a)) && (this._head = c)));\n            ((((this._tail === a)) && (this._tail = d)));\n            delete this._nodes[b];\n        }\n    ;\n    ;\n        return this;\n    },\n    JSBNG__find: function(b) {\n        for (var a = this._head; a; a = a.next) {\n            if (b(a.data)) {\n                return a.key;\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    },\n    reduce: function(b, a) {\n        for (var c = this._head; c; c = c.next) {\n            a = b(c.data, a);\n        ;\n        };\n    ;\n        return a;\n    },\n    exists: function(a) {\n        return !!this._nodes[a];\n    },\n    isEmpty: function() {\n        return !this._head;\n    }\n};\nvar Quickling = ((window.Quickling || {\n    isActive: function() {\n        return ((Quickling._is_active || false));\n    },\n    isFeatureEnabled: function(a) {\n        return ((Quickling._capabilities && Quickling._capabilities[a]));\n    },\n    init: function(c, b, a) {\n        if (Quickling._is_initialized) {\n            return;\n        }\n    ;\n    ;\n        copy_properties(Quickling, {\n            _is_initialized: true,\n            _is_active: true,\n            _session_length: b,\n            _capabilities: a,\n            _is_in_transition: false,\n            _title_interval: false,\n            _ie_cache_title: \"\",\n            _version: c\n        });\n        Quickling._instrumentTimeoutFunc(\"JSBNG__setInterval\");\n        Quickling._instrumentTimeoutFunc(\"JSBNG__setTimeout\");\n        PageTransitions.registerHandler(Quickling._transitionHandler, 1);\n    },\n    _startQuicklingTransition: function() {\n        Quickling._is_in_transition = true;\n    },\n    _stopQuicklingTransition: function() {\n        (function() {\n            Quickling._is_in_transition = false;\n        }).defer();\n    },\n    goHashOrGoHere: function(d) {\n        var c = URI.getRequestURI();\n        var b = c.getFragment();\n        if (b.startsWith(\"/\")) {\n            var a = b;\n        }\n         else var a = d\n    ;\n        JSBNG__setTimeout(function() {\n            PageTransitions.go(a, true);\n        }, 0);\n    },\n    isPageActive: function(e) {\n        if (((e == \"#\"))) {\n            return false;\n        }\n    ;\n    ;\n        e = new URI(e);\n        if (((e.getDomain() && ((e.getDomain() != URI().getDomain()))))) {\n            return false;\n        }\n    ;\n    ;\n        var b = Quickling.isPageActive.regex;\n        if (!b) {\n            b = Quickling.isPageActive.regex = new RegExp(env_get(\"quickling_inactive_page_regex\"));\n        }\n    ;\n    ;\n        if (((e.getPath() == \"/l.php\"))) {\n            var c = e.getQueryData().u;\n            if (c) {\n                c = URI(unescape(c)).getDomain();\n                if (((c && ((c != URI().getDomain()))))) {\n                    return false;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var d = e.getPath();\n        var a = e.getQueryData();\n        if (!is_empty(a)) {\n            d += ((\"?\" + URI.implodeQuery(a)));\n        }\n    ;\n    ;\n        if (b.test(d)) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    _setHTML: function(a, b) {\n        if (((ua.ie() <= 6))) {\n            a.innerHTML = b;\n        }\n         else DOM.setContent(a, HTML(b).setDeferred(true));\n    ;\n    ;\n    },\n    _transitionHandler: function(a) {\n        AjaxPipeRequest.setCurrentRequest(null);\n        if (Quickling._isTimeToRefresh()) {\n            return false;\n        }\n    ;\n    ;\n        if (!Quickling.isPageActive(a)) {\n            return false;\n        }\n    ;\n    ;\n        window.ExitTime = (new JSBNG__Date()).getTime();\n        removeHook(\"JSBNG__onafterloadhooks\");\n        removeHook(\"JSBNG__onloadhooks\");\n        _runHooks(\"JSBNG__onleavehooks\");\n        Arbiter.inform(\"JSBNG__onload/exit\", true);\n        Quickling._startQuicklingTransition();\n        $(\"JSBNG__content\").style.visibility = \"visible\";\n        new QuickPipeRequest(a).setCanvasId(\"JSBNG__content\").send();\n        return true;\n    },\n    _changePageTitle: function(a) {\n        a = ((a || \"Facebook\"));\n        DocumentTitle.set(a);\n        if (ua.ie()) {\n            Quickling._ie_cache_title = a;\n            if (!Quickling._title_interval) {\n                Quickling._title_interval = window.JSBNG__setInterval(function() {\n                    var b = Quickling._ie_cache_title;\n                    var c = DocumentTitle.get();\n                    if (((b != c))) {\n                        DocumentTitle.set(b);\n                    }\n                ;\n                ;\n                }, 5000, false);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _replaceSyndicationLinks: function(d) {\n        var c = JSBNG__document.getElementsByTagName(\"link\");\n        for (var b = 0; ((b < c.length)); ++b) {\n            if (((c[b].rel != \"alternate\"))) {\n                continue;\n            }\n        ;\n        ;\n            DOM.remove(c[b]);\n        };\n    ;\n        if (d.length) {\n            var a = DOM.JSBNG__find(JSBNG__document, \"head\");\n            ((a && DOM.appendContent(a, HTML(d[0]))));\n        }\n    ;\n    ;\n    },\n    _isTimeToRefresh: function() {\n        Quickling._load_count = ((((Quickling._load_count || 0)) + 1));\n        return ((Quickling._load_count >= Quickling._session_length));\n    },\n    _instrumentTimeoutFunc: function(a) {\n        window[((a + \"_native\"))] = (function(c) {\n            var b = function b(e, d) {\n                return c(e, d);\n            };\n            return b;\n        })(window[a]);\n        window[a] = function _setTimeout(d, c, b) {\n            var e = window[((a + \"_native\"))](d, c);\n            if (((c > 0))) {\n                if (((b !== false))) {\n                    JSBNG__onleaveRegister(function() {\n                        JSBNG__clearInterval(e);\n                    });\n                }\n            ;\n            }\n        ;\n        ;\n            return e;\n        };\n    }\n}));\nfunction QuickPipeRequest(b) {\n    var a = {\n        version: Quickling._version\n    };\n    this.parent.construct(this, b, {\n        quickling: a\n    });\n};\n;\nClass.extend(QuickPipeRequest, \"AjaxPipeRequest\");\ncopy_properties(QuickPipeRequest.prototype, {\n    _preBootloadFirstResponse: function(a) {\n        DOMScroll.JSBNG__scrollTo(new Vector2(0, 0, \"JSBNG__document\"), false);\n        return true;\n    },\n    _fireDomContentCallback: function() {\n        ((this._request.cavalry && this._request.cavalry.setTimeStamp(\"t_domcontent\")));\n        Quickling._stopQuicklingTransition();\n        PageTransitions.transitionComplete();\n        ((this._onPageDisplayed && this._onPageDisplayed(this.pipe)));\n        this.parent._fireDomContentCallback();\n    },\n    _fireOnloadCallback: function() {\n        if (this._request.cavalry) {\n            this._request.cavalry.setTimeStamp(\"t_hooks\");\n            this._request.cavalry.setTimeStamp(\"t_layout\");\n            this._request.cavalry.setTimeStamp(\"t_onload\");\n        }\n    ;\n    ;\n        this.parent._fireOnloadCallback();\n    },\n    _redirect: function(a) {\n        if (a.redirect) {\n            if (((a.force || !Quickling.isPageActive(a.redirect)))) {\n                go_or_replace(window.JSBNG__location, URI(a.redirect).removeQueryData([\"quickling\",\"ajaxpipe\",]), true);\n            }\n             else PageTransitions.go(a.redirect, true);\n        ;\n        ;\n            return true;\n        }\n         else return false\n    ;\n    },\n    _versionCheck: function(a) {\n        if (((a.version != Quickling._version))) {\n            go_or_replace(window.JSBNG__location, URI(a.uri).removeQueryData([\"quickling\",\"ajaxpipe\",]), true);\n            return false;\n        }\n         else return true\n    ;\n    },\n    _processFirstResponse: function(c) {\n        var b = c.getPayload();\n        Quickling._changePageTitle(b.title);\n        Quickling._replaceSyndicationLinks(((b.syndication || [])));\n        var a = ((b.body_class || \"\"));\n        CSS.setClass(JSBNG__document.body, a);\n    }\n});\nvar MessagingEvents = ((window.MessagingEvents || (function() {\n    JSBNG__onloadRegister(function() {\n        var b = {\n        };\n        MessagingEvents.subscribe(\"mark-as-read\", function(c, d) {\n            ((((d.tids || d.chat_ids)) || [])).forEach(function(f) {\n                f = ((\"\" + f));\n                if (!((f in b))) {\n                    b[f] = true;\n                    var g = function() {\n                        MessagingEvents.unsubscribe(h);\n                        JSBNG__clearTimeout(e);\n                        delete b[f];\n                    };\n                    var h = MessagingEvents.subscribe(\"read\", function(i, j) {\n                        if (((((j.tids || [])).contains(f) || ((j.chat_ids || [])).contains(f)))) {\n                            g();\n                        }\n                    ;\n                    ;\n                    });\n                    var e = g.defer(60000);\n                }\n            ;\n            ;\n            });\n        });\n        var a = function(c) {\n            if (!is_empty(b)) {\n                return;\n            }\n        ;\n        ;\n            for (var d in c) {\n                MessagingEvents.inform(((\"count/\" + d)), c[d]);\n            ;\n            };\n        ;\n        };\n        Arbiter.subscribe(\"presence/message:messaging\", function(c, e) {\n            var f = copy_properties(e.obj);\n            var JSBNG__event = ((f.JSBNG__event || \"\"));\n            delete f.type;\n            delete f.JSBNG__event;\n            MessagingEvents.inform(JSBNG__event, f);\n            if (((\"unread_counts\" in f))) {\n                var d = f.unread_counts;\n                a({\n                    unread: d.inbox,\n                    other_unseen: d.other\n                });\n            }\n        ;\n        ;\n        });\n        Arbiter.subscribe(\"presence/message:inbox\", function(c, d) {\n            var e = copy_properties(d.obj);\n            delete e.type;\n            a(e);\n        });\n    });\n    return new Arbiter();\n})()));\nvar MessagingConst = {\n    APP_ID: 313785040330,\n    XD_MESSAGE: {\n        SANDBOX_READY: \"sandbox_ready\",\n        SET_CONTENT: \"set_content\",\n        HTML_SIZE: \"html_size\",\n        REFRESH_SIZE: \"refresh_size\"\n    },\n    SHINGLE_SCROLL_TRIGGER: 5,\n    EVENTS: {\n        MESSAGE_SENT: \"messaging/message_sent\"\n    }\n};\nfunction MessagingJewelMenubarController(b, a) {\n    this.parent.construct(this);\n    this._content = ge(a);\n    this._open = false;\n    Arbiter.subscribe([MessagingConst.EVENTS.MESSAGE_SENT,\"chat/message-sent\",], this._onSend.bind(this));\n    Toggler.listen([\"show\",\"hide\",], $(b), this._onToggle.bind(this));\n    this._init();\n};\n;\nClass.extend(MessagingJewelMenubarController, \"MenubarMessageController\");\ncopy_properties(MessagingJewelMenubarController, {\n    FETCH_URI: \"/ajax/messaging/jewel_fetch.php\",\n    MARK_SEEN_URI: \"/ajax/messaging/jewel_mark_seen.php\",\n    ensureInitialized: function(d, c, a, b) {\n        if (((MessagingJewelMenubarController.initialized || !ge(c)))) {\n            return false;\n        }\n    ;\n    ;\n        var e = new MessagingJewelMenubarController(d, c);\n        MessagingJewelMenubarController.instance = e;\n        MenubarMessageController.instance = e;\n        e.ensureInitialized(d, c, a, b);\n        MessagingJewelMenubarController.initialized = true;\n    }\n});\ncopy_properties(MessagingJewelMenubarController.prototype, {\n    _init: function() {\n        this.initializeEvents();\n    },\n    initializeEvents: function() {\n        var a = null;\n        JSBNG__Event.listen(this._content, {\n            mouseover: function(JSBNG__event) {\n                var b = JSBNG__event.getTarget();\n                a = Parent.byTag(b, \"li\");\n                if (((a && ((a != b))))) {\n                    CSS.addClass(a, \"selected\");\n                }\n            ;\n            ;\n            },\n            mouseout: function(JSBNG__event) {\n                ((a && CSS.removeClass(a, \"selected\")));\n                a = null;\n            }\n        });\n    },\n    _fetch: function() {\n        new AsyncRequest().setURI(MessagingJewelMenubarController.FETCH_URI).setMethod(\"GET\").setData({\n            action: \"jewelPreview\",\n            seen: false\n        }).setReadOnly(true).setHandler(function() {\n            Arbiter.inform.bind(Arbiter, \"jewel/messages/fetched\").defer(100);\n        }).setAllowCrossPageTransition(true).send();\n    },\n    _onSend: function() {\n        this._dirty = true;\n    },\n    JSBNG__onCounterUpdate: function() {\n        this.parent.JSBNG__onCounterUpdate();\n        if (this._open) {\n            this.doRefetch();\n        }\n    ;\n    ;\n    },\n    _onToggle: function(b, a) {\n        this._open = ((b == \"show\"));\n        if (this._open) {\n            this.doRefetch();\n        }\n    ;\n    ;\n    },\n    markSeen: function() {\n        if (this.fetchOnHover) {\n            new AsyncSignal(MessagingJewelMenubarController.MARK_SEEN_URI, {\n                action: \"markSeen\"\n            }).send();\n        }\n    ;\n    ;\n    }\n});\nvar MusicEvents = new Arbiter();\nvar MusicProviders = {\n    SPOTIFY: \"open.spotify.com\"\n};\nvar MusicConstants = {\n    sameURLs: function(a, b) {\n        var c = /\\/$/;\n        return ((((a && b)) && ((a.replace(c, \"\") == b.replace(c, \"\")))));\n    },\n    OP: {\n        RESUME: \"RESUME\",\n        PAUSE: \"PAUSE\",\n        PLAY: \"PLAY\",\n        VERSION: \"VERSION\",\n        LOGIN: \"LOGIN\"\n    },\n    STATUS_CHANGE_OP: {\n        STATUS: \"STATUS\"\n    },\n    STATUS_CHANGE_EVENT: {\n        playing: \"PLAY_STATE_CHANGED\",\n        track: \"TRACK_CHANGED\"\n    },\n    DIAGNOSTIC_EVENT: {\n        ALL_PAUSED: \"ALL_PAUSED\",\n        ALL_OFFLINE: \"ALL_OFFLINE\",\n        OFFLINE: \"OFFLINE\",\n        ONLINE: \"ONLINE\",\n        SEARCHING: \"SEARCHING\",\n        HIT: \"HIT\",\n        MISS: \"MISS\",\n        RESIGN: \"RESIGN\",\n        IFRAME_POLLING: \"IFRAME_POLLING\",\n        RELAUNCH: \"RELAUNCH\",\n        STATE_CHANGE: \"STATE_CHANGE\",\n        WRONG_VERSION: \"WRONG_VERSION\"\n    },\n    ALLOWED_STATUS_PARAMS: {\n        playing: \"playing\",\n        track: \"track\",\n        context: \"context\",\n        client_version: \"client_version\",\n        start_time: \"start_time\",\n        expires_in: \"expires_in\"\n    },\n    LIVE_LISTEN_OP: {\n        NOW_LEADING: \"NOW_LEADING\",\n        NOW_LISTENING: \"NOW_LISTENING\",\n        END_SESSION: \"END_SESSION\",\n        SONG_PLAYING: \"SONG_PLAYING\",\n        LISTENER_UPDATE: \"LISTENER_UPDATE\"\n    },\n    MUSIC_BUTTON: {\n        ACTIVATE: \"ACTIVATE\"\n    },\n    ERROR: {\n        1: \"SERVICE_UNAVAILABLE_WITHOUT_PREMIUM\",\n        2: \"SERVICE_UNAVAILABLE_WITHOUT_PREMIUM_OR_WAIT\",\n        3: \"SERVICE_UNAVAILABLE_BILLING_ISSUE\",\n        4: \"SERVICE_UNAVAILABLE_TECHNICAL_ISSUE\",\n        5: \"AUDIO_AD_PLAYING\",\n        99: \"SERVICE_TEMPORARILY_UNAVAILABLE\",\n        101: \"SONG_UNAVAILABLE_WITHOUT_PURCHASE\",\n        102: \"SONG_UNAVAILABLE_WITHOUT_PREMIUM\",\n        103: \"SONG_UNAVAILABLE_INDEFINITELY\"\n    }\n};\nvar MusicButton = function(e, a, f, c, d, b) {\n    this.provider = e;\n    this.buttonID = a;\n    this.url = f;\n    this.context = ((c || {\n    }));\n    this.mediaType = d;\n    this.buttonType = ((b || this.BUTTON_TYPES.STANDARD));\n    this.setState(this.STATES.OFFLINE);\n    MusicEvents.subscribe(MusicConstants.MUSIC_BUTTON.ACTIVATE, this.processClick.bind(this));\n};\ncopy_properties(MusicButton, {\n    tracksetableTypes: []\n});\ncopy_properties(MusicButton.prototype, {\n    SHOW_LOADING_TIMEOUT: 500,\n    HIDE_LOADING_TIMEOUT: 4000,\n    RECENTLY_ONLINE_TIMEOUT: 6000,\n    STATES: {\n        PLAYING: \"music_playing\",\n        PAUSED: \"music_paused\",\n        LOADING: \"async_saving\",\n        DISABLED: \"music_disabled\",\n        OFFLINE: \"music_offline\"\n    },\n    BUTTON_TYPES: {\n        STANDARD: \"button_type_standard\",\n        LIVE_LISTEN: \"button_type_live_listen\"\n    },\n    setState: function(a) {\n        if (((a !== this.STATES.LOADING))) {\n            this.resetLoadingTimers();\n            this.previousState = ((this.state || a));\n        }\n    ;\n    ;\n        var b = this._getStatElem();\n        ((this.state && CSS.removeClass(b, this.state)));\n        this.state = a;\n        CSS.addClass(b, this.state);\n    },\n    isTracksetable: function(a) {\n        return ((MusicButton.tracksetableTypes.indexOf(this.mediaType) !== -1));\n    },\n    handleIncomingEvent: function(d, b) {\n        JSBNG__clearTimeout(this._showLoadingTimer);\n        if (((((b && b.provider)) && ((b.provider != this.provider))))) {\n            return;\n        }\n    ;\n    ;\n        switch (d) {\n          case MusicConstants.DIAGNOSTIC_EVENT.ONLINE:\n        \n          case MusicConstants.STATUS_CHANGE_EVENT.track:\n        \n          case MusicConstants.STATUS_CHANGE_EVENT.playing:\n            var c = ((((b && b.track)) && b.track.uri));\n            var a = ((((b && b.context)) && b.context.uri));\n            if (((((b && b.playing)) && ((MusicConstants.sameURLs(c, this.url) || MusicConstants.sameURLs(a, this.url)))))) {\n                this.setState(this.STATES.PLAYING);\n            }\n             else if (((((this.state === this.STATES.LOADING)) && ((((this.previousState === this.STATES.PAUSED)) || ((this.previousState === this.STATES.OFFLINE))))))) {\n                JSBNG__clearTimeout(this._attemptingPlayTimer);\n                this._attemptingPlayTimer = this.setState.bind(this, this.STATES.PAUSED).defer(this.RECENTLY_ONLINE_TIMEOUT, false);\n            }\n             else if (!this._attemptingPlayTimer) {\n                this.setState(this.STATES.PAUSED);\n            }\n            \n            \n        ;\n        ;\n            break;\n          case MusicConstants.DIAGNOSTIC_EVENT.OFFLINE:\n            this.setState(this.STATES.OFFLINE);\n            break;\n          case MusicConstants.DIAGNOSTIC_EVENT.ALL_OFFLINE:\n            this.setState(this.STATES.OFFLINE);\n            break;\n          case MusicConstants.LIVE_LISTEN_OP.NOW_LISTENING:\n            if (((this.buttonType == this.BUTTON_TYPES.LIVE_LISTEN))) {\n                if (((((((b.listen_to && ((b.listen_to == this.context.live_listen_user)))) || ((((b.session && b.session.session_id)) && ((b.session.session_id == this.context.live_listen_id)))))) || ((((b.session && b.session.leader)) && ((b.session.leader == this.context.live_listen_user))))))) {\n                    this._setLiveListening(true);\n                }\n                 else this._setLiveListening(false);\n            ;\n            }\n        ;\n        ;\n            break;\n          case MusicConstants.LIVE_LISTEN_OP.END_SESSION:\n            if (((((this.buttonType == this.BUTTON_TYPES.LIVE_LISTEN)) && ((((((b.listen_to && ((b.listen_to == this.context.live_listen_user)))) || ((((b.session && b.session.session_id)) && ((b.session.session_id == this.context.live_listen_id)))))) || ((((b.session && b.session.leader)) && ((b.session.leader == this.context.live_listen_user))))))))) {\n                this._setLiveListening(false);\n            }\n        ;\n        ;\n            break;\n        };\n    ;\n    },\n    processClick: function(a, h) {\n        var d = ge(this.buttonID);\n        if (((!d || ((h != d))))) {\n            if (((((this.state === this.STATES.LOADING)) && d))) {\n                ((this.previousState && this.setState(this.previousState)));\n            }\n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        var e = ((this.isTracksetable() && Parent.byClass(d, \"music_trackset_container\")));\n        var l = [];\n        if (e) {\n            var k = e.getAttribute(\"data-trackset-title\");\n            var g = this.provider;\n            var f = DOM.scry(e, \".music_button\");\n            for (var i = 0; ((i < f.length)); i++) {\n                var c = MusicButtonManager.getButton([f[i].id,]);\n                if (((((c && ((c.provider == g)))) && c.isTracksetable()))) {\n                    l.push(c.url);\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        var j = function() {\n            return ((((e && ((l.length > 1)))) ? Music.playPauseSongList(this.provider, this.url, l, k, this.context) : Music.playPauseSong(this.provider, this.url, this.context)));\n        }.bind(this);\n        if (!window.Music) {\n            this.showLoading(true);\n            Bootloader.loadComponents(\"Music\", j);\n            return;\n        }\n    ;\n    ;\n        var b = j();\n        this.showLoading(!b);\n    },\n    _getStatElem: function() {\n        var a = $(this.buttonID);\n        return ((Parent.byClass(a, \"music_button_trigger_group\") || a.parentNode));\n    },\n    showLoading: function(a) {\n        this.resetLoadingTimers();\n        this._hideLoadingTimer = this._timeout.bind(this, a).defer(this.HIDE_LOADING_TIMEOUT, false);\n        this._showLoadingTimer = this.setState.bind(this, this.STATES.LOADING).defer(this.SHOW_LOADING_TIMEOUT, false);\n    },\n    _setLiveListening: function(a) {\n        CSS.conditionClass(this._getStatElem(), \"music_listening\", a);\n    },\n    resetLoadingTimers: function() {\n        JSBNG__clearTimeout(this._hideLoadingTimer);\n        JSBNG__clearTimeout(this._showLoadingTimer);\n        JSBNG__clearTimeout(this._attemptingPlayTimer);\n        this._attemptingPlayTimer = null;\n    },\n    _timeout: function(a) {\n        ((window.Music && Music.reInform([this.provider,])));\n        if (((!a && ((this.state === this.STATES.LOADING))))) {\n            this.setState(this.STATES.PAUSED);\n        }\n    ;\n    ;\n    }\n});\nvar MusicButtonManager = (function() {\n    var h = null;\n    var b = {\n    };\n    var a = {\n    };\n    function c(JSBNG__event) {\n        var k = $E(JSBNG__event).getTarget();\n        var j = Parent.byClass(k, \"music_button\");\n        j = ((j || ((!JSBNG__event.getModifiers().any && d(k)))));\n        if (!j) {\n            return;\n        }\n    ;\n    ;\n        return g(j, JSBNG__event);\n    };\n;\n    function e(j) {\n        return Parent.byClass(j, \"music_button_trigger\");\n    };\n;\n    function d(l) {\n        var k = ((e(l) && Parent.byClass(l, \"music_button_trigger_group\")));\n        if (k) {\n            var j = DOM.scry(k, \".music_button\");\n            if (j.length) {\n                return j[0];\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return null;\n    };\n;\n    function g(j, JSBNG__event) {\n        ((JSBNG__event && $E(JSBNG__event).JSBNG__stop()));\n        MusicEvents.inform(MusicConstants.MUSIC_BUTTON.ACTIVATE, j);\n        return false;\n    };\n;\n    function i(j) {\n        ((window.Music && Music.reInform(j)));\n    };\n;\n    function f(l, k) {\n        for (var j in b) {\n            if (ge(j)) {\n                b[j].handleIncomingEvent(l, k);\n            }\n             else MusicButtonManager.removeButton(j);\n        ;\n        ;\n        };\n    ;\n    };\n;\n    return {\n        init: function(j) {\n            if (h) {\n                return;\n            }\n        ;\n        ;\n            h = true;\n            MusicButton.tracksetableTypes = ((j || []));\n            JSBNG__Event.listen(JSBNG__document.body, \"click\", c);\n            MusicEvents.subscribe([MusicConstants.STATUS_CHANGE_EVENT.playing,MusicConstants.STATUS_CHANGE_EVENT.track,MusicConstants.DIAGNOSTIC_EVENT.OFFLINE,MusicConstants.DIAGNOSTIC_EVENT.ALL_OFFLINE,MusicConstants.DIAGNOSTIC_EVENT.ONLINE,], f);\n            MusicEvents.subscribe([MusicConstants.LIVE_LISTEN_OP.NOW_LISTENING,MusicConstants.LIVE_LISTEN_OP.END_SESSION,], f, Arbiter.SUBSCRIBE_NEW);\n        },\n        getButton: function(j) {\n            return b[j];\n        },\n        addButton: function(n, j, o, l, m, k) {\n            ((h || MusicButtonManager.init()));\n            if (!ge(j)) {\n                return;\n            }\n        ;\n        ;\n            b[j];\n            b[j] = new MusicButton(n, j, o, l, m, k);\n            if (((n && !a[n]))) {\n                a[n] = function() {\n                    var p = keys(a);\n                    ((p.length && i(p)));\n                    a = {\n                    };\n                }.defer();\n            }\n        ;\n        ;\n            return b[j];\n        },\n        removeButton: function(j) {\n            ((b[j] && b[j].resetLoadingTimers()));\n            delete b[j];\n        }\n    };\n})();\nfunction NotificationList(a) {\n    this._list = new DoublyLinkedListMap();\n    this.unreadCount = 0;\n    this.contentRoot = a;\n    this.noItemsElement = null;\n    this.ITEM_TAG = \"li\";\n    this.ITEM_CLASS = \"notification\";\n    this.NO_ITEMS_ID = \"jewelNoNotifications\";\n    this.NO_ITEMS_CLASS = \"empty\";\n};\n;\ncopy_properties(NotificationList, {\n    ITEM_UNREAD_CLASS: \"jewelItemNew\",\n    MARK_READ_TYPE: \"mark_read\",\n    UNREAD_COUNT_CHANGE_TYPE: \"unread_count_change\",\n    getIdFromDom: function(a) {\n        return a.getAttribute(\"id\").replace(\"notification_\", \"\");\n    },\n    localizeUrls: function(a) {\n        DOM.scry(a, \"a\").each(function(b) {\n            ((URI(b.href).isFacebookURI() && (b.href = URI(b.href).getUnqualifiedURI().getQualifiedURI().setSubdomain(URI(b.href).getSubdomain()).toString())));\n        });\n    }\n});\nClass.mixin(NotificationList, \"Arbiter\", {\n    _getField: function(c, b) {\n        var a = this._list.get(c);\n        return ((a && a[b]));\n    },\n    getDomObj: function(a) {\n        return this._getField(a, \"obj\");\n    },\n    fromDom: function() {\n        var e = ((((this.ITEM_TAG + \".\")) + this.ITEM_CLASS));\n        var c = DOM.scry(this.contentRoot, e);\n        for (var d = 0; ((d < c.length)); ++d) {\n            var b = c[d];\n            var a = NotificationList.getIdFromDom(b);\n            this.insert(a, b.getAttribute(\"data-notiftime\"), null);\n        };\n    ;\n    },\n    insert: function(c, e, d, k, b) {\n        var j = true, i = 0;\n        if (this._list.exists(c)) {\n            if (!((k && d))) {\n                return false;\n            }\n             else {\n                j = this._getField(c, \"unread\");\n                i = this._getField(c, \"time\");\n                if (((i > e))) {\n                    return false;\n                }\n            ;\n            ;\n                this.remove(c);\n            }\n        ;\n        }\n    ;\n    ;\n        var f = ((((d && HTML(d).getRootNode())) || $(((\"notification_\" + c))))), l = Math.max(e, i), m = CSS.hasClass(f, NotificationList.ITEM_UNREAD_CLASS), a = {\n            id: c,\n            obj: f,\n            time: l,\n            unread: m\n        };\n        var h = null;\n        this._list.JSBNG__find(function(n) {\n            var o = ((n.time <= l));\n            ((!o && (h = n.id)));\n            return o;\n        });\n        var g = this.getDomObj(h);\n        if (g) {\n            this._list.insertAfter(c, a, h);\n            DOM.insertAfter(g, f);\n        }\n         else {\n            this._list.prepend(c, a);\n            DOM.prependContent(this.contentRoot, f);\n        }\n    ;\n    ;\n        NotificationList.localizeUrls(f);\n        hide(this.NO_ITEMS_ID);\n        if (m) {\n            this.unreadCount = this.getUnreadIds().length;\n            this.inform(NotificationList.UNREAD_COUNT_CHANGE_TYPE);\n            ((((b && !j)) && this.markRead([c,])));\n        }\n    ;\n    ;\n        return true;\n    },\n    showNoNotifications: function() {\n        if (((null == this.noItemsElement))) {\n            this.noItemsElement = ge(this.NO_ITEMS_ID);\n        }\n    ;\n    ;\n        if (((null == this.noItemsElement))) {\n            this.noItemsElement = $N(this.ITEM_TAG, {\n                id: this.NO_ITEMS_ID,\n                className: this.NO_ITEMS_CLASS\n            }, _tx(\"No new notifications.\"));\n            DOM.appendContent(this.contentRoot, this.noItemsElement);\n        }\n    ;\n    ;\n        CSS.show(this.NO_ITEMS_ID);\n    },\n    remove: function(a) {\n        var b = this._getField(a, \"obj\");\n        if (!b) {\n            return false;\n        }\n    ;\n    ;\n        this.markRead([a,]);\n        this._list.remove(a);\n        DOM.remove(b);\n        ((this._list.isEmpty() && this.showNoNotifications()));\n        return true;\n    },\n    getUnreadIds: function() {\n        return this._list.reduce(function(a, b) {\n            ((a.unread && b.push(a.id)));\n            return b;\n        }, []);\n    },\n    isUnreadId: function(a) {\n        return this._getField(a, \"unread\");\n    },\n    markRead: function(a) {\n        a = ((a ? a.filter(this.isUnreadId.bind(this)) : this.getUnreadIds()));\n        for (var b = 0; ((b < a.length)); b++) {\n            var c = this._list.get(a[b]);\n            if (c) {\n                this.inform(NotificationList.MARK_READ_TYPE, c.obj);\n                c.unread = false;\n            }\n        ;\n        ;\n        };\n    ;\n        if (a.length) {\n            this.unreadCount = this.getUnreadIds().length;\n            this.inform(NotificationList.UNREAD_COUNT_CHANGE_TYPE);\n        }\n    ;\n    ;\n    },\n    insertMany: function(d, a) {\n        if (((((\"object\" == typeof d)) && !is_empty(d)))) {\n            for (var c in d) {\n                var b = d[c];\n                this.insert(c, b.time, b.markup, true, a);\n            };\n        ;\n            hide(this.NO_ITEMS_ID);\n        }\n         else ((this.isEmpty() && this.showNoNotifications()));\n    ;\n    ;\n    },\n    isEmpty: function() {\n        return this._list.isEmpty();\n    }\n});\nfunction Notifications(a) {\n    this.updateTime = ((a.updateTime || new JSBNG__Date().getTime()));\n    this.user = Env.user;\n    this.cache_version = ((a.cacheVersion || 0));\n    this.allowDesktopNotifications = ((a.allowDesktopNotifications || false));\n    this.latest_notif_time = ((a.latestNotif || 0));\n    this.latest_read_notif_time = ((a.latestReadNotif || 0));\n    this.update_period = ((a.updatePeriod || 60000));\n    this.notifReceivedType = ((a.notifReceivedType || \"notification\"));\n    this.counterInFront = ((a.counterInFront || false));\n    this.wrapperID = ((a.wrapperID || \"notificationsWrapper\"));\n    this.contentID = ((a.contentID || \"jewelNotifs\"));\n    this.timeElement = \"small.time\";\n    this.ua = new UserNoOp();\n    this._init();\n};\n;\nNotifications.BEEPS_EXPIRED = \"beeper/beeps_expired\";\nNotifications.prototype = {\n    _init: function() {\n        this.cookieName = ((\"notifications_\" + this.user));\n        this.beepsExpiredToken = null;\n        this.updateCheckCount = 0;\n        this.needMarkRead = false;\n        this.currentFetchRequest = null;\n        this.wrapper = ge(this.wrapperID);\n        this.JSBNG__content = ge(this.contentID);\n        this.jewelFlyout = ge(\"fbNotificationsFlyout\");\n        this.loadingIndicator = ge(((this.contentID + \"_loading_indicator\")));\n        NotificationCounter.init(this.counterInFront);\n        this.alertList = new NotificationList(this.JSBNG__content);\n        this._updateCount();\n        ((((window.MinNotifications && MinNotifications.fetched())) && (this.fetch = bagofholding)));\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(this.notifReceivedType), this._handleNotificationMsg.bind(this));\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"notifications_read\"), this._handleNotificationsReadMsg.bind(this));\n        MessagingEvents.subscribe(\"count/unread\", this._updateInboxUnreadCount.bind(this));\n        MessagingEvents.subscribe(\"count/unseen\", this._updateInboxUnseenCount.bind(this));\n        MessagingEvents.subscribe(\"count/other_unseen\", this._updateInboxOtherUnseenCount.bind(this));\n        this.alertList.subscribe(NotificationList.UNREAD_COUNT_CHANGE_TYPE, this._updateCount.bind(this));\n        this._poller = new Poller(this.update_period, this._update.bind(this), true);\n        if (this.wrapper) {\n            this.countSpan = DOM.JSBNG__find(this.wrapper, \"span.jewelCount span\");\n        }\n    ;\n    ;\n        this.initializeEvents();\n        this.fromDom();\n    },\n    fromDom: function() {\n        this.alertList.fromDom();\n    },\n    initializeEvents: function() {\n        var a = null;\n        JSBNG__Event.listen(this.JSBNG__content, {\n            mouseover: function(JSBNG__event) {\n                var b = JSBNG__event.getTarget();\n                a = Parent.byTag(b, \"li\");\n                if (((a && ((b != a))))) {\n                    CSS.addClass(a, \"selected\");\n                }\n            ;\n            ;\n            },\n            mouseout: function(JSBNG__event) {\n                ((a && CSS.removeClass(a, \"selected\")));\n                a = null;\n            }\n        });\n        JSBNG__Event.listen(this.wrapper, \"mouseover\", this.JSBNG__onMouseOver.bind(this));\n        Toggler.listen(\"show\", this.wrapper, this.JSBNG__onClick.bind(this));\n        Toggler.listen(\"hide\", this.wrapper, this.JSBNG__onHide.bind(this));\n    },\n    JSBNG__onMouseOver: function(JSBNG__event) {\n        this.ua = user_action(JSBNG__event.target, \"jewel\", JSBNG__event).set_namespace(\"notifs\").set_ua_id(\"prefetch\").add_event(\"hover\");\n        this.fetch();\n    },\n    JSBNG__onClick: function() {\n        ((((window.ArbiterMonitor && ((this.fetch != bagofholding)))) && Arbiter.registerCallback(bagofholding, [\"notifs/fetched\",])));\n        this.ua.add_event(\"show\");\n        this.fetch();\n        this.markRead(true);\n    },\n    JSBNG__onHide: function() {\n        this.ua.add_event(\"hide\");\n    },\n    signalMarkRead: function(a) {\n        a = ((a || []));\n        if (((((a.length === 0)) && this.currentFetchRequest))) {\n            this.needMarkRead = true;\n            return;\n        }\n    ;\n    ;\n        data = {\n        };\n        for (var b = 0; ((b < a.length)); ++b) {\n            data[((((\"alert_ids[\" + b)) + \"]\"))] = a[b];\n        ;\n        };\n    ;\n        new AsyncSignal(\"/ajax/notifications/mark_read.php\", data).send();\n    },\n    markRead: function(b, a) {\n        if (((this.alertList.unreadCount === 0))) {\n            return;\n        }\n    ;\n    ;\n        ((b && this.signalMarkRead(a)));\n        this.alertList.markRead(a);\n        this._updateCount();\n    },\n    _updateErrorHandler: function(a) {\n    \n    },\n    _updateURI: \"/ajax/presence/update.php\",\n    _update: function(a) {\n        a.setHandler(this._handleUpdate.bind(this)).setOption(\"suppressErrorAlerts\", true).setErrorHandler(this._updateErrorHandler.bind(this)).setData({\n            user: this.user,\n            notif_latest: this.latest_notif_time,\n            notif_latest_read: this.latest_read_notif_time\n        }).setURI(this._updateURI).setAllowCrossPageTransition(true);\n    },\n    _updateInboxOtherUnseenCount: function(a, b) {\n        CounterDisplay.setCount(\"other_unseen\", b);\n    },\n    _updateInboxUnreadCount: function(a, b) {\n        CounterDisplay.setCount(\"messages_unread\", b);\n    },\n    _updateInboxUnseenCount: function(a, b) {\n        CounterDisplay.setCount(\"messages_unseen\", b);\n        Arbiter.inform(\"jewel/count-updated\", {\n            jewel: \"messages\",\n            count: b\n        }, Arbiter.BEHAVIOR_STATE);\n    },\n    _handleUpdate: function(b) {\n        var a = b.payload.notifications;\n        if (!a.no_change) {\n            this.updateTime = b.payload.time;\n            this.latest_notif_time = a.latest_notif;\n            this.latest_read_notif_time = a.latest_read_notif;\n            this._updateDisplayDelayed();\n            this.alertList.insertMany(a.notifications);\n        }\n    ;\n    ;\n    },\n    _updateDisplayDelayed: function() {\n        if (((typeof Beeper != \"undefined\"))) {\n            this.beepsExpiredToken = Arbiter.subscribe(Notifications.BEEPS_EXPIRED, this._updateDisplay.bind(this));\n        }\n         else this._updateDisplay();\n    ;\n    ;\n    },\n    _updateDisplay: function() {\n        if (!this.JSBNG__content) {\n            return;\n        }\n    ;\n    ;\n        this._updateCount();\n        if (this.beepsExpiredToken) {\n            Arbiter.unsubscribe(this.beepsExpiredToken);\n        }\n    ;\n    ;\n    },\n    _updateCount: function() {\n        Arbiter.inform(\"jewel/count-updated\", {\n            jewel: \"notifications\",\n            count: this.alertList.unreadCount\n        }, Arbiter.BEHAVIOR_STATE);\n    },\n    fetch: function() {\n        var a = URI(\"/ajax/notifications/get.php\");\n        if (this.currentFetchRequest) {\n            return true;\n        }\n    ;\n    ;\n        this.ua.add_event(\"fetch\");\n        a.setQueryData({\n            time: this.latest_notif_time,\n            user: this.user,\n            version: this.cache_version,\n            locale: Env.locale\n        });\n        this.currentFetchRequest = new AsyncRequest().setURI(a).setStatusElement(this.loadingIndicator).setMethod(\"GET\").setReadOnly(true).setTimeoutHandler(30000, this.fetchErrorHandler.bind(this)).setHandler(this.fetchHandler.bind(this)).setErrorHandler(this.fetchErrorHandler.bind(this)).setAllowCrossPageTransition(true);\n        ((!this.currentFetchRequest.send() && this.fetchErrorHandler()));\n        return true;\n    },\n    fetchErrorHandler: function(a) {\n        this.currentFetchRequest = null;\n        this.ua.add_event(\"fetch_error\");\n    },\n    fetchHandler: function(b) {\n        this.ua.add_event(\"fetch_success\");\n        var a = b.getPayload();\n        this.alertList.insertMany(a.notifications, true);\n        ((this.loadingIndicator && CSS.hide(this.loadingIndicator)));\n        this.loadingIndicator = null;\n        this.currentFetchRequest = null;\n        this.fetch = bagofholding;\n        if (this.needMarkRead) {\n            this.needMarkRead = false;\n            this.signalMarkRead();\n        }\n    ;\n    ;\n        ((window.ArbiterMonitor && Arbiter.inform(\"notifs/fetched\", \"\", Arbiter.BEHAVIOR_STATE)));\n    },\n    _mergeNotification: function(b, d, c) {\n        var a = !this.alertList.isUnreadId(b);\n        this.alertList.insert(b, d, c, true);\n        this.latest_notif_time = 0;\n        if (a) {\n            this._updateCount();\n        }\n    ;\n    ;\n        if (this.isTabOpen()) {\n            this._merged_mouseover_handler = JSBNG__Event.listen(this.JSBNG__content, \"mouseover\", (function() {\n                this._merged_mouseover_handler.remove();\n                this.markRead(true);\n            }).bind(this));\n        }\n    ;\n    ;\n    },\n    _handleNotificationMsg: function(d, a) {\n        var b = a.obj;\n        if (((typeof this.useDesktopNotifications == \"undefined\"))) {\n            var c;\n            this.useDesktopNotifications = ((((this.allowDesktopNotifications && window.JSBNG__webkitNotifications)) && ((window.JSBNG__webkitNotifications.checkPermission() === 0))));\n        }\n    ;\n    ;\n        if (this.useDesktopNotifications) {\n            Bootloader.loadComponents(\"desktop-notifications\", function() {\n                DesktopNotifications.addNotification(b.alert_id);\n            });\n        }\n    ;\n    ;\n        b.time = ((b.time || +new JSBNG__Date()));\n        if (b.markup) {\n            this._mergeNotification(b.alert_id, b.time, b.markup);\n        }\n         else this._poller.requestNow();\n    ;\n    ;\n    },\n    _handleNotificationsReadMsg: function(c, a) {\n        var b = a.obj;\n        if (((typeof Beeper != \"undefined\"))) {\n            Beeper.getInstance().markRead(false, b.alert_ids);\n        }\n    ;\n    ;\n        this.markRead(false, b.alert_ids);\n    },\n    isTabOpen: function() {\n        return ((this.wrapper && CSS.hasClass(this.wrapper, \"openToggler\")));\n    }\n};\nfunction OriginalNotifications(a) {\n    this.parent.construct(this, a);\n};\n;\nClass.extend(OriginalNotifications, \"Notifications\");\ncopy_properties(OriginalNotifications.prototype, {\n    _init: function() {\n        this.parent._init();\n        this.alertList.subscribe(NotificationList.MARK_READ_TYPE, this._animateMarkRead.bind(this));\n        Arbiter.subscribe(\"jewel/resize\", this._hideOverflow.bind(this));\n    },\n    fetchHandler: function(c) {\n        this.parent.fetchHandler(c);\n        var b = c.getPayload();\n        var d = b.generated;\n        var a = Math.round((((new JSBNG__Date()).getTime() / 1000)));\n        if (((((a - d)) > 15))) {\n            d = a;\n        }\n    ;\n    ;\n        Bootloader.loadComponents(\"live-timer\", function() {\n            LiveTimer.restart(d);\n            LiveTimer.startLoop(0);\n        });\n        this._hideOverflow();\n    },\n    _mergeNotification: function(a, c, b) {\n        this.parent._mergeNotification(a, c, b);\n        var d = this.alertList.getDomObj(a);\n        if (d) {\n            Bootloader.loadComponents(\"live-timer\", function() {\n                LiveTimer.addTimeStamps(d);\n            });\n        }\n    ;\n    ;\n    },\n    _animateMarkRead: function(a, b) {\n        animation(b).duration(5000).checkpoint().from(\"backgroundColor\", \"#EFF1F7\").to(\"backgroundColor\", \"#FFFFFF\").duration(2250).JSBNG__ondone(CSS.removeClass.bind(null, b, NotificationList.ITEM_UNREAD_CLASS)).go();\n    },\n    JSBNG__onClick: function() {\n        this.parent.JSBNG__onClick();\n        this._hideOverflow();\n    },\n    _updateCount: function() {\n        this.parent._updateCount();\n        this._hideOverflow();\n    },\n    _hideOverflow: function() {\n        var a = DOM.JSBNG__find(this.jewelFlyout, \".jewelFooter\"), d = DOM.scry($(\"fbNotificationsList\"), \".notification\");\n        if (((!d.length || ((CSS.hasClass(JSBNG__document.documentElement, \"tinyViewport\") && !CSS.hasClass(JSBNG__document.body, \"fixedBody\")))))) {\n            d.each(CSS.show);\n            return;\n        }\n    ;\n    ;\n        var b = ((((Vector2.getViewportDimensions().y - Vector2.getElementPosition(d[0], \"viewport\").y)) - Vector2.getElementDimensions(a).y)), c = 0;\n        for (; ((((c < d.length)) && ((b > 0)))); ++c) {\n            CSS.show(d[c]);\n            b -= Vector2.getElementDimensions(d[c]).y;\n        };\n    ;\n        ((((b < 0)) && --c));\n        for (; ((c < d.length)); ++c) {\n            CSS.hide(d[c]);\n        ;\n        };\n    ;\n    }\n});\nfunction SearchDataSource(b) {\n    this._token = ((b.token || \"\"));\n    this._lazyonload = ((((b.lazyonload === false)) ? false : true));\n    this._leanOnAllTypes = b.leanOnAllTypes;\n    this._extraTypes = b.extraTypes;\n    var a = ((b.maxResults || 8));\n    this.parent.construct(this, b);\n    this._numResults = {\n        min: 3,\n        max: a\n    };\n    this._genTime = b.genTime;\n};\n;\nClass.extend(SearchDataSource, \"DataSource\");\nSearchDataSource.prototype = {\n    init: function() {\n        this.parent.init();\n        this._leanPayload = null;\n        this._bootstrapRequestsPending = 0;\n        this._criticalOnly = true;\n        this._updateMaxResults();\n        JSBNG__Event.listen(window, \"resize\", this._updateMaxResults.bind(this));\n    },\n    dirty: function() {\n        this.parent.dirty();\n        this._fetchOnUseRequests = [];\n    },\n    asyncErrorHandler: function(a) {\n        if (((((window.Dialog && ((Dialog.getCurrent() == null)))) && ((a.getError() == 1400003))))) {\n            AsyncResponse.verboseErrorHandler(a);\n        }\n    ;\n    ;\n    },\n    fetch: function(b, a, c) {\n        c = ((c || {\n        }));\n        c.fetch_start = (+new JSBNG__Date());\n        this.parent.fetch(b, a, c);\n    },\n    fetchHandler: function(f, c) {\n        var e = f.getPayload();\n        var g = copy_properties({\n            fetch_end: (+new JSBNG__Date())\n        }, c);\n        var b = ((g.value ? Arbiter.BEHAVIOR_EVENT : Arbiter.BEHAVIOR_PERSISTENT));\n        if (((c.type == \"lean\"))) {\n            this._leanPayload = e;\n            this._processLean();\n        }\n         else {\n            this.parent.fetchHandler(f, c);\n            if (((c.bootstrap && !f.getRequest().getData().no_cache))) {\n                g.browserCacheHit = ((e.timestamp < this._genTime));\n            }\n        ;\n        ;\n            if (((((c.bootstrap && !e.no_data)) && ((this._bootstrapRequestsPending > 0))))) {\n                if (e.num_remaining_pieces) {\n                    c.remaining_pieces = e.num_remaining_pieces;\n                    for (var d = 0; ((d < e.num_remaining_pieces)); ++d) {\n                        var a = copy_properties({\n                        }, f.getRequest().getData());\n                        a.piece_idx = d;\n                        this.fetch(this.bootstrapEndpoint, a, c);\n                    };\n                ;\n                }\n                 else {\n                    --c.remaining_pieces;\n                    if (!c.remaining_pieces) {\n                        c.bootstrap = false;\n                        --this._bootstrapRequestsPending;\n                    }\n                ;\n                ;\n                    ((!this._bootstrapRequestsPending && this._bootstrapPostProcess()));\n                }\n            ;\n            ;\n                ((this.value && this.respond(this.value, this.buildUids(this.value))));\n            }\n        ;\n        ;\n            if (((((e.stale || e.no_data)) || ((e.token !== this._token))))) {\n                var a = copy_properties({\n                }, f.getRequest().getData());\n                if (((a.stale_ok || a.lazy))) {\n                    a.stale_ok = 0;\n                    a.lazy = 0;\n                    a.token = this._token;\n                    this._fetchOnUse(a, c);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this.inform(\"endpointStats\", g, b);\n    },\n    _bootstrapPostProcess: function() {\n        var a = {\n            time: (+new JSBNG__Date())\n        };\n        this.inform(\"bootstrapped\", a, Arbiter.BEHAVIOR_PERSISTENT);\n        this._processLean();\n    },\n    _processLean: function() {\n        if (this._leanPayload) {\n            var b;\n            var a = this._leanPayload.entries;\n            for (var c in a) {\n                b = this.getEntry(c);\n                ((b && (b.index = a[c])));\n            };\n        ;\n            this._leanPayload = null;\n        }\n    ;\n    ;\n    },\n    _updateMaxResults: function() {\n        var a = ((window.JSBNG__innerHeight || JSBNG__document.documentElement.clientHeight));\n        this.setMaxResults(Math.max(this._numResults.min, Math.min(this._numResults.max, Math.ceil(((2 + ((((a - 370)) / 56))))))));\n    },\n    mergeUids: function(a, c, b, e) {\n        var d = function(f, g) {\n            var h = this.getEntry(f);\n            var i = this.getEntry(g);\n            if (((((h.extended_match || false)) !== ((i.extended_match || false))))) {\n                return ((h.extended_match ? 1 : -1));\n            }\n        ;\n        ;\n            if (((h.index !== i.index))) {\n                return ((h.index - i.index));\n            }\n        ;\n        ;\n            if (((h.text.length !== i.text.length))) {\n                return ((h.text.length - i.text.length));\n            }\n        ;\n        ;\n            if (((h.text !== i.text))) {\n                return ((((h.text < i.text)) ? -1 : 1));\n            }\n        ;\n        ;\n            return ((((h.uid < i.uid)) ? -1 : 1));\n        }.bind(this);\n        this._checkExtendedMatch(e, a);\n        this._checkExtendedMatch(e, c);\n        return a.sort(d).concat(c, b);\n    },\n    _checkExtendedMatch: function(e, d) {\n        var b = ((this._alwaysPrefixMatch ? TypeaheadUtil.isPrefixMatch : TypeaheadUtil.isQueryMatch));\n        for (var a = 0; ((a < d.length)); ++a) {\n            var c = this.getEntry(d[a]);\n            c.extended_match = ((c.tokens && !b(e, c.text)));\n        };\n    ;\n    },\n    _multifetch: function(e, b) {\n        var d = copy_properties(b, this.bootstrapData);\n        d.stale_ok = 1;\n        for (var f = 0; ((f < e.length)); ++f) {\n            var a = copy_properties({\n                filter: e[f]\n            }, d);\n            var c = {\n                bootstrap: true,\n                remaining_pieces: 1,\n                type: ((((e[f].length === 1)) ? e[f][0] : \"other\"))\n            };\n            this.fetch(this.bootstrapEndpoint, a, c);\n            ++this._bootstrapRequestsPending;\n        };\n    ;\n    },\n    _fetchOnUse: function(a, b) {\n        for (var c in this.bootstrapData) {\n            ((!a.hasOwnProperty(c) && (a[c] = this.bootstrapData[c])));\n        ;\n        };\n    ;\n        if (this._criticalOnly) {\n            this._fetchOnUseRequests.push({\n                args: a,\n                ctx: b\n            });\n        }\n         else this.fetch(this.bootstrapEndpoint, a, b);\n    ;\n    ;\n    },\n    _fetchLean: function() {\n        var a = {\n            filter: [\"user\",],\n            no_cache: 1\n        };\n        if (this._leanOnAllTypes) {\n            a = {\n                no_cache: 1\n            };\n        }\n    ;\n    ;\n        a.options = $A(a.options);\n        a.options.push(\"lean\");\n        this._fetchOnUse(a, {\n            type: \"lean\"\n        });\n    },\n    bootstrap: function(a) {\n        if (!a) {\n            this._criticalOnly = false;\n            this._flushFetchOnUseRequests();\n        }\n    ;\n    ;\n        if (this._bootstrapped) {\n            return;\n        }\n    ;\n    ;\n        if (this.bootstrapData.filter) {\n            this.fetch(this.bootstrapEndpoint, this.bootstrapData);\n        }\n         else {\n            var b = {\n                filter: [\"JSBNG__event\",],\n                no_cache: 1\n            };\n            this._fetchOnUse(b, {\n                type: \"JSBNG__event\"\n            });\n            var d = [\"app\",\"page\",\"group\",];\n            d = d.concat(((this._extraTypes || [])));\n            d = [[\"user\",],d,];\n            var c = ((((this._criticalOnly && this._lazyonload)) ? {\n                lazy: 1\n            } : {\n            }));\n            this._multifetch(d, c);\n        }\n    ;\n    ;\n        this._fetchLean();\n        this._bootstrapped = true;\n    },\n    _flushFetchOnUseRequests: function() {\n        var c = this._fetchOnUseRequests.length;\n        for (var b = 0; ((b < c)); ++b) {\n            var a = this._fetchOnUseRequests[b];\n            this.fetch(this.bootstrapEndpoint, a.args, a.ctx);\n        };\n    ;\n        this._fetchOnUseRequests = [];\n    },\n    JSBNG__onLoad: function(a, b) {\n        this.inform(\"JSBNG__onload\", {\n            time: (+new JSBNG__Date())\n        }, Arbiter.BEHAVIOR_PERSISTENT);\n        if (a) {\n            this.bootstrap.bind(this, b).defer();\n        }\n    ;\n    ;\n    }\n};\nfunction SearchTypeaheadCore(a) {\n    this.parent.construct(this, a);\n};\n;\nClass.extend(SearchTypeaheadCore, \"TypeaheadCore\");\nSearchTypeaheadCore.prototype = {\n    init: function(a, f, d) {\n        this.parent.init(a, f, d);\n        var b = Parent.byTag(d, \"form\"), c = this.reset.bind(this);\n        if (b) {\n            var e = DOM.JSBNG__find(b, \"input.search_sid_input\");\n            JSBNG__Event.listen(b, \"submit\", function() {\n                if (((this.data && this.data.queryData))) {\n                    e.value = this.data.queryData.sid;\n                }\n            ;\n            ;\n                c.defer();\n            }.bind(this), JSBNG__Event.Priority.URGENT);\n        }\n    ;\n    ;\n    },\n    select: function() {\n        this.reset();\n        this.element.JSBNG__focus();\n        (function() {\n            this.element.JSBNG__blur();\n        }).bind(this).defer();\n    },\n    handleTab: function(JSBNG__event) {\n        var a = this.view.getQuerySuggestion(this.value);\n        if (a) {\n            Input.setValue(this.element, a);\n            this.checkValue();\n            JSBNG__event.kill();\n        }\n         else this.parent.handleTab(JSBNG__event);\n    ;\n    ;\n    }\n};\nfunction SearchTypeaheadRecorder(a) {\n    this.init(a);\n    this.initEvents();\n};\n;\nSearchTypeaheadRecorder.prototype = {\n    _endPoint: \"/ajax/typeahead/record_metrics.php\",\n    init: function(a) {\n        this.core = a.getCore();\n        this.data = a.getData();\n        this.view = a.getView();\n        this.element = this.core.getElement();\n        this.initTime = this.time();\n        this._onloadTime = 0;\n        this.initStartTime = $(\"search_first_focus\").value;\n        this.bootstrapStats = {\n            bootstrapped: 0\n        };\n        this._reset();\n    },\n    _reset: function() {\n        this.stats = {\n        };\n        this.avgStats = {\n        };\n        this.appendStats = {\n        };\n        this._backspacing = false;\n        var a = Math.JSBNG__random();\n        this.data.setQueryData({\n            sid: a\n        });\n        this.view.setSid(a);\n        this.recordStat(\"sid\", a);\n    },\n    initEvents: function() {\n        this.core.subscribe(\"JSBNG__focus\", function(JSBNG__event) {\n            if (!this.stats[\"session_start_time\"]) {\n                this.recordStat(\"session_start_time\", this.time());\n            }\n        ;\n        ;\n        }.bind(this));\n        this.core.subscribe(\"JSBNG__blur\", function(JSBNG__event) {\n            this.recordStat(\"session_end_time\", this.time());\n            this.submit();\n        }.bind(this));\n        this.view.subscribe(\"select\", function(a, b) {\n            this.recordSelectInfo(b);\n        }.bind(this));\n        this.view.subscribe(\"render\", function(a, b) {\n            this.recordRender(b);\n        }.bind(this));\n        this.data.subscribe(\"activity\", function(a, b) {\n            this.recordStat(\"pending_request\", b.activity);\n        }.bind(this));\n        this.data.subscribe(\"beforeQuery\", function(a, b) {\n            if (!b.value) {\n                return;\n            }\n        ;\n        ;\n            if (!this.stats.first_query_time) {\n                this.recordStat(\"first_query_time\", this.time());\n            }\n        ;\n        ;\n            this.query = b.value;\n            this.recordCountStat(\"num_queries\");\n        }.bind(this));\n        this.data.subscribe(\"queryEndpoint\", function(a, b) {\n            this.recordCountStat(\"num_search_ajax_requests\");\n            this.recordAvgStat(\"endpoint_query_length\", b.value.length);\n        }.bind(this));\n        this.data.subscribe(\"JSBNG__onload\", function(a, b) {\n            this._onloadTime = b.time;\n        }.bind(this));\n        this.data.subscribe(\"bootstrapped\", function(a, b) {\n            this.bootstrapStats.endTime = b.time;\n            this.bootstrapStats.bootstrapped = 1;\n        }.bind(this));\n        this.data.subscribe(\"endpointStats\", function(a, c) {\n            var b = ((c.fetch_end - c.fetch_start));\n            if (c.value) {\n                this.recordAvgStat(\"search_endpoint_ms_from_js\", b);\n            }\n             else this.bootstrapStats[c.type] = b;\n        ;\n        ;\n            if (((typeof c.browserCacheHit != \"undefined\"))) {\n                this.recordCountStat(((c.browserCacheHit ? \"bootstrap_cachehits\" : \"bootstrap_cachemisses\")));\n            }\n        ;\n        ;\n        }.bind(this));\n        this.data.subscribe(\"query\", function(a, b) {\n            this.recordAvgStat(\"num_results_from_cache\", b.results.length);\n        }.bind(this));\n        JSBNG__Event.listen(this.element, \"keydown\", function(JSBNG__event) {\n            if (((JSBNG__Event.getKeyCode(JSBNG__event) == KEYS.BACKSPACE))) {\n                if (!this._backspacing) {\n                    this._backspacing = true;\n                    this.recordAppendStat(\"before_backspace_queries\", this.query);\n                }\n            ;\n            ;\n            }\n             else this._backspacing = false;\n        ;\n        ;\n        }.bind(this));\n    },\n    recordStat: function(a, b) {\n        this.stats[a] = b;\n    },\n    recordCountStat: function(a) {\n        var b = this.stats[a];\n        this.stats[a] = ((b ? ((b + 1)) : 1));\n    },\n    recordAvgStat: function(a, b) {\n        if (this.avgStats[a]) {\n            this.avgStats[a][0] += b;\n            ++this.avgStats[a][1];\n        }\n         else this.avgStats[a] = [b,1,];\n    ;\n    ;\n    },\n    recordAppendStat: function(a, b) {\n        if (!this.appendStats.hasOwnProperty(a)) {\n            this.appendStats[a] = [];\n        }\n    ;\n    ;\n        this.appendStats[a].push(b);\n    },\n    recordRender: function(a) {\n        this.results = a.filter(function(b) {\n            return ((((b.uid != \"search\")) && ((b.type != \"header\"))));\n        });\n        if (((((this.results.length > 0)) && !this.stats.first_result_time))) {\n            this.recordStat(\"first_result_time\", this.time());\n        }\n    ;\n    ;\n    },\n    recordSelectInfo: function(c) {\n        var f = c.selected;\n        var b = ((((c.index - f.groupIndex)) - 1));\n        var d = {\n            href: f.path\n        };\n        var a = ((f.dataGT ? {\n            gt: JSON.parse(f.dataGT)\n        } : {\n        }));\n        user_action(d, \"click\", null, null, a);\n        if (((f.uid == \"search\"))) {\n            this.recordStat(\"selected_search\", 1);\n        }\n         else {\n            var g = ((((f.rankType || f.render_type)) || f.type));\n            var e = ((((g == \"friend\")) ? \"user\" : g));\n            this.recordStat(((\"selected_\" + e)), 1);\n            this.recordStat(\"selected_position\", b);\n            this.recordStat(\"selected_type\", g);\n            this.recordStat(\"selected_name_length\", f.text.length);\n            this.recordStat(\"selected_id\", f.uid);\n            this.recordStat(\"selected_degree\", ((f.bootstrapped ? 1 : 2)));\n            this.recordStat(\"selected_extended_match\", f.extended_match);\n        }\n    ;\n    ;\n        this.recordStat(\"selected_with_mouse\", ((c.clicked ? 1 : 0)));\n    },\n    _dataToSubmit: function() {\n        this.recordStat(\"candidate_results\", this.buildResults());\n        this.recordStat(\"query\", this.query);\n        this.recordStat(\"init_time\", this.initTime);\n        if (this.initStartTime) {\n            this.recordStat(\"init_start_time\", this.initStartTime);\n            this.recordStat(\"JSBNG__onload_time\", this._onloadTime);\n            this.initStartTime = 0;\n        }\n    ;\n    ;\n        this.recordStat(\"bootstrapped\", this.bootstrapStats.bootstrapped);\n        if (this.bootstrapStats.endTime) {\n            this.recordStat(\"bootstrapped_time\", this.bootstrapStats.endTime);\n            this.recordStat(\"user_bootstrap_ms\", this.bootstrapStats.user);\n            this.recordStat(\"other_bootstrap_ms\", this.bootstrapStats.other);\n            this.bootstrapStats.endTime = 0;\n        }\n    ;\n    ;\n        this.recordStat(\"max_results\", this.data._maxResults);\n        var b = this.stats;\n        for (var d in this.avgStats) {\n            var c = this.avgStats[d];\n            b[d] = ((c[0] / c[1]));\n        };\n    ;\n        for (var a in this.appendStats) {\n            b[a] = JSON.stringify(this.appendStats[a]);\n        ;\n        };\n    ;\n        return b;\n    },\n    buildResults: function() {\n        var a = ((this.results || [])).map(function(d, c) {\n            var e = ((((d.rankType || d.render_type)) || d.type));\n            var b = ((d.bootstrapped ? 1 : 0));\n            if (((typeof d.groupIndex == \"number\"))) {\n                return [d.groupIndex,d.indexInGroup,d.uid,e,b,];\n            }\n        ;\n        ;\n            return [0,c,d.uid,e,b,];\n        });\n        return JSON.stringify(a);\n    },\n    submit: function() {\n        var a = this._dataToSubmit();\n        if (((count(a) > 0))) {\n            new AsyncRequest().setURI(this._endPoint).setMethod(\"POST\").setData({\n                stats: a\n            }).setOption(\"handleErrorAfterUnload\", true).setErrorHandler(function(b) {\n                a.retry = true;\n                new AsyncRequest().setURI(this._endPoint).setMethod(\"POST\").setData({\n                    stats: a\n                }).setOption(\"asynchronous\", false).send();\n            }.bind(this)).send();\n        }\n    ;\n    ;\n        this._reset();\n    },\n    time: function() {\n        return (new JSBNG__Date()).getTime();\n    }\n};\nfunction BucketedTypeaheadView(a, b) {\n    this.parent.construct(this, a, b);\n};\n;\nClass.extend(BucketedTypeaheadView, \"TypeaheadView\");\nBucketedTypeaheadView.prototype = {\n    render: function(c, a, b) {\n        a = this.buildBuckets(c, a);\n        return this.parent.render(c, a, b);\n    },\n    highlight: function(a, b) {\n        if (((((a == -1)) && ((this.index !== 0))))) {\n            a = this.index;\n        }\n    ;\n    ;\n        if (((((((a >= 0)) && ((a < this.items.length)))) && ((this.results[a].type == \"header\"))))) {\n            a = ((a + 1));\n        }\n    ;\n    ;\n        this.parent.highlight(a, b);\n    },\n    buildBuckets: function(i, f) {\n        if (!this.typeObjects) {\n            return f;\n        }\n    ;\n    ;\n        var b = [];\n        var h = {\n        };\n        for (var d = 0; ((d < f.length)); ++d) {\n            var c = f[d];\n            var g = ((c.render_type || c.type));\n            if (!h.hasOwnProperty(g)) {\n                h[g] = b.length;\n                b.push([this.buildBucketHeader(g),]);\n            }\n        ;\n        ;\n            c.classNames = g;\n            c.groupIndex = h[g];\n            c.indexInGroup = ((b[c.groupIndex].length - 1));\n            b[c.groupIndex].push(c);\n        };\n    ;\n        var a = [];\n        for (var e = 0; ((e < b.length)); ++e) {\n            a = a.concat(b[e]);\n        ;\n        };\n    ;\n        return a;\n    },\n    buildBucketHeader: function(b) {\n        var a = this.typeObjects[b];\n        if (a.markup) {\n            a.text = a.markup;\n            delete a.markup;\n        }\n    ;\n    ;\n        return this.typeObjects[b];\n    },\n    buildResults: function(b) {\n        var a = this.parent.buildResults(b);\n        return $N(\"div\", {\n            className: \"bucketed\"\n        }, [a,]);\n    },\n    select: function(a) {\n        var b = this.results[this.index];\n        if (((b && ((b.type != \"header\"))))) {\n            this.parent.select(a);\n        }\n    ;\n    ;\n    },\n    getDefaultIndex: function(c) {\n        var a = ((this.autoSelect && !this.disableAutoSelect));\n        var b = ((((c.length === 0)) ? -1 : ((((c[0].type == \"header\")) ? 1 : 0))));\n        return ((((((this.index < 0)) && !a)) ? -1 : b));\n    },\n    prev: function() {\n        var a = this.results[((this.index - 1))];\n        if (((a && ((a.type == \"header\"))))) {\n            this.index--;\n        }\n    ;\n    ;\n        return this.parent.prev();\n    },\n    next: function() {\n        var a = this.results[((this.index + 1))];\n        if (((a && ((a.type == \"header\"))))) {\n            this.index++;\n        }\n    ;\n    ;\n        return this.parent.next();\n    }\n};\nfunction SearchTypeaheadView(a, b) {\n    this.parent.construct(this, a, b);\n};\n;\nClass.extend(SearchTypeaheadView, \"BucketedTypeaheadView\");\nSearchTypeaheadView.prototype = {\n    ignoreClick: function(JSBNG__event) {\n        JSBNG__event.prevent();\n    },\n    shouldShowSeeMore: true,\n    queryData: {\n        init: \"quick\"\n    },\n    buildBuckets: function(c, b) {\n        var a = b.length;\n        b = this.parent.buildBuckets(c, b);\n        if (((c && this.shouldShowSeeMore))) {\n            b.push(this.buildSeeMore(c, a));\n        }\n    ;\n    ;\n        return b;\n    },\n    buildSeeMore: function(e, c) {\n        var d = ((((c > 0)) ? _tx(\"See more results for {query}\", {\n            query: e\n        }) : _tx(\"See results for {query}\", {\n            query: e\n        })));\n        var a = ((((c == 1)) ? _tx(\"Displaying top result\") : _tx(\"Displaying top {number} results\", {\n            number: c\n        })));\n        var b = $N(\"li\", {\n            className: \"calltoaction\"\n        }, [$N(\"a\", {\n            href: this.getEndpoint(e),\n            rel: \"ignore\"\n        }, [$N(\"span\", {\n            className: \"text\"\n        }, [$N(\"span\", {\n            className: \"seeMore\"\n        }, [d,$N(\"span\", {\n            className: \"arrow\"\n        }),]),$N(\"span\", {\n            className: \"subtext\"\n        }, [a,]),]),]),]);\n        return {\n            uid: \"search\",\n            node: b,\n            search: true\n        };\n    },\n    searchPageQueryData: function(a) {\n        return copy_properties({\n            q: a\n        }, ((this.queryData || {\n        })));\n    },\n    select: function(b) {\n        var d = this.index;\n        var e = this.results[d];\n        if (((!e || ((e.type == \"header\"))))) {\n            return;\n        }\n    ;\n    ;\n        var c = this.items[d];\n        var a = DOM.JSBNG__find(c, \"a\");\n        if (e.song) {\n            if (a) {\n                MusicEvents.inform(MusicConstants.MUSIC_BUTTON.ACTIVATE, a);\n            }\n        ;\n        ;\n            ((b && this.inform(\"highlight\", {\n                index: d,\n                selected: e\n            })));\n        }\n         else {\n            this.parent.select(b);\n            if (((a && a.href))) {\n                if (((a.target == \"_blank\"))) {\n                    window.open(a.href);\n                }\n                 else goURI(a.href);\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    setSid: function(a) {\n        this.queryData.tas = a;\n    },\n    getEndpoint: function(c) {\n        var b = Parent.byTag(this.element, \"form\");\n        var a = Form.getAttribute(b, \"action\");\n        return ((URI(a).addQueryData(this.searchPageQueryData(c)) + \"\"));\n    },\n    show: function() {\n        Arbiter.inform(\"layer_shown\", {\n            type: \"SearchTypeahead\"\n        });\n        this.parent.show();\n    },\n    hide: function() {\n        Arbiter.inform(\"layer_hidden\", {\n            type: \"SearchTypeahead\"\n        });\n        this.parent.hide();\n    },\n    getQuerySuggestion: function(c) {\n        var a = this.results[this.index];\n        var b = ((((a && ((a.type != \"header\")))) ? a.text.toLowerCase() : \"\"));\n        return ((((b == c.toLowerCase())) ? \"\" : b));\n    }\n};\nadd_properties(\"TypeaheadBehaviors\", {\n    searchRecorderBasic: function(a) {\n        a.subscribe(\"init\", function(b, c) {\n            new SearchTypeaheadRecorder(a);\n        });\n    }\n});\nJSBNG__onloadRegister(function() {\n    add_properties(\"__behaviors\", {\n    });\n    if (__behaviors.Scrollable) {\n        return;\n    }\n;\n;\n    __behaviors.Scrollable = true;\n    var a = \"scrollable\";\n    JSBNG__Event.listen(JSBNG__document.documentElement, ((ua.firefox() ? \"DOMMouseScroll\" : \"mousewheel\")), function(JSBNG__event) {\n        var h = Parent.byClass(JSBNG__event.getTarget(), a);\n        if (!h) {\n            return;\n        }\n    ;\n    ;\n        if (((((((typeof JSBNG__event.axis !== \"undefined\")) && ((JSBNG__event.axis === JSBNG__event.HORIZONTAL_AXIS)))) || ((JSBNG__event.wheelDeltaX && !JSBNG__event.wheelDeltaY))))) {\n            JSBNG__event.prevent();\n            return;\n        }\n    ;\n    ;\n        var c = ((JSBNG__event.wheelDelta ? JSBNG__event.wheelDelta : -JSBNG__event.detail));\n        var f = h.scrollHeight;\n        var b = h.clientHeight;\n        if (((f > b))) {\n            var g = h.scrollTop;\n            if (((((((c > 0)) && ((g === 0)))) || ((((c < 0)) && ((g >= ((f - b))))))))) {\n                JSBNG__event.prevent();\n            }\n             else if (((ua.ie() < 9))) {\n                var e = CSS.getStyle(h, \"font-size\");\n                if (((e.indexOf(\"px\") < 0))) {\n                    var d = $N(\"div\");\n                    d.style.fontSize = e;\n                    d.style.height = \"1em\";\n                    e = d.style.pixelHeight;\n                }\n                 else e = parseInt(e, 10);\n            ;\n            ;\n                h.scrollTop = ((g - Math.round(((((c / 120)) * e)))));\n                JSBNG__event.prevent();\n            }\n            \n        ;\n        ;\n        }\n    ;\n    ;\n    });\n});\nadd_properties(\"TypeaheadBehaviors\", {\n    showLoadingIndicator: function(a) {\n        a.subscribe(\"activity\", function(b, c) {\n            CSS.conditionClass(a.getElement(), \"typeaheadLoading\", c.activity);\n        });\n    }\n});\nadd_properties(\"TypeaheadRenderers\", {\n    basic: function(a, b) {\n        var c = [];\n        if (a.icon) {\n            c.push($N(\"img\", {\n                alt: \"\",\n                src: a.icon\n            }));\n        }\n    ;\n    ;\n        if (a.text) {\n            c.push($N(\"span\", {\n                className: \"text\"\n            }, [a.text,]));\n        }\n    ;\n    ;\n        if (a.subtext) {\n            c.push($N(\"span\", {\n                className: \"subtext\"\n            }, [a.subtext,]));\n        }\n    ;\n    ;\n        return $N(\"li\", {\n            className: ((a.type || \"\"))\n        }, c);\n    }\n});\nadd_properties(\"TypeaheadRenderers\", {\n    search: function(c, e) {\n        var g = [];\n        if (c.photo) {\n            g.push($N(\"img\", {\n                className: \"photo\",\n                alt: \"\",\n                src: c.photo\n            }));\n            if (c.song) {\n                g.push($N(\"span\", {\n                    className: \"playButton\"\n                }));\n                g.push($N(\"span\", {\n                    className: \"playLoader\"\n                }));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (c.text) {\n            g.push($N(\"span\", {\n                className: \"text\"\n            }, [c.text,]));\n        }\n    ;\n    ;\n        if (c.category) {\n            var a = [c.category,];\n            if (c.is_external) {\n                a.push($N(\"span\", {\n                    className: \"arrow\"\n                }));\n            }\n        ;\n        ;\n            g.push($N(\"span\", {\n                className: \"category\"\n            }, a));\n        }\n    ;\n    ;\n        if (c.subtext) {\n            g.push($N(\"span\", {\n                className: \"subtext\"\n            }, [c.subtext,]));\n        }\n    ;\n    ;\n        var b = ((((c.classNames || c.type)) || \"\"));\n        var h = ((c.is_external ? \"_blank\" : \"\"));\n        var d = ((((!c.song && c.path)) || \"\"));\n        if (d) {\n            if (!(/^https?\\:\\/\\//).test(d)) {\n                d = ((Env.www_base + d.substr(1)));\n            }\n        ;\n        ;\n            d += ((((((d.indexOf(\"?\") > 0)) ? \"&\" : \"?\")) + \"ref=ts\"));\n        }\n    ;\n    ;\n        var f = $N(\"a\", {\n            href: d,\n            rel: \"ignore\",\n            target: h\n        }, g);\n        if (c.song) {\n            f.id = ((\"mb_\" + ((((Math.JSBNG__random() * 1000000)) | 0))));\n            MusicButtonManager.addButton.curry(c.song.provider, f.id, c.song.url, c.song.context, c.song.media_type).defer();\n            f.JSBNG__onclick = this.ignoreClick;\n        }\n    ;\n    ;\n        return $N(\"li\", {\n            className: b\n        }, [f,]);\n    }\n});");
// 4374
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[3], o9,o22);
// undefined
o9 = null;
// 4429
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"ctRPa\",]);\n}\n;\n;\nfunction CIBase(a, b) {\n    copy_properties(this, {\n        ci_config: a,\n        element_ids: b\n    });\n    return this;\n};\n;\ncopy_properties(CIBase.prototype, {\n    getId: function(a) {\n        return this.element_ids[a];\n    },\n    setId: function(a, b) {\n        this.element_ids[a] = b;\n        return this;\n    },\n    setAjaxMode: function(a) {\n        this.ajax_mode = a;\n        return this;\n    },\n    getConfigData: function() {\n        var a = {\n            type: this.ci_config.type,\n            flow: this.ci_config.flow,\n            domain_id: this.ci_config.domain_id,\n            import_id: this.ci_config.import_id,\n            tracked_params: this.ci_config.tracked_params\n        };\n        return a;\n    }\n});\nfunction CICaptcha(a) {\n    copy_properties(this, {\n        captcha_endpoint: \"/contact_importer/ajax/captcha.php\",\n        callback: a,\n        form_name: \"ci_captcha_form\"\n    });\n    return this;\n};\n;\ncopy_properties(CICaptcha.prototype, {\n    showDialog: function() {\n        var a = new AsyncRequest().setMethod(\"GET\").setReadOnly(true).setURI(this.captcha_endpoint).setData({\n            form_name: this.form_name\n        }).setHandler(bind(this, \"handleCaptchaRender\")).send();\n    },\n    handleCaptchaRender: function(c) {\n        var b = c.getPayload();\n        var a = [{\n            JSBNG__name: \"submit\",\n            label: _tx(\"Submit\"),\n            handler: bind(this, \"submitCaptchaResponse\")\n        },Dialog.CANCEL,];\n        new Dialog().setTitle(\"\").setBody(b.JSBNG__content).setButtons(a).setClickButtonOnEnter(\"captcha_response\", \"submit\").show();\n    },\n    submitCaptchaResponse: function() {\n        var a = Form.serialize($(this.form_name));\n        new AsyncRequest().setURI(this.captcha_endpoint).setMethod(\"POST\").setData(a).setHandler(this.callback.bind(this)).send();\n    }\n});\nfunction ProgressBar(a) {\n    copy_properties(this, {\n        _updateInterval: 100,\n        _lastProgress: null,\n        _inited: false,\n        _innerBar: DOM.JSBNG__find(a, \"div.progress_bar_inner\"),\n        _outerBar: DOM.JSBNG__find(a, \"div.progress_bar_outer\")\n    });\n    var b = this._innerBar.style.width;\n    this._innerBar.style.width = \"100%\";\n    (function() {\n        this._inited = true;\n        this._width = Vector2.getElementDimensions(this._innerBar).x;\n        this._innerBar.style.width = b;\n    }.bind(this)).defer();\n};\n;\nProgressBar.prototype = {\n    setUpdateInterval: function(a) {\n        this._updateInterval = a;\n        return this;\n    },\n    setProgress: function(a) {\n        if (((((a < 0)) || ((a > 100))))) {\n            return;\n        }\n    ;\n    ;\n        if (!this._inited) {\n            this.setProgress.bind(this, a).defer();\n            return this;\n        }\n    ;\n    ;\n        animation(this._innerBar).to(\"width\", Math.round(((this._width * ((a / 100)))))).duration(this._updateInterval).go();\n        return this;\n    }\n};\nfunction CIProgressBar(a) {\n    this.parent.construct(this, a);\n    copy_properties(this, {\n        percent: DOM.JSBNG__find(a, \"span.progress_bar_percent\"),\n        message: DOM.JSBNG__find(a, \"span.progress_bar_message\")\n    });\n    return this;\n};\n;\nClass.extend(CIProgressBar, \"ProgressBar\");\ncopy_properties(CIProgressBar.prototype, {\n    setProgress: function(b, a, c) {\n        this.parent.setProgress(b);\n        this.state = c;\n        DOM.setContent(this.percent, HTML(((\"\" + b))));\n        DOM.setContent(this.message, HTML(a));\n    }\n});\nfunction CIProgressBarDialog() {\n    copy_properties(this, {\n        dialog: null,\n        progressBar: null,\n        pollCounter: 0,\n        title: null,\n        body: null,\n        startTime: null,\n        endpoint: null,\n        importer: null\n    });\n};\n;\nCIProgressBarDialog.MAX_POLLS = 15;\ncopy_properties(CIProgressBarDialog.prototype, {\n    startTimer: function() {\n        this.startTime = +new JSBNG__Date();\n    },\n    show: function() {\n        this.startTimer();\n        this.dialog = new Dialog().setModal(true).showLoading().setAsyncURL(this.endpoint).JSBNG__onloadRegister(bind(this, this.startPolling)).setCancelHandler(bind(this, this.handleCancelResponse)).show();\n        return this;\n    },\n    hide: function() {\n        if (this.dialog) {\n            this.dialog.hide();\n            this.dialog = null;\n        }\n    ;\n    ;\n    },\n    startPolling: function(a) {\n        a = ((((typeof (a) != \"undefined\")) ? a : 1000));\n        (function() {\n            this.progressBar = new CIProgressBar(this.dialog.getRoot());\n        }.bind(this)).defer();\n        JSBNG__setTimeout(bind(this, \"poll\"), a);\n        this.pollCounter = 0;\n    },\n    poll: function() {\n        if (((this.pollCounter >= CIProgressBarDialog.MAX_POLLS))) {\n            this.hide();\n            return;\n        }\n    ;\n    ;\n        new AsyncRequest().setURI(this.endpoint).setHandler(bind(this, this.handlePollResponse)).setErrorHandler(bind(this, this.handleErrorResponse)).setReadOnly(true).send();\n        this.pollCounter += 1;\n    },\n    handlePollResponse: function(b) {\n        var a = b.getPayload().progress;\n        if (((((!a || !this.progressBar)) || !this.dialog))) {\n            return;\n        }\n    ;\n    ;\n        this.progressBar.setProgress(a.percent, a.message, a.state);\n        if (((((a.state != 2)) && ((a.percent != 100))))) {\n            this.poll.bind(this).defer(3000);\n        }\n    ;\n    ;\n    },\n    handleErrorResponse: function(a) {\n        if (!this.dialog) {\n            return;\n        }\n    ;\n    ;\n        this.hide();\n        AsyncResponse.defaultErrorHandler(a);\n    },\n    handleCancelResponse: function() {\n        if (this.importer) {\n            this.importer.logAsync({\n                login_str: this.importer.getLoginString(),\n                time_ms: ((+new JSBNG__Date() - this.startTime)),\n                cancel_progress_bar: ((this.progressBar.state || 0))\n            });\n        }\n    ;\n    ;\n        this.hide();\n    },\n    setEndpoint: function(a) {\n        this.endpoint = a;\n        return this;\n    },\n    setImporter: function(a) {\n        this.importer = a;\n        return this;\n    },\n    setProgress: function(b, a, c) {\n        ((this.progressBar && this.progressBar.setProgress(b, a, c)));\n    }\n});\nfunction CIInputController(b, c, d, a) {\n    this.parent.construct(this, b, c);\n    this.parent.setAjaxMode(a);\n    copy_properties(this, {\n        show_captcha: d\n    });\n    return this;\n};\n;\nClass.extend(CIInputController, \"CIBase\");\ncopy_properties(CIInputController, {\n    instance: null\n});\ncopy_properties(CIInputController.prototype, {\n    JSBNG__onSubmit: function(c) {\n        if (!this.getLoginString()) {\n            return false;\n        }\n    ;\n    ;\n        if (this.show_captcha) {\n            var a = new CICaptcha(bind(this, this._submitLoginForm, c));\n            a.showDialog();\n            return false;\n        }\n    ;\n    ;\n        if (((((this.ci_config.ffagent_config && this.ci_config.ffagent_config.force_use)) || ((c && c.use_ffagent))))) {\n            var b = this.getForm();\n            CSS.addClass(b, \"async_saving\");\n            Bootloader.loadComponents(\"contact-importer-ffagent-js\", function() {\n                CIFFAgent.startFFAgent(this.ci_config.ffagent_config, this.getId(\"ffagent_params\"), function(f, d, e) {\n                    if (((((f === 0)) || ((f === 1))))) {\n                        CSS.removeClass(b, \"async_saving\");\n                        this._submitLoginForm(c);\n                    }\n                     else {\n                        if (((f === 2))) {\n                            CSS.removeClass(b, \"async_saving\");\n                            CIFFAgent.showTimeoutMessage();\n                        }\n                    ;\n                    ;\n                        if (e) {\n                            this.logAsync({\n                                ffagent_app_type: d,\n                                ffagent_error: e,\n                                login_str: this.getLoginString()\n                            });\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }.bind(this));\n            }.bind(this));\n            return false;\n        }\n    ;\n    ;\n        return this._submitLoginForm(c);\n    },\n    toggleProgressBar: function(a) {\n        this.enableProgressBar = a;\n        return this;\n    },\n    progress_dialog: null,\n    startProgressBar: function() {\n        this.progress_dialog = new CIProgressBarDialog().setEndpoint(this.ci_config.progress_endpoint).setImporter(this).show();\n    },\n    _submitLoginForm: function(g) {\n        var d = this.getForm();\n        var a = ((d.getAttributeNode(\"action\") || {\n        })).value;\n        var c = Form.serialize(d);\n        if (g) {\n            copy_properties(c, g);\n        }\n    ;\n    ;\n        if (((((g && g.full_post)) || !this.ajax_mode))) {\n            JSBNG__setTimeout(function() {\n                Form.post(this.ci_config.full_endpoint, c);\n            }.bind(this), 0);\n            return false;\n        }\n    ;\n    ;\n        var b = new AsyncRequest();\n        a = this.ci_config.ajax_endpoint;\n        if (c.jsonp) {\n            var e = this.getId(\"login_input\");\n            var h = this.getId(\"password\");\n            var f = {\n            };\n            f[e] = c[e];\n            f[h] = c[h];\n            c.creds = Base64.encodeObject(f);\n            delete c[e];\n            delete c[h];\n            b.setOption(\"jsonp\", true).setMethod(\"GET\").setReadOnly(true);\n        }\n    ;\n    ;\n        b.setURI(a).setData(c).setHandler(bind(this, function(i) {\n            this.handleLoginSubmit(i.getPayload());\n        })).setErrorHandler(bind(this, function(i) {\n            ((this.progress_dialog && this.progress_dialog.hide()));\n            AsyncResponse.defaultErrorHandler(i);\n        })).setStatusElement(this.getStatusElement());\n        if (this.enableProgressBar) {\n            this.startProgressBar();\n        }\n    ;\n    ;\n        CIInputController.instance = this;\n        b.send();\n        if (this.ci_config.should_log_tti) {\n            window.ciSubmitTime = new JSBNG__Date().getTime();\n        }\n    ;\n    ;\n        return false;\n    },\n    handleLoginSubmit: function(b) {\n        if (((b == null))) {\n            ((this.progress_dialog && this.progress_dialog.hide()));\n            return;\n        }\n    ;\n    ;\n        if (((b.progress && this.progress_dialog))) {\n            progress = b.progress;\n            this.progress_dialog.setProgress(progress.percent, progress.message, progress.state);\n        }\n    ;\n    ;\n        var a = this.getContainer();\n        DOM.replace(a, HTML(b.JSBNG__content));\n        ((this.progress_dialog && this.progress_dialog.hide.bind(this.progress_dialog).defer(300)));\n    },\n    submitChallengeDialog: function(d) {\n        var e = DOM.JSBNG__find(d.getContentNode(), \"form\");\n        var c = d.getFormData();\n        var a = ((e.getAttributeNode(\"action\") || {\n        })).value;\n        var b = new AsyncRequest().setOption(\"jsonp\", true).setMethod(\"GET\").setReadOnly(true).setURI(a).setData(c).setHandler(bind(this, function(f) {\n            this.handleLoginSubmit(f.getPayload());\n        })).setErrorHandler(bind(this, function(f) {\n            this.progress_dialog.hide();\n            AsyncResponse.defaultErrorHandler(f);\n        })).setStatusElement(this.getForm());\n        b.addStatusIndicator();\n        this.startProgressBar();\n        b.send();\n    },\n    getLoginString: function() {\n        return ((this.getLogin() ? trim(this.getLogin().value) : \"\"));\n    },\n    openAPIPopup: function(a, d) {\n        var b = this.getConfigData();\n        copy_properties(b, {\n            api_instance: a,\n            login_str: d\n        });\n        var i = new URI(this.ci_config.api_endpoint).addQueryData(b);\n        var j = 0;\n        var c = 0;\n        if (((a == 1))) {\n            j = 600;\n            c = 400;\n        }\n         else if (((a == 2))) {\n            j = 600;\n            c = 450;\n        }\n         else if (((a == 3))) {\n            j = 500;\n            c = 500;\n        }\n         else if (((a == 25))) {\n            j = 1000;\n            c = 675;\n        }\n         else {\n            j = 830;\n            c = 600;\n        }\n        \n        \n        \n    ;\n    ;\n        var l = ((((window.JSBNG__screenLeft || window.JSBNG__screenX)) || 0));\n        var m = ((((window.JSBNG__screenTop || window.JSBNG__screenY)) || 0));\n        var k = Vector2.getViewportDimensions();\n        var g = ((l + ((((k.x - j)) / 2))));\n        var h = ((m + 115));\n        var f = ((((((((((((((((\"height=\" + c)) + \",width=\")) + j)) + \",left=\")) + g)) + \",top=\")) + h)) + \",resizable=1,scrollbars=1,toolbar=0,status=0\"));\n        var e = ((((((((((((((((((((((((\"dialogHeight=\" + c)) + \"px;\")) + \"dialogWidth=\")) + j)) + \"px;\")) + \"dialogLeft=\")) + g)) + \"px;\")) + \"dialogTop=\")) + h)) + \"px;\")) + \"center=1;resizable=1;status=0;\"));\n        if (this.supportShowModalDialog()) {\n            this.apiWindow = window.JSBNG__showModalDialog(i, \"api_contact_importer\", e);\n            this.isModal = true;\n        }\n         else {\n            this.apiWindow = window.open(i, \"api_contact_importer\", f);\n            if (this.apiWindow) {\n                this.apiWindow.JSBNG__focus();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    supportShowModalDialog: function() {\n        return ((((window.JSBNG__showModalDialog && !ua.ie())) && !ua.JSBNG__opera()));\n    },\n    processToken: function(a, b, e) {\n        var d = {\n            api_instance: a,\n            auth_token: b,\n            auth_crypt: Boolean(e)\n        };\n        if (this.show_captcha) {\n            var c = new CICaptcha(bind(this, \"_submitLoginForm\", d));\n            c.showDialog();\n        }\n         else this._submitLoginForm(d);\n    ;\n    ;\n    },\n    getForm: function() {\n        return $(this.getId(\"form\"));\n    },\n    getLogin: function() {\n        return $(this.getId(\"login_input\"));\n    },\n    getContainer: function() {\n        return $(this.getId(\"contacts_container\"));\n    },\n    getStatusElement: function() {\n        return $(this.getId(\"form\"));\n    },\n    logAsync: function(a) {\n        a = ((a || {\n        }));\n        var b = copy_properties(a, this.getConfigData());\n        new AsyncSignal(this.ci_config.log_endpoint, b).send();\n    }\n});\nfunction CIModularController() {\n\n};\n;\ncopy_properties(CIModularController.prototype, {\n    init: function(d, a, c, f) {\n        this.items = d;\n        this.animate = a;\n        this.noSteplist = f;\n        for (var b in d) {\n            if (d[b].expanded) {\n                this.expanded = b;\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        if (!c) {\n            return;\n        }\n    ;\n    ;\n        this.iconItems = c;\n        for (var e in c) {\n            if (c[e].selected) {\n                this.selected = e;\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    handleClick: function(c, b) {\n        if (this.items[c].expanded) {\n            return false;\n        }\n    ;\n    ;\n        if (this.animate) {\n            var a = animation(this.getContentElement(c)).from(\"height\", 0).to(\"height\", \"auto\").duration(150).show();\n            ((((ua.ie() != 9)) && a.blind()));\n            a.go();\n            if (this.expanded) {\n                a = animation(this.getContentElement(this.expanded)).to(\"height\", 0).duration(150).hide();\n                ((((ua.ie() != 9)) && a.blind()));\n                a.go();\n            }\n        ;\n        ;\n        }\n         else {\n            CSS.show(this.getContentElement(c));\n            if (this.expanded) {\n                CSS.hide(this.getContentElement(this.expanded));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        CSS.toggleClass($(c), \"expanded\");\n        if (this.expanded) {\n            CSS.toggleClass($(this.expanded), \"expanded\");\n            this.items[this.expanded].expanded = false;\n        }\n    ;\n    ;\n        if (!this.noSteplist) {\n            var d = ge(\"ci_steplist_3\");\n            if (d) {\n                if (this.items[c].invitable) {\n                    CSS.show(d);\n                }\n                 else CSS.hide(d);\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this.items[c].expanded = true;\n        this.expanded = c;\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        CSS.toggleClass($(b), \"selected\");\n        if (this.selected) {\n            CSS.toggleClass($(this.selected), \"selected\");\n            this.iconItems[this.selected].selected = false;\n        }\n    ;\n    ;\n        this.iconItems[b].selected = true;\n        this.selected = b;\n    },\n    getContentElement: function(a) {\n        return DOM.JSBNG__find($(a), \".ci_module_content\");\n    }\n});\nvar CIWebmailValidator = (function() {\n    var c;\n    var b = false;\n    var d = false;\n    var a = [];\n    var e = function(h) {\n        var l = h.tokens;\n        delete h.tokens;\n        for (var g in h) {\n            var f = h[g];\n            for (var k in l) {\n                if (!l.hasOwnProperty(k)) {\n                    continue;\n                }\n            ;\n            ;\n                var i = k.replace(/([.?*+\\^$\\[\\]\\\\(){}\\-])/g, \"\\\\$1\");\n                var j = new RegExp(i, \"g\");\n                f = f.replace(j, l[k]);\n            };\n        ;\n            h[g] = f;\n        };\n    ;\n        c = h;\n        b = true;\n        while (((a.length > 0))) {\n            (a.shift())();\n        ;\n        };\n    ;\n    };\n    return {\n        hasFullMapping: function() {\n            return b;\n        },\n        init: function(f) {\n            if (((!b && !d))) {\n                c = f;\n            }\n        ;\n        ;\n        },\n        isValidEmail: function(f) {\n            var g = new RegExp(\"[A-Za-z0-9_!#$%&'*+/=?^`{|}~-]+(?:\\\\.[A-Za-z0-9_!#$%&'*+/=?^`{|}~-]+)*@(?:[A-Za-z0-9](?:[A-Za-z0-9-]*[A-Za-z0-9])?\\\\.)+[A-Za-z0-9](?:[A-Za-z0-9-]*[A-Za-z0-9])?\");\n            return g.test(f);\n        },\n        getDomain: function(g) {\n            var f = g.split(\"@\");\n            return f[1];\n        },\n        getDomainImporterName: function(f) {\n            var i = [\"msft\",\"yahoo\",\"gmail\",\"yahoo_jp\",\"other\",];\n            var k = f.split(/\\./);\n            for (var g = 0; ((g < ((k.length - 1)))); g++) {\n                var l = k.slice(g).join(\".\");\n                l = ((((\"|\" + l.toLowerCase())) + \"~\"));\n                for (var j = 0; ((j < i.length)); j++) {\n                    var h = i[j];\n                    if (((c[h].indexOf(l) != -1))) {\n                        return h;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            return null;\n        },\n        getUseFFAgent: function(g) {\n            var f = this.getDomain(g);\n            var j = [\"msft\",\"yahoo\",\"gmail\",\"yahoo_jp\",\"other\",];\n            var l = f.split(/\\./);\n            for (var h = 0; ((h < ((l.length - 1)))); h++) {\n                var m = l.slice(h).join(\".\");\n                m = ((((\"|\" + m.toLowerCase())) + \"~1|\"));\n                for (var k = 0; ((k < j.length)); k++) {\n                    var i = j[k];\n                    if (((c[i].indexOf(m) != -1))) {\n                        return true;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n            return false;\n        },\n        getImporterName: function(f) {\n            return this.getDomainImporterName(this.getDomain(f));\n        },\n        isLiveDomain: function(f) {\n            return ((this.getImporterName(f) == \"msft\"));\n        },\n        isGmailDomain: function(f) {\n            return ((this.getImporterName(f) == \"gmail\"));\n        },\n        isYahooDomain: function(f) {\n            return ((this.getImporterName(f) == \"yahoo\"));\n        },\n        isYahooJpDomain: function(f) {\n            return ((this.getImporterName(f) == \"yahoo_jp\"));\n        },\n        isSupportedDomain: function(f) {\n            var g = this.getDomainImporterName(this.getDomain(f));\n            return ((g != null));\n        },\n        downloadDomainMapping: function(f) {\n            if (b) {\n                return;\n            }\n        ;\n        ;\n            if (f) {\n                a.push(f);\n            }\n        ;\n        ;\n            if (!d) {\n                d = true;\n                new AsyncRequest().setURI(URI(\"/contact_importer/ajax/get_domains.php\")).setMethod(\"GET\").setReadOnly(true).setHandler(bind(this, function(h) {\n                    var g = h.getPayload();\n                    e(g);\n                })).send();\n            }\n        ;\n        ;\n        },\n        setDomainMapping: function(f) {\n            e(f);\n        }\n    };\n})();\nfunction CIWebmailInputController(b, d, f, a) {\n    this.parent.construct(this, b, d, f, a);\n    copy_properties(this, {\n        login_str: null,\n        ms_login: null,\n        timer: null\n    });\n    this.importer_widget = this.getWidget();\n    var c = CIWebmailValidator.downloadDomainMapping.bind(CIWebmailValidator, null);\n    JSBNG__Event.listen(this.importer_widget, \"mouseover\", c);\n    var e = this.getLogin();\n    JSBNG__Event.listen(e, \"JSBNG__focus\", c);\n    JSBNG__Event.listen(e, \"change\", this.validate.bind(this));\n    JSBNG__Event.listen(e, \"keydown\", this.JSBNG__onKeyDown.bind(this));\n    JSBNG__Event.listen(e, \"keydown\", c);\n    this.form_onsubmit = this.getForm().JSBNG__onsubmit;\n    CIInputController.instance = this;\n    return this;\n};\n;\nClass.extend(CIWebmailInputController, \"CIInputController\");\ncopy_properties(CIWebmailInputController.prototype, {\n    JSBNG__onSubmit: function(a) {\n        try {\n            return this._onSubmit(a);\n        } catch (b) {\n            var data = {\n                js_error: b.message\n            };\n            this.logAsync(data);\n            return false;\n        };\n    ;\n    },\n    _onSubmit: function(c) {\n        CIInputController.instance = this;\n        if (this.deferred) {\n            JSBNG__clearTimeout(this.deferred);\n        }\n    ;\n    ;\n        if (!this.validate()) {\n            return false;\n        }\n    ;\n    ;\n        var d = this.getLoginString();\n        var a = this.getAPIInstance(d);\n        var g = CIWebmailValidator.getUseFFAgent(d);\n        var e = ((((this instanceof CINUXToDoWebmailInputController)) && CIWebmailValidator.isGmailDomain(d)));\n        if (e) {\n            a = 2;\n        }\n    ;\n    ;\n        if (a) {\n            this.openAPIPopup(a, d);\n            this.getPassword().value = \"\";\n            return false;\n        }\n         else if (Input.isEmpty(this.getPassword())) {\n            return false;\n        }\n        \n    ;\n    ;\n        var b = CIWebmailValidator.getDomain(d);\n        if (((b == \"yahoo.co.jp\"))) {\n            if (((this.ci_config.use_applet && JSBNG__navigator.javaEnabled()))) {\n                this.injectApplet();\n                return false;\n            }\n        ;\n        }\n    ;\n    ;\n        var f = {\n            use_ffagent: g\n        };\n        return this.parent.JSBNG__onSubmit(f);\n    },\n    injectApplet: function() {\n        var b = this.getForm();\n        CSS.addClass(b, \"async_saving\");\n        show(b);\n        var a = DOM.create(\"applet\", {\n            height: 1,\n            width: 1,\n            archive: ((\"/contact_importer/CI.jar?rand=\" + Math.JSBNG__random())),\n            code: \"com.facebook.CI\"\n        });\n        a.setAttribute(\"mayscript\", \"true\");\n        a.setAttribute(\"scriptable\", \"true\");\n        a.appendChild(DOM.create(\"param\", {\n            JSBNG__name: \"username\",\n            value: this.getLoginString()\n        }));\n        a.appendChild(DOM.create(\"param\", {\n            JSBNG__name: \"password\",\n            value: trim(this.getPassword().value)\n        }));\n        this.importer_widget.appendChild(a);\n    },\n    validate: function() {\n        var b = this.getLoginString();\n        this.login_str = b;\n        if (!b) {\n            this.setDefault();\n            return false;\n        }\n    ;\n    ;\n        var c = CIWebmailValidator;\n        if (!c.isValidEmail(b)) {\n            this.setDefault();\n            return false;\n        }\n    ;\n    ;\n        if (c.isSupportedDomain(b)) {\n            this.updateSubmitButton(c, b);\n            var a = this.getAPIInstance(b);\n            if (a) {\n                if (c.isYahooJpDomain(b)) {\n                    this.showBookmarkletDialog();\n                }\n                 else this.setAPI();\n            ;\n            ;\n            }\n             else this.setValid();\n        ;\n        ;\n            return true;\n        }\n         else {\n            if (CIWebmailValidator.hasFullMapping()) {\n                this.setUnsupported();\n            }\n             else {\n                this.setWaiting();\n                CIWebmailValidator.downloadDomainMapping(this.validate.bind(this));\n            }\n        ;\n        ;\n            return false;\n        }\n    ;\n    ;\n    },\n    showBookmarkletDialog: function() {\n        new Dialog().setAsyncURL(\"/contact_importer/ajax/bookmarklet_dialog.php\").show();\n    },\n    updateSubmitButton: function(c, a) {\n        var b = this.getForm();\n        if (c.isYahooJpDomain(a)) {\n            b.JSBNG__onsubmit = function(d) {\n                this.showBookmarkletDialog();\n                JSBNG__Event.kill(d);\n                return false;\n            }.bind(this);\n        }\n         else b.JSBNG__onsubmit = this.form_onsubmit;\n    ;\n    ;\n    },\n    setValid: function() {\n        this.enablePassword();\n        CSS.setClass(this.importer_widget, \"valid\");\n    },\n    setWaiting: function() {\n        CSS.setClass(this.importer_widget, \"waiting\");\n    },\n    setUnsupported: function() {\n        CSS.setClass(this.importer_widget, \"unsupported\");\n        this.disablePassword();\n        this.logAsync({\n            unsupported_login: this.login_str\n        });\n    },\n    setAPI: function() {\n        CSS.setClass(this.importer_widget, \"api\");\n        if (((this.ci_config.enable_yahoo_login_button && CIWebmailValidator.isYahooDomain(this.getLoginString())))) {\n            CSS.addClass(this.importer_widget, \"yahoo_api\");\n        }\n    ;\n    ;\n        this.disablePassword();\n    },\n    setDefault: function() {\n        CSS.setClass(this.importer_widget, \"default\");\n        this.enablePassword();\n    },\n    JSBNG__onKeyDown: function(b) {\n        if (this.deferred) {\n            JSBNG__clearTimeout(this.deferred);\n        }\n    ;\n    ;\n        var a = JSBNG__Event.getKeyCode(b);\n        if (((((!a || ((a == KEYS.RETURN)))) || ((a == KEYS.TAB))))) {\n            return;\n        }\n    ;\n    ;\n        this.deferred = this.updateDisplayOnKeyEvent.bind(this).defer(300);\n    },\n    updateDisplayOnKeyEvent: function() {\n        var a = this.getLoginString();\n        if (((CIWebmailValidator.isValidEmail(a) && this.getAPIInstance(a)))) {\n            this.setAPI();\n            return;\n        }\n    ;\n    ;\n        if (CSS.hasClass(this.importer_widget, \"unsupported\")) {\n            this.setDefault();\n            return;\n        }\n    ;\n    ;\n    },\n    canHidePassword: function() {\n        return !CSS.hasClass(this.importer_widget, \"default\");\n    },\n    disablePassword: function() {\n        var b = this.getPassword();\n        if (!this.canHidePassword()) {\n            return;\n        }\n    ;\n    ;\n        var a = DOM.JSBNG__find(this.getForm(), \".ci_password_row\");\n        CSS.hide(a);\n    },\n    enablePassword: function() {\n        var b = this.getPassword();\n        var a = DOM.JSBNG__find(this.getForm(), \".ci_password_row\");\n        CSS.show(a);\n    },\n    getWidget: function() {\n        return $(this.getId(\"widget\"));\n    },\n    getPassword: function() {\n        return $(this.getId(\"password\"));\n    },\n    setAPIData: function(a, b) {\n        this.enabledApis = a;\n        this.nameToImporter = b;\n        return this;\n    },\n    getAPIInstance: function(a) {\n        var c = CIWebmailValidator.getImporterName(a);\n        if (!c) {\n            return null;\n        }\n    ;\n    ;\n        var b = this.nameToImporter[c];\n        if (((b && this.enabledApis[b]))) {\n            return b;\n        }\n    ;\n    ;\n        return null;\n    }\n});\nfunction CIKddiWebmailInputController(b, c, d, a) {\n    this.parent.construct(this, b, c, d, a);\n    return this;\n};\n;\nClass.extend(CIKddiWebmailInputController, \"CIWebmailInputController\");\ncopy_properties(CIKddiWebmailInputController.prototype, {\n    validate: function() {\n        return true;\n    },\n    getLoginString: function() {\n        return \"foobar@placeholder.com\";\n    },\n    getAPIInstance: function() {\n        return 25;\n    }\n});\nfunction CINUXToDoWebmailInputController(b, c, d, a) {\n    this.parent.construct(this, b, c, d, a);\n    return this;\n};\n;\nClass.extend(CINUXToDoWebmailInputController, \"CIWebmailInputController\");\ncopy_properties(CINUXToDoWebmailInputController.prototype, {\n    disablePassword: function() {\n    \n    },\n    enablePassword: function() {\n    \n    }\n});\nfunction CIEMUWebmailInputController(b, c, d, a) {\n    this.parent.construct(this, b, c, d, a);\n    return this;\n};\n;\nClass.extend(CIEMUWebmailInputController, \"CIWebmailInputController\");\ncopy_properties(CIEMUWebmailInputController.prototype, {\n    updateDisplayOnKeyEvent: function() {\n        this.validate();\n    }\n});\nfunction ciImportBegin() {\n\n};\n;\nfunction ciImportEnd() {\n\n};\n;\nfunction ciImportResults(a) {\n    var b = {\n        scraped_data: a,\n        full_post: true\n    };\n    CIInputController.instance.parent.JSBNG__onSubmit(b);\n};\n;\nfunction ciImportError(a, b) {\n    ciImportResults(((((\"\\u003Cerror\\u003E\" + a)) + \"\\u003C/error\\u003E\")));\n};\n;\nfunction CIWlmInputController(c, d, e, a, b) {\n    this.parent.construct(this, c, d, e, a);\n    copy_properties(this, {\n        api_instance: b\n    });\n    return this;\n};\n;\nClass.extend(CIWlmInputController, \"CIInputController\");\ncopy_properties(CIWlmInputController.prototype, {\n    JSBNG__onSubmit: function() {\n        CIInputController.instance = this;\n        var a = this.getLoginString();\n        this.openAPIPopup(this.api_instance, a);\n        return false;\n    }\n});");
// 4527
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[7], o14,o22);
// undefined
o14 = null;
// 4629
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"LX4bR\",]);\n}\n;\n;\nvar ConnectDialog = {\n    newInstance: function(i, o, f, e, g, a, k, l, j, n, h) {\n        var b = new Dialog();\n        var m = new AsyncRequest().setURI(\"/ajax/profile/connect.php\").setData({\n            dialog: 1,\n            profile_id: i,\n            source: o,\n            pymk_score: k,\n            pymk_source: l,\n            pymk_page: j,\n            show_confirmation_optout: n,\n            precheck_confirmation_optout: h\n        }).setFinallyHandler(function() {\n            var p = b.getButtonElement(\"connect\");\n            if (p) {\n                p.JSBNG__focus();\n            }\n        ;\n        ;\n        });\n        for (var d in a) {\n            m.setContextData(d, a[d]);\n        ;\n        };\n    ;\n        b.setAsync(m);\n        var c = {\n            JSBNG__ondone_func: f,\n            JSBNG__ondone_data: e,\n            JSBNG__ondone_reload: g,\n            pymk_score: k,\n            pymk_source: l,\n            pymk_page: j\n        };\n        ConnectDialog.prepare(b, c);\n        return b;\n    },\n    prepare: function(a, b) {\n        copy_properties(a, ((b || {\n        })));\n        a.setCloseHandler(ConnectDialog.deleteInstance);\n        ConnectDialog.setInstance(a);\n    },\n    deleteInstance: function() {\n        delete ConnectDialog.instance;\n    },\n    setInstance: function(a) {\n        ConnectDialog.instance = a;\n    },\n    getInstance: function() {\n        return ConnectDialog.instance;\n    }\n};\nvar FriendBrowserCheckboxController = {\n    addTypeahead: function(b, a) {\n        b.subscribe(\"select\", this.JSBNG__onHubSelect.bind(this, b, a));\n    },\n    JSBNG__onHubSelect: function(f, e, JSBNG__event, c) {\n        if (!((((JSBNG__event == \"select\")) && c.selected))) {\n            return;\n        }\n    ;\n    ;\n        var d = this.buildNewCheckbox(e, c.selected.text, c.selected.uid);\n        var a = $(((\"checkboxes_\" + e)));\n        DOM.appendContent(a.firstChild, d);\n        var b = DOM.scry(f.getElement(), \"input[type=\\\"button\\\"]\");\n        if (((b && b[0]))) {\n            b[0].click();\n        }\n    ;\n    ;\n        this.getNew(true);\n    },\n    buildNewCheckbox: function(i, e, j) {\n        var a = ((((i + \"_ids_\")) + j));\n        var g = ((i + \"_ids[]\"));\n        var b = $N(\"input\", {\n            id: a,\n            type: \"checkbox\",\n            value: j,\n            JSBNG__name: g,\n            checked: true\n        });\n        JSBNG__Event.listen(b, \"click\", bind(this, \"getNew\", false));\n        var c = $N(\"td\", null, b);\n        CSS.addClass(c, \"vTop hLeft\");\n        var d = $N(\"label\", null, e);\n        var f = $N(\"td\", null, d);\n        CSS.addClass(f, \"vMid hLeft\");\n        var h = $N(\"tr\");\n        h.appendChild(c);\n        h.appendChild(f);\n        return h;\n    },\n    showMore: function() {\n        var b = ge(\"show_more_pager\");\n        if (!b) {\n            return false;\n        }\n    ;\n    ;\n        if (CSS.hasClass(b, \"async_saving\")) {\n            return false;\n        }\n    ;\n    ;\n        var d = this.numGetNewRequests;\n        var a = Form.serialize($(\"friend_browser_form\"));\n        a.show_more = true;\n        var c = new AsyncRequest().setURI(\"/ajax/growth/friend_browser/checkbox.php\").setData(a).setHandler(bind(this, function(e) {\n            this.showMoreHandler(e, d);\n        })).setStatusElement($(\"show_more_pager\")).send();\n    },\n    showMoreHandler: function(c, b) {\n        if (((b == this.numGetNewRequests))) {\n            var a = c.payload;\n            DOM.appendContent($(\"friendBrowserCheckboxContentGrid\"), HTML(a.results));\n            this.updatePagerAndExtraData(a.pager, a.extra_data);\n        }\n    ;\n    ;\n    },\n    numGetNewRequests: 0,\n    getNew: function(c) {\n        this.numGetNewRequests++;\n        var b = this.numGetNewRequests;\n        CSS.addClass($(\"friendBrowserCheckboxResultsId\"), \"friendBrowserCheckboxContentOnload\");\n        CSS.show($(\"friendBrowsingCheckboxContentLoadingIndicator\"));\n        var a = Form.serialize($(\"friend_browser_form\"));\n        a.used_typeahead = c;\n        new AsyncRequest().setURI(\"/ajax/growth/friend_browser/checkbox.php\").setData(a).setHandler(bind(this, function(d) {\n            this.getNewHandler(d, b);\n        })).send();\n    },\n    getNewHandler: function(c, b) {\n        if (((b == this.numGetNewRequests))) {\n            var a = c.payload;\n            DOM.setContent($(\"friendBrowserCheckboxContentGrid\"), HTML(a.results));\n            CSS.removeClass($(\"friendBrowserCheckboxResultsId\"), \"friendBrowserCheckboxContentOnload\");\n            CSS.hide($(\"friendBrowsingCheckboxContentLoadingIndicator\"));\n            this.updatePagerAndExtraData(a.pager, a.extra_data);\n        }\n    ;\n    ;\n    },\n    updatePagerAndExtraData: function(b, a) {\n        DOM.setContent($(\"friendBrowserCheckboxContentPager\"), HTML(b));\n        if (b) {\n            new OnVisible($(\"show_more_pager\"), bind(this, \"showMore\"), false, 1000);\n        }\n    ;\n    ;\n        DOM.replace($(\"extra_data\"), HTML(a));\n    },\n    makeFriendRequest: function(e, f, b, a, d) {\n        var c = Form.serialize($(\"friend_browser_form\"));\n        c.friend_id = f;\n        if (b) {\n            c.countdown_complete = b;\n        }\n    ;\n    ;\n        if (a) {\n            c.cancel = a;\n        }\n    ;\n    ;\n        if (d) {\n            c.dialog_success = d;\n        }\n    ;\n    ;\n        var g = new AsyncRequest();\n        g.setURI(\"/ajax/growth/friend_browser/friend.php\").setData(c).setRelativeTo(e).send();\n    },\n    queuedRequests: {\n    },\n    queueRequest: function(a, b) {\n        this.queuedRequests[b] = true;\n        JSBNG__setTimeout(bind(this, function() {\n            this.sendQueuedRequest(a, b);\n        }), 5000);\n    },\n    sendQueuedRequest: function(b, c) {\n        if (this.queuedRequests[c]) {\n            this.queuedRequests[c] = false;\n            var a = $(b);\n            var d = DOM.JSBNG__find(a, \"^.friendBrowserUnit\");\n            CSS.removeClass(d, \"friendBrowserRequesting\");\n            CSS.addClass(d, \"friendBrowserRequested\");\n            this.makeFriendRequest(a, c, true);\n        }\n    ;\n    ;\n    },\n    cancelQueuedRequest: function(a, b) {\n        this.queuedRequests[b] = false;\n        this.makeFriendRequest(a, b, false, true);\n    },\n    showConfirmationDialog: function(a, b, c, e, d) {\n        ConnectDialog.newInstance(b, c, function() {\n            FriendBrowserCheckboxController.makeFriendRequest(a, b, false, false, true);\n            return false;\n        }, null, false, null, 0, \"\", \"\", e, d).show();\n        return false;\n    }\n};");
// 4630
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[8], o15,o22);
// undefined
o15 = null;
// 4657
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"VVPTI\",]);\n}\n;\n;\nfunction EmuController(a, b) {\n    this.impression = b;\n    this.containerId = a;\n    DataStore.set($(a), \"emuController\", this);\n    return this;\n};\n;\ncopy_properties(EmuController, {\n    fromContainer: function(a) {\n        var b = ge(a);\n        if (!b) {\n            return null;\n        }\n    ;\n    ;\n        return DataStore.get(b, \"emuController\");\n    },\n    getEventClass: function(a) {\n        return ((\"emuEvent\" + String(a).trim()));\n    }\n});\ncopy_properties(EmuController.prototype, {\n    EVENT_HANDLER_PATH: \"/ajax/emu/end.php\",\n    CLICK: 1,\n    FAN: \"fad_fan\",\n    JSBNG__event: function(c, b, d, a) {\n        var e = {\n            eid: this.impression,\n            f: 0,\n            ui: this.containerId,\n            en: c,\n            a: 1\n        };\n        if (b) {\n            e.ed = JSON.stringify(b);\n        }\n    ;\n    ;\n        if (!a) {\n            var a = bagofholding;\n        }\n    ;\n    ;\n        var f = new AsyncRequest().setURI(this.EVENT_HANDLER_PATH).setData(e).setErrorHandler(a);\n        if (d) {\n            f.setHandler(d);\n        }\n    ;\n    ;\n        f.send();\n    },\n    redirect: function() {\n        var a = {\n            eid: this.impression,\n            f: 0,\n            ui: this.containerId,\n            en: this.CLICK,\n            a: 0,\n            sig: ((Math.floor(((Math.JSBNG__random() * 65535))) + 65536))\n        };\n        var b = new URI(this.EVENT_HANDLER_PATH);\n        b.setQueryData(a);\n        goURI(b);\n    }\n});\nvar ShortClickHandlers = {\n    EVENT_NAME_CAME_BACK: \"cameback\",\n    JSBNG__onclicked: function(a) {\n        if (this.JSBNG__onsite) {\n            return;\n        }\n    ;\n    ;\n        if (((((a.button !== 0)) || a.getModifiers().any))) {\n            return;\n        }\n    ;\n    ;\n        this.click_ts = (+new JSBNG__Date());\n        if (((this.listeners !== undefined))) {\n            for (var b in this.listeners) {\n                this.listeners[b].remove();\n            ;\n            };\n        }\n    ;\n    ;\n        this.listeners = {\n            JSBNG__focus: JSBNG__Event.listen(window, \"JSBNG__focus\", ShortClickHandlers.JSBNG__oncameback.bind(this))\n        };\n    },\n    JSBNG__oncameback: function(c) {\n        var b = (((+new JSBNG__Date()) - this.click_ts));\n        this.listeners[c.type].remove();\n        var a = {\n            click_ts: this.click_ts,\n            length: b,\n            trigger: c.type\n        };\n        this.sendData(ShortClickHandlers.EVENT_NAME_CAME_BACK, a);\n    }\n};\nfunction EmuTracker(a, c) {\n    this.base = EmuController.fromContainer(a);\n    !this.base;\n    this.JSBNG__onsite = c;\n    var b = DOM.scry($(a), ((\"a.\" + EmuController.getEventClass(EmuTracker.EVENT_CLICK))));\n    b.each(function(d) {\n        JSBNG__Event.listen(d, \"click\", ShortClickHandlers.JSBNG__onclicked.bind(this));\n    }.bind(this));\n    return this;\n};\n;\ncopy_properties(EmuTracker, {\n    EVENT_CLICK: 1\n});\ncopy_properties(EmuTracker.prototype, {\n    sendData: function(b, a) {\n        this.base.JSBNG__event(b, a);\n    }\n});\nfunction FutureProfileSideNav() {\n    this.parent.construct(this);\n};\n;\nClass.extend(FutureProfileSideNav, \"FutureSideNav\");\nFutureProfileSideNav.prototype = {\n    init: function() {\n        this.parent.init.apply(this, arguments);\n        this.ajaxPipe = true;\n        this.altKeyParam = \"v\";\n        this.sidecol = false;\n    },\n    _constructItem: function(a, b) {\n        return new FutureProfileSideNavItem(a, b);\n    },\n    _doPageTransition: function(a, b) {\n        if (((!this._profileChanged(b) && !this._scopeChanged(a)))) {\n            return this.parent._doPageTransition(a, b);\n        }\n    ;\n    ;\n    },\n    _profileChanged: function(c) {\n        var b = c.getQueryData();\n        var a = this.uri.getQueryData();\n        return ((((((b.id !== a.id)) || ((b.viewas !== a.viewas)))) || ((b.and !== a.and))));\n    },\n    _scopeChanged: function(a) {\n        return ((!this.selected || ((a.layoutType !== this.selected.layoutType))));\n    },\n    _getKey: function(a) {\n        return ((this.parent._getKey(a) || a[this.altKeyParam]));\n    }\n};\nfunction FutureProfileSideNavItem(a, b) {\n    this.parent.construct(this, a, b);\n    this.layoutType = a.layouttype;\n};\n;\nClass.extend(FutureProfileSideNavItem, \"FutureSideNavItem\");\nFriendRequestMessage = {\n    STATUS: \"FriendRequest/change\",\n    UNFRIEND: \"FriendRequest/unfriend\",\n    CANCEL: \"FriendRequest/cancel\",\n    CANCELLING: \"FriendRequest/cancelling\",\n    CANCEL_FAIL: \"FriendRequest/cancelFail\",\n    SENT: \"FriendRequest/sent\",\n    SENDING: \"FriendRequest/sending\",\n    SEND_FAIL: \"FriendRequest/sendFail\",\n    CONFIRM: \"FriendRequest/confirm\",\n    CONFIRMING: \"FriendRequest/confirming\",\n    CONFIRM_FAIL: \"FriendRequest/confirmFail\"\n};\nfunction FriendStatus(a, c, b) {\n    this.id = a;\n    this.update(c, b);\n};\n;\nFriendStatus.prototype = {\n    update: function(b, a) {\n        ((b && (this.JSBNG__status = b)));\n        if (a) {\n            this.lists = $A(a).map(String);\n            this._informListChange();\n        }\n    ;\n    ;\n    },\n    isComplete: function() {\n        return !!this.lists;\n    },\n    addToList: function(a) {\n        if (((this.lists && !this.lists.contains(a)))) {\n            this.lists.push(a);\n        }\n    ;\n    ;\n        this._informListChange();\n    },\n    removeFromList: function(b) {\n        if (this.lists) {\n            var a = this.lists.indexOf(b);\n            ((((a !== -1)) && this.lists.splice(a, 1)));\n        }\n    ;\n    ;\n        this._informListChange();\n    },\n    updateList: function(b, a) {\n        ((a ? this.addToList(b) : this.removeFromList(b)));\n    },\n    _informListChange: function() {\n        Arbiter.inform(\"FriendListMembershipChange\", {\n            uid: this.id,\n            lists: this.lists\n        });\n    }\n};\ncopy_properties(FriendStatus, {\n    ARE_FRIENDS: 1,\n    INCOMING_REQUEST: 2,\n    OUTGOING_REQUEST: 3,\n    CAN_REQUEST: 4\n});\n(function() {\n    var a = {\n    };\n    var b = {\n    };\n    function c(f, d, e) {\n        if (!a[e.uid]) {\n            a[e.uid] = new FriendStatus(e.uid, f);\n        }\n         else a[e.uid].update(f);\n    ;\n    ;\n        Arbiter.inform(FriendRequestMessage.STATUS, {\n            uid: e.uid,\n            JSBNG__status: f\n        });\n    };\n;\n    JSBNG__onloadRegister(function() {\n        Arbiter.subscribe([FriendRequestMessage.CANCEL,FriendRequestMessage.UNFRIEND,FriendRequestMessage.SEND_FAIL,], c.curry(FriendStatus.CAN_REQUEST));\n        Arbiter.subscribe([FriendRequestMessage.CONFIRM_FAIL,], c.curry(FriendStatus.INCOMING_REQUEST));\n        Arbiter.subscribe([FriendRequestMessage.CANCEL_FAIL,FriendRequestMessage.SENT,FriendRequestMessage.SENDING,], c.curry(FriendStatus.OUTGOING_REQUEST));\n        Arbiter.subscribe([FriendRequestMessage.CONFIRM,FriendRequestMessage.CONFIRMING,], c.curry(FriendStatus.ARE_FRIENDS));\n    });\n    copy_properties(FriendStatus, {\n        CLOSE_FRIENDS: null,\n        ACQUAINTANCES: null,\n        getFriend: function(d, e) {\n            if (((a[d] && a[d].isComplete()))) {\n                e(a[d]);\n            }\n             else if (b[d]) {\n                b[d].push(e);\n            }\n             else {\n                b[d] = [e,];\n                new AsyncRequest().setURI(\"/ajax/friends/status.php\").setData({\n                    friend: d\n                }).setHandler(function(g) {\n                    var f = g.getPayload();\n                    FriendStatus.initFriend(d, f.JSBNG__status, f.lists);\n                }).send();\n            }\n            \n        ;\n        ;\n        },\n        initFriend: function(e, g, f) {\n            var d = ((a[e] || new FriendStatus(e)));\n            d.update(((d.JSBNG__status || g)), ((d.lists || f)));\n            a[e] = d;\n            ((b[e] && b[e].forEach(function(h) {\n                h(d);\n            })));\n            b[e] = null;\n        },\n        setSpecialLists: function(d) {\n            FriendStatus.CLOSE_FRIENDS = ((d.close + \"\"));\n            FriendStatus.ACQUAINTANCES = ((d.acq + \"\"));\n        }\n    });\n})();\nvar DynamicFriendListEducation = (function() {\n    var h;\n    var e;\n    var d;\n    var c;\n    var a;\n    var i;\n    var g = function() {\n        ((d && d.hide()));\n        ((c && c.hide()));\n    };\n    var f = function(j) {\n        e.remove(j);\n        g();\n        a({\n            accept_tag_education: true\n        });\n    };\n    var b = function() {\n        g();\n        a({\n            nux_cancel: true\n        });\n    };\n    return {\n        init: function(k, j) {\n            h = k;\n            e = $A(j).map(String);\n            PageTransitions.registerHandler(function() {\n                g();\n                h = false;\n                a = undefined;\n                e = [];\n            });\n        },\n        showDialog: function(k, l, j) {\n            if (((h && e.contains(k)))) {\n                g();\n                Arbiter.inform(\"DynamicFriendListEducation/dialogOpen\", {\n                    uid: l,\n                    flid: k\n                });\n                a = j;\n                d = new Dialog().setAsync(new AsyncRequest(\"/ajax/friends/lists/smart_list_education.php\").setMethod(\"GET\").setData({\n                    flid: k,\n                    uid: l\n                }).setReadOnly(true)).setHandler(f.bind(this, k)).setCloseHandler(function() {\n                    Arbiter.inform(\"DynamicFriendListEducation/dialogClosed\", {\n                        uid: l,\n                        flid: k\n                    });\n                }).setCancelHandler(function() {\n                    Arbiter.inform(\"DynamicFriendListEducation/dialogCancel\", {\n                        uid: l,\n                        flid: k\n                    });\n                }).show();\n            }\n             else j();\n        ;\n        ;\n        },\n        showContextualDialog: function(k, m, l, j) {\n            if (((h && e.contains(k)))) {\n                g();\n                i = l;\n                a = j;\n                new AsyncRequest(\"/ajax/friends/lists/smart_list_contextual_education.php\").setMethod(\"GET\").setData({\n                    flid: k,\n                    uid: m\n                }).setReadOnly(true).send();\n            }\n             else j();\n        ;\n        ;\n        },\n        setContextualDialog: function(l, j, k, m) {\n            c = l;\n            c.setContext(i);\n            c.show();\n            JSBNG__Event.listen(j, \"click\", f.bind(this, m));\n            JSBNG__Event.listen(k, \"click\", b);\n        }\n    };\n})();\nvar FriendEditLists = (function() {\n    var a = 7;\n    var c = {\n    };\n    var m = \"/ajax/profile/removefriendconfirm.php\";\n    var b = \"/friends/ajax/remove_friend.php?type=friend&fbx=1\";\n    var h;\n    function j(p, q, o) {\n        var r = c[p.id];\n        var n = function(u) {\n            var t = {\n                action: ((o ? \"add_list\" : \"del_list\")),\n                to_friend: r.id,\n                friendlists: [q,],\n                source: h\n            };\n            if (u) {\n                copy_properties(t, u);\n            }\n        ;\n        ;\n            r.updateList(q, o);\n            var v;\n            if (((o && ((q == FriendStatus.CLOSE_FRIENDS))))) {\n                v = e(p, FriendStatus.ACQUAINTANCES);\n                if (Menu.isItemChecked(v)) {\n                    Menu.toggleItem(v);\n                    j(p, FriendStatus.ACQUAINTANCES, false);\n                }\n            ;\n            ;\n            }\n             else if (((o && ((q == FriendStatus.ACQUAINTANCES))))) {\n                v = e(p, FriendStatus.CLOSE_FRIENDS);\n                if (Menu.isItemChecked(v)) {\n                    Menu.toggleItem(v);\n                    j(p, FriendStatus.CLOSE_FRIENDS, false);\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n            var w = {\n                flid: q,\n                uid: r.id\n            };\n            var s = ((o ? \"FriendListHovercard/add\" : \"FriendListHovercard/remove\"));\n            Arbiter.inform(s, w);\n            new AsyncRequest().setURI(\"/ajax/add_friend/action.php\").setData(t).send();\n        };\n        if (o) {\n            DynamicFriendListEducation.showDialog(q, r.id, n);\n        }\n         else n();\n    ;\n    ;\n    };\n;\n    function d(o) {\n        var n = DOM.scry(o, \"input\")[0];\n        return ((n && n.value));\n    };\n;\n    function f(n, p, q) {\n        var o = {\n            uid: p.id\n        };\n        new AsyncRequest().setURI(b).setMethod(\"POST\").setData({\n            friend: p.id\n        }).setHandler(Arbiter.inform.bind(Arbiter, FriendRequestMessage.CANCEL, o)).setErrorHandler(Arbiter.inform.bind(Arbiter, FriendRequestMessage.CANCEL_FAIL, o)).setStatusElement(q).send();\n    };\n;\n    function e(n, o) {\n        var q = Menu.getItems(n);\n        for (var p = 0; ((p < q.length)); p++) {\n            if (((d(q[p]) == o))) {\n                return q[p];\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    };\n;\n    function k(n, o) {\n        var p = Menu.getItems(n);\n        p.forEach(function(s) {\n            var r = d(s);\n            var q = o.lists.contains(r);\n            if (((Menu.isItemChecked(s) !== q))) {\n                Menu.toggleItem(s);\n            }\n        ;\n        ;\n        });\n    };\n;\n    function i(o) {\n        var p = Menu.getItems(o);\n        var n = [];\n        var s = [];\n        var u = 0;\n        var t = 0;\n        p.forEach(function(x) {\n            if (CSS.hasClass(x, \"neverHide\")) {\n                CSS.removeClass(x, \"underShowMore\");\n                u++;\n            }\n             else if (Menu.isItemChecked(x)) {\n                n.push(x);\n            }\n             else if (((CSS.hasClass(x, \"neverShow\") || CSS.hasClass(x, \"FriendListCreateTrigger\")))) {\n                CSS.addClass(x, \"underShowMore\");\n                t++;\n            }\n             else s.push(x);\n            \n            \n        ;\n        ;\n        });\n        var w = ((a - u));\n        var r = n.concat(s);\n        var q = t;\n        r.forEach(function(x) {\n            if (CSS.hasClass(x, \"ShowMoreItem\")) {\n                w--;\n                return;\n            }\n        ;\n        ;\n            if (w) {\n                CSS.removeClass(x, \"underShowMore\");\n                w--;\n            }\n             else {\n                CSS.addClass(x, \"underShowMore\");\n                q = true;\n            }\n        ;\n        ;\n        });\n        CSS.conditionClass(o, \"hasMoreFriendListItems\", q);\n        var v = DOM.scry(o, \".FriendListMenuShowMore\");\n        v.forEach(function(x) {\n            CSS.removeClass(x, \"FriendListMenuShowMore\");\n        });\n    };\n;\n    function l(o, p) {\n        var q = DOM.scry(o, \".FriendListUnfriend\")[0];\n        var n = DOM.scry(o, \".FriendListCancel\")[0];\n        if (n) {\n            CSS.conditionShow(n, ((p.JSBNG__status == FriendStatus.OUTGOING_REQUEST)));\n        }\n    ;\n    ;\n        if (q) {\n            CSS.conditionShow(q, ((p.JSBNG__status == FriendStatus.ARE_FRIENDS)));\n            DOM.JSBNG__find(q, \"a\").href = URI(m).addQueryData({\n                uid: p.id\n            });\n        }\n    ;\n    ;\n    };\n;\n    var g = function() {\n        g = bagofholding;\n        Arbiter.subscribe(FriendRequestMessage.STATUS, function(r, q) {\n            for (var p in c) {\n                var n = ge(p);\n                var o = c[p];\n                if (((((n && o)) && ((o.id == q.uid))))) {\n                    k(n, o);\n                    l(n, o);\n                    i(n);\n                }\n            ;\n            ;\n            };\n        ;\n        });\n        Menu.subscribe(\"select\", function(n, o) {\n            if (((CSS.hasClass(o.item, \"ShowMoreItem\") && CSS.hasClass(o.menu, \"FriendListMenu\")))) {\n                CSS.addClass(o.menu, \"FriendListMenuShowMore\");\n                var p = ScrollableArea.getInstance(o.item);\n                ((p && p.adjustGripper().showScrollbar(false)));\n            }\n        ;\n        ;\n        });\n    };\n    return {\n        init: function(n, o, p) {\n            n = $(n);\n            h = p;\n            g();\n            if (!c[n.id]) {\n                Menu.subscribe(\"select\", function(q, r) {\n                    if (DOM.contains(n, r.item)) {\n                        if (Parent.byClass(r.item, \"FriendListItem\")) {\n                            Menu.toggleItem(r.item);\n                            var s = d(r.item);\n                            j(n, s, Menu.isItemChecked(r.item));\n                        }\n                         else if (Parent.byClass(r.item, \"FriendListCancel\")) {\n                            f(n, c[n.id], r.item);\n                        }\n                         else if (Parent.byClass(r.item, \"FriendListUnfriend\")) {\n                            FriendListFlyoutController.hide(false);\n                        }\n                        \n                        \n                    ;\n                    }\n                ;\n                ;\n                });\n            }\n        ;\n        ;\n            CSS.addClass(n, \"async_saving\");\n            FriendStatus.getFriend(o, function(q) {\n                k(n, q);\n                l(n, q);\n                c[n.id] = q;\n                i(n);\n                CSS.removeClass(n, \"async_saving\");\n            }.bind(this));\n        }\n    };\n})();\nvar FriendListFlyoutController = (function() {\n    var c;\n    var d;\n    var m;\n    var a;\n    var n;\n    var u;\n    var k;\n    var r;\n    var e;\n    function g(w) {\n        if (DOM.isNode(w, [\"body\",\"html\",])) {\n            return JSBNG__document.body;\n        }\n    ;\n    ;\n        while ((((w = w.parentNode) && ((w !== JSBNG__document.body))))) {\n            if (((CSS.getStyle(w, \"position\") !== \"static\"))) {\n                return w;\n            }\n        ;\n        ;\n        };\n    ;\n        return JSBNG__document.body;\n    };\n;\n    function l(w) {\n        while (((w && ((w !== JSBNG__document.body))))) {\n            if (((CSS.getStyle(w, \"position\") === \"fixed\"))) {\n                return true;\n            }\n        ;\n        ;\n            w = g(w);\n        };\n    ;\n        return false;\n    };\n;\n    function p() {\n        JSBNG__clearTimeout(k);\n    };\n;\n    function o() {\n        if (a) {\n            CSS.removeClass(a, \"selected\");\n            CSS.removeClass(a, \"uiButtonHover\");\n            if (DataStore.get(a, \"flfcloselistener\")) {\n                var w = a;\n                DataStore.set(a, \"flfcloselistenertimeout\", f.curry(w).defer(1500));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        d = false;\n        b();\n        a = null;\n    };\n;\n    function h(w) {\n        if (((DOM.isNode(w, \"label\") && CSS.hasClass(w, \"uiButton\")))) {\n            w = Button.getInputElement(w);\n        }\n    ;\n    ;\n        return DataStore.get(w, \"profileid\");\n    };\n;\n    function b() {\n        ((n && n.remove()));\n        n = null;\n        ((r && Arbiter.unsubscribe(r)));\n        r = null;\n        ((k && JSBNG__clearTimeout(k)));\n        k = null;\n    };\n;\n    function t(x) {\n        if (((!c || d))) {\n            return;\n        }\n    ;\n    ;\n        c.setContext(x);\n        var y = h(x);\n        var w = DataStore.get(x, \"flloc\");\n        FriendEditLists.init(m, y, w);\n        CSS.addClass(x, \"selected\");\n        CSS.addClass(x, \"uiButtonHover\");\n        c.setFixed(l(x)).show();\n        a = x;\n        d = true;\n        var z = DOM.scry(m, \"div.uiScrollableArea\")[0];\n        ((z && ScrollableArea.getInstance(z).adjustGripper().showScrollbar()));\n        b();\n        n = JSBNG__Event.listen(x, \"mouseleave\", i);\n        r = Arbiter.subscribe(\"Overlay/show\", j);\n        if (DataStore.get(x, \"flfcloselistener\")) {\n            JSBNG__clearTimeout(DataStore.remove(x, \"flfcloselistenertimeout\"));\n        }\n    ;\n    ;\n        FriendStatus.getFriend(y, function(zb) {\n            var za = DOM.scry(c.getContent(), \".FlyoutFriendListMenuNUX\")[0];\n            if (!za) {\n                return;\n            }\n        ;\n        ;\n            if (((zb.JSBNG__status == FriendStatus.OUTGOING_REQUEST))) {\n                CSS.show(za);\n                AsyncRequest.bootstrap(\"/ajax/friends/lists/nux_flyout.php\", null, true);\n            }\n             else CSS.hide(za);\n        ;\n        ;\n        });\n    };\n;\n    function s(w) {\n        a = w;\n        u = t.curry(w).defer(100);\n        n = JSBNG__Event.listen(w, \"mouseleave\", function() {\n            JSBNG__clearTimeout(u);\n            a = null;\n            ((n && n.remove()));\n        });\n    };\n;\n    function i() {\n        k = j.defer(150);\n    };\n;\n    function v() {\n        var x = Dialog.getCurrent();\n        var w = ((x && x.getBody()));\n        return !!((w && DOM.scry(w, \".friendListDialogTourCarousel\")[0]));\n    };\n;\n    function j() {\n        if (((e || v()))) {\n            return;\n        }\n    ;\n    ;\n        ((((ua.ie() < 8)) && JSBNG__document.documentElement.JSBNG__focus()));\n        ((c && c.hide()));\n    };\n;\n    function q(JSBNG__event) {\n        var w = Parent.byTag(JSBNG__event.getTarget(), \"a\");\n        if (((w && CSS.hasClass(w, \"FriendListActionItem\")))) {\n            i();\n        }\n    ;\n    ;\n    };\n;\n    function f(x) {\n        var w = DataStore.remove(x, \"flfcloselistener\");\n        ((w && w()));\n    };\n;\n    return {\n        init: function() {\n            FriendListFlyoutController.init = bagofholding;\n            AsyncRequest.bootstrap(\"/ajax/friends/lists/flyout.php\");\n            JSBNG__Event.listen(JSBNG__document.documentElement, \"mouseover\", function(w) {\n                var x = Parent.byClass(w.getTarget(), \"enableFriendListFlyout\");\n                if (x) {\n                    if (((a === x))) {\n                        JSBNG__clearTimeout(k);\n                    }\n                     else {\n                        ((d && j()));\n                        s(x);\n                    }\n                ;\n                }\n            ;\n            ;\n            });\n            Arbiter.subscribe(\"DynamicFriendListEducation/dialogOpen\", function() {\n                e = true;\n            });\n            Arbiter.subscribe(\"DynamicFriendListEducation/dialogClosed\", function() {\n                e = false;\n                i();\n            });\n        },\n        setDialog: function(w, x) {\n            c = w;\n            m = x;\n            c.subscribe(\"mouseenter\", p);\n            c.subscribe(\"mouseleave\", i);\n            c.subscribe(\"hide\", o);\n            JSBNG__Event.listen(m, \"click\", q);\n        },\n        show: function(w) {\n            t(w);\n        },\n        hide: function(w) {\n            ((((w === false)) ? j() : i()));\n        },\n        setCloseListener: function(x, w) {\n            DataStore.set(x, \"flfcloselistener\", w);\n            if (((a != x))) {\n                DataStore.set(x, \"flfcloselistenertimeout\", f.curry(x).defer(1500));\n            }\n        ;\n        ;\n        }\n    };\n})();\nvar AddFriendButton = {\n    ERROR_ALREADY_ADDED: 1431005,\n    init: function(f, l, j, g, m, o, h, n, i, k) {\n        function b(p, r) {\n            var q = new URI(f.getAttribute(\"ajaxify\"));\n            new AsyncRequest().setURI(i).setData({\n                to_friend: m,\n                action: p,\n                how_found: h,\n                ref_param: n,\n                outgoing_id: l.id,\n                xids: q.getQueryData().xids,\n                logging_location: k\n            }).setErrorHandler(r).setRelativeTo(l).send();\n        };\n    ;\n        function e(p) {\n            ((f && CSS.hide(f)));\n            ((l && CSS.hide(l)));\n            ((j && CSS.hide(j)));\n            ((g && CSS.hide(g)));\n            if (p) {\n                CSS.show(p);\n            }\n        ;\n        ;\n        };\n    ;\n        function c(p) {\n            if (CSS.hasClass(p, \"enableFriendListFlyout\")) {\n                FriendListFlyoutController.show(p);\n            }\n             else FriendListFlyoutController.hide();\n        ;\n        ;\n        };\n    ;\n        var d = Arbiter.subscribe(FriendRequestMessage.STATUS, function(q, p) {\n            if (((p.uid != m))) {\n                return;\n            }\n        ;\n        ;\n            switch (p.JSBNG__status) {\n              case FriendStatus.ARE_FRIENDS:\n                return e(g);\n              case FriendStatus.INCOMING_REQUEST:\n                return e(j);\n              case FriendStatus.OUTGOING_REQUEST:\n                return e(l);\n              case FriendStatus.CAN_REQUEST:\n                return e(f);\n            };\n        ;\n        });\n        var a;\n        if (o) {\n            a = Arbiter.subscribe(FriendRequestMessage.CONFIRM, function(p, q) {\n                ((((q.uid == m)) && goURI(o)));\n            });\n        }\n    ;\n    ;\n        ((f && JSBNG__Event.listen(f, \"click\", function() {\n            Arbiter.inform(FriendRequestMessage.SENDING, {\n                uid: m\n            });\n            c(l);\n            b(\"add_friend\", function(q) {\n                var p = ((((q.error == AddFriendButton.ERROR_ALREADY_ADDED)) ? FriendRequestMessage.SENT : FriendRequestMessage.SEND_FAIL));\n                Arbiter.inform(p, {\n                    uid: m\n                });\n                FriendListFlyoutController.hide();\n                AsyncResponse.defaultErrorHandler(q);\n            });\n        })));\n        PageTransitions.registerHandler(function() {\n            Arbiter.unsubscribe(d);\n            ((a && Arbiter.unsubscribe(a)));\n        });\n    }\n};\nvar FriendButtonIcon = {\n    init: function(b, e, f) {\n        var d = DOM.JSBNG__find(e, \".defaultIcon\");\n        var c = DOM.JSBNG__find(e, \".closeIcon\");\n        var a = DOM.JSBNG__find(e, \".acqIcon\");\n        Arbiter.subscribe(\"FriendListMembershipChange\", function(g, h) {\n            if (((h.uid == f))) {\n                var j = h.lists.contains(FriendStatus.CLOSE_FRIENDS);\n                var i = h.lists.contains(FriendStatus.ACQUAINTANCES);\n                if (((j && !i))) {\n                    Button.setIcon(b, c);\n                }\n                 else if (((i && !j))) {\n                    Button.setIcon(b, a);\n                }\n                 else Button.setIcon(b, d);\n                \n            ;\n            ;\n            }\n        ;\n        ;\n        });\n    }\n};\nvar ComposerAudienceSelector = function() {\n    var b = {\n    };\n    var a = {\n    };\n    JSBNG__onloadRegister(function() {\n        Selector.subscribe(\"select\", function(c, d) {\n            if (!CSS.hasClass(d.selector, \"composerAudienceSelector\")) {\n                return;\n            }\n        ;\n        ;\n            if (!CSS.hasClass(d.option, \"groupOption\")) {\n                Arbiter.inform(\"ComposerAudienceSelector/nongroup\");\n            }\n        ;\n        ;\n            if (!CSS.hasClass(d.option, \"specialOption\")) {\n                return;\n            }\n        ;\n        ;\n            var e = DOM.JSBNG__find(d.option, \"a\").getAttribute(\"data-type\");\n            if (((e == \"group\"))) {\n                Arbiter.inform(\"ComposerAudienceSelector/group\", {\n                    group: Selector.getOptionValue(d.option)\n                });\n            }\n        ;\n        ;\n        });\n        Arbiter.subscribe(\"CustomPrivacyOption/update\", function(c, d) {\n            if (CSS.hasClass(d.selector, \"composerAudienceSelector\")) {\n                Arbiter.inform(\"ComposerAudienceSelector/nongroup\");\n            }\n        ;\n        ;\n        });\n        Selector.subscribe(\"close\", function(c, d) {\n            if (!CSS.hasClass(d.selector, \"composerAudienceSelector\")) {\n                return;\n            }\n        ;\n        ;\n            var e = Selector.getSelectedOptions(d.selector)[0];\n            CSS.conditionClass(d.selector, \"showSecondaryGroups\", CSS.hasClass(e, \"secondaryGroup\"));\n        });\n    });\n    return {\n        syncSelector: function(e) {\n            ((b[e] && Selector.setSelected(e, b[e])));\n            if (((((b[e] == PrivacyBaseValue.CUSTOM)) && a[e]))) {\n                var c = Selector.getOption(e, ((PrivacyBaseValue.CUSTOM + \"\")));\n                var d = a[e];\n                (function() {\n                    CustomPrivacyOption.update(c.id, d.data, d.audience, d.tooltip);\n                }).defer();\n            }\n        ;\n        ;\n        }\n    };\n}();\nfunction CustomPrivacyOption() {\n\n};\n;\ncopy_properties(CustomPrivacyOption, {\n    _instances: {\n    },\n    update: function(c, b, a, e) {\n        var d = CustomPrivacyOption._instances[c];\n        d._update(b, a)._updateSelector(a, e);\n        Arbiter.inform(\"Form/change\", {\n            node: d._container\n        });\n    },\n    getData: function(a) {\n        return CustomPrivacyOption._instances[a]._privacyData;\n    }\n});\nCustomPrivacyOption.prototype = {\n    init: function(d, c, b, e, a) {\n        (function() {\n            var g = ge(d);\n            if (!g) {\n                return;\n            }\n        ;\n        ;\n            CustomPrivacyOption._instances[d] = this;\n            this._selector = Parent.byClass(g, \"uiSelector\");\n            this._container = DOM.JSBNG__find(g, \".customPrivacyInputs\");\n            this._id = c;\n            this._privacyData = {\n            };\n            var f = Form.serialize(this._container);\n            if (f.audience) {\n                this._privacyData = f.audience[c];\n            }\n        ;\n        ;\n            JSBNG__Event.listen(g, \"click\", function(h) {\n                var i = new AsyncRequest(\"/ajax/privacy/custom_dialog/\").setData({\n                    option_id: d,\n                    id: this._id,\n                    privacy_data: this._privacyData,\n                    explain_tags: b,\n                    autosave: a\n                });\n                new Dialog().setAsync(i).setModal(true).show();\n            }.bind(this));\n            Selector.listen(this._selector, \"select\", function(h) {\n                if (((h.option._id != this._id))) {\n                    this._clear();\n                }\n            ;\n            ;\n            }.bind(this));\n            if (e) {\n                Selector.setButtonTooltip(this._selector, e);\n            }\n        ;\n        ;\n        }).bind(this).defer();\n    },\n    _updateSelector: function(c, b) {\n        var a = ((Selector.getOption(this._selector, c) || Selector.getOption(this._selector, ((PrivacyBaseValue.CUSTOM + \"\")))));\n        Arbiter.inform(\"CustomPrivacyOption/update\", {\n            selector: this._selector,\n            option: a,\n            tooltip: b\n        });\n        return this;\n    },\n    _clear: function() {\n        this._privacyData = {\n        };\n        DOM.empty(this._container);\n    },\n    _update: function(b, a) {\n        this._clear();\n        this._privacyData = copy_properties({\n        }, b);\n        var c = ((((a == PrivacyBaseValue.CUSTOM)) || !Selector.getOption(this._selector, a)));\n        if (c) {\n            var d = this._selector.getAttribute(\"data-name\");\n            if (d) {\n                d = d.slice(0, -\"[value]\".length);\n                var e = {\n                };\n                e[d] = b;\n                Form.createHiddenInputs(e, this._container, null, true);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return this;\n    }\n};\nvar FriendListPrivacyOptions = (function() {\n    var e = false;\n    var d = false;\n    var a = null;\n    var c = {\n    };\n    var b = function(g) {\n        if (is_empty(c)) {\n            PageTransitions.registerHandler(function() {\n                c = {\n                };\n                e = false;\n                d = false;\n            });\n        }\n    ;\n    ;\n        var h = Parent.byClass(g, \"audienceSelector\");\n        if (h) {\n            var f = h.getAttribute(\"data-name\");\n            if (!c[f]) {\n                c[f] = h;\n                Selector.listen(h, \"select\", function(i) {\n                    var m = i.option;\n                    var l = DOM.JSBNG__find(m, \"a.itemAnchor\");\n                    var k = l.getAttribute(\"data-flid\");\n                    if (!k) {\n                        return;\n                    }\n                ;\n                ;\n                    var j = l.getAttribute(\"data-dynamic\");\n                    if (((j && e))) {\n                        FriendListPrivacyOptions.showSmartListNux(m);\n                    }\n                     else if (((!j && d))) {\n                        FriendListPrivacyOptions.showDumbListNux([k,]);\n                    }\n                    \n                ;\n                ;\n                });\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n    return {\n        listenForSmartListNux: function(g) {\n            var f = ge(g);\n            if (!f) {\n                return;\n            }\n        ;\n        ;\n            b(f);\n            e = true;\n        },\n        listenForDumbListNux: function(g) {\n            var f = ge(g);\n            if (!f) {\n                return;\n            }\n        ;\n        ;\n            b(f);\n            d = true;\n        },\n        showSmartListNux: function(f) {\n            new AsyncRequest(\"/ajax/friends/lists/smart_list_publish_nux.php\").setData({\n                option_id: f.id\n            }).send();\n            e = false;\n        },\n        setContextualDialog: function(f, g) {\n            var h = Parent.byClass(g, \"audienceSelector\");\n            if (h) {\n                f.setContext(h);\n                f.show();\n                var i = Arbiter.subscribe(\"composer/publish\", function() {\n                    f.hide();\n                });\n                f.subscribe(\"hide\", function() {\n                    Arbiter.unsubscribe(i);\n                });\n            }\n        ;\n        ;\n        },\n        showDumbListNux: function(f) {\n            new AsyncRequest(\"/ajax/friends/lists/dumb_list_publish_nux.php\").setData({\n                flids: f\n            }).send();\n            d = false;\n        },\n        showBothListsNux: function(g, f) {\n            a = g;\n            FriendListPrivacyOptions.showDumbListNux(f);\n        },\n        setDialog: function() {\n            if (!a) {\n                return;\n            }\n        ;\n        ;\n            var f = Dialog.getCurrent();\n            if (f) {\n                f.setCloseHandler(function() {\n                    FriendListPrivacyOptions.showSmartListNux(a);\n                    a = null;\n                });\n            }\n        ;\n        ;\n        }\n    };\n})();\nfunction FriendsPrivacyOption() {\n\n};\n;\nFriendsPrivacyOption.prototype = {\n    init: function(a, b) {\n        this._selector = Parent.byClass(a, \"composerAudienceSelector\");\n        if (!this._selector) {\n            return;\n        }\n    ;\n    ;\n        this._elem = a;\n        this._hasRestricted = b;\n        this._plusLabel = DOM.JSBNG__find(a, \".plusLabel\");\n        this._tags = [];\n        this._recalculateTooltipAndLabel();\n        this._updateSelector();\n        Arbiter.subscribe(\"Composer/changedtags\", function(c, d) {\n            this._tags = d.withTags.map(function(g) {\n                return g.getText();\n            });\n            var f = d.withTags.map(function(g) {\n                return g.getValue();\n            });\n            for (var e in d.mention) {\n                if (((d.mention[e].type == \"user\"))) {\n                    this._tags.push(d.mention[e].text);\n                    f.push(d.mention[e].uid);\n                }\n            ;\n            ;\n            };\n        ;\n            if (((this._recalculateTooltipAndLabel() && this._updateSelector()))) {\n                Arbiter.inform(\"FriendsPrivacyOption/changed\", f);\n            }\n        ;\n        ;\n        }.bind(this));\n        Selector.listen(this._selector, \"change\", this._updateSelector.bind(this));\n    },\n    _recalculateTooltipAndLabel: function() {\n        var a = this._tags.length, b = this._tooltip;\n        if (((a > 2))) {\n            this._tooltip = ((this._hasRestricted ? _tx(\"Your friends and friends of anyone tagged; Except: Restricted\") : _tx(\"Your friends and friends of anyone tagged\")));\n        }\n         else if (((a == 2))) {\n            if (this._hasRestricted) {\n                this._tooltip = _tx(\"Your friends, {user}'s friends and {user2}'s friends; Except: Restricted \", {\n                    user: this._tags[0],\n                    user2: this._tags[1]\n                });\n            }\n             else this._tooltip = _tx(\"Your friends, {user}'s friends and {user2}'s friends\", {\n                user: this._tags[0],\n                user2: this._tags[1]\n            });\n        ;\n        ;\n        }\n         else if (((a == 1))) {\n            if (this._hasRestricted) {\n                this._tooltip = _tx(\"Your friends and {user}'s friends; Except: Restricted\", {\n                    user: this._tags[0]\n                });\n            }\n             else this._tooltip = _tx(\"Your friends and {user}'s friends\", {\n                user: this._tags[0]\n            });\n        ;\n        ;\n        }\n         else this._tooltip = ((this._hasRestricted ? _tx(\"Your friends; Except: Restricted\") : _tx(\"Your friends\")));\n        \n        \n    ;\n    ;\n        CSS.conditionShow(this._plusLabel, this._tags.length);\n        return ((b != this._tooltip));\n    },\n    _updateSelector: function() {\n        if (!Selector.isOptionSelected(this._elem)) {\n            return false;\n        }\n    ;\n    ;\n        var a = this._elem.getAttribute(\"data-label\");\n        if (this._tags.length) {\n            a += \" (+)\";\n        }\n    ;\n    ;\n        Selector.setButtonLabel(this._selector, a);\n        Selector.setButtonTooltip(this._selector, this._tooltip);\n        return true;\n    }\n};\nfunction MetaComposerEdDialog() {\n\n};\n;\nMetaComposerEdDialog.prototype = {\n    init: function(a, b) {\n        MetaComposerEdDialog.timesEnabled = b;\n        if (MetaComposerEdDialog.singleton) {\n            a.destroy();\n            return;\n        }\n    ;\n    ;\n        MetaComposerEdDialog.singleton = this;\n        this._dialog = a;\n        Arbiter.subscribe(\"FriendsPrivacyOption/changed\", function(c, d) {\n            if (!this._updateContext()) {\n                return;\n            }\n        ;\n        ;\n            ((this._async && this._async.abort()));\n            this._async = new AsyncRequest(\"/ajax/composer/audience_education\");\n            this._async.setData({\n                ids: d,\n                num: MetaComposerEdDialog.timesEnabled\n            }).setHandler(this._handler.bind(this)).send();\n        }.bind(this));\n        Selector.subscribe(\"open\", this._killAnim.bind(this));\n    },\n    _updateContext: function() {\n        var a = DOM.scry(JSBNG__document.body, \"div.composerAudienceWrapper\")[0];\n        var b = Vector2.getElementPosition(a);\n        if (((((a && ((b.x > 0)))) && ((b.y > 0))))) {\n            this._dialog.setContext(a);\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    _handler: function(c) {\n        var d = c.payload;\n        if (((!d || !this._updateContext()))) {\n            return;\n        }\n    ;\n    ;\n        var a = this._dialog.getContent();\n        DOM.setContent(a, HTML(d));\n        this._dialog.setDestroyOnHide(false).show();\n        var b = Parent.byClass(a, \"metaComposerUserEd\");\n        if (this._anim) {\n            this._anim.JSBNG__stop();\n            this._anim = animation(b);\n        }\n         else this._anim = animation(b).from(\"opacity\", 0);\n    ;\n    ;\n        this._anim.by(\"opacity\", 1).checkpoint().duration(3000).checkpoint().to(\"opacity\", 0).checkpoint().JSBNG__ondone(this._killAnim.bind(this)).go();\n    },\n    _killAnim: function(a, b) {\n        if (this._anim) {\n            this._anim.JSBNG__stop();\n            this._dialog.hide(false);\n            this._anim = null;\n        }\n    ;\n    ;\n    }\n};\nfunction ScrollingPager(d, c, a, b) {\n    this.scroll_loader_id = d;\n    this.pagelet_src = c;\n    this.data = a;\n    this.options = ((b || {\n    }));\n    if (this.options.target_id) {\n        this.target_id = this.options.target_id;\n        this.options.append = true;\n    }\n     else this.target_id = d;\n;\n;\n    this.handler = null;\n};\n;\nScrollingPager.prototype = {\n    register: function() {\n        this.JSBNG__onvisible = new OnVisible($(this.scroll_loader_id), this.getHandler(), false, this.options.buffer, this.options);\n    },\n    getHandler: function() {\n        if (this.handler) {\n            return this.handler;\n        }\n    ;\n    ;\n        function a() {\n            var c = ge(this.scroll_loader_id);\n            if (!c) {\n                this.JSBNG__onvisible.remove();\n                return;\n            }\n        ;\n        ;\n            CSS.addClass(c.firstChild, \"async_saving\");\n            var b = this.options.handler;\n            this.options.handler = function() {\n                Arbiter.inform(\"ScrollingPager/loadingComplete\");\n                ((b && b.apply(null, arguments)));\n            };\n            UIPagelet.loadFromEndpoint(this.pagelet_src, this.target_id, this.data, this.options);\n        };\n    ;\n        return a.bind(this);\n    },\n    setHandler: function(a) {\n        this.handler = a;\n    }\n};\nfunction StreamProfileComposer() {\n\n};\n;\nStreamProfileComposer.prototype = {\n    init: function(a) {\n        var b = $(a);\n        Arbiter.subscribe(\"composer/publish\", function(JSBNG__event, c) {\n            if (c.streamStory) {\n                animation.prependInsert(b, c.streamStory);\n            }\n        ;\n        ;\n        });\n    }\n};\nfunction SideNav() {\n    SideNav.instance = this;\n};\n;\nSideNav.instance = null;\nSideNav.getInstance = function() {\n    if (((SideNav.instance === null))) {\n        return new SideNav();\n    }\n;\n;\n    return SideNav.instance;\n};\nSideNav.prototype = {\n    init: function(c, a, b, d, e) {\n        this.selectedKey = d;\n        this.loadingKey = null;\n        this.loadingNode = null;\n        this.editNav = {\n        };\n        this.path = URI.getRequestURI().getPath();\n        this.domain = URI.getRequestURI().getDomain();\n        this.navData = {\n        };\n        this.root = c;\n        this.defaultKey = a;\n        this.endpoints = b;\n        this.keyParam = \"sk\";\n        this.useAjaxPipe = e;\n        PageTransitions.registerHandler(this.catchPageTransition.bind(this));\n        this._subscriptions = [Arbiter.subscribe(NavigationMessage.NAVIGATION_COMPLETED, this.navigationComplete.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_FAILED, this.navigationFailed.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_COUNT_UPDATE, this.navigationCountUpdate.bind(this)),Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"nav_count\"), this.navigationCountUpdateFromPresence.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_SELECT, this.navigationSelect.bind(this)),];\n        if (this.selectedKey) {\n            Arbiter.inform(\"SideNav.selectedKey\", this.selectedKey, Arbiter.BEHAVIOR_STATE);\n        }\n         else {\n            selected = Arbiter.query(\"SideNav.selectedKey\");\n            if (selected) {\n                data = {\n                    asLoading: false\n                };\n                data[this.keyParam] = selected;\n                this.navigationSelect(null, data);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this._listeners = [JSBNG__Event.listen(this.root, \"click\", (function(JSBNG__event) {\n            var f = JSBNG__event.getTarget();\n            if (((CSS.hasClass(f, \"uiCloseButton\") && ((f.parentNode.tagName == \"LI\"))))) {\n                CSS.hide(Parent.byTag(f, \"li\"));\n                return;\n            }\n        ;\n        ;\n            if (!((CSS.hasClass(f, \"navMoreLess\") || CSS.hasClass(f, \"navEditDone\")))) {\n                f = Parent.byTag(f, \"a\");\n            }\n        ;\n        ;\n            if (((f && CSS.hasClass(f, \"navEditDone\")))) {\n                this.toggleEditMode(f);\n                JSBNG__event.kill();\n            }\n        ;\n        ;\n        }).bind(this)),];\n        JSBNG__onleaveRegister(this._destroy.bind(this));\n    },\n    toggleEditMode: function(a) {\n        this.toggleSortMode(DOM.JSBNG__find(Parent.byClass(a, \"expandedMode\"), \"ul.uiSideNav\"), a.getAttribute(\"data-endpoint\"));\n    },\n    addEndpoints: function(a) {\n        this.endpoints = merge(this.endpoints, a);\n    },\n    addToURLMap: function() {\n    \n    },\n    updateCloseButtons: function(b, a) {\n        DOM.scry(b, \"span.buttonWrap\").each((function(c) {\n            JSBNG__Event.listen(c, \"click\", (function(JSBNG__event) {\n                var d = Parent.byClass(JSBNG__event.getTarget(), \"uiCloseButton\");\n                if (d) {\n                    d = DOM.JSBNG__find(d, \"input\");\n                    Form.bootstrap(d.form, d);\n                    if (a) {\n                        CSS.hide(Parent.byTag(d, \"li\"));\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                JSBNG__Event.kill(JSBNG__event);\n            }).bind(this));\n            CSS.show(c);\n        }).bind(this));\n    },\n    getEndpoint: function(a) {\n        return ((this.endpoints ? ((this.endpoints[a] || this.endpoints)) : \"\"));\n    },\n    catchPageTransition: function(c) {\n        var b = c.getQueryData(), a = this.resolveKey(b[this.keyParam], c);\n        if (((a === false))) {\n            return false;\n        }\n    ;\n    ;\n        if (((a === undefined))) {\n            a = this.defaultKey;\n        }\n    ;\n    ;\n        this.loadKey(a);\n        return this.handlePageTransition(c, b, a);\n    },\n    resolveKey: function(a, b) {\n        if (((((this.path != b.getPath())) || ((this.domain != b.getDomain()))))) {\n            return false;\n        }\n    ;\n    ;\n        return a;\n    },\n    loadKey: function(b, c) {\n        var a = DOM.scry(this.root, ((\"li.key-\" + b)));\n        ((((this.loadingNode && !c)) && CSS.removeClass(this.loadingNode, \"loading\")));\n        this.loadingKey = b;\n        if (a.length) {\n            this.loadingNode = a[0];\n            ((!c && CSS.addClass(this.loadingNode, \"loading\")));\n        }\n         else this.loadingNode = null;\n    ;\n    ;\n        this.refreshRightColumn = this.shouldRefreshRightColumn(this.loadingNode, b);\n    },\n    shouldRefreshRightColumn: function(b, a) {\n        return ((b && this.isTopLevelNode(b)));\n    },\n    handlePageTransition: function(d, c, b) {\n        var a = this.getEndpoint(b);\n        if (!((typeof a == \"string\"))) {\n            return false;\n        }\n    ;\n    ;\n        copy_properties(c, {\n            key: b,\n            endpoint: a,\n            sidecol: this.refreshRightColumn\n        });\n        c = {\n            params: c\n        };\n        c.useAjaxPipe = ((this.useAjaxPipe || c.params.ap));\n        Arbiter.inform(NavigationMessage.NAVIGATION_BEGIN, c);\n        return true;\n    },\n    isTopLevelNode: function(a) {\n        return ((((a && a.firstChild)) && ((CSS.hasClass(a.firstChild, \"item\") || CSS.hasClass(a.firstChild, \"inputsearch\")))));\n    },\n    navigationSelect: function(c, a) {\n        var b = a[this.keyParam];\n        if (((b !== undefined))) {\n            this.loadKey(b);\n            if (!a.asLoading) {\n                this.navigationComplete();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    navigationFailed: function() {\n        CSS.removeClass(this.loadingNode, \"loading\");\n        this.loadingNode = null;\n    },\n    navigationComplete: function() {\n        if (((Arbiter.inform(\"sidenav/scrolltop\") !== false))) {\n            DOMScroll.JSBNG__scrollTo(JSBNG__document.documentElement, false);\n        }\n    ;\n    ;\n        if (this.loadingKey) {\n            DOM.scry(this.root, \"li.selectedItem\").each(function(c) {\n                CSS.removeClass(c, \"selectedItem\");\n            });\n        }\n    ;\n    ;\n        if (this.loadingNode) {\n            CSS.removeClass(this.loadingNode, \"loading\");\n            var b = null;\n            if (this.isTopLevelNode(this.loadingNode)) {\n                b = this.loadingNode;\n            }\n             else b = this.loadingNode.parentNode.parentNode;\n        ;\n        ;\n            if (!CSS.hasClass(b, \"open\")) {\n                DOM.scry(this.root, \"li.open\").each(function(c) {\n                    CSS.removeClass(c, \"open\");\n                });\n                CSS.addClass(b, \"open\");\n            }\n        ;\n        ;\n            CSS.addClass(this.loadingNode, \"selectedItem\");\n            var a = CSS.hasClass(this.loadingNode, \"hider\");\n            DOM.scry(this.root, \"div.navFold\").forEach(function(c) {\n                CSS.conditionClass(c, \"hideContent\", a);\n            });\n            if (CSS.hasClass(this.loadingNode, \"expander\")) {\n                CSS.addClass(Parent.byClass(this.loadingNode, \"expandableSideNav\"), \"expandedMode\");\n            }\n        ;\n        ;\n            this.selectedKey = this.loadingKey;\n            Arbiter.inform(\"SideNav.selectedKey\", this.selectedKey, Arbiter.BEHAVIOR_STATE);\n            this.loadingNode = null;\n            this.loadingKey = null;\n        }\n    ;\n    ;\n    },\n    navigationCountUpdate: function(g, c) {\n        if (((((!c || !c[\"key\"])) || ((((c.count === undefined)) && ((c.increment === undefined))))))) {\n            return;\n        }\n    ;\n    ;\n        var f = DOM.scry(this.root, ((\"li.key-\" + c.key)));\n        if (((f && ((f.length > 0))))) {\n            var e = f[0];\n            var a = DOM.scry(e, \"span.count\");\n            if (((a && ((a.length > 0))))) {\n                var b = DOM.JSBNG__find(a[0], \"span.countValue\");\n                var h = 0;\n                if (b) {\n                    if (c.count) {\n                        h = c.count;\n                    }\n                     else if (c.increment) {\n                        h = ((c.increment + parseInt(DOM.getText(b), 10)));\n                        if (((h < 0))) {\n                            h = 0;\n                        }\n                    ;\n                    ;\n                    }\n                    \n                ;\n                ;\n                    DOM.setContent(b, h);\n                }\n            ;\n            ;\n                CSS.conditionClass(a[0], \"hidden_elem\", !h);\n                if (c.hide) {\n                    var d = \"hidden\";\n                    if (CSS.hasClass(e, \"subitem\")) {\n                        d = \"hiddenSubitem\";\n                    }\n                ;\n                ;\n                    CSS.conditionClass(e, d, h);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    navigationCountUpdateFromPresence: function(b, a) {\n        a = a.obj;\n        if (((((!a || !a[\"class_name\"])) || !CSS.hasClass(this.root, a[\"class_name\"])))) {\n            return;\n        }\n    ;\n    ;\n        this.navigationCountUpdate(b, a);\n    },\n    toggleSortMode: function(c, a) {\n        if (!this.editNav[c]) {\n            Bootloader.loadComponents(\"sortable-side-nav-js\", this.initializeSortable.bind(this, c, a));\n        }\n         else {\n            var d = c.parentNode, b = this.editNav[c].inEditMode();\n            CSS.conditionClass($(\"sideNav\"), \"editMode\", !b);\n            this.editNav[c][((b ? \"endEdit\" : \"beginEdit\"))]();\n        }\n    ;\n    ;\n        return false;\n    },\n    initializeSortable: function(b, a) {\n        this.editNav[b] = new SortableSideNav(b, a);\n        this.toggleSortMode(b);\n    },\n    _destroy: function() {\n        this._subscriptions.forEach(Arbiter.unsubscribe);\n        this._subscriptions.length = 0;\n        this._listeners.forEach(function(a) {\n            a.remove();\n        });\n        this._listeners.length = 0;\n    }\n};");
// 4701
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[9], o16,o22);
// undefined
o16 = null;
// 4728
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"/yQAb\",]);\n}\n;\n;\nGroupMall = {\n    init: function(a) {\n        this._mallNode = $(((\"group_mall_\" + a)));\n        this._composerPublishToken = Arbiter.subscribe(\"composer/publish\", function(JSBNG__event, b) {\n            if (((b.streamStory && !ge(b.streamStory.id)))) {\n                this._addPostToUI(b.streamStory);\n            }\n        ;\n        ;\n        }.bind(this));\n        JSBNG__onleaveRegister(this._onleave.bind(this));\n        this._navigationBeginToken = Arbiter.subscribe(NavigationMessage.NAVIGATION_BEGIN, this._onleave.bind(this));\n    },\n    _onleave: function() {\n        Arbiter.unsubscribe(this._navigationBeginToken);\n        Arbiter.unsubscribe(this._composerPublishToken);\n    },\n    _addPostToUI: function(c) {\n        var a = Vector2.getElementDimensions(this._mallNode).y;\n        DOM.prependContent(this._mallNode, c);\n        var b = this._mallNode.firstChild;\n        LiveTimer.startLoop(0);\n        new animation(b).from(\"opacity\", 0).to(\"opacity\", 1).duration(300).go();\n    }\n};\nJSBNG__onloadRegister(function() {\n    JSBNG__Event.listen(JSBNG__document.documentElement, \"submit\", function(b) {\n        var a = b.getTarget().getElementsByTagName(\"*\");\n        for (var c = 0; ((c < a.length)); c++) {\n            if (((a[c].getAttribute(\"required\") && Input.isEmpty(a[c])))) {\n                a[c].JSBNG__focus();\n                return false;\n            }\n        ;\n        ;\n        };\n    ;\n    }, JSBNG__Event.Priority.URGENT);\n});\nfunction startMessagingNavCountUpdater(h) {\n    var d;\n    if (window.FutureSideNav) {\n        d = FutureSideNav.getInstance().getNodeForKey(\"inbox\");\n    }\n     else d = DOM.scry($(\"sideNav\"), \".key-inbox\")[0];\n;\n;\n    if (!d) {\n        return;\n    }\n;\n;\n    var c = DOM.scry(d, \"span.count\")[0];\n    var b = DOM.scry(c, \"span.countValue\")[0];\n    var a = new CounterDisplay(\"messages_unread\", b, c, null, null, true);\n    var f;\n    if (window.FutureSideNav) {\n        f = FutureSideNav.getInstance().getNodeForKey(\"other\");\n    }\n     else f = DOM.scry(d, \"li.key-other\")[0];\n;\n;\n    var g = DOM.scry(f, \"span.count\")[0];\n    var e = DOM.scry(g, \"span.countValue\")[0];\n    var i = DOM.scry(g, \"span.maxCountIndicator\")[0];\n    new CounterMaxDisplay(\"other_unseen\", e, g, null, null, true).setMaxCounter(h, i);\n};\n;\nfunction CounterMaxDisplay() {\n    this._maxValue = null;\n    this._maxIndicatorNode = null;\n    var a = [this,].concat($A(arguments));\n    return this.parent.construct.apply(this.parent, a);\n};\n;\nClass.extend(CounterMaxDisplay, \"CounterDisplay\");\ncopy_properties(CounterMaxDisplay.prototype, {\n    setMaxCounter: function(a, b) {\n        this._maxValue = a;\n        this._maxIndicatorNode = b;\n    },\n    paint: function() {\n        var b = ((this._maxValue && ((this._count > this._maxValue))));\n        var a = ((b ? this._maxValue : this._count));\n        if (this._maxIndicatorNode) {\n            DOM.setContent(this._maxIndicatorNode, ((b ? \"+\" : \"\")));\n        }\n         else if (b) {\n            a = ((a + \"+\"));\n        }\n        \n    ;\n    ;\n        DOM.setContent(this._valueNode, a);\n        this._toggleNodes();\n    }\n});");
// 4745
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[10], o17,o22);
// undefined
o17 = null;
// 4786
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"poN6f\",]);\n}\n;\n;\n(function() {\n    if (!window.channel) {\n        window.channel = {\n        };\n    }\n     else if (channel.OK) {\n        return;\n    }\n    \n;\n;\n    var a = \"presence/\";\n    copy_properties(channel, {\n        ON_CONNECT: ((a + \"connect\")),\n        ON_IDLE: ((a + \"idle\")),\n        ON_SHUTDOWN: ((a + \"shutdown\")),\n        ON_INVALID_HISTORY: ((a + \"invalid_history\")),\n        ON_CONFIG: ((a + \"config\")),\n        OK: \"ok\",\n        ERROR: \"error\",\n        ERROR_CONN: \"error_conn\",\n        ERROR_MAX: \"error_max\",\n        ERROR_MISSING: \"error_missing\",\n        ERROR_MSG_TYPE: \"error_msg_type\",\n        ERROR_REFRESH: \"error_refresh\",\n        ERROR_SHUTDOWN: \"error_shutdown\",\n        ERROR_DOS: \"error_dos\",\n        HINT_AUTH: \"shutdown auth\",\n        HINT_CONN: \"shutdown conn\",\n        HINT_MAINT: \"shutdown maint\",\n        reason_Unknown: 0,\n        reason_AsyncError: 1,\n        reason_TooLong: 2,\n        reason_Refresh: 3,\n        reason_RefreshDelay: 4,\n        reason_UIRestart: 5,\n        reason_NeedSeq: 6,\n        reason_PrevFailed: 7,\n        reason_IFrameLoadGiveUp: 8,\n        reason_IFrameLoadRetry: 9,\n        reason_IFrameLoadRetryWorked: 10,\n        reason_PageTransitionRetry: 11,\n        reason_IFrameLoadMaxSubdomain: 12,\n        reason_NoChannelInfo: 13,\n        reason_NoChannelHost: 14,\n        reason_ChannelUnknown: 100,\n        reason_ChannelNoCUser: 101,\n        reason_ChannelInvalidCUser: 102,\n        reason_ChannelInvalidChanstr: 103,\n        reason_ChannelChDistribTimeout: 104,\n        reason_ChannelGetChannelOther: 105,\n        reason_ChannelNodeShutdown: 106,\n        reason_ChannelTermination: 107,\n        reason_ChannelUserMismatch: 108,\n        reason_ChannelUserMismatchShady: 109,\n        reason_ChannelBadXs: 110,\n        reason_ChannelSeqNeg: 111,\n        reason_ChannelSeqTooBig: 112,\n        reason_ChannelSeqTooSmall: 113,\n        reason_ChannelUnexpectedJoin: 114,\n        reason_ChannelInvalidXsCookie: 115,\n        reason_ChannelRelocate: 116,\n        reason_ChannelWrongPartition: 117,\n        getArbiterType: function(b) {\n            return ((((a + \"message:\")) + b));\n        }\n    });\n})();\n(function() {\n    if (window.channel_cookie) {\n        return;\n    }\n;\n;\n    window.channel_cookie = {\n        subdomainIndex: null,\n        init: function() {\n            var a = presenceCookieManager.getSubCookie(\"ch\");\n            this.retryInterval = ((presenceCookieManager.getSubCookie(\"ri\") || 0));\n            if (!channel.getConfig(\"nosubdomain\")) {\n                this.subdomainIndex = 0;\n                if (((a && a.sub))) {\n                    for (var b = 0; ((b < a.sub.length)); b++) {\n                        if (!a.sub[b]) {\n                            this.subdomainIndex = b;\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((b == a.sub.length))) {\n                        if (((((b == channel_manager.MAX_SUBDOMAINS)) && URI().isSecure()))) {\n                            this.subdomainIndex = null;\n                            presence.error(\"channel: iframe max subdomains reached\");\n                            channel_manager._sendIframeError(ChannelRebuildReasons.IFrameLoadMaxSubdomain);\n                        }\n                         else this.subdomainIndex = a.sub.length;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            presenceCookieManager.register(\"ch\", this.getInfo.bind(this));\n            var c = (function() {\n                this._clearSubdomain = true;\n                presence.doSync(true);\n            }).bind(this);\n            if (((typeof window.JSBNG__onpageshow != \"undefined\"))) {\n                JSBNG__Event.listen(window, \"pagehide\", c);\n            }\n             else JSBNG__onunloadRegister(c);\n        ;\n        ;\n        },\n        getInfo: function() {\n            var b = {\n            };\n            var c = channel.getConfig(\"host\");\n            var e = channel.getConfig(\"port\");\n            if (c) {\n                if (((null !== this.subdomainIndex))) {\n                    var a = presenceCookieManager.getSubCookie(\"ch\");\n                    var f = ((((a && a.sub)) ? a.sub : []));\n                    var d = f.length;\n                    f[this.subdomainIndex] = ((this._clearSubdomain ? 0 : 1));\n                    b.sub = f.map(function(g) {\n                        return ((g ? 1 : 0));\n                    });\n                }\n            ;\n            ;\n                b[channel.getConfig(\"user_channel\")] = channel.getConfig(\"seq\", 0);\n            }\n        ;\n        ;\n            b.ri = this.retryInterval;\n            return b;\n        }\n    };\n})();\n(function() {\n    if (!window.channel) {\n        window.channel = {\n        };\n    }\n     else if (channel.init) {\n        return;\n    }\n    \n;\n;\n    copy_properties(channel, {\n        inner: function() {\n            return this.manager.transport._iframe.contentWindow.transport;\n        },\n        _sitevars: {\n        },\n        _config: {\n            userActive: ((new JSBNG__Date() | 0)),\n            sessionID: ((((Math.JSBNG__random() * 2147483648)) | 0)).toString(16)\n        },\n        init: function() {\n            channel_cookie.init();\n            this._config.subdomainIndex = channel_cookie.subdomainIndex;\n            this.log = bind(this, \"_log\", \"log\");\n            this.error = bind(this, \"_log\", \"error\");\n            this.warn = bind(this, \"_log\", \"warn\");\n            if (((typeof (UserActivity) != \"undefined\"))) {\n                UserActivity.subscribe(function() {\n                    this._config.userActive = new JSBNG__Date().getTime();\n                }.bind(this));\n            }\n        ;\n        ;\n        },\n        _log: function(b, c) {\n            var d = ((this.manager && this.manager.transport));\n            var a = ((\"channel2:\" + ((d ? ((d.logName + \":\")) : \"\"))));\n            if (((b == \"log\"))) {\n                return false;\n            }\n             else if (((b == \"warn\"))) {\n                return presence.warn(((a + c)));\n            }\n             else if (((b == \"error\"))) {\n                return presence.error(((a + c)));\n            }\n            \n            \n        ;\n        ;\n        },\n        log: function(a) {\n            this._log(\"log\", a);\n        },\n        warn: function(a) {\n            this._log(\"warn\", a);\n        },\n        error: function(a) {\n            this._log(\"error\", a);\n        },\n        configure: function() {\n            $A(arguments).each(copy_properties.bind(null, this._config));\n            Arbiter.inform(channel.ON_CONFIG, this);\n        },\n        getConfig: function(b, a) {\n            return ((((b in this._config)) ? this._config[b] : a));\n        }\n    });\n})();\nvar DOMScroll = {\n    getScrollState: function() {\n        var d = Vector2.getViewportDimensions();\n        var a = Vector2.getDocumentDimensions();\n        var b = ((a.x > d.x));\n        var c = ((a.y > d.y));\n        b += 0;\n        c += 0;\n        return new Vector2(b, c);\n    },\n    _scrollbarSize: null,\n    _initScrollbarSize: function() {\n        var a = $N(\"p\");\n        a.style.width = \"100%\";\n        a.style.height = \"200px\";\n        var b = $N(\"div\");\n        b.style.position = \"absolute\";\n        b.style.JSBNG__top = \"0px\";\n        b.style.left = \"0px\";\n        b.style.visibility = \"hidden\";\n        b.style.width = \"200px\";\n        b.style.height = \"150px\";\n        b.style.overflow = \"hidden\";\n        b.appendChild(a);\n        JSBNG__document.body.appendChild(b);\n        var c = a.offsetWidth;\n        b.style.overflow = \"JSBNG__scroll\";\n        var d = a.offsetWidth;\n        if (((c == d))) {\n            d = b.clientWidth;\n        }\n    ;\n    ;\n        JSBNG__document.body.removeChild(b);\n        DOMScroll._scrollbarSize = ((c - d));\n        if (((DOMScroll._scrollbarSize < 5))) {\n            DOMScroll._scrollbarSize = 15;\n        }\n    ;\n    ;\n    },\n    getScrollbarSize: function() {\n        if (((DOMScroll._scrollbarSize === null))) {\n            DOMScroll._initScrollbarSize();\n        }\n    ;\n    ;\n        return DOMScroll._scrollbarSize;\n    },\n    JSBNG__scrollTo: function(e, a, d, b, c) {\n        if (((((typeof a == \"undefined\")) || ((a === true))))) {\n            a = 750;\n        }\n    ;\n    ;\n        if (!((e instanceof Vector2))) {\n            var f = Vector2.getScrollPosition().x;\n            var g = Vector2.getElementPosition($(e)).y;\n            g = ((g - Math.min(0, Math.max(((Vector2.getViewportDimensions().y / 3)), 100))));\n            e = new Vector2(f, g, \"JSBNG__document\");\n        }\n    ;\n    ;\n        if (d) {\n            e.y -= ((Vector2.getViewportDimensions().y / 2));\n        }\n         else if (b) {\n            e.y -= Vector2.getViewportDimensions().y;\n            e.y += b;\n        }\n        \n    ;\n    ;\n        e = e.convertTo(\"JSBNG__document\");\n        if (a) {\n            Bootloader.loadComponents(\"animation\", function() {\n                var h = JSBNG__document.body;\n                animation(h).to(\"scrollTop\", e.y).to(\"scrollLeft\", e.x).ease(animation.ease.end).duration(a).JSBNG__ondone(c).go();\n            });\n        }\n         else if (window.JSBNG__scrollTo) {\n            window.JSBNG__scrollTo(e.x, e.y);\n            ((c && c.call(this)));\n        }\n        \n    ;\n    ;\n    }\n};\nfunction AjaxPipeRequest(b, a) {\n    this._uri = b;\n    this._query_data = a;\n    this._request = new AsyncRequest();\n    this._canvas_id = null;\n    this._allow_cross_page_transition = true;\n};\n;\ncopy_properties(AjaxPipeRequest.prototype, {\n    setCanvasId: function(a) {\n        this._canvas_id = a;\n        return this;\n    },\n    setURI: function(a) {\n        this._uri = a;\n        return this;\n    },\n    setData: function(a) {\n        this._query_data = a;\n        return this;\n    },\n    getData: function(a) {\n        return this._query_data;\n    },\n    setAllowCrossPageTransition: function(a) {\n        this._allow_cross_page_transition = a;\n        return this;\n    },\n    setAppend: function(a) {\n        this._append = a;\n        return this;\n    },\n    send: function() {\n        this._request.setOption(\"useIframeTransport\", true).setURI(this._uri).setData(copy_properties({\n            ajaxpipe: 1\n        }, this._query_data)).setPreBootloadHandler(this._preBootloadHandler.bind(this)).setInitialHandler(this._onInitialResponse.bind(this)).setHandler(this._onResponse.bind(this)).setMethod(\"GET\").setReadOnly(true).setAllowCrossPageTransition(this._allow_cross_page_transition);\n        AjaxPipeRequest._current_request = this._request;\n        this._request.send();\n        return this;\n    },\n    _preBootloadFirstResponse: function(a) {\n        return false;\n    },\n    _fireDomContentCallback: function() {\n        this._arbiter.inform(\"ajaxpipe/domcontent_callback\", true, Arbiter.BEHAVIOR_STATE);\n    },\n    _fireOnloadCallback: function() {\n        this._arbiter.inform(\"ajaxpipe/onload_callback\", true, Arbiter.BEHAVIOR_STATE);\n    },\n    _isRelevant: function(a) {\n        return ((((this._request == AjaxPipeRequest._current_request)) || this._jsNonBlock));\n    },\n    _preBootloadHandler: function(b) {\n        var a = b.getPayload();\n        if (((((!a || a.redirect)) || !this._isRelevant(b)))) {\n            return false;\n        }\n    ;\n    ;\n        var c = false;\n        if (b.is_first) {\n            ((!this._append && AjaxPipeRequest.clearCanvas(this._canvas_id, this._constHeight)));\n            this._arbiter = new Arbiter();\n            c = this._preBootloadFirstResponse(b);\n            this.pipe = new BigPipe({\n                arbiter: this._arbiter,\n                rootNodeID: this._canvas_id,\n                lid: this._request.lid,\n                rrEnabled: b.payload.roadrunner_enabled,\n                isAjax: true,\n                domContentCallback: this._fireDomContentCallback.bind(this),\n                JSBNG__onloadCallback: this._fireOnloadCallback.bind(this),\n                domContentEvt: \"ajaxpipe/domcontent_callback\",\n                JSBNG__onloadEvt: \"ajaxpipe/onload_callback\",\n                jsNonBlock: this._jsNonBlock\n            });\n        }\n    ;\n    ;\n        return c;\n    },\n    _redirect: function(a) {\n        return false;\n    },\n    _versionCheck: function(a) {\n        return true;\n    },\n    _onInitialResponse: function(b) {\n        var a = b.getPayload();\n        if (!this._isRelevant(b)) {\n            return false;\n        }\n    ;\n    ;\n        if (!a) {\n            return true;\n        }\n    ;\n    ;\n        if (((this._redirect(a) || !this._versionCheck(a)))) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    _processFirstResponse: function(b) {\n        var a = b.getPayload();\n        if (((ge(this._canvas_id) && ((a.canvas_class !== null))))) {\n            CSS.setClass(this._canvas_id, a.canvas_class);\n        }\n    ;\n    ;\n    },\n    setFirstResponseCallback: function(a) {\n        this._firstResponseCallback = a;\n        return this;\n    },\n    setFirstResponseHandler: function(a) {\n        this._processFirstResponse = a;\n        return this;\n    },\n    _onResponse: function(b) {\n        var a = b.payload;\n        if (!this._isRelevant(b)) {\n            return AsyncRequest.suppressOnloadToken;\n        }\n    ;\n    ;\n        if (b.is_first) {\n            this._processFirstResponse(b);\n            ((this._firstResponseCallback && this._firstResponseCallback()));\n            a.provides = ((a.provides || []));\n            a.provides.push(\"uipage_onload\");\n            if (this._append) {\n                a.append = this._canvas_id;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (a) {\n            if (((((((\"JSBNG__content\" in a.JSBNG__content)) && ((this._canvas_id !== null)))) && ((this._canvas_id != \"JSBNG__content\"))))) {\n                a.JSBNG__content[this._canvas_id] = a.JSBNG__content.JSBNG__content;\n                delete a.JSBNG__content.JSBNG__content;\n            }\n        ;\n        ;\n            this.pipe.JSBNG__onPageletArrive(a);\n        }\n    ;\n    ;\n        if (b.is_last) {\n            AjaxPipeRequest.restoreCanvas(this._canvas_id, this._constHeight);\n        }\n    ;\n    ;\n        return AsyncRequest.suppressOnloadToken;\n    },\n    setNectarModuleDataSafe: function(a) {\n        this._request.setNectarModuleDataSafe(a);\n        return this;\n    },\n    setFinallyHandler: function(a) {\n        this._request.setFinallyHandler(a);\n        return this;\n    },\n    setErrorHandler: function(a) {\n        this._request.setErrorHandler(a);\n        return this;\n    },\n    abort: function() {\n        this._request.abort();\n        if (((AjaxPipeRequest._current_request == this._request))) {\n            AjaxPipeRequest._current_request = null;\n        }\n    ;\n    ;\n        this._request = null;\n        return this;\n    },\n    setJSNonBlock: function(a) {\n        this._jsNonBlock = a;\n        return this;\n    },\n    setConstHeight: function(a) {\n        this._constHeight = a;\n        return this;\n    },\n    getAsyncRequest: function() {\n        return this._request;\n    }\n});\ncopy_properties(AjaxPipeRequest, {\n    clearCanvas: function(a, b) {\n        var c = ge(a);\n        if (c) {\n            if (!b) {\n                c.style.minHeight = \"600px\";\n            }\n        ;\n        ;\n            DOM.empty(c);\n        }\n    ;\n    ;\n    },\n    restoreCanvas: function(a, b) {\n        var c = ge(a);\n        if (c) {\n            if (!b) {\n                c.style.minHeight = \"100px\";\n            }\n        ;\n        }\n    ;\n    ;\n    },\n    getCurrentRequest: function() {\n        return AjaxPipeRequest._current_request;\n    },\n    setCurrentRequest: function(a) {\n        AjaxPipeRequest._current_request = a;\n    },\n    isActiveOnPage: function(a) {\n        return env_get(\"ajaxpipe_enabled\");\n    }\n});\nvar HistoryManager = ((window.HistoryManager || {\n    _IFRAME_BASE_URI: \"http://static.ak.facebook.com/common/history_manager.php\",\n    JSBNG__history: null,\n    current: 0,\n    fragment: null,\n    _setIframeSrcFragment: function(b) {\n        b = b.toString();\n        var a = ((HistoryManager.JSBNG__history.length - 1));\n        HistoryManager.iframe.src = ((((((((HistoryManager._IFRAME_BASE_URI + \"?|index=\")) + a)) + \"#\")) + encodeURIComponent(b)));\n        return HistoryManager;\n    },\n    getIframeSrcFragment: function() {\n        return decodeURIComponent(URI(HistoryManager.iframe.contentWindow.JSBNG__document.JSBNG__location.href).getFragment());\n    },\n    nextframe: function(a, b) {\n        if (b) {\n            HistoryManager._setIframeSrcFragment(a);\n            return;\n        }\n    ;\n    ;\n        if (((a !== undefined))) {\n            HistoryManager.iframeQueue.push(a);\n        }\n         else {\n            HistoryManager.iframeQueue.splice(0, 1);\n            HistoryManager.iframeTimeout = null;\n            HistoryManager.checkURI();\n        }\n    ;\n    ;\n        if (((HistoryManager.iframeQueue.length && !HistoryManager.iframeTimeout))) {\n            var c = HistoryManager.iframeQueue[0];\n            HistoryManager.iframeTimeout = JSBNG__setTimeout(function() {\n                HistoryManager._setIframeSrcFragment(c);\n            }, 100, false);\n        }\n    ;\n    ;\n    },\n    isInitialized: function() {\n        return !!HistoryManager._initialized;\n    },\n    init: function() {\n        if (((!env_get(\"ALLOW_TRANSITION_IN_IFRAME\") && ((window != window.JSBNG__top))))) {\n            return;\n        }\n    ;\n    ;\n        if (HistoryManager._initialized) {\n            return HistoryManager;\n        }\n    ;\n    ;\n        var b = URI();\n        var a = ((b.getFragment() || \"\"));\n        if (((a.charAt(0) === \"!\"))) {\n            a = a.substr(1);\n            b.setFragment(a);\n        }\n    ;\n    ;\n        if (((URI.getRequestURI(false).getProtocol().toLowerCase() == \"https\"))) {\n            HistoryManager._IFRAME_BASE_URI = \"https://s-static.ak.facebook.com/common/history_manager.php\";\n        }\n    ;\n    ;\n        copy_properties(HistoryManager, {\n            _initialized: true,\n            fragment: a,\n            orig_fragment: a,\n            JSBNG__history: [b,],\n            callbacks: [],\n            lastChanged: new JSBNG__Date().getTime(),\n            canonical: URI(\"#\"),\n            fragmentTimeout: null,\n            user: 0,\n            iframeTimeout: null,\n            iframeQueue: [],\n            enabled: true,\n            debug: bagofholding\n        });\n        if (((window.JSBNG__history && JSBNG__history.pushState))) {\n            this.lastURI = JSBNG__document.JSBNG__URL;\n            window.JSBNG__history.replaceState(this.lastURI, null);\n            JSBNG__Event.listen(window, \"popstate\", function(c) {\n                if (((((c && c.state)) && ((HistoryManager.lastURI != c.state))))) {\n                    HistoryManager.lastURI = c.state;\n                    HistoryManager.lastChanged = (+new JSBNG__Date());\n                    HistoryManager.notify(URI(c.state).getUnqualifiedURI().toString());\n                }\n            ;\n            ;\n            }.bind(HistoryManager));\n            if (((((ua.safari() < 534)) || ((ua.JSBNG__chrome() <= 13))))) {\n                JSBNG__setInterval(HistoryManager.checkURI, 42, false);\n                HistoryManager._updateRefererURI(this.lastURI);\n            }\n        ;\n        ;\n            return HistoryManager;\n        }\n    ;\n    ;\n        HistoryManager._updateRefererURI(URI.getRequestURI(false));\n        if (((((ua.safari() < 500)) || ((ua.firefox() < 2))))) {\n            HistoryManager.enabled = false;\n            return HistoryManager;\n        }\n    ;\n    ;\n        if (((ua.ie() < 8))) {\n            HistoryManager.iframe = JSBNG__document.createElement(\"div\");\n            copy_properties(HistoryManager.iframe.style, {\n                width: \"0\",\n                height: \"0\",\n                frameborder: \"0\",\n                left: \"0\",\n                JSBNG__top: \"0\",\n                position: \"absolute\"\n            });\n            JSBNG__onloadRegister(function() {\n                HistoryManager._setIframeSrcFragment(a);\n                JSBNG__document.body.insertBefore(HistoryManager.iframe, JSBNG__document.body.firstChild);\n            });\n        }\n         else if (((\"JSBNG__onhashchange\" in window))) {\n            JSBNG__Event.listen(window, \"hashchange\", function() {\n                HistoryManager.checkURI.bind(HistoryManager).defer();\n            });\n        }\n         else JSBNG__setInterval(HistoryManager.checkURI, 42, false);\n        \n    ;\n    ;\n        return HistoryManager;\n    },\n    registerURIHandler: function(a) {\n        HistoryManager.callbacks.push(a);\n        return HistoryManager;\n    },\n    setCanonicalLocation: function(a) {\n        HistoryManager.canonical = URI(a);\n        return HistoryManager;\n    },\n    notify: function(c) {\n        if (((c == HistoryManager.orig_fragment))) {\n            c = HistoryManager.canonical.getFragment();\n        }\n    ;\n    ;\n        for (var b = 0; ((b < HistoryManager.callbacks.length)); b++) {\n            try {\n                if (HistoryManager.callbacks[b](c)) {\n                    return true;\n                }\n            ;\n            ;\n            } catch (a) {\n            \n            };\n        ;\n        };\n    ;\n        return false;\n    },\n    checkURI: function() {\n        if (((((new JSBNG__Date().getTime() - HistoryManager.lastChanged)) < 400))) {\n            return;\n        }\n    ;\n    ;\n        if (((window.JSBNG__history && JSBNG__history.pushState))) {\n            var d = URI(JSBNG__document.JSBNG__URL).removeQueryData(\"ref\").toString();\n            var c = URI(HistoryManager.lastURI).removeQueryData(\"ref\").toString();\n            if (((d != c))) {\n                HistoryManager.lastChanged = (+new JSBNG__Date());\n                HistoryManager.lastURI = d;\n                if (((ua.safari() < 534))) {\n                    HistoryManager._updateRefererURI(d);\n                }\n            ;\n            ;\n                HistoryManager.notify(URI(d).getUnqualifiedURI().toString());\n            }\n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        if (((((ua.ie() < 8)) && HistoryManager.iframeQueue.length))) {\n            return;\n        }\n    ;\n    ;\n        if (((ua.safari() && ((window.JSBNG__history.length == 200))))) {\n            if (!HistoryManager.warned) {\n                HistoryManager.warned = true;\n            }\n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        var a = URI().getFragment();\n        if (((a.charAt(0) == \"!\"))) {\n            a = a.substr(1);\n        }\n    ;\n    ;\n        if (((ua.ie() < 8))) {\n            a = HistoryManager.getIframeSrcFragment();\n        }\n    ;\n    ;\n        a = a.replace(/%23/g, \"#\");\n        if (((a != HistoryManager.fragment.replace(/%23/g, \"#\")))) {\n            HistoryManager.debug([a,\" vs \",HistoryManager.fragment,\"whl: \",window.JSBNG__history.length,\"QHL: \",HistoryManager.JSBNG__history.length,].join(\" \"));\n            for (var b = ((HistoryManager.JSBNG__history.length - 1)); ((b >= 0)); --b) {\n                if (((HistoryManager.JSBNG__history[b].getFragment().replace(/%23/g, \"#\") == a))) {\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            ++HistoryManager.user;\n            if (((b >= 0))) {\n                HistoryManager.go(((b - HistoryManager.current)));\n            }\n             else HistoryManager.go(((\"#\" + a)));\n        ;\n        ;\n            --HistoryManager.user;\n        }\n    ;\n    ;\n    },\n    _updateRefererURI: function(e) {\n        e = e.toString();\n        if (((((e.charAt(0) != \"/\")) && ((e.indexOf(\"//\") == -1))))) {\n            return;\n        }\n    ;\n    ;\n        var d = new URI(window.JSBNG__location);\n        if (d.isFacebookURI()) {\n            var a = ((d.getPath() + window.JSBNG__location.search));\n        }\n         else var a = \"\"\n    ;\n        var c = URI(e).getQualifiedURI().setFragment(a).toString();\n        var b = 2048;\n        if (((c.length > b))) {\n            c = ((c.substring(0, b) + \"...\"));\n        }\n    ;\n    ;\n        setCookie(\"x-referer\", c);\n    },\n    go: function(c, e, f) {\n        if (((window.JSBNG__history && JSBNG__history.pushState))) {\n            ((e || ((typeof (c) == \"number\"))));\n            var h = URI(c).removeQueryData(\"ref\").toString();\n            HistoryManager.lastChanged = (+new JSBNG__Date());\n            this.lastURI = h;\n            if (f) {\n                window.JSBNG__history.replaceState(c, null, h);\n            }\n             else window.JSBNG__history.pushState(c, null, h);\n        ;\n        ;\n            if (((ua.safari() < 534))) {\n                HistoryManager._updateRefererURI(c);\n            }\n        ;\n        ;\n            return false;\n        }\n    ;\n    ;\n        HistoryManager.debug(((\"go: \" + c)));\n        if (((e === undefined))) {\n            e = true;\n        }\n    ;\n    ;\n        if (!HistoryManager.enabled) {\n            if (!e) {\n                return false;\n            }\n        ;\n        }\n    ;\n    ;\n        if (((typeof (c) == \"number\"))) {\n            if (!c) {\n                return false;\n            }\n        ;\n        ;\n            var b = ((c + HistoryManager.current));\n            var d = Math.max(0, Math.min(((HistoryManager.JSBNG__history.length - 1)), b));\n            HistoryManager.current = d;\n            b = ((HistoryManager.JSBNG__history[d].getFragment() || HistoryManager.orig_fragment));\n            b = URI(b).removeQueryData(\"ref\").getUnqualifiedURI().toString();\n            HistoryManager.fragment = b;\n            HistoryManager.lastChanged = new JSBNG__Date().getTime();\n            if (((ua.ie() < 8))) {\n                if (HistoryManager.fragmentTimeout) {\n                    JSBNG__clearTimeout(HistoryManager.fragmentTimeout);\n                }\n            ;\n            ;\n                HistoryManager._temporary_fragment = b;\n                HistoryManager.fragmentTimeout = JSBNG__setTimeout(function() {\n                    window.JSBNG__location.hash = ((\"#!\" + b));\n                    delete HistoryManager._temporary_fragment;\n                }, 750, false);\n                if (!HistoryManager.user) {\n                    HistoryManager.nextframe(b, f);\n                }\n            ;\n            ;\n            }\n             else if (!HistoryManager.user) {\n                go_or_replace(window.JSBNG__location, ((((window.JSBNG__location.href.split(\"#\")[0] + \"#!\")) + b)), f);\n            }\n            \n        ;\n        ;\n            if (e) {\n                HistoryManager.notify(b);\n            }\n        ;\n        ;\n            HistoryManager._updateRefererURI(b);\n            return false;\n        }\n    ;\n    ;\n        c = URI(c);\n        if (((c.getDomain() == URI().getDomain()))) {\n            c = URI(((\"#\" + c.getUnqualifiedURI())));\n        }\n    ;\n    ;\n        var a = HistoryManager.JSBNG__history[HistoryManager.current].getFragment();\n        var g = c.getFragment();\n        if (((((g == a)) || ((((a == HistoryManager.orig_fragment)) && ((g == HistoryManager.canonical.getFragment()))))))) {\n            if (e) {\n                HistoryManager.notify(g);\n            }\n        ;\n        ;\n            HistoryManager._updateRefererURI(g);\n            return false;\n        }\n    ;\n    ;\n        if (f) {\n            HistoryManager.current--;\n        }\n    ;\n    ;\n        var i = ((((HistoryManager.JSBNG__history.length - HistoryManager.current)) - 1));\n        HistoryManager.JSBNG__history.splice(((HistoryManager.current + 1)), i);\n        HistoryManager.JSBNG__history.push(URI(c));\n        return HistoryManager.go(1, e, f);\n    },\n    getCurrentFragment: function() {\n        var a = ((((HistoryManager._temporary_fragment !== undefined)) ? HistoryManager._temporary_fragment : URI.getRequestURI(false).getFragment()));\n        return ((((a == HistoryManager.orig_fragment)) ? HistoryManager.canonical.getFragment() : a));\n    }\n}));\nvar PageTransitions = ((window.PageTransitions || {\n    _transition_handlers: [],\n    _scroll_positions: {\n    },\n    _scroll_locked: false,\n    isInitialized: function() {\n        return !!PageTransitions._initialized;\n    },\n    _init: function() {\n        if (((!env_get(\"ALLOW_TRANSITION_IN_IFRAME\") && ((window != window.JSBNG__top))))) {\n            return;\n        }\n    ;\n    ;\n        if (PageTransitions._initialized) {\n            return PageTransitions;\n        }\n    ;\n    ;\n        PageTransitions._initialized = true;\n        var d = URI.getRequestURI(false);\n        var a = d.getUnqualifiedURI();\n        var e = URI(a).setFragment(null);\n        var c = a.getFragment();\n        if (((((c.charAt(0) === \"!\")) && ((e.toString() === c.substr(1)))))) {\n            a = e;\n        }\n    ;\n    ;\n        copy_properties(PageTransitions, {\n            _current_uri: a,\n            _most_recent_uri: a,\n            _next_uri: a\n        });\n        var b;\n        if (d.getFragment().startsWith(\"/\")) {\n            b = d.getFragment();\n        }\n         else b = a;\n    ;\n    ;\n        HistoryManager.init().setCanonicalLocation(((\"#\" + b))).registerURIHandler(PageTransitions._historyManagerHandler);\n        LinkController.registerFallbackHandler(PageTransitions._rewriteHref, ((LinkController.TARGETS | LinkController.MODIFIERS)));\n        LinkController.registerFallbackHandler(PageTransitions._onlinkclick);\n        FormController.registerFallbackHandler(PageTransitions._onformsubmit);\n        JSBNG__Event.listen(window, \"JSBNG__scroll\", function() {\n            if (!PageTransitions._scroll_locked) {\n                PageTransitions._scroll_positions[PageTransitions._current_uri] = Vector2.getScrollPosition();\n            }\n        ;\n        ;\n        });\n        return PageTransitions;\n    },\n    registerHandler: function(b, a) {\n        PageTransitions._init();\n        a = ((a || 5));\n        if (!PageTransitions._transition_handlers[a]) {\n            PageTransitions._transition_handlers[a] = [];\n        }\n    ;\n    ;\n        PageTransitions._transition_handlers[a].push(b);\n    },\n    getCurrentURI: function(a) {\n        if (((!PageTransitions._current_uri && !a))) {\n            return new URI(PageTransitions._most_recent_uri);\n        }\n    ;\n    ;\n        return new URI(PageTransitions._current_uri);\n    },\n    getMostRecentURI: function() {\n        return new URI(PageTransitions._most_recent_uri);\n    },\n    getNextURI: function() {\n        return new URI(PageTransitions._next_uri);\n    },\n    _rewriteHref: function(a) {\n        var c = a.getAttribute(\"href\");\n        var b = _computeRelativeURI(PageTransitions._most_recent_uri.getQualifiedURI(), c).toString();\n        if (((c != b))) {\n            a.setAttribute(\"href\", b);\n        }\n    ;\n    ;\n    },\n    _onlinkclick: function(a) {\n        _BusyUIManager.lookBusy(a);\n        PageTransitions.go(a.getAttribute(\"href\"));\n        return false;\n    },\n    _onformsubmit: function(a) {\n        var c = new URI(((Form.getAttribute(a, \"action\") || \"\"))), b = _computeRelativeURI(PageTransitions._most_recent_uri, c);\n        a.setAttribute(\"action\", b.toString());\n        if (((((Form.getAttribute(a, \"method\") || \"GET\")).toUpperCase() === \"GET\"))) {\n            PageTransitions.go(b.addQueryData(Form.serialize(a)));\n            return false;\n        }\n    ;\n    ;\n    },\n    go: function(d, b) {\n        var a = new URI(d).removeQueryData(\"quickling\").getQualifiedURI();\n        var c = a.getUnqualifiedURI();\n        delete PageTransitions._scroll_positions[c];\n        ((!b && user_action({\n            href: a.toString()\n        }, \"uri\", null, \"INDIRECT\")));\n        _BusyUIManager.lookBusy();\n        PageTransitions._loadPage(a, function(e) {\n            if (e) {\n                HistoryManager.go(a.toString(), false, b);\n            }\n             else go_or_replace(window.JSBNG__location, a, b);\n        ;\n        ;\n        });\n    },\n    _historyManagerHandler: function(a) {\n        if (((a.charAt(0) != \"/\"))) {\n            return false;\n        }\n    ;\n    ;\n        user_action({\n            href: a\n        }, \"h\", null);\n        PageTransitions._loadPage(new URI(a), function(b) {\n            if (!b) {\n                go_or_replace(window.JSBNG__location, a, true);\n            }\n        ;\n        ;\n        });\n        return true;\n    },\n    _loadPage: function(e, c) {\n        if (((URI(e).getFragment() && are_equal(URI(e).setFragment(null).getQualifiedURI(), URI(PageTransitions._current_uri).setFragment(null).getQualifiedURI())))) {\n            PageTransitions._current_uri = PageTransitions._most_recent_uri = e;\n            PageTransitions.restoreScrollPosition();\n            _BusyUIManager.stopLookingBusy();\n            return;\n        }\n    ;\n    ;\n        var d = PageTransitions._scroll_positions[PageTransitions._current_uri];\n        PageTransitions._current_uri = null;\n        PageTransitions._next_uri = e;\n        if (d) {\n            DOMScroll.JSBNG__scrollTo(d, false);\n        }\n    ;\n    ;\n        var b = function() {\n            PageTransitions._scroll_locked = true;\n            var f = PageTransitions._handleTransition(e);\n            ((c && c(f)));\n        };\n        var a = _runHooks(\"JSBNG__onbeforeleavehooks\");\n        if (a) {\n            _BusyUIManager.stopLookingBusy();\n            PageTransitions._warnBeforeLeaving(a, b);\n        }\n         else b();\n    ;\n    ;\n    },\n    _handleTransition: function(g) {\n        window.JSBNG__onbeforeleavehooks = undefined;\n        _BusyUIManager.lookBusy();\n        if (!g.isSameOrigin()) {\n            return false;\n        }\n    ;\n    ;\n        var f = ((window.AsyncRequest && AsyncRequest.getLastId()));\n        Arbiter.inform(\"pre_page_transition\", {\n            from: PageTransitions.getMostRecentURI(),\n            to: g\n        });\n        for (var c = ((PageTransitions._transition_handlers.length - 1)); ((c >= 0)); --c) {\n            var b = PageTransitions._transition_handlers[c];\n            if (!b) {\n                continue;\n            }\n        ;\n        ;\n            for (var d = ((b.length - 1)); ((d >= 0)); --d) {\n                if (((b[d](g) === true))) {\n                    var e = {\n                        sender: this,\n                        uri: g,\n                        id: f\n                    };\n                    try {\n                        Arbiter.inform(\"page_transition\", e);\n                    } catch (a) {\n                    \n                    };\n                ;\n                    return true;\n                }\n                 else b.splice(d, 1);\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        return false;\n    },\n    unifyURI: function() {\n        PageTransitions._current_uri = PageTransitions._most_recent_uri = PageTransitions._next_uri;\n    },\n    transitionComplete: function(a) {\n        PageTransitions._executeCompletionCallback();\n        _BusyUIManager.stopLookingBusy();\n        PageTransitions.unifyURI();\n        if (!a) {\n            PageTransitions.restoreScrollPosition();\n        }\n    ;\n    ;\n        try {\n            if (((JSBNG__document.activeElement && ((JSBNG__document.activeElement.nodeName === \"A\"))))) {\n                JSBNG__document.activeElement.JSBNG__blur();\n            }\n        ;\n        ;\n        } catch (b) {\n        \n        };\n    ;\n    },\n    _executeCompletionCallback: function() {\n        if (PageTransitions._completionCallback) {\n            PageTransitions._completionCallback();\n        }\n    ;\n    ;\n        PageTransitions._completionCallback = null;\n    },\n    setCompletionCallback: function(a) {\n        PageTransitions._completionCallback = a;\n    },\n    rewriteCurrentURI: function(b, a) {\n        PageTransitions.registerHandler(function() {\n            if (((b == PageTransitions.getMostRecentURI().getUnqualifiedURI().toString()))) {\n                PageTransitions.transitionComplete();\n                return true;\n            }\n        ;\n        ;\n        });\n        PageTransitions.go(a, true);\n    },\n    _warnBeforeLeaving: function(b, a) {\n        new Dialog().setTitle(_tx(\"Are you sure you want to leave this page?\")).setBody(htmlize(b)).setButtons([{\n            JSBNG__name: \"leave_page\",\n            label: _tx(\"Leave this Page\"),\n            handler: a\n        },{\n            JSBNG__name: \"continue_editing\",\n            label: _tx(\"Stay on this Page\"),\n            className: \"inputaux\"\n        },]).setModal(true).show();\n    },\n    restoreScrollPosition: function() {\n        PageTransitions._scroll_locked = false;\n        var c = PageTransitions._current_uri;\n        var e = PageTransitions._scroll_positions[c];\n        if (e) {\n            DOMScroll.JSBNG__scrollTo(e, false);\n            return;\n        }\n    ;\n    ;\n        function d(f) {\n            return ((((f || null)) && ((DOM.scry(JSBNG__document.body, ((((\"a[name='\" + escape_js_quotes(f))) + \"']\")))[0] || ge(f)))));\n        };\n    ;\n        var a = d(URI(c).getFragment());\n        if (a) {\n            var b = Vector2.getElementPosition(a);\n            b.x = 0;\n            DOMScroll.JSBNG__scrollTo(b);\n        }\n    ;\n    ;\n    }\n}));\nfunction _computeRelativeURI(d, b) {\n    var e = new URI(), c = b;\n    d = new URI(d);\n    b = new URI(b);\n    if (((b.getDomain() && !b.isFacebookURI()))) {\n        return c;\n    }\n;\n;\n    var f = d;\n    var a = [\"Protocol\",\"Domain\",\"Port\",\"Path\",\"QueryData\",\"Fragment\",];\n    a.forEach(function(h) {\n        var g = ((((h == \"Path\")) && ((f === d))));\n        if (g) {\n            e.setPath(_computeRelativePath(d.getPath(), b.getPath()));\n        }\n    ;\n    ;\n        if (!is_empty(b[((\"get\" + h))]())) {\n            f = b;\n        }\n    ;\n    ;\n        if (!g) {\n            e[((\"set\" + h))](f[((\"get\" + h))]());\n        }\n    ;\n    ;\n    });\n    return e;\n};\n;\nfunction _computeRelativePath(b, a) {\n    if (!a) {\n        return b;\n    }\n;\n;\n    if (((a.charAt(0) == \"/\"))) {\n        return a;\n    }\n;\n;\n    var c = b.split(\"/\").slice(0, -1);\n    ((c[0] !== \"\"));\n    a.split(\"/\").forEach(function(d) {\n        if (!((d == \".\"))) {\n            if (((d == \"..\"))) {\n                if (((c.length > 1))) {\n                    c = c.slice(0, -1);\n                }\n            ;\n            ;\n            }\n             else c.push(d);\n        ;\n        }\n    ;\n    ;\n    });\n    return c.join(\"/\");\n};\n;\nfunction go_or_replace(a, d, c) {\n    var e = new URI(d);\n    if (((((((a.pathname == \"/\")) && ((e.getPath() != \"/\")))) && e.isQuicklingEnabled()))) {\n        var b = ((a.search ? {\n        } : {\n            q: \"\"\n        }));\n        e = new URI().setPath(\"/\").setQueryData(b).setFragment(e.getUnqualifiedURI()).toString();\n        d = e.toString();\n    }\n;\n;\n    if (((c && !((ua.ie() < 8))))) {\n        a.replace(d);\n    }\n     else if (((a.href == d))) {\n        a.reload();\n    }\n     else a.href = d;\n    \n;\n;\n};\n;\nvar _BusyUIManager = ((window._BusyUIManager || {\n    _looking_busy: false,\n    _original_cursors: [],\n    lookBusy: function(a) {\n        if (a) {\n            _BusyUIManager._giveProgressCursor(a);\n        }\n    ;\n    ;\n        if (_BusyUIManager._looking_busy) {\n            return;\n        }\n    ;\n    ;\n        _BusyUIManager._looking_busy = true;\n        _BusyUIManager._giveProgressCursor(JSBNG__document.documentElement);\n    },\n    stopLookingBusy: function() {\n        if (!_BusyUIManager._looking_busy) {\n            return;\n        }\n    ;\n    ;\n        _BusyUIManager._looking_busy = false;\n        while (_BusyUIManager._original_cursors.length) {\n            var c = _BusyUIManager._original_cursors.pop();\n            var b = c[0];\n            var a = c[1];\n            if (b.style) {\n                b.style.cursor = ((a || \"\"));\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    _giveProgressCursor: function(a) {\n        if (!ua.safari()) {\n            _BusyUIManager._original_cursors.push([a,a.style.cursor,]);\n            a.style.cursor = \"progress\";\n        }\n    ;\n    ;\n    }\n}));\nvar NavigationMessage = {\n    NAVIGATION_BEGIN: \"NavigationMessage/navigationBegin\",\n    NAVIGATION_SELECT: \"NavigationMessage/navigationSelect\",\n    NAVIGATION_FIRST_RESPONSE: \"NavigationMessage/navigationFirstResponse\",\n    NAVIGATION_COMPLETED: \"NavigationMessage/navigationCompleted\",\n    NAVIGATION_FAILED: \"NavigationMessage/navigationFailed\",\n    NAVIGATION_COUNT_UPDATE: \"NavigationMessage/navigationCount\",\n    NAVIGATION_FAVORITE_UPDATE: \"NavigationMessage/navigationFavoriteUpdate\",\n    NAVIGATION_ITEM_REMOVED: \"NavigationMessage/navigationItemRemoved\",\n    NAVIGATION_ITEM_HIDDEN: \"NavigationMessage/navigationItemHidden\",\n    INTERNAL_LOADING_BEGIN: \"NavigationMessage/internalLoadingBegin\",\n    INTERNAL_LOADING_COMPLETED: \"NavigationMessage/internalLoadingCompleted\"\n};\nfunction AsyncLayout() {\n\n};\n;\nAsyncLayout.prototype = {\n    init: function(b, a, c, d) {\n        this.canvas_id = b.id;\n        if (a) {\n            this.auxiliary_id = a.id;\n        }\n    ;\n    ;\n        if (c) {\n            this.header_id = c.id;\n        }\n    ;\n    ;\n        if (d) {\n            this.toolbar_id = d.id;\n        }\n    ;\n    ;\n        this.waitingForAux = false;\n        PageTransitions.registerHandler(this.catchPageTransition.bind(this));\n        this.subscription = Arbiter.subscribe(NavigationMessage.NAVIGATION_BEGIN, this.JSBNG__onNavigate.bind(this));\n        return this;\n    },\n    catchPageTransition: function(a) {\n        Arbiter.unsubscribe(this.subscription);\n        return false;\n    },\n    getCanvasID: function(a) {\n        return ((this.customCanvasID ? this.customCanvasID : ((a.sidecol ? \"contentCol\" : \"contentArea\"))));\n    },\n    JSBNG__onNavigate: function(c, a) {\n        var d = ((a.useAjaxPipe && AjaxPipeRequest.isActiveOnPage(a.params.endpoint)));\n        a = a.params;\n        if (a.endpoint) {\n            if (this.request) {\n                this.request.setFinallyHandler(bagofholding);\n                this.request.abort();\n            }\n        ;\n        ;\n            if (this.sideRequest) {\n                this.sideRequest.abort();\n            }\n        ;\n        ;\n            if (d) {\n                this.request = new AjaxPipeRequest().setURI(a.endpoint).setData(a).setCanvasId(this.getCanvasID(a)).setFinallyHandler(this.finallyHandler.bind(this)).setErrorHandler(this.errorHandler.bind(this)).setFirstResponseCallback(this.firstResponseCallback.bind(this)).send();\n            }\n             else {\n                a.handled = true;\n                this.waitingForAux = a.sidecol;\n                var e = !!a.iframe;\n                var b = new AsyncRequest().setOption(\"useIframeTransport\", e).setURI(new URI(a.endpoint)).setReadOnly(true).setMethod(\"GET\").setData(a).setHandler(this.JSBNG__onResponse.bind(this)).setErrorHandler(this.errorHandler.bind(this)).setFinallyHandler(this.finallyHandler.bind(this));\n                this.request = b;\n                b.send();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    JSBNG__onSideResponse: function(b) {\n        var a = b.getPayload();\n        if (((a && this.auxiliary_id))) {\n            this.receivedAux(a);\n        }\n    ;\n    ;\n    },\n    receivedAux: function(a) {\n        !this.waitingForAux;\n        this.waitingForAux = false;\n        DOM.setContent($(this.auxiliary_id), HTML(a));\n    },\n    JSBNG__onResponse: function(e) {\n        var d = e.getPayload();\n        if (d.redirect) {\n            goURI(d.redirect);\n        }\n         else {\n            var c = ((d.html || d));\n            DOM.setContent($(this.canvas_id), HTML(c));\n            if (((d.side_html && this.auxiliary_id))) {\n                this.receivedAux(d.side_html);\n            }\n        ;\n        ;\n            if (((this.header_id && !d.keep_header))) {\n                var b = $(this.header_id);\n                DOM.setContent(b, HTML(((d.header_html || \"\"))));\n                CSS.conditionShow(b, d.header_html);\n            }\n        ;\n        ;\n            if (((d.toolbar_html && this.toolbar_id))) {\n                DOM.setContent($(this.toolbar_id), HTML(d.toolbar_html));\n            }\n        ;\n        ;\n            if (d.js) {\n                (new Function(d.js))();\n            }\n        ;\n        ;\n            CSS.conditionClass(\"contentCol\", \"hasRightCol\", ((this.auxiliary_id && !d.noRightSide)));\n            var f = ge(\"rightCol\");\n            if (((f && d.noRightSide))) {\n                DOM.empty(f);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var a = e.getRequest().getData();\n        Arbiter.inform(NavigationMessage.NAVIGATION_COMPLETED, a.key);\n    },\n    errorHandler: function(a) {\n        AsyncResponse.verboseErrorHandler(a);\n        Arbiter.inform(NavigationMessage.NAVIGATION_FAILED);\n        this.request = null;\n    },\n    firstResponseCallback: function(a) {\n        Arbiter.inform(NavigationMessage.NAVIGATION_FIRST_RESPONSE);\n    },\n    finallyHandler: function(a) {\n        this.request = null;\n        PageTransitions.transitionComplete(true);\n        Arbiter.inform(NavigationMessage.NAVIGATION_COMPLETED);\n    }\n};\nfunction SimpleDrag(a) {\n    JSBNG__Event.listen(a, \"mousedown\", this._start.bind(this));\n};\n;\nClass.mixin(SimpleDrag, \"Arbiter\", {\n    _start: function(JSBNG__event) {\n        this.inform(\"start\", JSBNG__event);\n        var b = ((((ua.ie() < 9)) ? JSBNG__document.documentElement : window));\n        var a = JSBNG__Event.listen(b, {\n            selectstart: JSBNG__Event.prevent,\n            mousemove: this.inform.bind(this, \"update\"),\n            mouseup: function(JSBNG__event) {\n                for (var c in a) {\n                    a[c].remove();\n                ;\n                };\n            ;\n                this.inform(\"end\", JSBNG__event);\n            }.bind(this)\n        });\n        return false;\n    }\n});\nfunction adjustImage(e, g) {\n    if (!g) {\n        var a = e.parentNode;\n        while (((a.parentNode && ((((CSS.getStyle(a, \"display\") != \"block\")) || ((a.offsetWidth == 0))))))) {\n            a = a.parentNode;\n        ;\n        };\n    ;\n        g = a.offsetWidth;\n    }\n;\n;\n    var c = e.offsetWidth;\n    if (((c == 0))) {\n        var d = e.nextSibling, f = e.parentNode;\n        JSBNG__document.body.appendChild(e);\n        c = e.offsetWidth;\n        if (d) {\n            f.insertBefore(e, d);\n        }\n         else f.appendChild(e);\n    ;\n    ;\n    }\n;\n;\n    if (((c > g))) {\n        try {\n            if (((ua.ie() < 8))) {\n                var img_div = JSBNG__document.createElement(\"div\");\n                img_div.style.filter = ((((\"progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\"\" + e.src.replace(\"\\\"\", \"%22\"))) + \"\\\", sizingMethod=\\\"scale\\\")\"));\n                img_div.style.width = ((g + \"px\"));\n                img_div.style.height = ((Math.floor(((((g / e.offsetWidth)) * e.offsetHeight))) + \"px\"));\n                if (((e.parentNode.tagName == \"A\"))) {\n                    img_div.style.cursor = \"pointer\";\n                }\n            ;\n            ;\n                e.parentNode.insertBefore(img_div, e);\n                e.parentNode.removeChild(e);\n            }\n             else throw 1\n        ;\n        } catch (b) {\n            e.style.width = ((g + \"px\"));\n        };\n    }\n;\n;\n    CSS.removeClass(e, \"img_loading\");\n};\n;\nfunction imageConstrainSize(e, b, c, d) {\n    var a = new JSBNG__Image();\n    a.JSBNG__onload = function() {\n        if (((((a.width > 0)) && ((a.height > 0))))) {\n            var k = a.width;\n            var h = a.height;\n            if (((((k > b)) || ((h > c))))) {\n                var g = ((c / b));\n                var f = ((h / k));\n                if (((f > g))) {\n                    k = ((k * ((c / h))));\n                    h = c;\n                }\n                 else {\n                    h = ((h * ((b / k))));\n                    k = b;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            var j = ge(d);\n            if (j) {\n                var i = JSBNG__document.createElement(\"img\");\n                i.src = e;\n                i.width = k;\n                i.height = h;\n                j.parentNode.insertBefore(i, j);\n                j.parentNode.removeChild(j);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n    a.src = e;\n};\n;\nfunction image_has_loaded(a) {\n    if (((a.naturalWidth !== undefined))) {\n        return ((a.complete && ((a.width != 0))));\n    }\n     else if (((((((a.height == 20)) && ((a.width == 20)))) && a.complete))) {\n        return false;\n    }\n     else if (((((a.complete === undefined)) && ((ua.safari() < 500))))) {\n        var b = new JSBNG__Image();\n        b.src = a.src;\n        return b.complete;\n    }\n    \n    \n;\n;\n    return a.complete;\n};\n;\nfunction image_has_failed(a) {\n    if (((((((((((a.complete == null)) && ((a.width == 20)))) && ((a.height == 20)))) || ((((((a.mimeType != null)) && a.complete)) && ((a.mimeType == \"\")))))) || ((((((a.naturalHeight != null)) && a.complete)) && ((a.naturalHeight == 0))))))) {\n        return true;\n    }\n;\n;\n};\n;\nadd_properties(\"Input\", {\n    JSBNG__getSelection: function(b) {\n        if (!JSBNG__document.selection) {\n            return {\n                start: b.selectionStart,\n                end: b.selectionEnd\n            };\n        }\n    ;\n    ;\n        var d = JSBNG__document.selection.createRange();\n        if (((d.parentElement() !== b))) {\n            return {\n                start: 0,\n                end: 0\n            };\n        }\n    ;\n    ;\n        var c = b.value.length;\n        if (((b.tagName == \"INPUT\"))) {\n            return {\n                start: -d.moveStart(\"character\", -c),\n                end: -d.moveEnd(\"character\", -c)\n            };\n        }\n         else {\n            var e = d.duplicate();\n            e.moveToElementText(b);\n            e.setEndPoint(\"StartToEnd\", d);\n            var a = ((c - e.text.length));\n            e.setEndPoint(\"StartToStart\", d);\n            return {\n                start: ((c - e.text.length)),\n                end: a\n            };\n        }\n    ;\n    ;\n    },\n    setSelection: function(d, f, c) {\n        if (((typeof c == \"undefined\"))) {\n            c = f;\n        }\n    ;\n    ;\n        if (JSBNG__document.selection) {\n            if (((d.tagName == \"TEXTAREA\"))) {\n                var a = ((d.value.slice(0, f).match(/\\r/g) || [])).length;\n                var b = ((d.value.slice(f, c).match(/\\r/g) || [])).length;\n                f -= a;\n                c -= ((a + b));\n            }\n        ;\n        ;\n            var e = d.createTextRange();\n            e.collapse(true);\n            e.moveStart(\"character\", f);\n            e.moveEnd(\"character\", ((c - f)));\n            e.select();\n        }\n         else {\n            d.selectionStart = f;\n            d.selectionEnd = Math.min(c, d.value.length);\n            Input.JSBNG__focus(d);\n        }\n    ;\n    ;\n    }\n});\nadd_properties(\"Input\", {\n    enforceMaxLength: function(c, e) {\n        var i = Input.getValue(c);\n        var d = i.length;\n        var f = ((d - e));\n        if (((f > 0))) {\n            var g;\n            var a;\n            try {\n                g = Input.JSBNG__getSelection(c);\n                a = g.end;\n            } catch (b) {\n                g = null;\n                a = 0;\n            };\n        ;\n            if (((a >= f))) {\n                d = a;\n            }\n        ;\n        ;\n            var h = ((d - f));\n            if (((h && ((((i.charCodeAt(((h - 1))) & 64512)) === 55296))))) {\n                h--;\n            }\n        ;\n        ;\n            a = Math.min(a, h);\n            Input.setValue(c, ((i.slice(0, h) + i.slice(d))));\n            if (g) {\n                Input.setSelection(c, Math.min(g.start, a), a);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    }\n});\nJSBNG__onloadRegister(function() {\n    function a(JSBNG__event) {\n        var b = JSBNG__event.getTarget();\n        var c = parseInt(b.getAttribute(\"maxlength\"), 10);\n        if (((((c > 0)) && DOM.isNode(b, [\"input\",\"textarea\",])))) {\n            Input.enforceMaxLength.bind(Input, b, c).defer();\n        }\n    ;\n    ;\n    };\n;\n    JSBNG__Event.listen(JSBNG__document.documentElement, {\n        keydown: a,\n        paste: a\n    });\n});\nadd_properties(\"Input\", {\n    setMaxLength: function(a, b) {\n        if (((b > 0))) {\n            a.setAttribute(\"maxlength\", b);\n            Input.enforceMaxLength(a, b);\n        }\n         else a.removeAttribute(\"maxlength\");\n    ;\n    ;\n    }\n});\nfunction TextInputControl(b) {\n    this.parent.construct(this, b);\n    var a = this.getRoot();\n    var c = function() {\n        this.update.bind(this).defer();\n    }.bind(this);\n    JSBNG__Event.listen(a, {\n        keydown: c,\n        paste: c\n    });\n};\n;\nClass.extend(TextInputControl, \"DOMControl\");\nTextInputControl.prototype = {\n    setMaxLength: function(a) {\n        Input.setMaxLength(this.getRoot(), a);\n        return this;\n    },\n    getValue: function() {\n        return Input.getValue(this.getRoot());\n    },\n    isEmpty: function() {\n        return Input.isEmpty(this.getRoot());\n    },\n    setValue: function(a) {\n        Input.setValue(this.getRoot(), a);\n        this.update();\n        return this;\n    },\n    clear: function() {\n        return this.setValue(\"\");\n    },\n    setPlaceholderText: function(a) {\n        Input.setPlaceholder(this.getRoot(), a);\n        return this;\n    }\n};\nfunction JSBNG__TextMetrics(a) {\n    this._node = a;\n    var b = this._shadow = $N(\"textarea\", {\n        className: \"textMetrics\"\n    });\n    var c = [\"fontSize\",\"fontStyle\",\"fontWeight\",\"fontFamily\",\"lineHeight\",\"wordWrap\",];\n    c.each(function(d) {\n        CSS.setStyle(b, d, CSS.getStyle(a, d));\n    });\n    JSBNG__document.body.appendChild(b);\n};\n;\nJSBNG__TextMetrics.prototype = {\n    measure: function() {\n        var a = this._node;\n        var b = this._shadow;\n        var c = ((((a.clientWidth - CSS.getStyleFloat(a, \"paddingLeft\"))) - CSS.getStyleFloat(a, \"paddingRight\")));\n        CSS.setStyle(b, \"width\", ((c + \"px\")));\n        b.value = ((a.value + \"...\"));\n        return {\n            width: b.scrollWidth,\n            height: b.scrollHeight\n        };\n    },\n    destroy: function() {\n        DOM.remove(this._shadow);\n    }\n};\nfunction TextAreaControl(a) {\n    this.autogrow = false;\n    this.parent.construct(this, a);\n    this.width = null;\n    JSBNG__Event.listen(a, {\n        JSBNG__focus: this._handleFocus.bind(this)\n    });\n};\n;\nClass.extend(TextAreaControl, \"TextInputControl\");\nClass.mixin(TextAreaControl, \"Arbiter\", {\n    setAutogrow: function(a) {\n        this.autogrow = a;\n        return this;\n    },\n    JSBNG__onupdate: function() {\n        this.parent.JSBNG__onupdate();\n        if (this.autogrow) {\n            var d = this.getRoot();\n            if (!this.metrics) {\n                this.metrics = new JSBNG__TextMetrics(d);\n            }\n        ;\n        ;\n            if (((typeof this.minHeight === \"undefined\"))) {\n                var c = CSS.getStyleFloat(d, \"height\");\n                this.minHeight = ((((c > 0)) ? c : ((d.offsetHeight - 8))));\n            }\n        ;\n        ;\n            if (((typeof this.isBorderBox === \"undefined\"))) {\n                if (((((((CSS.getStyle(d, \"box-sizing\") == \"border-box\")) || ((CSS.getStyle(d, \"-moz-box-sizing\") == \"border-box\")))) || ((CSS.getStyle(d, \"-webkit-box-sizing\") == \"border-box\"))))) {\n                    this.isBorderBox = true;\n                    this.borderBoxOffset = ((((((CSS.getStyleFloat(d, \"padding-top\") + CSS.getStyleFloat(d, \"padding-bottom\"))) + CSS.getStyleFloat(d, \"border-top-width\"))) + CSS.getStyleFloat(d, \"border-bottom-width\")));\n                }\n                 else this.isBorderBox = false;\n            ;\n            }\n        ;\n        ;\n            var b = this.metrics.measure();\n            var a = Math.max(this.minHeight, b.height);\n            if (this.isBorderBox) {\n                a += this.borderBoxOffset;\n            }\n        ;\n        ;\n            if (((a != this.height))) {\n                CSS.setStyle(d, \"height\", ((a + \"px\")));\n                this.height = a;\n                Arbiter.inform(\"reflow\");\n                this.inform(\"resize\");\n            }\n        ;\n        ;\n        }\n         else if (this.metrics) {\n            this.metrics.destroy();\n            this.metrics = null;\n        }\n        \n    ;\n    ;\n    },\n    resetHeight: function() {\n        this.height = -1;\n        this.update();\n    },\n    _handleFocus: function() {\n        this.width = null;\n    }\n});\nfunction KeyEventController() {\n    this.handlers = {\n    };\n    JSBNG__document.JSBNG__onkeyup = this.JSBNG__onkeyevent.bind(this, \"JSBNG__onkeyup\");\n    JSBNG__document.JSBNG__onkeydown = this.JSBNG__onkeyevent.bind(this, \"JSBNG__onkeydown\");\n    JSBNG__document.JSBNG__onkeypress = this.JSBNG__onkeyevent.bind(this, \"JSBNG__onkeypress\");\n};\n;\ncopy_properties(KeyEventController, {\n    instance: null,\n    getInstance: function() {\n        return ((KeyEventController.instance || (KeyEventController.instance = new KeyEventController())));\n    },\n    defaultFilter: function(JSBNG__event, a) {\n        JSBNG__event = $E(JSBNG__event);\n        return ((((KeyEventController.filterEventTypes(JSBNG__event, a) && KeyEventController.filterEventTargets(JSBNG__event, a))) && KeyEventController.filterEventModifiers(JSBNG__event, a)));\n    },\n    filterEventTypes: function(JSBNG__event, a) {\n        if (((a === \"JSBNG__onkeydown\"))) {\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    filterEventTargets: function(JSBNG__event, b) {\n        var a = JSBNG__event.getTarget();\n        return ((((!DOM.isNode(a, KeyEventController._interactiveElements) || ((a.type in KeyEventController._uninterestingTypes)))) || ((((DOM.isNode(a, [\"input\",\"textarea\",]) && ((a.value.length === 0)))) && ((JSBNG__event.keyCode in KeyEventController._controlKeys))))));\n    },\n    filterEventModifiers: function(JSBNG__event, a) {\n        if (((((((JSBNG__event.ctrlKey || JSBNG__event.altKey)) || JSBNG__event.metaKey)) || JSBNG__event.repeat))) {\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    registerKey: function(f, a, d, g) {\n        if (((d === undefined))) {\n            d = KeyEventController.defaultFilter;\n        }\n    ;\n    ;\n        var b = KeyEventController.getInstance();\n        var c = b.mapKey(f);\n        if (is_empty(b.handlers)) {\n            JSBNG__onleaveRegister(b.resetHandlers.bind(b));\n        }\n    ;\n    ;\n        for (var e = 0; ((e < c.length)); e++) {\n            f = c[e];\n            if (((!b.handlers[f] || g))) {\n                b.handlers[f] = [];\n            }\n        ;\n        ;\n            b.handlers[f].push({\n                callback: a,\n                filter: d\n            });\n        };\n    ;\n    },\n    keyCodeMap: {\n        BACKSPACE: [8,],\n        TAB: [9,],\n        RETURN: [13,],\n        ESCAPE: [27,],\n        LEFT: [37,63234,],\n        UP: [38,63232,],\n        RIGHT: [39,63235,],\n        DOWN: [40,63233,],\n        DELETE: [46,],\n        COMMA: [188,],\n        PERIOD: [190,],\n        \"`\": [192,],\n        \"[\": [219,],\n        \"]\": [221,]\n    },\n    _interactiveElements: [\"input\",\"select\",\"textarea\",\"object\",\"embed\",],\n    _uninterestingTypes: {\n        checkbox: 1,\n        radio: 1,\n        submit: 1\n    },\n    _controlKeys: {\n        8: 1,\n        9: 1,\n        13: 1,\n        27: 1,\n        37: 1,\n        63234: 1,\n        38: 1,\n        63232: 1,\n        39: 1,\n        63235: 1,\n        40: 1,\n        63233: 1,\n        46: 1\n    }\n});\ncopy_properties(KeyEventController.prototype, {\n    mapKey: function(a) {\n        if (((((a >= 0)) && ((a <= 9))))) {\n            if (((typeof (a) != \"number\"))) {\n                a = ((a.charCodeAt(0) - 48));\n            }\n        ;\n        ;\n            return [((48 + a)),((96 + a)),];\n        }\n    ;\n    ;\n        var b = KeyEventController.keyCodeMap[a.toUpperCase()];\n        if (b) {\n            return b;\n        }\n    ;\n    ;\n        return [a.toUpperCase().charCodeAt(0),];\n    },\n    JSBNG__onkeyevent: function(i, c) {\n        c = $E(c);\n        var d = null;\n        var g = this.handlers[c.keyCode];\n        var b, f, a;\n        if (g) {\n            for (var h = 0; ((h < g.length)); h++) {\n                b = g[h].callback;\n                f = g[h].filter;\n                try {\n                    if (((!f || f(c, i)))) {\n                        a = b(c, i);\n                        if (((a === false))) {\n                            return JSBNG__Event.kill(c);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                } catch (e) {\n                \n                };\n            ;\n            };\n        }\n    ;\n    ;\n        return true;\n    },\n    resetHandlers: function() {\n        this.handlers = {\n        };\n    }\n});\nfunction URLScraper(a) {\n    this.input = a;\n    this.enable();\n};\n;\nClass.mixin(URLScraper, \"Arbiter\", {\n    reset: function() {\n        this.lastMatch = null;\n    },\n    enable: function() {\n        if (this.events) {\n            return;\n        }\n    ;\n    ;\n        var a = function(b) {\n            JSBNG__setTimeout(this.check.bind(this, b), 30);\n        };\n        this.events = JSBNG__Event.listen(this.input, {\n            paste: a.bind(this, false),\n            keydown: a.bind(this, true)\n        });\n    },\n    disable: function() {\n        if (!this.events) {\n            return;\n        }\n    ;\n    ;\n        for (var JSBNG__event in this.events) {\n            this.events[JSBNG__event].remove();\n        ;\n        };\n    ;\n        this.events = null;\n    },\n    check: function(b) {\n        var c = this.input.value;\n        if (((b && URLScraper.trigger(c)))) {\n            return;\n        }\n    ;\n    ;\n        var a = URLScraper.match(c);\n        if (((a && ((a != this.lastMatch))))) {\n            this.lastMatch = a;\n            this.inform(\"match\", {\n                url: a\n            });\n        }\n    ;\n    ;\n    }\n});\n(function() {\n    var a = \"!\\\"#%&'()*,-./:;\\u003C\\u003E?@[\\\\]^_`{|}\", r = \"\\u2000-\\u206f\\u00ab\\u00bb\";\n    var o = \"(?:(?:ht|f)tps?)://\", g = \"(?:(?:\\\\d{1,3}[.]){3}\\\\d{1,3})\", s = \"(?:\\\\b)www\\\\d{0,3}[.]\", j = ((((((\"[^\\\\s\" + a)) + r)) + \"]\")), h = ((((((((\"(?:(?:[.:\\\\-_%@]|\" + j)) + \")*\")) + j)) + \")\")), p = \"(?:[.][a-z]{2,4})\", n = \"(?::\\\\d+){0,1}\", d = \"(?=[/?#])\";\n    var f = ((((((((((((((((((((((((((((((((((((((((((((\"(?:\" + \"(?:\")) + o)) + h)) + n)) + \")|\")) + \"(?:\")) + g)) + n)) + \")|\")) + \"(?:\")) + s)) + h)) + p)) + n)) + \")|\")) + \"(?:\")) + h)) + p)) + n)) + d)) + \")\")) + \")\"));\n    var e = \"[/#?]\", c = \"\\\\([^\\\\s()\\u003C\\u003E]+\\\\)\", l = ((((\"[^\\\\s()\\u003C\\u003E\" + r)) + \"]+\")), k = ((((((\"[^\\\\s\" + a)) + r)) + \"]\"));\n    var m = ((((((((((((((((((((((((((((((((\"(?:\" + \"(?:\")) + e)) + \")\")) + \"(?:\")) + \"(?:\")) + c)) + \"|\")) + l)) + \")*\")) + \"(?:\")) + c)) + \"|\")) + k)) + \")\")) + \")*\")) + \")*\"));\n    var i = new RegExp(((((((((((((((\"(\" + \"(?:\")) + f)) + \")\")) + \"(?:\")) + m)) + \")\")) + \")\")), \"im\");\n    var b = new RegExp(((((((((((((((((((((((((\"(\" + \"(?:\")) + o)) + h)) + n)) + \")|\")) + \"(?:\")) + s)) + h)) + p)) + n)) + \")\")) + \")\")));\n    var q = /[\\s'\";]/;\n    URLScraper.match = function(u) {\n        var t = ((((i.exec(u) || []))[1] || null));\n        if (((t && ((t.indexOf(\"@\") != -1))))) {\n            return (((b.exec(t)) ? t : null));\n        }\n         else return t\n    ;\n    };\n    URLScraper.trigger = function(t) {\n        return !q.test(t.charAt(((t.length - 1))));\n    };\n})();\nfunction rand32() {\n    return Math.floor(((Math.JSBNG__random() * 4294967295)));\n};\n;\nfunction verifyNumber(a) {\n    if (((((((((typeof a == \"undefined\")) || isNaN(a))) || ((a == Number.POSITIVE_INFINITY)))) || ((a == Number.NEGATIVE_INFINITY))))) {\n        a = 0;\n    }\n;\n;\n    return a;\n};\n;\nfunction mod(a, b) {\n    var c = ((a % b));\n    if (((((c * b)) < 0))) {\n        c += b;\n    }\n;\n;\n    return c;\n};\n;\nfunction clip(c, b, a) {\n    return Math.max(b, Math.min(c, a));\n};\n;\nfunction htmlspecialchars(a) {\n    if (((((((typeof (a) == \"undefined\")) || ((a === null)))) || !a.toString))) {\n        return \"\";\n    }\n;\n;\n    if (((a === false))) {\n        return \"0\";\n    }\n     else if (((a === true))) {\n        return \"1\";\n    }\n    \n;\n;\n    return a.toString().replace(/&/g, \"&amp;\").replace(/\"/g, \"&quot;\").replace(/'/g, \"&#039;\").replace(/</g, \"&lt;\").replace(/>/g, \"&gt;\");\n};\n;\nfunction htmlize(a) {\n    return htmlspecialchars(a).replace(/\\n/g, \"\\u003Cbr /\\u003E\");\n};\n;\nfunction escape_js_quotes(a) {\n    if (((((typeof (a) == \"undefined\")) || !a.toString))) {\n        return \"\";\n    }\n;\n;\n    return a.toString().replace(/\\\\/g, \"\\\\\\\\\").replace(/\\n/g, \"\\\\n\").replace(/\\r/g, \"\\\\r\").replace(/\"/g, \"\\\\x22\").replace(/'/g, \"\\\\'\").replace(/</g, \"\\\\x3c\").replace(/>/g, \"\\\\x3e\").replace(/&/g, \"\\\\x26\");\n};\n;\nfunction html_hyperlink(g, h, i, e) {\n    if (((((typeof g === \"undefined\")) || !g.toString))) {\n        return \"\";\n    }\n;\n;\n    if (((typeof h !== \"function\"))) {\n        h = htmlize;\n    }\n;\n;\n    if (((typeof i !== \"function\"))) {\n        i = htmlize;\n    }\n;\n;\n    var g = g.toString();\n    var f = [];\n    var b;\n    while ((b = URLScraper.match(g))) {\n        var d = g.indexOf(b);\n        if (((d >= 0))) {\n            f.push(h(g.substring(0, d)));\n        }\n    ;\n    ;\n        var a = i(b);\n        var c = b.replace(/\"/g, \"%22\");\n        if (!(/^[a-z][a-z0-9\\-+.]+:\\/\\//i.test(b))) {\n            c = ((\"http://\" + c));\n        }\n    ;\n    ;\n        f.push(((((\"\\u003Ca target=\\\"_blank\\\" rel=\\\"nofollow\\\" href=\\\"\" + c)) + \"\\\"\")));\n        if (e) {\n            f.push(((((\" onmousedown=\\\"UntrustedLink.bootstrap(this, '\" + Env.lhsh)) + \"', event)\\\"\")));\n        }\n    ;\n    ;\n        f.push(((((\"\\u003E\" + a)) + \"\\u003C/a\\u003E\")));\n        g = g.substring(((d + b.length)));\n    };\n;\n    ((g && f.push(h(g))));\n    return f.join(\"\");\n};\n;\nfunction nl2br(a) {\n    if (((((typeof (a) == \"undefined\")) || !a.toString))) {\n        return \"\";\n    }\n;\n;\n    return a.toString().replace(/\\n/g, \"\\u003Cbr /\\u003E\");\n};\n;\nfunction is_email(a) {\n    return /^([\\w!.%+\\-])+@([\\w\\-])+(?:\\.[\\w\\-]+)+$/.test(a);\n};\n;\nvar OverlayZIndexHelper = {\n    getZIndex: function(c, e) {\n        e = ((e || JSBNG__document.body));\n        var b = [];\n        while (((c && ((c !== e))))) {\n            b.push(c);\n            c = c.parentNode;\n        };\n    ;\n        for (var d = ((b.length - 1)); ((d >= 0)); d--) {\n            var a = b[d];\n            if (((CSS.getStyle(a, \"position\") != \"static\"))) {\n                var f = parseInt(CSS.getStyle(a, \"z-index\"), 10);\n                if (!isNaN(f)) {\n                    return f;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        return 0;\n    }\n};\nHovercard = ((window.Hovercard || {\n    RESERVED_WIDTH: 297,\n    RESERVED_HEIGHT: 237,\n    ARROW_LEFT_OFFSET: 32,\n    cache: {\n    },\n    active: {\n    },\n    contextElem: null,\n    fetchDelay: 150,\n    showDelay: 700,\n    loadingDelay: 1000,\n    hideDelay: 250,\n    fetchTimer: null,\n    showTimer: null,\n    loadingTimer: null,\n    hideTimer: null,\n    init: function() {\n        if (((ua.ie() < 7))) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"mouseover\", this.handle.bind(this));\n    },\n    handle: function(JSBNG__event) {\n        var a = Parent.byTag(JSBNG__event.getTarget(), \"a\");\n        if (((((a || !this.isShowing)) && this.setActive(a)))) {\n            this.process(a);\n            JSBNG__event.JSBNG__stop();\n        }\n    ;\n    ;\n    },\n    setActive: function(b) {\n        if (!this.isActive(b)) {\n            var a;\n            if (((!b || !(a = this.getEndpoint(b))))) {\n                this.active = {\n                };\n                return false;\n            }\n        ;\n        ;\n            if (((this.active.node != b))) {\n                ((this.active.moveToken && this.active.moveToken.remove()));\n                this.active = {\n                    node: b,\n                    endpoint: a,\n                    pos: null\n                };\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return true;\n    },\n    isActive: function(a) {\n        return ((((a && this.isShowing)) && ((this.active.node == a))));\n    },\n    getEndpoint: function(a) {\n        return a.getAttribute(\"data-hovercard\");\n    },\n    process: function(b) {\n        var d = JSBNG__Event.listen(b, \"mouseout\", function() {\n            JSBNG__clearTimeout(this.fetchTimer);\n            JSBNG__clearTimeout(this.showTimer);\n            d.remove();\n            this.hide();\n        }.bind(this));\n        if (!this.active.moveToken) {\n            this.active.moveToken = JSBNG__Event.listen(b, \"mousemove\", function(JSBNG__event) {\n                this.active.pos = Vector2.getEventPosition(JSBNG__event);\n            }.bind(this));\n        }\n    ;\n    ;\n        JSBNG__clearTimeout(this.fetchTimer);\n        JSBNG__clearTimeout(this.showTimer);\n        JSBNG__clearTimeout(this.hideTimer);\n        var a = this.fetchDelay;\n        var c = ((this.contextElem ? this.hideDelay : this.showDelay));\n        if (b.getAttribute(\"data-hovercard-instant\")) {\n            a = c = 50;\n        }\n    ;\n    ;\n        this.fetchTimer = JSBNG__setTimeout(this.fetch.bind(this, b), a);\n        this.showTimer = JSBNG__setTimeout(this.show.bind(this, b), c);\n    },\n    show: function(c, b) {\n        this.build();\n        if (((this.active.node != c))) {\n            return;\n        }\n    ;\n    ;\n        var a;\n        if (this.cache[this.getEndpoint(c)]) {\n            a = this.cache[this.getEndpoint(c)];\n        }\n         else if (b) {\n            a = {\n                JSBNG__content: \"\",\n                node: this.loading\n            };\n        }\n         else {\n            var d = ((this.contextElem ? this.hideDelay : this.showDelay));\n            this.loadingTimer = JSBNG__setTimeout(this.show.bind(this, c, true), ((this.loadingDelay - d)));\n        }\n        \n    ;\n    ;\n        ((a && this.update(a)));\n    },\n    hide: function(a) {\n        if (!this.contextElem) {\n            return;\n        }\n    ;\n    ;\n        if (a) {\n            Arbiter.inform(\"layer_hidden\", {\n                type: \"Hovercard\"\n            });\n            Arbiter.inform(\"Hovercard/hide\", {\n                node: this.contextElem\n            });\n            if (((this.stage && this.stage.firstChild))) {\n                this.preload.appendChild(this.stage.firstChild);\n            }\n        ;\n        ;\n            var b = ((this.container && this.container.parentNode));\n            ((b && b.removeChild(this.container)));\n            this.contextElem = null;\n        }\n         else this.hideTimer = JSBNG__setTimeout(this.hide.bind(this, true), this.hideDelay);\n    ;\n    ;\n    },\n    build: function() {\n        this.build = bagofholding;\n        var c = $N(\"div\", {\n            className: \"arrow\"\n        }, $N(\"i\"));\n        this.loading = $N(\"div\", {\n            className: \"loading\"\n        }, _tx(\"Loading...\"));\n        this.stage = $N(\"div\", {\n            className: \"stage\"\n        });\n        this.preload = $N(\"div\", {\n            id: \"hovercardPreload\"\n        }, this.loading);\n        this.overlay = $N(\"div\", {\n            className: \"HovercardOverlay\"\n        });\n        this.container = $N(\"div\", {\n            className: \"hovercard clearfix\"\n        }, [this.stage,c,]);\n        JSBNG__Event.listen(window, \"JSBNG__scroll\", bind(this, \"hide\", true));\n        JSBNG__Event.listen(this.container, {\n            mouseleave: bind(this, \"hide\", false),\n            mouseenter: function() {\n                JSBNG__clearTimeout(this.hideTimer);\n            }.bind(this)\n        });\n        var a = null;\n        var b = [];\n        Arbiter.subscribe(\"Overlay/show\", function(d, e) {\n            var f = e.overlay;\n            if (f.getContext) {\n                if (DOM.contains(this.container, f.getContext())) {\n                    while (b.length) {\n                        a.unsubscribe(b.pop());\n                    ;\n                    };\n                ;\n                    a = f;\n                    b = [f.subscribe(\"mouseenter\", function() {\n                        JSBNG__clearTimeout(this.hideTimer);\n                    }.bind(this)),f.subscribe(\"mouseleave\", bind(this, \"hide\", false)),];\n                }\n            ;\n            }\n        ;\n        ;\n        }.bind(this));\n        Arbiter.subscribe(\"Overlay/hide\", function(d, e) {\n            if (((a === e.overlay))) {\n                while (b.length) {\n                    a.unsubscribe(b.pop());\n                ;\n                };\n            ;\n                a = null;\n            }\n        ;\n        ;\n        }.bind(this));\n        Arbiter.subscribe(\"page_transition\", function() {\n            this.abort();\n            this.dirtyAll();\n        }.bind(this), Arbiter.SUBSCRIBE_NEW);\n        Arbiter.subscribe(\"layer_shown\", function(d, e) {\n            ((((((e.type != \"Hovercard\")) && ((e.type != \"Overlay\")))) && this.abort()));\n        }.bind(this), Arbiter.SUBSCRIBE_NEW);\n        JSBNG__document.body.appendChild(this.preload);\n    },\n    abort: function() {\n        this.hide(true);\n        JSBNG__clearTimeout(this.showTimer);\n        JSBNG__clearTimeout(this.loadingTimer);\n    },\n    update: function(a) {\n        var g = this.contextElem;\n        var f = this.stage.firstChild;\n        var h = ((f === this.loading));\n        if (f) {\n            this.preload.appendChild(f);\n        }\n    ;\n    ;\n        var b = a.node;\n        var c = ((b && b.getAttribute(\"data-hovercard-layout\")));\n        this.container.className = \"hovercard\";\n        ((c && CSS.addClass(this.container, c)));\n        var d = this.active.node;\n        var e = ((((d != g)) && !h));\n        if (e) {\n            (function() {\n                new AsyncSignal(\"/ajax/hovercard/shown.php\").send();\n                report_data(\"himp\", {\n                    ft: {\n                        evt: 39\n                    }\n                });\n            }).defer();\n        }\n    ;\n    ;\n        var i = OverlayZIndexHelper.getZIndex(d);\n        CSS.setStyle(this.overlay, \"z-index\", ((((i > 200)) ? ((i + 1)) : \"\")));\n        this.stage.appendChild(b);\n        this.position(d, d.getAttribute(\"data-hovercard-fixed\"));\n        this.overlay.appendChild(this.container);\n        JSBNG__document.body.appendChild(this.overlay);\n        this.contextElem = d;\n        if (e) {\n            if (g) {\n                Arbiter.inform(\"Hovercard/hide\", {\n                    node: g\n                });\n            }\n             else Arbiter.inform(\"layer_shown\", {\n                type: \"Hovercard\"\n            });\n        ;\n        ;\n            Arbiter.inform(\"Hovercard/show\", {\n                node: d\n            });\n        }\n    ;\n    ;\n    },\n    position: function(f, e) {\n        if (((!this.wCheck && e))) {\n            this.wCheck = $N(\"div\", {\n                className: \"HovercardWidthCheck\"\n            });\n            JSBNG__document.body.appendChild(this.wCheck);\n        }\n    ;\n    ;\n        var h;\n        var c = ((((this.wCheck && e)) ? this.wCheck.offsetWidth : 0));\n        var b = this.getBounds(f);\n        var i = b.getPositionVector().convertTo(\"viewport\");\n        var a = ((i.y < this.RESERVED_HEIGHT));\n        var j = Vector2.getViewportDimensions();\n        var g = ((((c || j.x)) < ((this.RESERVED_WIDTH + b.l))));\n        var d = ((g ? ((c - b.r)) : b.l));\n        if (((b.w() < ((2 * this.ARROW_LEFT_OFFSET))))) {\n            d += ((((b.w() / 2)) - this.ARROW_LEFT_OFFSET));\n        }\n    ;\n    ;\n        if (a) {\n            h = ((e ? ((i.y + b.h())) : b.b));\n        }\n         else h = ((e ? ((j.y - i.y)) : -b.t));\n    ;\n    ;\n        CSS.conditionClass(this.container, \"HovercardFromRight\", g);\n        CSS.conditionClass(this.container, \"HovercardBelow\", a);\n        CSS.conditionClass(this.container, \"HovercardFixed\", e);\n        CSS.setStyle(this.container, ((g ? \"right\" : \"left\")), ((d + \"px\")));\n        CSS.setStyle(this.container, ((g ? \"left\" : \"right\")), \"auto\");\n        CSS.setStyle(this.container, ((a ? \"JSBNG__top\" : \"bottom\")), ((h + \"px\")));\n        CSS.setStyle(this.container, ((a ? \"bottom\" : \"JSBNG__top\")), \"auto\");\n    },\n    getBounds: function(e) {\n        var a = this.active.pos;\n        var h = e.getClientRects();\n        if (((!a || ((h.length === 0))))) {\n            return JSBNG__Rect.getElementBounds(e);\n        }\n    ;\n    ;\n        var b;\n        var c = false;\n        for (var d = 0; ((d < h.length)); d++) {\n            var g = new JSBNG__Rect(Math.round(h[d].JSBNG__top), Math.round(h[d].right), Math.round(h[d].bottom), Math.round(h[d].left), \"viewport\").convertTo(\"JSBNG__document\");\n            var f = g.getPositionVector();\n            var i = f.add(g.getDimensionVector());\n            if (((!b || ((((f.x <= b.l)) && ((f.y > b.t))))))) {\n                if (c) {\n                    break;\n                }\n            ;\n            ;\n                b = new JSBNG__Rect(f.y, i.x, i.y, f.x, \"JSBNG__document\");\n            }\n             else {\n                b.t = Math.min(b.t, f.y);\n                b.b = Math.max(b.b, i.y);\n                b.r = i.x;\n            }\n        ;\n        ;\n            if (g.contains(a)) {\n                c = true;\n            }\n        ;\n        ;\n        };\n    ;\n        return b;\n    },\n    fetch: function(d, a) {\n        a = ((((typeof a === \"function\")) ? a : bagofholding));\n        if (((d.id && ((this.cache[d.id] != null))))) {\n            return a();\n        }\n    ;\n    ;\n        var b = this.getEndpoint(d);\n        if (((this.cache[b] != null))) {\n            return a();\n        }\n    ;\n    ;\n        this.setFetchInProgress(b);\n        var c = function() {\n            this.dirty(b);\n            this.abort();\n        }.bind(this);\n        new AsyncRequest(b).setMethod(\"GET\").setReadOnly(true).setHandler(function(f) {\n            var e = f.getPayload();\n            if (((!e || !e.JSBNG__content))) {\n                c();\n                return;\n            }\n        ;\n        ;\n            e.node = HTML(e.JSBNG__content).getRootNode();\n            delete e.JSBNG__content;\n            this.setCache(b, e);\n        }.bind(this)).setErrorHandler(c).setTransportErrorHandler(c).setFinallyHandler(a).send();\n    },\n    setFetchInProgress: function(a) {\n        this.cache[a] = false;\n    },\n    setCache: function(b, a) {\n        this.build();\n        this.cache[b] = a;\n        if (((((this.active.endpoint == b)) && this.contextElem))) {\n            this.update(a);\n        }\n         else DOM.appendContent(this.preload, a.node);\n    ;\n    ;\n    },\n    contains: function(a) {\n        return DOM.contains(this.stage, a);\n    },\n    dirty: function(b) {\n        var a = this.cache[b];\n        var c = a.node;\n        var d = ((c && c.parentNode));\n        ((d && d.removeChild(c)));\n        delete this.cache[b];\n    },\n    dirtyAll: function() {\n        for (var b in this.cache) {\n            var a = this.cache[b];\n            ((((a && !a.cachepermanently)) && this.dirty(b)));\n        };\n    ;\n    }\n}));\nJSBNG__onloadRegister(Hovercard.init.bind(Hovercard));\nvar DocumentTitle = ((window.DocumentTitle || (function(g) {\n    var a = 1500;\n    var f = [];\n    var e = 0;\n    var c = null;\n    var d = true;\n    function b() {\n        if (((f.length > 0))) {\n            if (d) {\n                DocumentTitle.set(f[e].title, true);\n                e = ((++e % f.length));\n                d = false;\n            }\n             else DocumentTitle.reset();\n        ;\n        ;\n        }\n         else {\n            JSBNG__clearInterval(c);\n            c = null;\n            DocumentTitle.reset();\n        }\n    ;\n    ;\n    };\n;\n    return {\n        get: function() {\n            return g;\n        },\n        set: function(h, i) {\n            JSBNG__document.title = h;\n            if (!i) {\n                g = h;\n                Arbiter.inform(\"update_title\", h);\n            }\n        ;\n        ;\n        },\n        reset: function() {\n            DocumentTitle.set(DocumentTitle.get(), true);\n            d = true;\n        },\n        blink: function(i) {\n            var h = {\n                title: i\n            };\n            f.push(h);\n            if (((c === null))) {\n                c = JSBNG__setInterval(b, a);\n            }\n        ;\n        ;\n            return {\n                JSBNG__stop: function() {\n                    var j = f.indexOf(h);\n                    if (((j >= 0))) {\n                        f.splice(j, 1);\n                        if (((e > j))) {\n                            e--;\n                        }\n                         else if (((((e == j)) && ((e == f.length))))) {\n                            e = 0;\n                        }\n                        \n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            };\n        }\n    };\n})(JSBNG__document.title)));\nfunction Poller(c, b, a) {\n    this._clearOnQuicklingEvent = !a;\n    this._requestCallback = b;\n    this.setTimePeriod(c);\n};\n;\nPoller.MIN_TIME_PERIOD = 2000;\ncopy_properties(Poller.prototype, {\n    JSBNG__stop: function() {\n        JSBNG__clearTimeout(this._token);\n        this._token = null;\n        this._cancelRequest();\n    },\n    scheduleRequest: function() {\n        this.JSBNG__stop();\n        if (this._timePeriod) {\n            this._token = this._makeRequest.bind(this).defer(this._timePeriod, this._clearOnQuicklingEvent);\n        }\n    ;\n    ;\n    },\n    requestNow: function() {\n        this.JSBNG__stop();\n        this._makeRequest();\n    },\n    _timePeriod: null,\n    setTimePeriod: function(a) {\n        a = ((a || null));\n        if (((a && ((isNaN(a) || ((a < Poller.MIN_TIME_PERIOD))))))) {\n            return;\n        }\n    ;\n    ;\n        if (((a && ((this._timePeriod == null))))) {\n            this._token = this._makeRequest.bind(this).defer(a, this._clearOnQuicklingEvents);\n        }\n    ;\n    ;\n        this._timePeriod = a;\n    },\n    _makeRequest: function() {\n        this._cancelRequest();\n        if (!this._isLoadUser()) {\n            return;\n        }\n    ;\n    ;\n        var b = new AsyncRequest();\n        var a = true;\n        b.setInitialHandler(function() {\n            return a;\n        });\n        this._cancelRequest = function() {\n            a = false;\n        };\n        b.setFinallyHandler(this.scheduleRequest.bind(this));\n        b.setInitialHandler = bagofholding;\n        b.setFinallyHandler = bagofholding;\n        this._requestCallback(b);\n        if (a) {\n            b.send();\n        }\n    ;\n    ;\n    },\n    _isLoadUser: function() {\n        return ((Env.user == getCookie(\"c_user\")));\n    },\n    _cancelRequest: bagofholding,\n    getTimePeriod: function() {\n        return this._timePeriod;\n    }\n});\nfunction XHPTemplate(a) {\n    this.model = a;\n};\n;\nXHPTemplate.prototype = {\n    render: function() {\n        if (HTML.isHTML(this.model)) {\n            this.model = DOM.setContent(JSBNG__document.createDocumentFragment(), this.model)[0];\n        }\n    ;\n    ;\n        return this.model.cloneNode(true);\n    }\n};\n(function() {\n    var a = \"XHPTemplate:nodes\";\n    copy_properties(XHPTemplate, {\n        getNode: function(c, b) {\n            return XHPTemplate.getNodes(c)[b];\n        },\n        getNodes: function(e) {\n            var d = DataStore.get(e, a);\n            if (!d) {\n                d = {\n                };\n                var f = DOM.scry(e, \"[data-jsid]\");\n                f.push(e);\n                var b = f.length;\n                while (b--) {\n                    var c = f[b];\n                    d[c.getAttribute(\"data-jsid\")] = c;\n                    c.removeAttribute(\"data-jsid\");\n                };\n            ;\n                DataStore.set(e, a, d);\n            }\n        ;\n        ;\n            return d;\n        }\n    });\n})();\nUserActivity = ((window.UserActivity || {\n    SIGNAL: \"useractivity/activity\",\n    _lastActive: +new JSBNG__Date(),\n    _listeners: null,\n    DEFAULT_IDLE_MS: 5000,\n    EVENT_INTERVAL_MS: 500,\n    JSBNG__onActivity: function(JSBNG__event) {\n        UserActivity._listeners.forEach(function(a) {\n            a.remove();\n        });\n        UserActivity._listeners = null;\n        UserActivity._lastActive = +new JSBNG__Date();\n        JSBNG__setTimeout(UserActivity.listen, UserActivity.EVENT_INTERVAL_MS);\n        Arbiter.inform(UserActivity.SIGNAL, JSBNG__event);\n    },\n    listen: function() {\n        if (UserActivity._listeners) {\n            return;\n        }\n    ;\n    ;\n        UserActivity._listeners = [JSBNG__Event.listen(JSBNG__document.body, \"mouseover\", UserActivity.JSBNG__onActivity),JSBNG__Event.listen(JSBNG__document.body, \"keydown\", UserActivity.JSBNG__onActivity),JSBNG__Event.listen(JSBNG__document.body, \"click\", UserActivity.JSBNG__onActivity),];\n    },\n    subscribeOnce: function(a) {\n        var b = UserActivity.subscribe(function() {\n            UserActivity.unsubscribe(b);\n            a();\n        });\n    },\n    subscribe: function(a) {\n        UserActivity.listen();\n        return Arbiter.subscribe(UserActivity.SIGNAL, a, Arbiter.SUBSCRIBE_NEW);\n    },\n    unsubscribe: function(a) {\n        Arbiter.unsubscribe(a);\n    },\n    isActive: function(a) {\n        return ((((new JSBNG__Date() - UserActivity._lastActive)) < ((a || UserActivity.DEFAULT_IDLE_MS))));\n    }\n}));\nJSBNG__onloadRegister(UserActivity.listen);\nvar Live = {\n    logAll: false,\n    startup: function() {\n        Live.startup = bagofholding;\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"live\"), Live.handleMessage.bind(Live));\n    },\n    lookupLiveNode: function(b, a) {\n        var c = DOM.scry(JSBNG__document.body, ((((((\".live_\" + b)) + \"_\")) + a)));\n        c.forEach(function(e) {\n            if (((DataStore.get(e, \"seqnum\") === undefined))) {\n                var d = JSON.parse(e.getAttribute(\"data-live\"));\n                DataStore.set(e, \"seqnum\", d.seq);\n            }\n        ;\n        ;\n        });\n        return c;\n    },\n    handleMessage: function(f, b) {\n        var d = b.obj;\n        var c = d.fbid;\n        var a = d.assoc;\n        var e = this.lookupLiveNode(c, a);\n        if (!e) {\n            return false;\n        }\n    ;\n    ;\n        e.forEach(function(l) {\n            var k = {\n                getRelativeTo: function() {\n                    return l;\n                }\n            };\n            if (d.expseq) {\n                var i = DataStore.get(l, \"seqnum\");\n                var g = DataStore.get(l, \"message_buffer\");\n                if (((g === undefined))) {\n                    g = {\n                    };\n                    DataStore.set(l, \"message_buffer\", g);\n                }\n            ;\n            ;\n                var h = {\n                    obj: d\n                };\n                g[d.expseq] = h;\n                if (((d.expseq != i))) {\n                    Live.log(\"mismatch\", d.fbid, d.expseq, i);\n                    return false;\n                }\n            ;\n            ;\n                while (true) {\n                    i = DataStore.get(l, \"seqnum\");\n                    var j = g[i];\n                    if (j) {\n                        Live._applyUpdates(j.obj.updates, k);\n                        Live.log(\"seqmatch\", d.fbid, \"exp\", d.expseq, \"cur\", i);\n                        delete g[i];\n                    }\n                     else break;\n                ;\n                ;\n                };\n            ;\n            }\n             else Live._applyUpdates(d.updates, k);\n        ;\n        ;\n        });\n    },\n    _applyUpdates: function(c, b) {\n        try {\n            $A(c).each(function(d) {\n                new Function(d).apply(b);\n            });\n        } catch (a) {\n        \n        };\n    ;\n    },\n    log: function() {\n        if (Live.logAll) {\n            var a = $A(arguments).join(\":\");\n            new AsyncSignal(\"/common/scribe_endpoint.php\", {\n                c: \"live_sequence\",\n                m: a\n            }).send();\n        }\n    ;\n    ;\n    }\n};\nfunction OnVisible(b, c, f, a, d) {\n    d = ((d || {\n    }));\n    this.buffer = coalesce(a, 300);\n    this.lastY = Vector2.getScrollPosition().y;\n    this.lastTime = (+new JSBNG__Date());\n    var e = throttle(function() {\n        this.targetY = Vector2.getElementPosition(b).y;\n        var l = Vector2.getScrollPosition().y;\n        var j = Vector2.getViewportDimensions().y;\n        var k = ((((l + j)) + this.buffer));\n        if (((k > this.targetY))) {\n            var i = ((!f || ((((l - this.buffer)) < ((this.targetY + Vector2.getElementDimensions(b).y))))));\n            if (i) {\n                this.remove();\n                if (d.detect_speed) {\n                    var g = ((l - this.lastY));\n                    var h = ((g / (((((+new JSBNG__Date()) - this.lastTime)) + 1))));\n                    if (((((h > ((j / 100)))) || ((((k >= Vector2.getDocumentDimensions().y)) && ((g > 1000))))))) {\n                        return true;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                c();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (d.detect_speed) {\n            this.lastY = l;\n            this.lastTime = (+new JSBNG__Date());\n        }\n    ;\n    ;\n        return true;\n    }.bind(this), 100);\n    this.scrollListener = JSBNG__Event.listen(window, \"JSBNG__scroll\", e);\n    this.resizeListener = JSBNG__Event.listen(window, \"resize\", e);\n    e();\n    JSBNG__onleaveRegister(this.remove.bind(this));\n};\n;\ncopy_properties(OnVisible.prototype, {\n    remove: function() {\n        if (this.scrollListener) {\n            this.scrollListener.remove();\n            this.resizeListener.remove();\n            this.scrollListener = this.resizeListener = null;\n        }\n    ;\n    ;\n    }\n});\nvar PhotosConst = {\n    VIEWER_PERMALINK: 0,\n    VIEWER_THEATER: 1,\n    VIEWER_SNOWBOX: 2,\n    inCenterStage: function(a) {\n        return ((((a == PhotosConst.VIEWER_THEATER)) || ((a == PhotosConst.VIEWER_SNOWBOX))));\n    },\n    SIZE_NORMAL: \"n\"\n};\nvar PhotoInlineCaptionEditor = function(a) {\n    this.instanceId = a;\n    PhotoInlineCaptionEditor.instances[a] = this;\n};\ncopy_properties(PhotoInlineCaptionEditor, {\n    instances: {\n    },\n    getInstance: function(a) {\n        return this.instances[a];\n    }\n});\nPhotoInlineCaptionEditor.prototype = {\n    init: function(a) {\n        this.element = a;\n        JSBNG__Event.listen(a, \"click\", this.handleClick.bind(this));\n        var b = DOM.scry(a, \"input[name=\\\"caption_id\\\"]\");\n        if (b.length) {\n            b[0].value = this.instanceId;\n        }\n    ;\n    ;\n        this.inputStr = \"\";\n        var c = DOM.scry(this.element, \"textarea.fbPhotoCaptionInput\")[0];\n        if (c) {\n            this.inputStr = Input.getValue(c);\n        }\n    ;\n    ;\n    },\n    handleClick: function(JSBNG__event) {\n        var a = JSBNG__event.getTarget();\n        if (((Parent.byClass(a, \"editIcon\") || Parent.byClass(a, \"noCaption\")))) {\n            this.toggleEditDescription(true);\n        }\n         else if (Parent.byClass(a, \"cancelEdit\")) {\n            Input.setValue(DOM.JSBNG__find(this.element, \"textarea.fbPhotoCaptionInput\"), this.inputStr);\n            this.toggleEditDescription(false);\n        }\n        \n    ;\n    ;\n    },\n    setCaption: function(a) {\n        DOM.setContent(DOM.JSBNG__find(this.element, \".fbPhotoCaptionText\"), a);\n        this.toggleEditDescription(false);\n        this.inputStr = Input.getValue(DOM.JSBNG__find(this.element, \"textarea.fbPhotoCaptionInput\"));\n    },\n    getCaption: function() {\n        return DOM.getText(DOM.JSBNG__find(this.element, \".fbPhotoCaptionText\"));\n    },\n    toggleEditDescription: function(c) {\n        if (!c) {\n            DOM.JSBNG__find(this.element, \"textarea.fbPhotoCaptionInput\").JSBNG__blur();\n        }\n    ;\n    ;\n        CSS.conditionClass(this.element, \"fbPhotoInlineCaptionEditorEditMode\", !!c);\n        if (c) {\n            var b = DOM.JSBNG__find(this.element, \"textarea.fbPhotoCaptionInput\");\n            var a = DOMControl.getInstance(b);\n            ((a && a.update()));\n            b.JSBNG__focus();\n        }\n         else CSS.conditionClass(DOM.JSBNG__find(this.element, \".noCaption\"), \"hidden_elem\", this.getCaption().length);\n    ;\n    ;\n    }\n};\nfunction PhotosTaggingWaterfall(a) {\n    PhotosTaggingWaterfall._queueName = ((a || PhotosTaggingWaterfall._queueName));\n};\n;\ncopy_properties(PhotosTaggingWaterfall, {\n    BEGIN: \"begin\",\n    TAG_FACE: \"tag_face\",\n    ADD_NAME: \"add_name\",\n    TAG_CONFIRMED: \"tag_confirmed\",\n    FINISH: \"finish\",\n    TYPE_NAME: \"type_name\",\n    SELECT_NAME: \"select_name\",\n    _queueName: null,\n    sendSignal: function(b, a) {\n        new AsyncSignal(\"/ajax/photos/tag_waterfall.php\", {\n            data: JSON.stringify(b)\n        }).setHandler(a).send();\n    }\n});\nfunction Typeahead(b, d, a, c) {\n    this.args = {\n        data: b,\n        view: d,\n        core: a\n    };\n    DataStore.set(c, \"Typeahead\", this);\n    this.element = c;\n};\n;\nTypeahead.getInstance = function(a) {\n    var b = Parent.byClass(a, \"uiTypeahead\");\n    return ((b ? DataStore.get(b, \"Typeahead\") : null));\n};\nClass.mixin(Typeahead, \"Arbiter\", {\n    init: function(a) {\n        this.init = bagofholding;\n        this.getCore();\n        this.proxyEvents();\n        this.initBehaviors(((a || [])));\n        this.inform(\"init\", this);\n        this.data.bootstrap();\n        this.core.JSBNG__focus();\n    },\n    getData: function() {\n        if (!this.data) {\n            var a = this.args.data;\n            this.data = a;\n            this.data.init();\n        }\n    ;\n    ;\n        return this.data;\n    },\n    getView: function() {\n        if (!this.view) {\n            var a = this.args.view;\n            var b = ge(a.node_id);\n            if (!b) {\n                b = $N(\"div\", {\n                    className: \"uiTypeaheadView\"\n                });\n                DOM.appendContent(this.element, b);\n            }\n        ;\n        ;\n            this.view = new window[a.ctor](b, ((a.options || {\n            })));\n            this.view.init();\n        }\n    ;\n    ;\n        return this.view;\n    },\n    getCore: function() {\n        if (!this.core) {\n            var a = this.args.core;\n            this.core = new window[a.ctor](((a.options || {\n            })));\n            this.core.init(this.getData(), this.getView(), this.getElement());\n        }\n    ;\n    ;\n        return this.core;\n    },\n    getElement: function() {\n        return this.element;\n    },\n    swapData: function(b) {\n        var a = this.core;\n        this.data = this.args.data = b;\n        b.init();\n        if (a) {\n            a.data = b;\n            a.initData();\n            a.reset();\n        }\n    ;\n    ;\n        b.bootstrap();\n        return b;\n    },\n    proxyEvents: function() {\n        [this.data,this.view,this.core,].each(function(a) {\n            a.subscribe(a.events, this.inform.bind(this));\n        }, this);\n    },\n    initBehaviors: function(a) {\n        if (window.TypeaheadBehaviors) {\n            a.each(function(b) {\n                ((TypeaheadBehaviors[b] || bagofholding))(this);\n            }, this);\n        }\n    ;\n    ;\n    }\n});\nvar TypeaheadUtil = (function() {\n    var b = /[ ]+/g;\n    var c = /[^ ]+/g;\n    var a = /[.,+*?$|#{}()\\^\\-\\[\\]\\\\\\/!@%'\"~=<>_:;\\u2010\\u2011\\u2012\\u2013\\u2014\\u2015\\u30fb]/g;\n    var d = {\n    };\n    var r = {\n        a: \"\\u0430 \\u00e0 \\u00e1 \\u00e2 \\u00e3 \\u00e4 \\u00e5\",\n        b: \"\\u0431\",\n        c: \"\\u0446 \\u00e7 \\u010d\",\n        d: \"\\u0434 \\u00f0 \\u010f \\u0111\",\n        e: \"\\u044d \\u0435 \\u00e8 \\u00e9 \\u00ea \\u00eb \\u011b\",\n        f: \"\\u0444\",\n        g: \"\\u0433 \\u011f\",\n        h: \"\\u0445 \\u0127\",\n        i: \"\\u0438 \\u00ec \\u00ed \\u00ee \\u00ef \\u0131\",\n        j: \"\\u0439\",\n        k: \"\\u043a \\u0138\",\n        l: \"\\u043b \\u013e \\u013a \\u0140 \\u0142\",\n        m: \"\\u043c\",\n        n: \"\\u043d \\u00f1 \\u0148 \\u0149 \\u014b\",\n        o: \"\\u043e \\u00f8 \\u00f6 \\u00f5 \\u00f4 \\u00f3 \\u00f2\",\n        p: \"\\u043f\",\n        r: \"\\u0440 \\u0159 \\u0155\",\n        s: \"\\u0441 \\u015f \\u0161 \\u017f\",\n        t: \"\\u0442 \\u0165 \\u0167 \\u00fe\",\n        u: \"\\u0443 \\u044e \\u00fc \\u00fb \\u00fa \\u00f9 \\u016f\",\n        v: \"\\u0432\",\n        y: \"\\u044b \\u00ff \\u00fd\",\n        z: \"\\u0437 \\u017e\",\n        ae: \"\\u00e6\",\n        oe: \"\\u0153\",\n        ts: \"\\u0446\",\n        ch: \"\\u0447\",\n        ij: \"\\u0133\",\n        sh: \"\\u0448\",\n        ss: \"\\u00df\",\n        ya: \"\\u044f\"\n    };\n    for (var m in r) {\n        var f = r[m].split(\" \");\n        for (var h = 0; ((h < f.length)); h++) {\n            d[f[h]] = m;\n        ;\n        };\n    ;\n    };\n;\n    var p = {\n    };\n    function e(s) {\n        return ((s ? s.replace(a, \" \") : \"\"));\n    };\n;\n    function g(v) {\n        v = ((\"\" + v)).toLowerCase();\n        var u = \"\";\n        var s = \"\";\n        for (var t = v.length; t--; ) {\n            s = v.charAt(t);\n            u = ((((d[s] || s)) + u));\n        };\n    ;\n        return u.replace(b, \" \");\n    };\n;\n    function q(t) {\n        var u = [];\n        var s = c.exec(t);\n        while (s) {\n            s = s[0];\n            u.push(s);\n            s = c.exec(t);\n        };\n    ;\n        return u;\n    };\n;\n    function o(v, u) {\n        v = ((\"\" + v));\n        if (!p.hasOwnProperty(v)) {\n            var t = g(v);\n            var s = e(t);\n            p[v] = {\n                value: v,\n                flatValue: t,\n                tokens: q(s),\n                isPrefixQuery: ((s && ((s[((s.length - 1))] != \" \"))))\n            };\n        }\n    ;\n    ;\n        if (((u && ((typeof p[v].sortedTokens == \"undefined\"))))) {\n            p[v].sortedTokens = copy_properties([], p[v].tokens);\n            p[v].sortedTokens.sort(function(w, x) {\n                return ((x.length - w.length));\n            });\n        }\n    ;\n    ;\n        return p[v];\n    };\n;\n    function j(s, y, u) {\n        var x = o(y, ((s == \"prefix\")));\n        var z = ((((s == \"prefix\")) ? x.sortedTokens : x.tokens));\n        var v = o(u).tokens;\n        var t = {\n        };\n        var w = ((((x.isPrefixQuery && ((s == \"query\")))) ? ((z.length - 1)) : null));\n        return z.every(function(zc, zb) {\n            for (var za = 0; ((za < v.length)); ++za) {\n                var zd = v[za];\n                if (((!t[za] && ((((zd == zc)) || ((((((((s == \"query\")) && ((zb === w)))) || ((s == \"prefix\")))) && ((zd.indexOf(zc) === 0))))))))) {\n                    return (t[za] = true);\n                }\n            ;\n            ;\n            };\n        ;\n            return false;\n        });\n    };\n;\n    var i = j.curry(\"exact\");\n    var l = j.curry(\"query\");\n    var k = j.curry(\"prefix\");\n    var n = {\n        parse: o,\n        isExactMatch: i,\n        isQueryMatch: l,\n        isPrefixMatch: k\n    };\n    return n;\n})();\nfunction DataSource(a) {\n    this._maxResults = ((a.maxResults || 10));\n    this.token = a.token;\n    this.queryData = ((a.queryData || {\n    }));\n    this.queryEndpoint = ((a.queryEndpoint || \"\"));\n    this.bootstrapData = ((a.bootstrapData || {\n    }));\n    this.bootstrapEndpoint = ((a.bootstrapEndpoint || \"\"));\n    this._exclusions = ((a.exclusions || []));\n    this._indexedFields = ((a.indexedFields || [\"text\",\"tokens\",]));\n    this._alwaysPrefixMatch = ((a.alwaysPrefixMatch || false));\n    this._minExactMatchLength = 4;\n};\n;\nClass.mixin(DataSource, \"Arbiter\", {\n    events: [\"activity\",\"query\",\"respond\",],\n    init: function() {\n        this.init = bagofholding;\n        this._fields = Object.from(this._indexedFields);\n        this._activeQueries = 0;\n        this.dirty();\n    },\n    dirty: function() {\n        this.value = \"\";\n        this._bootstrapped = false;\n        this._data = {\n        };\n        this.localCache = {\n        };\n        this.queryCache = {\n        };\n    },\n    bootstrap: function() {\n        if (this._bootstrapped) {\n            return;\n        }\n    ;\n    ;\n        this.bootstrapWithoutToken();\n        this._bootstrapped = true;\n    },\n    bootstrapWithoutToken: function() {\n        this.fetch(this.bootstrapEndpoint, this.bootstrapData, {\n            token: this.token\n        });\n    },\n    bootstrapWithToken: function() {\n        var a = copy_properties({\n        }, this.bootstrapData);\n        a.token = this.token;\n        this.fetch(this.bootstrapEndpoint, a, {\n            replaceCache: true\n        });\n    },\n    query: function(f, c, a) {\n        this.inform(\"beforeQuery\", {\n            value: f\n        });\n        var e = this.buildUids(f, [], a);\n        var d = this.respond(f, e);\n        this.value = f;\n        this.inform(\"query\", {\n            value: f,\n            results: d\n        });\n        var b = TypeaheadUtil.parse(f).flatValue;\n        if (((((((((c || !b)) || !this.queryEndpoint)) || this.getQueryCache().hasOwnProperty(b))) || !this.shouldFetchMoreResults(d)))) {\n            return false;\n        }\n    ;\n    ;\n        this.inform(\"queryEndpoint\", {\n            value: f\n        });\n        this.fetch(this.queryEndpoint, this.getQueryData(f, e), {\n            value: f,\n            exclusions: a\n        });\n        return true;\n    },\n    shouldFetchMoreResults: function(a) {\n        return ((a.length < this._maxResults));\n    },\n    getQueryData: function(c, b) {\n        var a = copy_properties({\n            value: c\n        }, ((this.queryData || {\n        })));\n        b = ((b || []));\n        if (b.length) {\n            a.existing_ids = b.join(\",\");\n        }\n    ;\n    ;\n        return a;\n    },\n    setQueryData: function(a, b) {\n        if (b) {\n            this.queryData = {\n            };\n        }\n    ;\n    ;\n        copy_properties(this.queryData, a);\n        return this;\n    },\n    setBootstrapData: function(a, b) {\n        if (b) {\n            this.bootstrapData = {\n            };\n        }\n    ;\n    ;\n        copy_properties(this.bootstrapData, a);\n        return this;\n    },\n    getExclusions: function() {\n        return $A(this._exclusions);\n    },\n    setExclusions: function(a) {\n        this._exclusions = ((a || []));\n    },\n    setFilter: function(a) {\n        this.filter = a;\n    },\n    respond: function(d, c, a) {\n        var b = this.buildData(c);\n        this.inform(\"respond\", {\n            value: d,\n            results: b,\n            isAsync: !!a\n        });\n        return b;\n    },\n    asyncErrorHandler: bagofholding,\n    fetch: function(c, b, d) {\n        if (!c) {\n            return;\n        }\n    ;\n    ;\n        var a = new AsyncRequest().setURI(c).setData(b).setMethod(\"GET\").setReadOnly(true).setHandler(function(e) {\n            this.fetchHandler(e, ((d || {\n            })));\n        }.bind(this)).setFinallyHandler(function() {\n            this._activeQueries--;\n            if (!this._activeQueries) {\n                this.inform(\"activity\", {\n                    activity: false\n                });\n            }\n        ;\n        ;\n        }.bind(this));\n        a.setErrorHandler(this.asyncErrorHandler);\n        this.inform(\"beforeFetch\", {\n            request: a\n        });\n        a.send();\n        if (!this._activeQueries) {\n            this.inform(\"activity\", {\n                activity: true\n            });\n        }\n    ;\n    ;\n        this._activeQueries++;\n    },\n    fetchHandler: function(c, b) {\n        var d = b.value;\n        var a = b.exclusions;\n        if (((!d && b.replaceCache))) {\n            this.localCache = {\n            };\n        }\n    ;\n    ;\n        this.addEntries(c.getPayload().entries, d);\n        this.inform(\"fetchComplete\", {\n            response: c,\n            value: d\n        });\n        this.respond(d, this.buildUids(d, [], a), true);\n        if (((((!d && b.token)) && ((c.getPayload().token !== b.token))))) {\n            this.bootstrapWithToken();\n        }\n    ;\n    ;\n    },\n    addEntries: function(b, e) {\n        var c = this.processEntries($A(((b || []))), e);\n        var a = this.buildUids(e, c);\n        if (e) {\n            var d = this.getQueryCache();\n            d[TypeaheadUtil.parse(e).flatValue] = a;\n        }\n         else this.fillCache(a);\n    ;\n    ;\n    },\n    processEntries: function(a, b) {\n        return a.map(function(e, d) {\n            var f = (e.uid = ((e.uid + \"\")));\n            var c = this.getEntry(f);\n            if (!c) {\n                c = e;\n                c.query = b;\n                this.setEntry(f, c);\n            }\n             else copy_properties(c, e);\n        ;\n        ;\n            ((((c.index === undefined)) && (c.index = d)));\n            return f;\n        }, this);\n    },\n    getAllEntries: function() {\n        return ((this._data || {\n        }));\n    },\n    getEntry: function(a) {\n        return ((this._data[a] || null));\n    },\n    setEntry: function(b, a) {\n        this._data[b] = a;\n    },\n    fillCache: function(b) {\n        var a = this.localCache;\n        b.each(function(g) {\n            var d = this.getEntry(g);\n            if (!d) {\n                return;\n            }\n        ;\n        ;\n            d.bootstrapped = true;\n            var f = TypeaheadUtil.parse(this.getTextToIndex(d)).tokens;\n            for (var c = 0, e = f.length; ((c < e)); ++c) {\n                var h = f[c];\n                if (!a.hasOwnProperty(h)) {\n                    a[h] = {\n                    };\n                }\n            ;\n            ;\n                a[h][g] = true;\n            };\n        ;\n        }, this);\n    },\n    getTextToIndex: function(c) {\n        if (c.textToIndex) {\n            return c.textToIndex;\n        }\n    ;\n    ;\n        var d = [];\n        for (var b in this._fields) {\n            var a = c[b];\n            if (a) {\n                d.push(((a.join ? a.join(\" \") : a)));\n            }\n        ;\n        ;\n        };\n    ;\n        return (c.textToIndex = d.join(\" \"));\n    },\n    mergeUids: function(a, c, b, e) {\n        var d = function(f, g) {\n            return ((this.getEntry(f).index - this.getEntry(g).index));\n        }.bind(this);\n        return a.sort(d).concat(c, b);\n    },\n    buildUids: function(h, d, a) {\n        if (!d) {\n            d = [];\n        }\n    ;\n    ;\n        if (!h) {\n            return d;\n        }\n    ;\n    ;\n        if (!a) {\n            a = [];\n        }\n    ;\n    ;\n        var b = this.buildCacheResults(h, this.localCache);\n        var f = this.buildQueryResults(h);\n        var e = this.mergeUids(b, f, d, h);\n        var g = Object.from(a.concat(this._exclusions));\n        var c = e.filter(function(i) {\n            if (((g.hasOwnProperty(i) || !this.getEntry(i)))) {\n                return false;\n            }\n        ;\n        ;\n            if (((this.filter && !this.filter(this.getEntry(i))))) {\n                return false;\n            }\n        ;\n        ;\n            return (g[i] = true);\n        }, this);\n        return this.uidsIncludingExact(h, c, g);\n    },\n    uidsIncludingExact: function(g, d, f) {\n        var e = d.length;\n        if (((((g.length < this._minExactMatchLength)) || ((e <= this._maxResults))))) {\n            return d;\n        }\n    ;\n    ;\n        for (var c = 0; ((c < e)); ++c) {\n            var a = this.getEntry(d[c]);\n            ((a.text_lower || (a.text_lower = a.text.toLowerCase())));\n            if (((a.text_lower === TypeaheadUtil.parse(g).flatValue))) {\n                if (((c >= this._maxResults))) {\n                    var b = d.splice(c, 1);\n                    d.splice(((this._maxResults - 1)), 0, b);\n                }\n            ;\n            ;\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        return d;\n    },\n    buildData: function(d) {\n        var c = [];\n        var b = Math.min(d.length, this._maxResults);\n        for (var a = 0; ((a < b)); ++a) {\n            c.push(this.getEntry(d[a]));\n        ;\n        };\n    ;\n        return c;\n    },\n    findQueryCache: function(e) {\n        var b = 0;\n        var a = null;\n        var d = this.getQueryCache();\n        for (var c in d) {\n            if (((((e.indexOf(c) == 0)) && ((c.length > b))))) {\n                b = c.length;\n                a = c;\n            }\n        ;\n        ;\n        };\n    ;\n        return ((d[a] || []));\n    },\n    buildQueryResults: function(c) {\n        var a = TypeaheadUtil.parse(c).flatValue;\n        var b = this.findQueryCache(a);\n        if (this.getQueryCache().hasOwnProperty(a)) {\n            return b;\n        }\n    ;\n    ;\n        return this.filterQueryResults(c, b);\n    },\n    filterQueryResults: function(c, b) {\n        var a = ((this._alwaysPrefixMatch ? TypeaheadUtil.isPrefixMatch : TypeaheadUtil.isQueryMatch));\n        return b.filter(function(d) {\n            return a(c, this.getTextToIndex(this.getEntry(d)));\n        }, this);\n    },\n    buildCacheResults: function(r, a) {\n        var k = TypeaheadUtil.parse(r, this._alwaysPrefixMatch);\n        var l = ((this._alwaysPrefixMatch ? k.sortedTokens : k.tokens));\n        var h = l.length;\n        var i = ((k.isPrefixQuery ? ((h - 1)) : null));\n        var e = {\n        };\n        var j = {\n        };\n        var o = {\n        };\n        var f = [];\n        var c = false;\n        var q = {\n        };\n        var p = 0;\n        for (var d = 0; ((d < h)); ++d) {\n            var m = l[d];\n            if (!q.hasOwnProperty(m)) {\n                p++;\n                q[m] = true;\n            }\n             else continue;\n        ;\n        ;\n            for (var g in a) {\n                if (((((!e.hasOwnProperty(g) && ((g === m)))) || ((((this._alwaysPrefixMatch || ((i === d)))) && ((g.indexOf(m) === 0))))))) {\n                    if (((g === m))) {\n                        if (j.hasOwnProperty(g)) {\n                            c = true;\n                        }\n                    ;\n                    ;\n                        e[g] = true;\n                    }\n                     else {\n                        if (((e.hasOwnProperty(g) || j.hasOwnProperty(g)))) {\n                            c = true;\n                        }\n                    ;\n                    ;\n                        j[g] = true;\n                    }\n                ;\n                ;\n                    for (var n in a[g]) {\n                        if (((((d === 0)) || ((o.hasOwnProperty(n) && ((o[n] == ((p - 1))))))))) {\n                            o[n] = p;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        for (var b in o) {\n            if (((o[b] == p))) {\n                f.push(b);\n            }\n        ;\n        ;\n        };\n    ;\n        if (((c || ((p < h))))) {\n            f = this.filterQueryResults(r, f);\n        }\n    ;\n    ;\n        return f;\n    },\n    getQueryCache: function() {\n        return this.queryCache;\n    },\n    setMaxResults: function(a) {\n        this._maxResults = a;\n        ((this.value && this.respond(this.value, this.buildUids(this.value))));\n    },\n    updateToken: function(a) {\n        this.token = a;\n        this.dirty();\n        return this;\n    }\n});\nfunction photos_viewer_version() {\n    if (CSS.hasClass(JSBNG__document.documentElement, \"theaterMode\")) {\n        if (window.Env) {\n            if (((Env.theater_ver === \"2\"))) {\n                return PhotosConst.VIEWER_SNOWBOX;\n            }\n             else return PhotosConst.VIEWER_THEATER\n        ;\n        }\n         else if (((ge(\"fbPhotoSnowbox\") !== null))) {\n            return PhotosConst.VIEWER_SNOWBOX;\n        }\n         else return PhotosConst.VIEWER_THEATER\n        \n    ;\n    }\n     else return PhotosConst.VIEWER_PERMALINK\n;\n};\n;\nfunction PhotoTagger(a) {\n    this.version = a;\n    PhotoTagger.instances[a] = this;\n};\n;\nPhotoTagger.instances = {\n};\nPhotoTagger.ACTIVATE_TAGGING = \"PhotoTagger.ACTIVATE_TAGGING\";\nPhotoTagger.getInstance = function(a) {\n    return PhotoTagger.instances[a];\n};\nPhotoTagger.getCurrentInstance = function() {\n    return PhotoTagger.getInstance(photos_viewer_version());\n};\ncopy_properties(PhotoTagger.prototype, {\n    TAG_BOX_SIZE: 100,\n    datasources: {\n    },\n    photoData: {\n    },\n    elemNames: {\n        1: {\n            tagger: \"div.theaterTagger\",\n            addTagLink: \"div.fbPhotosTheaterActions\",\n            overlayActions: \"div.fbPhotoTheaterButtons\",\n            tagAction: \"fbPhotosTheaterActionsTag\",\n            image: \"div.stage img\"\n        },\n        2: {\n            tagger: \"div.snowboxTagger\",\n            addTagLink: \"div.fbPhotosPhotoActions\",\n            overlayActions: \"div.fbPhotosPhotoButtons\",\n            tagAction: \"fbPhotosPhotoActionsTag\",\n            image: \"div.stage img\"\n        }\n    },\n    init: function(b, c) {\n        this.root = b;\n        this.tokenizer = c;\n        this._qn = null;\n        this.typeahead = c.getTypeahead();\n        this.clickState = DOM.JSBNG__find(this.root, \"div.stageActions\");\n        this.tagger = DOM.JSBNG__find(this.clickState, this.elemNames[this.version].tagger);\n        this.faceBox = DOM.JSBNG__find(this.tagger, \"div.faceBox\");\n        this.newTagBox = DOM.JSBNG__find(this.clickState, \"div.newTagBox\");\n        this.addTagLink = DOM.JSBNG__find(this.root, this.elemNames[this.version].addTagLink);\n        this.overlayActions = DOM.JSBNG__find(this.root, this.elemNames[this.version].overlayActions);\n        this.setupHandlers();\n        this.hideNewTagTimer = null;\n        new AsyncRequest().setURI(\"/ajax/photos/theater/tags_init.php\").setData({\n            owner: this.photoData.owner\n        }).setOption(\"retries\", 1).setHandler(function(d) {\n            this.typeahead.getView().setSuggestions(d.getPayload().taggees);\n        }.bind(this)).send();\n        var a = this.typeahead.subscribe(\"activity\", function(d, e) {\n            if (((e && !e.activity))) {\n                this.updateWithSuggestions();\n                this.typeahead.unsubscribe(a);\n                this.typeahead.subscribe(\"JSBNG__focus\", this.updateWithSuggestions.bind(this));\n                this.tokenizer.subscribe(\"removeToken\", this.updateWithSuggestions.bind(this));\n                this.tokenizer.subscribe(\"addToken\", this.addSuggestion.bind(this));\n                this.typeahead.subscribe(\"respond\", function(f, g) {\n                    if (((g && !g.results.length))) {\n                        this.updateWithSuggestions();\n                    }\n                ;\n                ;\n                }.bind(this));\n            }\n        ;\n        ;\n        }.bind(this));\n        this.setDataSource(this.typeahead.getData());\n        return this;\n    },\n    setupHandlers: function() {\n        this.handlers = [JSBNG__Event.listen(this.clickState, \"click\", this.addTag.bind(this)),JSBNG__Event.listen(window, \"resize\", this.hideTagger.bind(this)),JSBNG__Event.listen(this.addTagLink, \"click\", this.checkActions.bind(this)),JSBNG__Event.listen(this.overlayActions, \"click\", this.checkActions.bind(this)),];\n        if (((this.version == PhotosConst.VIEWER_THEATER))) {\n            this.subscriptions = [Arbiter.subscribe(PhotoTheater.PAGE, this.restartTagging.bind(this)),Arbiter.subscribe(PhotoTheater.DATA_CHANGE, this.setPhotoData.bind(this)),Arbiter.subscribe(PhotoTheater.CLOSE, this.deactivateTagging.bind(this)),];\n        }\n         else if (((this.version == PhotosConst.VIEWER_SNOWBOX))) {\n            this.subscriptions = [Arbiter.subscribe(PhotoSnowbox.PAGE, this.restartTagging.bind(this)),Arbiter.subscribe(PhotoSnowbox.DATA_CHANGE, this.setPhotoData.bind(this)),Arbiter.subscribe(PhotoSnowbox.CLOSE, this.deactivateTagging.bind(this)),];\n        }\n        \n    ;\n    ;\n        this.tokenizer.subscribe(\"addToken\", this.saveTag.bind(this));\n        this.tokenizer.subscribe(\"removeToken\", this.removeTag.bind(this));\n        this.tokenizer.subscribe(\"markTagAsSpam\", this.markTagAsSpam.bind(this));\n    },\n    getTaggingSource: function() {\n        if (((this.version == PhotosConst.VIEWER_SNOWBOX))) {\n            return \"snowbox\";\n        }\n         else if (((this.version == PhotosConst.VIEWER_THEATER))) {\n            return \"center_stage\";\n        }\n         else return null\n        \n    ;\n    },\n    updateWithSuggestions: function(a, c) {\n        var e = this.typeahead.getData().buildUids(\" \", this.typeahead.getView().getSuggestions(), this.typeahead.getCore().getExclusions());\n        if (!e.length) {\n            return;\n        }\n    ;\n    ;\n        var d = this.typeahead.getData().respond(\"\", e);\n        for (var b = 0; ((b < d.length)); b++) {\n            d[b].index = ((-1000 + b));\n        ;\n        };\n    ;\n    },\n    addSuggestion: function(a, b) {\n        var c = ((b.info && b.info.uid));\n        if (c) {\n            this.typeahead.getView().addSuggestion(c);\n        }\n    ;\n    ;\n    },\n    setQueueName: function(a) {\n        this._qn = a;\n        return this;\n    },\n    _sendWaterfallLogSignal: function(a) {\n        PhotosTaggingWaterfall.sendSignal({\n            qn: this._qn,\n            source: this.getTaggingSource(),\n            step: a,\n            pid: this.photoData.pid\n        });\n    },\n    _bumpQueueName: function() {\n        if (this._qn) {\n            this._qn += 1;\n        }\n    ;\n    ;\n    },\n    activateTagging: function() {\n        Arbiter.inform(PhotoTagger.ACTIVATE_TAGGING);\n        if (this.getDataSource()) {\n            this.dataSourceFetched(this.getDataSource());\n        }\n         else new AsyncRequest(\"/ajax/photos/theater/fetch_datasource.php\").setData({\n            fbid: this.photoData.fbid,\n            version: this.version\n        }).send();\n    ;\n    ;\n    },\n    restartTagging: function() {\n        this.hideNewTag();\n        this.hideTagger();\n        if (((this.taggingMode === true))) {\n            this.activateTagging();\n        }\n    ;\n    ;\n    },\n    getDataSource: function() {\n        return this.datasources[this.getDataSourceKey()];\n    },\n    getDataSourceKey: function() {\n        if (((((this.photoData.ownertype == \"user\")) && !this.photoData.obj_id))) {\n            return \"friends\";\n        }\n    ;\n    ;\n        return ((this.photoData.obj_id || this.photoData.owner));\n    },\n    setDataSource: function(a) {\n        if (((this.typeahead.getData() != a))) {\n            this.typeahead.swapData(a);\n        }\n    ;\n    ;\n        this.datasources[this.getDataSourceKey()] = a;\n    },\n    dataSourceFetched: function(a) {\n        this.taggingMode = true;\n        CSS.addClass(this.root, \"taggingMode\");\n        this._bumpQueueName();\n        this._sendWaterfallLogSignal(PhotosTaggingWaterfall.BEGIN);\n        this.setDataSource(a);\n    },\n    deactivateTagging: function() {\n        if (((this.taggingMode === true))) {\n            this._sendWaterfallLogSignal(PhotosTaggingWaterfall.FINISH);\n        }\n    ;\n    ;\n        this.taggingMode = false;\n        this.hideNewTag();\n        this.hideTagger();\n        CSS.removeClass(this.root, \"taggingMode\");\n    },\n    checkActions: function(JSBNG__event) {\n        var a = JSBNG__event.getTarget();\n        if (Parent.byClass(a, this.elemNames[this.version].tagAction)) {\n            ((this.taggingMode ? this.deactivateTagging() : this.activateTagging()));\n        }\n    ;\n    ;\n    },\n    hideTagger: function() {\n        CSS.hide(this.tagger);\n    },\n    showTagger: function() {\n        CSS.show(this.tagger);\n        var a = DOM.JSBNG__find(this.tagger, \"input.textInput\");\n        Input.reset(a);\n        a.JSBNG__focus();\n        this.updateWithSuggestions();\n        this.hideNewTag();\n    },\n    showNewTag: function(a) {\n        DOM.setContent(DOM.JSBNG__find(this.newTagBox, \"div.tagName\"), $N(\"span\", null, a));\n        CSS.show(this.newTagBox);\n        this.hideNewTagTimer = JSBNG__setTimeout(this.hideNewTag.bind(this), 3000);\n    },\n    hideNewTag: function() {\n        if (((this.hideNewTagTimer !== null))) {\n            JSBNG__clearTimeout(this.hideNewTagTimer);\n            this.hideNewTagTimer = null;\n        }\n    ;\n    ;\n        CSS.hide(this.newTagBox);\n    },\n    addTag: function(JSBNG__event) {\n        var m = JSBNG__event.getTarget();\n        if (((((!this.taggingMode || Parent.byClass(m, \"fbPhotosPhotoButtons\"))) || Parent.byClass(m, \"photoTagTypeahead\")))) {\n            return;\n        }\n    ;\n    ;\n        var h = DOM.JSBNG__find(this.root, this.elemNames[this.version].image);\n        var b = Vector2.getEventPosition(JSBNG__event);\n        var a = {\n            x: ((this.TAG_BOX_SIZE / 2)),\n            y: ((this.TAG_BOX_SIZE / 2))\n        };\n        var j = Vector2.getElementPosition(h);\n        var i = Vector2.getElementDimensions(h);\n        var k = b.sub(j);\n        var d = new Vector2(((JSBNG__event.offsetX || JSBNG__event.layerX)), ((JSBNG__event.offsetY || JSBNG__event.layerY)), \"JSBNG__document\");\n        for (var e in d) {\n            if (((((b[e] < j[e])) || ((b[e] > ((j[e] + i[e]))))))) {\n                this.hideTagger();\n                return;\n            }\n        ;\n        ;\n            if (((k[e] < ((this.TAG_BOX_SIZE / 2))))) {\n                a[e] = k[e];\n            }\n             else if (((i[e] < ((k[e] + ((this.TAG_BOX_SIZE / 2))))))) {\n                a[e] = ((this.TAG_BOX_SIZE - ((i[e] - k[e]))));\n            }\n            \n        ;\n        ;\n        };\n    ;\n        var l;\n        if (this.JSBNG__onRelativePositionTarget(m)) {\n            var g = 1;\n            if (ua.ie()) {\n                g = 5;\n            }\n        ;\n        ;\n            var c = {\n                x: ((((a.x - d.x)) - g)),\n                y: ((((a.y - d.y)) - g))\n            };\n            var n = this.getRelativeTargetPos(m);\n            var f = new Vector2(((n.left.substr(0, ((n.left.length - 2))) - 0)), ((n.JSBNG__top.substr(0, ((n.JSBNG__top.length - 2))) - 0)), \"JSBNG__document\");\n            l = f.sub(c.x, c.y);\n        }\n         else l = d.sub(a.x, a.y);\n    ;\n    ;\n        l.setElementPosition(this.tagger);\n        l.setElementPosition(this.newTagBox);\n        this.showTagger();\n        this.clickPoint = {\n            x: ((k.x / i.x)),\n            y: ((k.y / i.y))\n        };\n        this._sendWaterfallLogSignal(PhotosTaggingWaterfall.TAG_FACE);\n    },\n    JSBNG__onRelativePositionTarget: function(a) {\n        return ((a == this.faceBox));\n    },\n    getRelativeTargetPos: function(a) {\n        return this.tagger.style;\n    },\n    saveTag: function(a, b) {\n        new AsyncRequest().setURI(\"/ajax/photo_tagging_ajax.php\").setMethod(\"POST\").setData({\n            cs_ver: this.version,\n            pid: this.photoData.pid,\n            id: this.photoData.owner,\n            subject: ((b.isFreeform() ? \"\" : b.getValue())),\n            JSBNG__name: b.getText(),\n            action: \"add\",\n            x: ((this.clickPoint.x * 100)),\n            y: ((this.clickPoint.y * 100)),\n            source: this.getTaggingSource(),\n            qn: this._qn,\n            position: this.getPosition()\n        }).setAllowCrossPageTransition(true).setHandler(this.tagsChangeHandler.bind(this)).setErrorHandler(this.checkError.bind(this, b)).send();\n        this.showNewTag(b.getText());\n        this.hideTagger();\n    },\n    getPosition: function() {\n        var a = this.getPhotoViewerObj();\n        return ((a && a.position));\n    },\n    getPhotoViewerObj: function() {\n        if (((this.version == PhotosConst.VIEWER_THEATER))) {\n            return window.PhotoTheater;\n        }\n         else if (((this.version == PhotosConst.VIEWER_SNOWBOX))) {\n            return window.PhotoSnowbox;\n        }\n        \n    ;\n    ;\n        return null;\n    },\n    tagsChangeHandler: function(b) {\n        var a = this.getPhotoViewerObj();\n        if (((a && a.isOpen))) {\n            a.saveTagComplete(b);\n        }\n    ;\n    ;\n    },\n    checkError: function(b, a) {\n        if (((a.getPayload() && a.getPayload().clear_tag))) {\n            b.already_untagged = true;\n            this.tokenizer.removeToken(b);\n        }\n    ;\n    ;\n        ErrorDialog.showAsyncError(a);\n    },\n    removeTag: function(a, c) {\n        if (c.already_untagged) {\n            return;\n        }\n    ;\n    ;\n        var b = \"remove\";\n        if (DOM.scry(c.element, \"a.pending\")[0]) {\n            b = \"retract\";\n        }\n    ;\n    ;\n        if (c.blockUser) {\n            b = \"remove_block\";\n        }\n    ;\n    ;\n        new AsyncRequest().setURI(\"/ajax/photo_tagging_ajax.php\").setMethod(\"POST\").setData({\n            cs_ver: this.version,\n            pid: this.photoData.pid,\n            id: this.photoData.owner,\n            subject: ((c.isFreeform() ? \"\" : c.getInfo().uid)),\n            position: this.getPosition(),\n            JSBNG__name: c.getInfo().text,\n            action: b,\n            source: this.getTaggingSource()\n        }).setHandler(this.tagsChangeHandler.bind(this)).setAllowCrossPageTransition(true).send();\n    },\n    removeTagByID: function(b) {\n        var c = this.tokenizer.tokens;\n        for (var a = 0; ((a < c.length)); a++) {\n            if (((c[a].info.uid == b))) {\n                return this.removeTag(null, c[a]);\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    setPhotoData: function(a, b) {\n        this.photoData = b;\n        return this;\n    },\n    markTagAsSpam: function(a, b) {\n        new AsyncRequest().setURI(\"/ajax/photo_tagging_ajax.php\").setMethod(\"POST\").setData({\n            cs_ver: this.version,\n            pid: this.photoData.pid,\n            id: this.photoData.owner,\n            subject: b,\n            action: \"mark_as_spam\",\n            source: this.getTaggingSource()\n        }).send();\n    }\n});\nfunction PhotoSnowboxLog() {\n\n};\n;\ncopy_properties(PhotoSnowboxLog, {\n    UNKNOWN: 0,\n    ESC: 1,\n    X: 2,\n    OUTSIDE: 3,\n    UNLOAD: 4,\n    NAVIGATE: 5,\n    AGGREGATE: 6,\n    AGGREGATION_COUNT: 20,\n    set: null,\n    time: null,\n    views: 0,\n    fbidList: [],\n    width: 0,\n    height: 0,\n    first: false,\n    last: false,\n    logIds: false,\n    initLogging: function() {\n        this.set = null;\n        this.time = new JSBNG__Date();\n        this.views = 0;\n        this.first = true;\n        this.last = false;\n        this.logIds = false;\n        var a = Vector2.getViewportDimensions();\n        this.width = a.x;\n        this.height = a.y;\n    },\n    setLogFbids: function(a) {\n        this.logIds = a;\n    },\n    setPhotoSet: function(a) {\n        this.set = a;\n    },\n    addPhotoView: function(a) {\n        if (((this.logIds && ((this.views >= this.AGGREGATION_COUNT))))) {\n            this.logPhotoViews(this.AGGREGATE);\n        }\n    ;\n    ;\n        this.views++;\n        if (a) {\n            this.fbidList.push([a.fbid,a.owner,+new JSBNG__Date(),]);\n        }\n    ;\n    ;\n    },\n    logPhotoViews: function(a) {\n        if (this.views) {\n            var c = Vector2.getViewportDimensions();\n            if (((a != this.AGGREGATE))) {\n                this.last = true;\n            }\n        ;\n        ;\n            var b = {\n                set: this.set,\n                time: ((new JSBNG__Date() - this.time)),\n                fbids: ((this.logIds ? this.fbidList : [])),\n                width: ((c.x || this.width)),\n                height: ((c.y || this.height)),\n                first: this.first,\n                last: this.last,\n                close: ((a ? a : this.UNKNOWN))\n            };\n            new AsyncRequest().setURI(\"/ajax/photos/snowbox/session_logging.php\").setAllowCrossPageTransition(true).setOption(\"asynchronous\", ((a != PhotoSnowboxLog.UNLOAD))).setOption(\"suppressErrorHandlerWarning\", true).setData(b).send();\n            this.views = 0;\n            this.fbidList = [];\n            this.first = false;\n            if (this.last) {\n                this.set = null;\n                this.logIds = false;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    }\n});\nJSBNG__onunloadRegister(function() {\n    PhotoSnowboxLog.logPhotoViews(PhotoSnowboxLog.UNLOAD);\n});\nfunction useFacebookReferer(b, a) {\n    var d = false;\n    function e() {\n        if (d) {\n            return;\n        }\n    ;\n    ;\n        d = true;\n        b.contentWindow.JSBNG__document.body.style.margin = 0;\n        a();\n    };\n;\n    var c = ((((URI().isSecure() ? \"https://s-static.ak.facebook.com\" : \"http://static.ak.facebook.com\")) + \"/common/referer_frame.php\"));\n    JSBNG__Event.listen(b, \"load\", e);\n    b.src = c;\n};\n;\nfunction useFacebookRefererHtml(b, a) {\n    useFacebookReferer(b, function() {\n        b.contentWindow.JSBNG__document.body.innerHTML = a;\n    });\n};\n;\nif (((typeof deconcept == \"undefined\"))) {\n    var deconcept = {\n    };\n}\n;\n;\nif (((typeof deconcept.util == \"undefined\"))) {\n    deconcept.util = {\n    };\n}\n;\n;\nif (((typeof deconcept.SWFObjectUtil == \"undefined\"))) {\n    deconcept.SWFObjectUtil = {\n    };\n}\n;\n;\ndeconcept.SWFObject = function(h, d, j, c, i, a, f, l, g, b) {\n    if (!JSBNG__document.getElementById) {\n        return;\n    }\n;\n;\n    this.DETECT_KEY = ((b ? b : \"detectflash\"));\n    this.skipDetect = deconcept.util.getRequestParameter(this.DETECT_KEY);\n    this.params = {\n    };\n    this.variables = {\n    };\n    this.attributes = [];\n    this.fallback_html = \"\";\n    this.fallback_js_fcn = function() {\n    \n    };\n    if (h) {\n        this.setAttribute(\"swf\", h);\n    }\n;\n;\n    if (d) {\n        this.setAttribute(\"id\", d);\n    }\n;\n;\n    if (j) {\n        this.setAttribute(\"width\", j);\n    }\n;\n;\n    if (c) {\n        this.setAttribute(\"height\", c);\n    }\n;\n;\n    this.installedVer = deconcept.SWFObjectUtil.getPlayerVersion();\n    if (i) {\n        if (!((i instanceof Array))) {\n            i = [i,];\n        }\n    ;\n    ;\n        var k;\n        i.each(function(n) {\n            k = new deconcept.PlayerVersion(n.toString().split(\".\"));\n            if (((k.major == this.installedVer.major))) {\n                this.setAttribute(\"version\", k);\n                return;\n            }\n             else if (((!this.getAttribute(\"version\") || ((k.major < this.getAttribute(\"version\").major))))) {\n                this.setAttribute(\"version\", k);\n            }\n            \n        ;\n        ;\n        }.bind(this));\n    }\n;\n;\n    if (((((!window.JSBNG__opera && JSBNG__document.all)) && ((this.installedVer.major > 7))))) {\n        if (!deconcept.unloadSet) {\n            deconcept.SWFObjectUtil.prepUnload = function() {\n                __flash_unloadHandler = function() {\n                \n                };\n                __flash_savedUnloadHandler = function() {\n                \n                };\n                window.JSBNG__attachEvent(\"JSBNG__onunload\", deconcept.SWFObjectUtil.cleanupSWFs);\n            };\n            window.JSBNG__attachEvent(\"JSBNG__onbeforeunload\", deconcept.SWFObjectUtil.prepUnload);\n            deconcept.unloadSet = true;\n        }\n    ;\n    }\n;\n;\n    if (a) {\n        this.addParam(\"bgcolor\", a);\n    }\n;\n;\n    var e = ((f ? f : \"high\"));\n    this.addParam(\"quality\", e);\n    this.setAttribute(\"useExpressInstall\", false);\n    this.setAttribute(\"doExpressInstall\", false);\n    var m = (((l) ? l : window.JSBNG__location));\n    this.setAttribute(\"xiRedirectUrl\", m);\n    this.setAttribute(\"redirectUrl\", \"\");\n    if (g) {\n        this.setAttribute(\"redirectUrl\", g);\n    }\n;\n;\n    this.setAttribute(\"useIframe\", false);\n};\ndeconcept.SWFObject.ieWorkaroundApplied = false;\ndeconcept.SWFObject.ensureIEWorkaroundAttached = function() {\n    if (((!deconcept.SWFObject.ieWorkaroundApplied && JSBNG__document.JSBNG__attachEvent))) {\n        deconcept.SWFObject.ieWorkaroundApplied = true;\n        JSBNG__document.JSBNG__attachEvent(\"JSBNG__onpropertychange\", deconcept.SWFObject.JSBNG__onDocumentPropertyChange);\n    }\n;\n;\n};\ndeconcept.SWFObject.JSBNG__onDocumentPropertyChange = function(JSBNG__event) {\n    if (((JSBNG__event.propertyName == \"title\"))) {\n        var a = JSBNG__document.title;\n        if (((((a != null)) && ((a.indexOf(\"#!\") != -1))))) {\n            a = a.substring(0, a.indexOf(\"#!\"));\n            JSBNG__document.title = a;\n        }\n    ;\n    ;\n    }\n;\n;\n};\ndeconcept.SWFObject.prototype = {\n    useExpressInstall: function(a) {\n        this.xiSWFPath = ((!a ? \"/swf/expressinstall.swf\" : a));\n        this.setAttribute(\"useExpressInstall\", true);\n    },\n    setAttribute: function(a, b) {\n        this.attributes[a] = b;\n    },\n    getAttribute: function(a) {\n        return ((this.attributes[a] || \"\"));\n    },\n    addParam: function(a, b) {\n        this.params[a] = b;\n    },\n    getParams: function() {\n        return this.params;\n    },\n    addVariable: function(a, b) {\n        this.variables[a] = b;\n    },\n    getVariable: function(a) {\n        return ((this.variables[a] || \"\"));\n    },\n    getVariables: function() {\n        return this.variables;\n    },\n    getVariablePairs: function() {\n        var b = [];\n        var a;\n        var c = this.getVariables();\n        for (a in c) {\n            b[b.length] = ((((a + \"=\")) + c[a]));\n        ;\n        };\n    ;\n        return b;\n    },\n    getSWFHTML: function() {\n        var d = \"\";\n        if (((((JSBNG__navigator.plugins && JSBNG__navigator.mimeTypes)) && JSBNG__navigator.mimeTypes.length))) {\n            if (this.getAttribute(\"doExpressInstall\")) {\n                this.addVariable(\"MMplayerType\", \"PlugIn\");\n                this.setAttribute(\"swf\", this.xiSWFPath);\n            }\n        ;\n        ;\n            d = ((((((((((((((((\"\\u003Cembed type=\\\"application/x-shockwave-flash\\\" src=\\\"\" + htmlspecialchars(this.getAttribute(\"swf\")))) + \"\\\" width=\\\"\")) + htmlspecialchars(this.getAttribute(\"width\")))) + \"\\\" height=\\\"\")) + htmlspecialchars(this.getAttribute(\"height\")))) + \"\\\" style=\\\"\")) + htmlspecialchars(((this.getAttribute(\"style\") || \"\"))))) + \"\\\"\"));\n            d += ((((((((\" id=\\\"\" + htmlspecialchars(this.getAttribute(\"id\")))) + \"\\\" name=\\\"\")) + htmlspecialchars(this.getAttribute(\"id\")))) + \"\\\" \"));\n            var c = this.getParams();\n            for (var a in c) {\n                d += ((((((htmlspecialchars(a) + \"=\\\"\")) + htmlspecialchars(c[a]))) + \"\\\" \"));\n            ;\n            };\n        ;\n            var b = this.getVariablePairs().join(\"&\");\n            if (((b.length > 0))) {\n                d += ((((\"flashvars=\\\"\" + b)) + \"\\\"\"));\n            }\n        ;\n        ;\n            d += \"/\\u003E\";\n        }\n         else {\n            if (this.getAttribute(\"doExpressInstall\")) {\n                this.addVariable(\"MMplayerType\", \"ActiveX\");\n                this.setAttribute(\"swf\", this.xiSWFPath);\n            }\n        ;\n        ;\n            d = ((((((((((((((((\"\\u003Cobject id=\\\"\" + this.getAttribute(\"id\"))) + \"\\\" classid=\\\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\\\" width=\\\"\")) + this.getAttribute(\"width\"))) + \"\\\" height=\\\"\")) + this.getAttribute(\"height\"))) + \"\\\" style=\\\"\")) + ((this.getAttribute(\"style\") || \"\")))) + \"\\\"\\u003E\"));\n            d += ((((\"\\u003Cparam name=\\\"movie\\\" value=\\\"\" + this.getAttribute(\"swf\"))) + \"\\\" /\\u003E\"));\n            var c = this.getParams();\n            for (var a in c) {\n                d += ((((((((\"\\u003Cparam name=\\\"\" + a)) + \"\\\" value=\\\"\")) + c[a])) + \"\\\" /\\u003E\"));\n            ;\n            };\n        ;\n            var b = this.getVariablePairs().join(\"&\");\n            if (((b.length > 0))) {\n                d += ((((\"\\u003Cparam name=\\\"flashvars\\\" value=\\\"\" + b)) + \"\\\" /\\u003E\"));\n            }\n        ;\n        ;\n            d += \"\\u003C/object\\u003E\";\n        }\n    ;\n    ;\n        return d;\n    },\n    write: function(a) {\n        if (this.getAttribute(\"useExpressInstall\")) {\n            var b = new deconcept.PlayerVersion([6,0,65,]);\n            if (((this.installedVer.versionIsValid(b) && !this.installedVer.versionIsValid(this.getAttribute(\"version\"))))) {\n                this.setAttribute(\"doExpressInstall\", true);\n                this.addVariable(\"MMredirectURL\", escape(this.getAttribute(\"xiRedirectUrl\")));\n                JSBNG__document.title = ((JSBNG__document.title.slice(0, 47) + \" - Flash Player Installation\"));\n                this.addVariable(\"MMdoctitle\", JSBNG__document.title);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var c = ((((typeof a == \"string\")) ? JSBNG__document.getElementById(a) : a));\n        if (!c) {\n            return false;\n        }\n    ;\n    ;\n        CSS.addClass(c, \"swfObject\");\n        c.setAttribute(\"data-swfid\", this.getAttribute(\"id\"));\n        if (((((this.skipDetect || this.getAttribute(\"doExpressInstall\"))) || this.installedVer.versionIsValid(this.getAttribute(\"version\"))))) {\n            if (!this.getAttribute(\"useIframe\")) {\n                deconcept.SWFObject.ensureIEWorkaroundAttached();\n                c.innerHTML = this.getSWFHTML();\n            }\n             else this._createIframe(c);\n        ;\n        ;\n            return true;\n        }\n         else {\n            if (((this.getAttribute(\"redirectUrl\") != \"\"))) {\n                JSBNG__document.JSBNG__location.replace(this.getAttribute(\"redirectUrl\"));\n            }\n        ;\n        ;\n            need_version = ((((((((this.getAttribute(\"version\").major + \".\")) + this.getAttribute(\"version\").minor)) + \".\")) + this.getAttribute(\"version\").rev));\n            have_version = ((((((((this.installedVer.major + \".\")) + this.installedVer.minor)) + \".\")) + this.installedVer.rev));\n            this.fallback_js_fcn(have_version, need_version);\n            c.innerHTML = this.fallback_html;\n        }\n    ;\n    ;\n        return false;\n    },\n    _createIframe: function(b) {\n        var a = $N(\"div\", {\n            width: this.getAttribute(\"width\"),\n            height: this.getAttribute(\"height\"),\n            frameBorder: 0\n        });\n        DOM.empty(b);\n        b.appendChild(a);\n        useFacebookRefererHtml.bind(null, a, this.getSWFHTML()).defer();\n    }\n};\ndeconcept.SWFObjectUtil.getPlayerVersion = function() {\n    var a = new deconcept.PlayerVersion([0,0,0,]);\n    if (((JSBNG__navigator.plugins && JSBNG__navigator.mimeTypes.length))) {\n        for (var g = 0; ((g < JSBNG__navigator.plugins.length)); g++) {\n            try {\n                var x = JSBNG__navigator.plugins[g];\n                if (((x.JSBNG__name == \"Shockwave Flash\"))) {\n                    PlayerVersion_tmp = new deconcept.PlayerVersion(x.description.replace(/([a-zA-Z]|\\s)+/, \"\").replace(/(\\s+(r|d)|\\s+b[0-9]+)/, \".\").split(\".\"));\n                    if (((((((typeof a == \"undefined\")) || ((PlayerVersion_tmp.major > a.major)))) || ((((PlayerVersion_tmp.major == a.major)) && ((((PlayerVersion_tmp.minor > a.minor)) || ((((PlayerVersion_tmp.minor == a.minor)) && ((PlayerVersion_tmp.rev > a.rev))))))))))) {\n                        a = PlayerVersion_tmp;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            } catch (f) {\n            \n            };\n        ;\n        };\n    ;\n    }\n     else if (((JSBNG__navigator.userAgent && ((JSBNG__navigator.userAgent.indexOf(\"Windows CE\") >= 0))))) {\n        var b = 1;\n        var c = 3;\n        while (b) {\n            try {\n                c++;\n                b = new ActiveXObject(((\"ShockwaveFlash.ShockwaveFlash.\" + c)));\n                a = new deconcept.PlayerVersion([c,0,0,]);\n            } catch (d) {\n                b = null;\n            };\n        ;\n        };\n    ;\n    }\n     else {\n        try {\n            var b = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash.7\");\n        } catch (e) {\n            try {\n                var b = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash.6\");\n                a = new deconcept.PlayerVersion([6,0,21,]);\n                b.AllowScriptAccess = \"always\";\n            } catch (e2) {\n                if (((a.major == 6))) {\n                    return a;\n                }\n            ;\n            ;\n            };\n        ;\n            try {\n                b = new ActiveXObject(\"ShockwaveFlash.ShockwaveFlash\");\n            } catch (e3) {\n            \n            };\n        ;\n        };\n    ;\n        if (((b != null))) {\n            a = new deconcept.PlayerVersion(b.GetVariable(\"$version\").split(\" \")[1].split(\",\"));\n        }\n    ;\n    ;\n    }\n    \n;\n;\n    return a;\n};\ndeconcept.PlayerVersion = function(a) {\n    this.major = ((((a[0] != null)) ? parseInt(a[0]) : 0));\n    this.minor = ((((a[1] != null)) ? parseInt(a[1]) : 0));\n    this.rev = ((((a[2] != null)) ? parseInt(a[2]) : 0));\n};\ndeconcept.PlayerVersion.prototype.versionIsValid = function(a) {\n    if (((this.major < a.major))) {\n        return false;\n    }\n;\n;\n    if (((this.major > a.major))) {\n        return true;\n    }\n;\n;\n    if (((this.minor < a.minor))) {\n        return false;\n    }\n;\n;\n    if (((this.minor > a.minor))) {\n        return true;\n    }\n;\n;\n    if (((this.rev < a.rev))) {\n        return false;\n    }\n;\n;\n    return true;\n};\ndeconcept.util = {\n    getRequestParameter: function(c) {\n        var d = ((JSBNG__document.JSBNG__location.search || JSBNG__document.JSBNG__location.hash));\n        if (((c == null))) {\n            return d;\n        }\n    ;\n    ;\n        if (d) {\n            var b = d.substring(1).split(\"&\");\n            for (var a = 0; ((a < b.length)); a++) {\n                if (((b[a].substring(0, b[a].indexOf(\"=\")) == c))) {\n                    return b[a].substring(((b[a].indexOf(\"=\") + 1)));\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        return \"\";\n    }\n};\ndeconcept.SWFObjectUtil.cleanupSWFs = function() {\n    var b = JSBNG__document.getElementsByTagName(\"OBJECT\");\n    for (var a = ((b.length - 1)); ((a >= 0)); a--) {\n        b[a].style.display = \"none\";\n        for (var c in b[a]) {\n            if (((typeof b[a][c] == \"function\"))) {\n                b[a][c] = function() {\n                \n                };\n            }\n        ;\n        ;\n        };\n    ;\n    };\n;\n};\nif (((!JSBNG__document.getElementById && JSBNG__document.all))) {\n    JSBNG__document.getElementById = function(a) {\n        return JSBNG__document.all[a];\n    };\n}\n;\n;\nvar getQueryParamValue = deconcept.util.getRequestParameter;\nvar FlashObject = deconcept.SWFObject;\nvar SWFObject = deconcept.SWFObject;\nfunction spawn_flash_update_dialog() {\n    new AsyncRequest().setURI(\"/ajax/flash_update_dialog.php\").setMethod(\"GET\").setReadOnly(true).send();\n};\n;\nfunction setFlashFallback(d, g) {\n    var b = ge(d);\n    var a = deconcept.SWFObjectUtil.getPlayerVersion();\n    var e;\n    g.each(function(h) {\n        h = new deconcept.PlayerVersion(h.toString().split(\".\"));\n        if (((h.major == a.major))) {\n            e = h;\n            return;\n        }\n         else if (((((typeof e == \"undefined\")) || ((h.major < e.major))))) {\n            e = h;\n        }\n        \n    ;\n    ;\n    }.bind(this));\n    if (((b && ((a.major > 0))))) {\n        var c = ((((((((a.major + \".\")) + a.minor)) + \".\")) + a.rev));\n        var f = ((((((((e.major + \".\")) + e.minor)) + \".\")) + e.rev));\n        b.innerHTML = _tx(\"Flash {required-version} is required to view this content. Your current version is {current-version}. Please download the latest Flash Player.\", {\n            \"required-version\": f,\n            \"current-version\": c\n        });\n    }\n;\n;\n};\n;\nfunction getFlashPlayer() {\n    goURI(\"http://get.adobe.com/flashplayer\");\n    return false;\n};\n;\nfunction showFlashErrorDialog(b, a) {\n    Bootloader.loadComponents(\"error-dialog\", function() {\n        ErrorDialog.show(b, a);\n    });\n};\n;\nfunction PhotosUtils() {\n\n};\n;\nPhotosUtils.getNearestBox = function(e, l, k, j, c, a) {\n    var f = e.sub(l);\n    var d = k.magnitude();\n    var g = null;\n    for (var b in a) {\n        var h = a[b];\n        var i = new JSBNG__Rect(((((((h.t / 100)) * k.y)) * j)), ((((((h.r / 100)) * k.x)) * j)), ((((((h.b / 100)) * k.y)) * j)), ((((((h.l / 100)) * k.x)) * j)));\n        var m = i.getCenter().sub(f);\n        if (((((((Math.abs(m.x) <= c)) && ((Math.abs(m.y) <= c)))) && ((m.magnitude() <= d))))) {\n            d = m.magnitude();\n            g = b;\n            if (((0 === d))) {\n                break;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    return g;\n};\nfunction UIPagelet(c, d, a, b) {\n    this._id = ((c || null));\n    this._element = ge(((c || $N(\"div\"))));\n    this._src = ((d || null));\n    this._context_data = ((a || {\n    }));\n    this._data = ((b || {\n    }));\n    this._handler = bagofholding;\n    this._request = null;\n    this._use_ajaxpipe = false;\n    this._is_bundle = true;\n    this._allow_cross_page_transition = false;\n    this._append = false;\n    return this;\n};\n;\nUIPagelet.loadFromEndpoint = function(c, g, a, d) {\n    d = ((d || {\n    }));\n    var b = \"/ajax/pagelet/generic.php/\";\n    if (d.intern) {\n        b = ((\"/intern\" + b));\n    }\n;\n;\n    var f = ((b + c)).replace(/\\/+/g, \"/\");\n    if (d.subdomain) {\n        f = URI(f).setSubdomain(d.subdomain);\n    }\n;\n;\n    var e = new UIPagelet(g, f, a).setUseAjaxPipe(d.usePipe).setBundleOption(((((c.substring(0, 8) != \"/intern/\")) && ((d.bundle !== false))))).setAppend(d.append).setJSNonBlock(d.jsNonblock).setConstHeight(d.constHeight).setAllowCrossPageTransition(d.crossPage);\n    ((d.handler && e.setHandler(d.handler)));\n    e.go();\n    return e;\n};\ncopy_properties(UIPagelet.prototype, {\n    getElement: function(a) {\n        a = ((a || false));\n        if (a) {\n            this._element = ge(this._id);\n        }\n    ;\n    ;\n        return this._element;\n    },\n    setHandler: function(a) {\n        this._handler = a;\n        return this;\n    },\n    go: function(b, a) {\n        if (((((arguments.length >= 2)) || ((typeof b == \"string\"))))) {\n            this._src = b;\n            this._data = ((a || {\n            }));\n        }\n         else if (((arguments.length == 1))) {\n            this._data = b;\n        }\n        \n    ;\n    ;\n        this.refresh();\n        return this;\n    },\n    setAllowCrossPageTransition: function(a) {\n        this._allow_cross_page_transition = a;\n        return this;\n    },\n    setBundleOption: function(a) {\n        this._is_bundle = a;\n        return this;\n    },\n    refresh: function(b) {\n        var a = function(d) {\n            this._request = null;\n            if (((b && this._id))) {\n                this._element = ge(this._id);\n            }\n        ;\n        ;\n            var c = HTML(d.getPayload());\n            if (this._append) {\n                DOM.appendContent(this._element, c);\n            }\n             else DOM.setContent(this._element, c);\n        ;\n        ;\n            this._handler();\n        }.bind(this);\n        if (this._use_ajaxpipe) {\n            this._request = new AjaxPipeRequest();\n            this._request.setCanvasId(this._id).setAppend(this._append).setConstHeight(this._constHeight).setJSNonBlock(this._jsNonblock);\n        }\n         else this._request = new AsyncRequest().setMethod(\"GET\").setReadOnly(true).setOption(\"bundle\", this._is_bundle).setHandler(a);\n    ;\n    ;\n        this._request.setURI(this._src).setAllowCrossPageTransition(this._allow_cross_page_transition).setData({\n            data: JSON.stringify(merge(this._context_data, this._data))\n        }).send();\n        return this;\n    },\n    cancel: function() {\n        if (this._request) {\n            this._request.abort();\n        }\n    ;\n    ;\n    },\n    setUseAjaxPipe: function(a) {\n        this._use_ajaxpipe = !!a;\n        return this;\n    },\n    setAppend: function(a) {\n        this._append = !!a;\n        return this;\n    },\n    setJSNonBlock: function(a) {\n        this._jsNonblock = !!a;\n        return this;\n    },\n    setConstHeight: function(a) {\n        this._constHeight = !!a;\n        return this;\n    }\n});\nfunction PhotoStreamCache() {\n\n};\n;\ncopy_properties(PhotoStreamCache, {\n    ERROR: \"error\",\n    HTML: \"html\",\n    IMAGE_DATA: \"image\",\n    EXTRA: \"extra\",\n    BUFFER_SIZE: 3,\n    INIT_BUCKET_SIZE: 4,\n    FULL_BUCKET_SIZE: 12,\n    ERROR_ID: -1\n});\ncopy_properties(PhotoStreamCache.prototype, {\n    init: function(a) {\n        this.version = a;\n        this.bufferSize = PhotoStreamCache.BUFFER_SIZE;\n        this.initBucketSize = PhotoStreamCache.INIT_BUCKET_SIZE;\n        this.fullBucketSize = PhotoStreamCache.FULL_BUCKET_SIZE;\n        this.initError = false;\n        this.isActive = true;\n        this.leftLock = false;\n        this.rightLock = false;\n        this.reset();\n    },\n    reset: function() {\n        this.cache = {\n            image: {\n            },\n            extra: {\n            },\n            html: {\n            }\n        };\n        this.fbidList = [];\n        this.loaded = false;\n        this.allLoaded = false;\n        this.permalinkMap = {\n        };\n        this.position = 0;\n        this.totalCount = null;\n        this.firstCursor = null;\n        this.firstCursorIndex = null;\n    },\n    destroy: function() {\n        this.reset();\n        this.isActive = false;\n    },\n    isLoaded: function() {\n        return this.loaded;\n    },\n    canPage: function() {\n        if (((this.totalCount !== null))) {\n            return ((this.totalCount > 1));\n        }\n    ;\n    ;\n        return ((this.getLength() > 1));\n    },\n    errorInCurrent: function() {\n        if (this.initError) {\n            return true;\n        }\n         else if (!this.isLoaded()) {\n            return false;\n        }\n        \n    ;\n    ;\n        return this.checkErrorAt(this.getCursor());\n    },\n    getLength: function() {\n        return this.fbidList.length;\n    },\n    getPhotoSet: function() {\n        return this.photoSetQuery.set;\n    },\n    getCurrentImageData: function() {\n        return this.getImageData(this.getCursor());\n    },\n    getImageData: function(a) {\n        return this.getCacheContent(a, PhotoStreamCache.IMAGE_DATA);\n    },\n    getCurrentHtml: function() {\n        return this.getCacheContent(this.getCursor(), PhotoStreamCache.HTML);\n    },\n    getCurrentExtraData: function() {\n        return this.getCacheContent(this.getCursor(), PhotoStreamCache.EXTRA);\n    },\n    getCacheContent: function(a, b) {\n        if (((!a || ((a === PhotoStreamCache.ERROR_ID))))) {\n            return null;\n        }\n    ;\n    ;\n        return this.cache[b][a];\n    },\n    getCursorPos: function() {\n        return this.position;\n    },\n    getCursor: function() {\n        if (((((this.position >= 0)) && ((this.position < this.getLength()))))) {\n            return this.fbidList[this.position];\n        }\n    ;\n    ;\n        return null;\n    },\n    getCursorForURI: function(a) {\n        return this.permalinkMap[a];\n    },\n    calculatePositionForMovement: function(a) {\n        var b = ((this.position + a));\n        if (this.allLoaded) {\n            var c = this.getLength();\n            b = ((((c + ((b % c)))) % c));\n        }\n    ;\n    ;\n        return b;\n    },\n    isValidMovement: function(a) {\n        if (((!this.isLoaded() || !this.canPage()))) {\n            return false;\n        }\n    ;\n    ;\n        var b = this.calculatePositionForMovement(a);\n        return ((((this.getCursor() > 0)) || ((((b >= 0)) && ((b < this.getLength()))))));\n    },\n    moveCursor: function(a) {\n        if (!this.isValidMovement(a)) {\n            return;\n        }\n    ;\n    ;\n        this.position = this.calculatePositionForMovement(a);\n        if (((a !== 0))) {\n            this.loadMoreIfNeccessary(((a > 0)));\n        }\n    ;\n    ;\n    },\n    checkErrorAt: function(a) {\n        if (!this.isLoaded()) {\n            return false;\n        }\n    ;\n    ;\n        if (((a === PhotoStreamCache.ERROR_ID))) {\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    getRelativeMovement: function(a) {\n        for (var b = 0; ((b < this.getLength())); b++) {\n            if (((this.fbidList[b] === a))) {\n                return ((b - this.position));\n            }\n        ;\n        ;\n        };\n    ;\n        return null;\n    },\n    preloadImages: function() {\n        var e, c;\n        var f = this.getLength();\n        var b = this.cache.image;\n        var a = PhotoStreamCache.BUFFER_SIZE;\n        if (((f > ((a * 2))))) {\n            e = ((((((this.position + f)) - ((a % f)))) % f));\n            c = ((((this.position + a)) % f));\n        }\n         else {\n            e = 0;\n            c = ((f - 1));\n        }\n    ;\n    ;\n        while (((e != c))) {\n            var d = this.fbidList[e];\n            if (((((b[d] && !b[d].resource)) && b[d].url))) {\n                b[d].resource = new JSBNG__Image();\n                b[d].resource.src = b[d].url;\n            }\n        ;\n        ;\n            e = ((((e + 1)) % f));\n        };\n    ;\n    },\n    loadMoreIfNeccessary: function(c) {\n        if (((((this.allLoaded || ((c && this.rightLock)))) || ((!c && this.leftLock))))) {\n            return;\n        }\n    ;\n    ;\n        var d = ((c ? 1 : -1));\n        var a = ((this.fullBucketSize * d));\n        var b = ((this.position + ((this.bufferSize * d))));\n        if (((((b < 0)) && !this.checkErrorAt(this.getEndCursor(false))))) {\n            this.leftLock = true;\n            this.fetch(this.fullBucketSize, false);\n        }\n         else if (((((b > this.getLength())) && !this.checkErrorAt(this.getEndCursor(true))))) {\n            this.rightLock = true;\n            this.fetch(this.fullBucketSize, true);\n        }\n        \n    ;\n    ;\n    },\n    getEndCursor: function(a) {\n        return ((a ? this.fbidList[((this.getLength() - 1))] : this.fbidList[0]));\n    },\n    calculateRelativeIndex: function(c, a, d) {\n        if (!this.totalCount) {\n            return null;\n        }\n    ;\n    ;\n        var b = this.fbidList.indexOf(a);\n        var e = this.fbidList.indexOf(d);\n        if (((((b === -1)) || ((e === -1))))) {\n            return null;\n        }\n    ;\n    ;\n        var f = ((e - b));\n        return ((((((c + f)) + this.totalCount)) % this.totalCount));\n    },\n    fetch: function(a, d) {\n        var c = this.getEndCursor(d);\n        var b = copy_properties({\n            cursor: c,\n            version: this.version,\n            end: this.getEndCursor(!d),\n            fetchSize: ((d ? a : ((-1 * a))))\n        }, this.photoSetQuery);\n        if (((this.totalCount && ((this.firstCursorIndex !== null))))) {\n            b.total = this.totalCount;\n            b.cursorIndex = this.calculateRelativeIndex(this.firstCursorIndex, this.firstCursor, c);\n        }\n    ;\n    ;\n        UIPagelet.loadFromEndpoint(\"PhotoViewerPagelet\", null, b, {\n            usePipe: true,\n            jsNonblock: true,\n            crossPage: true\n        });\n    },\n    storeToCache: function(a) {\n        var b = {\n        };\n        if (!this.isActive) {\n            return b;\n        }\n    ;\n    ;\n        if (((\"error\" in a))) {\n            this.processErrorResult(a.error);\n            b.error = true;\n            return b;\n        }\n    ;\n    ;\n        if (((\"init\" in a))) {\n            this.processInitResult(a.init);\n            b.init = {\n                logids: a.init.logids,\n                fbid: a.init.fbid\n            };\n        }\n    ;\n    ;\n        if (((\"image\" in a))) {\n            this.processImageResult(a.image);\n            b.image = true;\n        }\n    ;\n    ;\n        if (((\"data\" in a))) {\n            this.processDataResult(a.data);\n            b.data = true;\n        }\n    ;\n    ;\n        return b;\n    },\n    processInitResult: function(a) {\n        if (this.loaded) {\n            return;\n        }\n    ;\n    ;\n        this.loaded = true;\n        this.photoSetQuery = a.query;\n        if (a.bufferSize) {\n            this.bufferSize = a.bufferSize;\n        }\n    ;\n    ;\n        if (a.initBucketSize) {\n            this.initBucketSize = a.initBucketSize;\n        }\n    ;\n    ;\n        if (a.fullBucketSize) {\n            this.fullBucketSize = a.fullBucketSize;\n        }\n    ;\n    ;\n        this.fbidList.push(a.fbid);\n        this.firstCursor = a.fbid;\n        if (((((\"initIndex\" in a)) && ((\"totalCount\" in a))))) {\n            this.firstCursorIndex = a.initIndex;\n            this.totalCount = a.totalCount;\n        }\n    ;\n    ;\n        this.rightLock = true;\n        this.fetch(this.initBucketSize, true);\n    },\n    processImageResult: function(b) {\n        for (var a in b) {\n            this.cache.image[a] = b[a];\n            if (b[a].dimensions) {\n                this.cache.image[a].dimensions = Vector2.deserialize(b[a].dimensions);\n            }\n        ;\n        ;\n            this.permalinkMap[URI(b[a].info.permalink).getUnqualifiedURI().toString()] = a;\n        };\n    ;\n    },\n    attachToFbidsList: function(d, e, a) {\n        if (this.allLoaded) {\n            return;\n        }\n    ;\n    ;\n        if (((e === -1))) {\n            for (var b = ((d.length - 1)); ((b >= 0)); b--) {\n                this.fbidList.unshift(d[b]);\n                this.position++;\n            };\n        ;\n            this.leftLock = false;\n        }\n         else {\n            for (var c = 0; ((c < d.length)); c++) {\n                this.fbidList.push(d[c]);\n            ;\n            };\n        ;\n            this.rightLock = false;\n        }\n    ;\n    ;\n        if (a) {\n            this.setAllLoaded();\n        }\n    ;\n    ;\n    },\n    setAllLoaded: function() {\n        this.allLoaded = true;\n        if (((this.getCursor() === null))) {\n            this.position = this.calculatePositionForMovement(0);\n        }\n    ;\n    ;\n    },\n    processDataResult: function(a) {\n        for (var b in a) {\n            if (!this.cache.html[b]) {\n                this.cache.html[b] = {\n                };\n            }\n        ;\n        ;\n            for (var d in a[b].html) {\n                var c = HTML(a[b].html[d]).getRootNode();\n                this.cache.html[b][d] = $A(c.childNodes);\n            };\n        ;\n            if (!((\"extra\" in a[b]))) {\n                this.cache.extra[b] = null;\n                continue;\n            }\n        ;\n        ;\n            this.cache.extra[b] = {\n                tagRects: {\n                }\n            };\n            if (a[b].extra.tagRects) {\n                for (var e in a[b].extra.tagRects) {\n                    if (a[b].extra.tagRects[e]) {\n                        this.cache.extra[b].tagRects[e] = JSBNG__Rect.deserialize(a[b].extra.tagRects[e]);\n                    }\n                ;\n                ;\n                };\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    processErrorResult: function(b) {\n        if (!this.isLoaded()) {\n            this.initError = true;\n            return;\n        }\n    ;\n    ;\n        var c = b.side;\n        var a = [PhotoStreamCache.ERROR_ID,];\n        this.attachToFbidsList(a, c);\n    },\n    setTotalCount: function(a) {\n        this.totalCount = a;\n    },\n    setFirstCursorIndex: function(a) {\n        this.firstCursorIndex = a;\n    }\n});\nfunction PhotoInlineEditor(a) {\n    this.version = a;\n    PhotoInlineEditor.instances[a] = this;\n};\n;\nPhotoInlineEditor.CANCEL_INLINE_EDITING = \"CANCEL_INLINE_EDITING\";\nPhotoInlineEditor.instances = {\n};\nPhotoInlineEditor.getInstance = function(a) {\n    return PhotoInlineEditor.instances[a];\n};\ncopy_properties(PhotoInlineEditor.prototype, {\n    cancel: function(a) {\n        var b = Parent.byClass(a, \"photoUfiContainer\");\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        this.setVisible(b, \".fbPhotosPhotoCaption\", true);\n        this.setVisible(b, \".fbPhotoTagList\", true);\n        this.setVisible(b, \".fbPhotosPhotoEdit\", true);\n        this.setVisible(b, \".fbPhotosPhotoDisabledEdit\", false);\n        this.setVisible(b, \".fbPhotoInlineEditor\", false);\n        Arbiter.unsubscribe(this.arbiterToken);\n        Arbiter.inform(PhotoInlineEditor.CANCEL_INLINE_EDITING);\n    },\n    setVisible: function(c, a, d) {\n        var b = DOM.scry(c, a)[0];\n        ((b && CSS[((d ? \"show\" : \"hide\"))](b)));\n    },\n    subscribeCancel: function(a) {\n        var b = [PhotoSnowbox.PAGE,PhotoSnowbox.CLOSE,PhotoSnowbox.OPEN,PhotoTagger.ACTIVATE_TAGGING,];\n        this.arbiterToken = Arbiter.subscribe(b, this.cancel.bind(this, a), Arbiter.SUBSCRIBE_NEW);\n    }\n});\nvar PhotoSnowbox = {\n    STATE_ERROR: \"error\",\n    STATE_HTML: \"html\",\n    STATE_IMAGE_PIXELS: \"image_pixels\",\n    STATE_IMAGE_DATA: \"image\",\n    CLOSE: \"PhotoSnowbox.CLOSE\",\n    DATA_CHANGE: \"PhotoSnowbox.DATA_CHANGE\",\n    GO: \"PhotoSnowbox.GO\",\n    OPEN: \"PhotoSnowbox.OPEN\",\n    PAGE: \"PhotoSnowbox.PAGE\",\n    RESET_HELP: \"PhotoSnowbox.RESET_HELP\",\n    LOADING_TIMEOUT: 2000,\n    STAGE_MAX: {\n        x: 960,\n        y: 960\n    },\n    STAGE_MIN: {\n        x: 720,\n        y: 402\n    },\n    STAGE_CHROME: {\n        x: 225,\n        y: 117\n    },\n    WIDE_ADS: 855,\n    MIN_TAG_DISTANCE: 83,\n    ADS_REFRESH_RATE: 30000,\n    switchTimer: null,\n    imageRefreshTimer: null,\n    imageLoadingTimer: null,\n    lastPage: 0,\n    currentMinSize: null,\n    normalSize: null,\n    thumbSrc: null,\n    ua: new UserNoOp(),\n    bootstrap: function(b, a) {\n        if (this.isOpen) {\n            return;\n        }\n    ;\n    ;\n        this.ua = user_action(a, \"snowbox\", null).set_namespace(\"snowbox\").set_ua_id(\"open\");\n        this.returningToStart = false;\n        ((this.loading && CSS.removeClass(this.loading, \"loading\")));\n        if (a) {\n            CSS.addClass((this.loading = a), \"loading\");\n            this.getThumbAndSize(a);\n        }\n         else this.loading = null;\n    ;\n    ;\n        Arbiter.inform(PhotoSnowbox.GO, b, Arbiter.BEHAVIOR_STATE);\n        this.loadFrameIfUninitialized();\n    },\n    getThumbAndSize: function(b) {\n        this.normalSize = null;\n        this.thumbSrc = null;\n        var e = URI(b.getAttribute(\"ajaxify\")).getQueryData();\n        if (!e.size) {\n            return;\n        }\n    ;\n    ;\n        var a = Vector2.deserialize(e.size);\n        if (((!a.x || !a.y))) {\n            return;\n        }\n    ;\n    ;\n        this.normalSize = a;\n        if (((((!CSS.hasClass(b, \"uiMediaThumb\") && !CSS.hasClass(b, \"uiPhotoThumb\"))) && !CSS.hasClass(b, \"uiScaledThumb\")))) {\n            return;\n        }\n    ;\n    ;\n        var d = DOM.scry(b, \"img\")[0];\n        var c = DOM.scry(b, \"i\")[0];\n        if (d) {\n            thumbSrc = d.src;\n        }\n         else if (c) {\n            thumbSrc = CSS.getStyle(c, \"backgroundImage\").replace(/.*url\\(\"?([^\"]*)\"?\\).*/, \"$1\");\n        }\n         else return\n        \n    ;\n        this.thumbSrc = thumbSrc;\n    },\n    loadFrameIfUninitialized: function() {\n        if (this.root) {\n            return;\n        }\n    ;\n    ;\n        new AsyncRequest(\"/ajax/photos/snowbox/init.php\").setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n    },\n    init: function(a) {\n        var b = ge(\"fbPhotoSnowbox\");\n        if (!b) {\n            b = DOM.appendContent(JSBNG__document.body, a)[0];\n            this.initialLoad = false;\n        }\n    ;\n    ;\n        if (((this.root == b))) {\n            return;\n        }\n    ;\n    ;\n        this.initializeNodes(b);\n        if (!this.subscription) {\n            LinkController.registerHandler(this.handleNavigateAway.bind(this), ((LinkController.TARGETS | LinkController.MODIFIERS)));\n            this.subscription = Arbiter.subscribe(PhotoSnowbox.GO, function(c, d) {\n                this.openExplicitly = true;\n                ((this.loading && CSS.removeClass(this.loading, \"loading\")));\n                this.open(d);\n            }.bind(this));\n        }\n    ;\n    ;\n        this.returningToStart = false;\n        PageTransitions.registerHandler(this.openHandler.bind(this));\n    },\n    initializeNodes: function(a) {\n        this.root = a;\n        this.closeTheater = DOM.JSBNG__find(a, \"a.closeTheater\");\n        this.container = DOM.JSBNG__find(a, \"div.container\");\n        this.infoWrapper = DOM.JSBNG__find(a, \"div.photoInfoWrapper\");\n        this.stageWrapper = DOM.JSBNG__find(a, \"div.stageWrapper\");\n        this.errorBox = DOM.JSBNG__find(this.stageWrapper, \"div.stageError\");\n        this.image = DOM.JSBNG__find(this.stageWrapper, \"img.spotlight\");\n        this.pivotBar = DOM.JSBNG__find(this.stageWrapper, \"div.pivotWrapper\");\n        this.stage = DOM.JSBNG__find(this.stageWrapper, \"div.stage\");\n        this.videoStage = DOM.JSBNG__find(this.stageWrapper, \"div.videoStage\");\n        this.stagePagers = DOM.JSBNG__find(a, \"div.stagePagers\");\n        this.stageActions = DOM.JSBNG__find(a, \"div.stageActions\");\n        this.buttonActions = DOM.JSBNG__find(this.stageActions, \"div.fbPhotosPhotoButtons\");\n        this.actionList = $(\"fbPhotoSnowboxActions\");\n        this.sideAdUnit = $(\"fbPhotoSnowboxAdsSide\");\n        this.bottomAdUnit = $(\"fbPhotoSnowboxAdsBottom\");\n    },\n    getRoot: function() {\n        return this.root;\n    },\n    openHandler: function(a) {\n        if (((((((((((this.isOpen || ((a.getPath() != \"/photo.php\")))) || this.returningToStart)) || a.getQueryData().closeTheater)) || a.getQueryData().permPage)) || a.getQueryData().makeprofile))) {\n            return false;\n        }\n    ;\n    ;\n        this.open(a);\n        this._uriStack.push(URI(a).getQualifiedURI().toString());\n        PageTransitions.transitionComplete();\n        return true;\n    },\n    open: function(c) {\n        var a = URI(c).getQueryData();\n        var b = a.src;\n        if (b) {\n            delete a.src;\n        }\n    ;\n    ;\n        this._uriStack = [];\n        if (!this.initialLoad) {\n            a.firstLoad = true;\n            this.initialLoad = true;\n        }\n    ;\n    ;\n        this.loadQuery = a;\n        this.isOpen = true;\n        this.refreshOnClose = false;\n        this.hilitedTag = null;\n        this.secondBatchArrived = false;\n        this.lastAdsLoad = 0;\n        this.loadingStates = {\n            image: false,\n            html: false\n        };\n        this.stream = new PhotoStreamCache();\n        this.stream.init(PhotosConst.VIEWER_SNOWBOX);\n        this.fetchInitialData();\n        this.setLoadingState(PhotoSnowbox.STATE_HTML, true);\n        KeyEventController.registerKey(\"ESCAPE\", this.closeListener.bind(this));\n        Bootloader.loadComponents([\"fb-photos-photo-css\",\"fb-photos-snowbox-css\",], function() {\n            this._open(c, b);\n        }.bind(this));\n    },\n    _open: function(d, c) {\n        this.createLoader(c);\n        CSS.show(this.root);\n        CSS.addClass.curry(JSBNG__document.documentElement, \"theaterMode\").defer();\n        this.ua.add_event(\"frame\");\n        Arbiter.inform(\"layer_shown\", {\n            type: \"PhotoSnowbox\"\n        });\n        Arbiter.inform(PhotoSnowbox.OPEN);\n        Bootloader.loadComponents([\"hovercard\",\"live-js\",\"photocrop2\",\"PhotoTag\",\"PhotoTagger\",\"TagToken\",\"TagTokenizer\",\"ui-ufi-css\",]);\n        this.stageHandlers = [JSBNG__Event.listen(window, \"resize\", this.adjustForResize.bind(this)),JSBNG__Event.listen(this.root, \"click\", this.closeListener.bind(this)),JSBNG__Event.listen(this.stageWrapper, \"click\", this.buttonListener.bind(this)),JSBNG__Event.listen(this.actionList, \"click\", this.rotateListener.bind(this)),];\n        var a = ge(\"fbPhotoSnowboxFeedback\");\n        if (a) {\n            this.stageHandlers.push(JSBNG__Event.listen(a, \"click\", function(JSBNG__event) {\n                if (Parent.byClass(JSBNG__event.getTarget(), \"like_link\")) {\n                    CSS.toggleClass(DOM.JSBNG__find(this.buttonActions, \"div.likeCommentGroup\"), \"viewerLikesThis\");\n                }\n            ;\n            ;\n            }.bind(this)));\n        }\n    ;\n    ;\n        var b = ge(\"fbPhotoSnowboxOnProfile\");\n        if (b) {\n            this.stageHandlers.push(JSBNG__Event.listen(b, \"click\", function(JSBNG__event) {\n                if (Parent.byClass(JSBNG__event.getTarget(), \"fbPhotoRemoveFromProfileLink\")) {\n                    this.refreshOnClose = true;\n                }\n            ;\n            ;\n            }.bind(this)));\n        }\n    ;\n    ;\n        PageTransitions.registerHandler(function(e) {\n            if (((((this.isOpen && !e.getQueryData().makeprofile)) && !this.returningToStart))) {\n                this.close();\n                PageTransitions.transitionComplete();\n                return true;\n            }\n        ;\n        ;\n            return false;\n        }.bind(this));\n        this.startingURI = URI.getMostRecentURI().addQueryData({\n            closeTheater: 1\n        }).getUnqualifiedURI();\n        if (!c) {\n            this.setLoadingState(PhotoSnowbox.STATE_IMAGE_DATA, true);\n        }\n    ;\n    ;\n        PageTransitions.registerHandler(this.transitionHandler.bind(this));\n        PhotoSnowboxLog.initLogging();\n        ((ua.firefox() && this.turnFlashAutoplayOff.defer()));\n        (function() {\n            this.adjustForResize();\n            if (ua.ie()) {\n                this.container.JSBNG__focus();\n            }\n             else this.root.JSBNG__focus();\n        ;\n        ;\n        }).bind(this).defer();\n    },\n    getStream: function() {\n        return this.stream;\n    },\n    fetchInitialData: function() {\n        this.ua.add_event(\"init_data\");\n        new AsyncRequest(\"/ajax/photos/snowbox/load.php\").setAllowCrossPageTransition(true).setData(this.loadQuery).setHandler(this.storeFromResponse.bind(this)).setMethod(\"GET\").setReadOnly(true).send();\n    },\n    turnFlashAutoplayOff: function() {\n        DOM.scry(JSBNG__document, \"div.swfObject\").each(function(d) {\n            var b = d.getAttribute(\"data-swfid\");\n            if (((b && window[b]))) {\n                var c = window[b];\n                c.addParam(\"autostart\", \"false\");\n                c.addParam(\"autoplay\", \"false\");\n                c.addParam(\"play\", \"false\");\n                c.addVariable(\"video_autoplay\", \"0\");\n                c.addVariable(\"autoplay\", \"0\");\n                c.addVariable(\"play\", \"0\");\n                var a = URI(c.getAttribute(\"swf\"));\n                a.addQueryData({\n                    autoplay: \"0\"\n                });\n                a.setPath(a.getPath().replace(\"autoplay=1\", \"autoplay=0\"));\n                c.setAttribute(\"swf\", a.toString());\n                c.write(d);\n            }\n        ;\n        ;\n        });\n    },\n    closeHandler: function() {\n        if (!this.isOpen) {\n            return;\n        }\n    ;\n    ;\n        if (((URI.getMostRecentURI().addQueryData({\n            closeTheater: 1\n        }).getUnqualifiedURI().toString() == this.startingURI.toString()))) {\n            this.close();\n            return;\n        }\n    ;\n    ;\n        this.close();\n        this.returnToStartingURI(this.refreshOnClose);\n    },\n    returnToStartingURI: function(c, a) {\n        if (!c) {\n            if (a) {\n                this.squashNextTransition(goURI.curry(a));\n            }\n             else this.squashNextTransition();\n        ;\n        }\n    ;\n    ;\n        this.returningToStart = true;\n        var d = Arbiter.subscribe(\"page_transition\", function() {\n            this.returningToStart = false;\n            Arbiter.unsubscribe(d);\n        });\n        var f = this._uriStack.length;\n        if (((f < window.JSBNG__history.length))) {\n            window.JSBNG__history.go(-f);\n        }\n         else {\n            var e = PhotoSnowbox.startingURI;\n            var b = new URI(e).removeQueryData(\"closeTheater\");\n            if (((((e.getQueryData().sk == \"approve\")) && ((e.getPath() == \"/profile.php\"))))) {\n                b.removeQueryData(\"highlight\");\n                b.removeQueryData(\"notif_t\");\n            }\n        ;\n        ;\n            goURI(b);\n        }\n    ;\n    ;\n    },\n    squashNextTransition: function(a) {\n        PhotoSnowbox.squashNext = true;\n        PageTransitions.registerHandler(function _squash() {\n            if (PhotoSnowbox.squashNext) {\n                PhotoSnowbox.squashNext = false;\n                if (a) {\n                    a.defer();\n                }\n            ;\n            ;\n                PageTransitions.transitionComplete();\n                return true;\n            }\n        ;\n        ;\n            return false;\n        });\n    },\n    handleNavigateAway: function(b) {\n        var a = _computeRelativeURI(window.PageTransitions._most_recent_uri.getQualifiedURI(), b.getAttribute(\"href\"));\n        if (((((((this.isOpen && ((a instanceof URI)))) && ((a.getUnqualifiedURI().toString() != this.startingURI.toString())))) && ((a.getPath() != \"/photo.php\"))))) {\n            if (!this.closingAction) {\n                this.closingAction = PhotoSnowboxLog.NAVIGATE;\n            }\n        ;\n        ;\n            this.close();\n            this.returnToStartingURI(false, a);\n            return false;\n        }\n    ;\n    ;\n        return true;\n    },\n    closeListener: function(JSBNG__event) {\n        if (((this.isOpen && !((window.Dialog && Dialog.getCurrent()))))) {\n            var c = JSBNG__event.getTarget();\n            var a = Parent.byClass(c, \"closeTheater\");\n            var b = ((((a || ((c == this.root)))) || ((c == this.infoWrapper))));\n            if (b) {\n                if (a) {\n                    this.closingAction = PhotoSnowboxLog.X;\n                }\n                 else this.closingAction = PhotoSnowboxLog.OUTSIDE;\n            ;\n            ;\n                JSBNG__Event.kill(JSBNG__event);\n                this.closeHandler();\n            }\n             else if (((JSBNG__Event.getKeyCode(JSBNG__event) == KEYS.ESC))) {\n                this.closingAction = PhotoSnowboxLog.ESC;\n                JSBNG__Event.kill(JSBNG__event);\n                this.closeHandler();\n            }\n            \n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    close: function() {\n        if (!this.isOpen) {\n            return;\n        }\n    ;\n    ;\n        CSS.hide(this.root);\n        this.openExplicitly = false;\n        this.closeCleanup.bind(this).defer();\n    },\n    closeCleanup: function() {\n        CSS.removeClass(JSBNG__document.documentElement, \"theaterMode\");\n        CSS.removeClass(this.root, \"dataLoaded\");\n        KeyEventController.getInstance().resetHandlers();\n        PhotoSnowboxLog.logPhotoViews(this.closingAction);\n        this.destroy();\n        CSS.hide(this.errorBox);\n        CSS.hide(this.image);\n        this.normalSize = null;\n        this.thumbSrc = null;\n        CSS.removeClass(this.stageWrapper, \"showVideo\");\n        DOM.empty(this.videoStage);\n        this.currentMinSize = null;\n        this.pinPagers = false;\n        this.recacheData();\n        DOM.empty(this.sideAdUnit);\n        DOM.empty(this.bottomAdUnit);\n        this.stream.destroy();\n        var a = ((this.closingAction === PhotoSnowboxLog.NAVIGATE));\n        this.closingAction = null;\n        PageTransitions.registerHandler(this.openHandler.bind(this));\n        Arbiter.inform(\"layer_hidden\", {\n            type: \"PhotoSnowbox\"\n        });\n        Arbiter.inform(PhotoSnowbox.CLOSE, a);\n        this.root.setAttribute(\"aria-busy\", \"true\");\n        this.isOpen = false;\n    },\n    createLoader: function(b) {\n        if (((((this.thumbSrc !== null)) && ((this.normalSize !== null))))) {\n            var a = this.getMaxImageSize(this.normalSize);\n            this.useImage($N(\"img\", {\n                className: \"spotlight\",\n                alt: \"\",\n                src: this.thumbSrc,\n                style: {\n                    width: ((a.x + \"px\")),\n                    height: ((a.y + \"px\"))\n                }\n            }), a, false);\n        }\n    ;\n    ;\n        this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n        if (b) {\n            (function() {\n                var c = new JSBNG__Image();\n                c.JSBNG__onload = async_callback(function() {\n                    if (((!this.stream || !this.stream.errorInCurrent()))) {\n                        this.switchImage(b, this.normalSize);\n                        this.ua.add_event(\"image\");\n                    }\n                ;\n                ;\n                }.bind(this), \"photo_theater\");\n                c.src = b;\n            }).bind(this).defer();\n        }\n    ;\n    ;\n        CSS.hide(this.stageActions);\n        CSS.hide(this.stagePagers);\n    },\n    initDataFetched: function(a) {\n        PhotoSnowboxLog.setPhotoSet(this.stream.getPhotoSet());\n        PhotoSnowboxLog.setLogFbids(a.logids);\n        PhotoSnowboxLog.addPhotoView(this.stream.getCurrentImageData().info);\n        this.position = this.stream.getCursor();\n        var b = {\n            click: this.pageListener.bind(this),\n            mouseleave: this.mouseLeaveListener.bind(this),\n            mousemove: this.mouseMoveListener.bind(this)\n        };\n        if (!this.pageHandlers) {\n            this.pageHandlers = values(JSBNG__Event.listen(this.root, b));\n            KeyEventController.registerKey(\"LEFT\", this.pageListener.bind(this));\n            KeyEventController.registerKey(\"RIGHT\", this.pageListener.bind(this));\n        }\n    ;\n    ;\n        CSS.show(this.stageActions);\n        this.root.setAttribute(\"aria-busy\", \"false\");\n        this.loadAds();\n    },\n    adjustForResize: function() {\n        this.currentMinSize = null;\n        this.pinPagers = false;\n        this.adjustStageSize();\n        this.adjustForNewData();\n    },\n    getMaxImageSize: function(c) {\n        var f = Vector2.getViewportDimensions();\n        var e = f.sub(new Vector2(PhotoSnowbox.STAGE_CHROME.x, PhotoSnowbox.STAGE_CHROME.y));\n        var a = new Vector2(Math.min(c.x, e.x, PhotoSnowbox.STAGE_MAX.x), Math.min(c.y, e.y, PhotoSnowbox.STAGE_MAX.y));\n        if (((((a.x === 0)) && ((a.y === 0))))) {\n            return new Vector2(0, 0);\n        }\n    ;\n    ;\n        var d = ((c.x / c.y));\n        var b = ((a.x / a.y));\n        if (((b < d))) {\n            return new Vector2(a.x, Math.round(((a.x / d))));\n        }\n    ;\n    ;\n        return new Vector2(Math.round(((a.y * d))), a.y);\n    },\n    adjustStageSize: function(c) {\n        var a;\n        var b = ((this.stream && this.stream.getCurrentImageData()));\n        if (c) {\n            a = c;\n        }\n         else if (((b && b.dimensions))) {\n            a = b.dimensions;\n        }\n         else if (((((this.image && this.image.src)) && image_has_loaded(this.image)))) {\n            a = Vector2.getElementDimensions(this.image);\n        }\n         else return\n        \n        \n    ;\n        var d = this.getMaxImageSize(a);\n        if (!this.currentMinSize) {\n            this.currentMinSize = new Vector2(Math.max(d.x, PhotoSnowbox.STAGE_MIN.x), Math.max(d.y, PhotoSnowbox.STAGE_MIN.y));\n        }\n         else this.currentMinSize = new Vector2(Math.max(d.x, this.currentMinSize.x), Math.max(d.y, PhotoSnowbox.STAGE_MIN.y));\n    ;\n    ;\n        CSS.setStyle(this.container, \"width\", ((this.currentMinSize.x + \"px\")));\n        CSS.setStyle(this.stageWrapper, \"height\", ((this.currentMinSize.y + \"px\")));\n        CSS.setStyle(this.stage, \"lineHeight\", ((this.currentMinSize.y + \"px\")));\n        CSS.setStyle(this.videoStage, \"lineHeight\", ((this.currentMinSize.y + \"px\")));\n        CSS.conditionClass(this.container, \"adsOnSide\", ((this.currentMinSize.x >= PhotoSnowbox.WIDE_ADS)));\n        this.adjustForAdUnit();\n        if (!this.pinPagers) {\n            CSS.setStyle(this.stagePagers, \"height\", ((((this.currentMinSize.y / 2)) + \"px\")));\n        }\n    ;\n    ;\n        this.pinPagers = true;\n    },\n    adjustForNewData: function() {\n        if (!this.image) {\n            return;\n        }\n    ;\n    ;\n        var c = DOM.scry(this.stage, \"div.tagsWrapper\")[0];\n        var a = Vector2.getElementDimensions(this.image);\n        if (c) {\n            CSS.setStyle(c, \"width\", ((a.x + \"px\")));\n            CSS.setStyle(c, \"height\", ((a.y + \"px\")));\n            if (((ua.ie() <= 7))) {\n                var b = DOM.scry(this.root, \"div.tagContainer\")[0];\n                if (b) {\n                    CSS.conditionClass(c, \"ie7VerticalFix\", ((Vector2.getElementDimensions(b).y > a.y)));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    setLoadingState: function(b, a) {\n        switch (b) {\n          case PhotoSnowbox.STATE_IMAGE_PIXELS:\n            CSS.conditionClass(this.root, \"imagePixelsLoading\", a);\n            break;\n          case PhotoSnowbox.STATE_IMAGE_DATA:\n            this.loadingStates[b] = a;\n            CSS.conditionClass(this.root, \"imageLoading\", a);\n            break;\n          case PhotoSnowbox.STATE_HTML:\n            this.loadingStates[b] = a;\n            CSS.conditionClass(this.root, \"dataLoading\", a);\n            CSS.conditionClass(this.root, \"dataLoaded\", !a);\n            this.infoWrapper.setAttribute(\"aria-busy\", ((a ? \"true\" : \"false\")));\n            break;\n        };\n    ;\n    },\n    destroy: function() {\n        this.stageHandlers.each(function(a) {\n            a.remove();\n        });\n        if (this.pageHandlers) {\n            this.pageHandlers.each(function(a) {\n                a.remove();\n            });\n            this.pageHandlers = null;\n        }\n    ;\n    ;\n    },\n    checkState: function(b) {\n        if (((((b != PhotoSnowbox.STATE_ERROR)) && !this.loadingStates[b]))) {\n            return;\n        }\n    ;\n    ;\n        switch (b) {\n          case PhotoSnowbox.STATE_IMAGE_DATA:\n            var a = this.stream.getCurrentImageData();\n            if (a) {\n                if (a.url) {\n                    this.switchImage(a.url, null, true);\n                }\n                 else if (a.video) {\n                    this.switchVideo(a.video, true);\n                }\n                \n            ;\n            ;\n                this.setLoadingState(b, false);\n            }\n        ;\n        ;\n            break;\n          case PhotoSnowbox.STATE_HTML:\n            if (this.stream.getCurrentHtml()) {\n                this.swapData();\n                this.setLoadingState(b, false);\n            }\n        ;\n        ;\n            break;\n          default:\n            if (this.stream.errorInCurrent()) {\n                CSS.hide(this.image);\n                CSS.show(this.errorBox);\n            }\n        ;\n        ;\n            break;\n        };\n    ;\n    },\n    buttonListener: function(JSBNG__event) {\n        var b = JSBNG__event.getTarget();\n        var a = +new JSBNG__Date();\n        if (((((a - this.lastPage)) < 350))) {\n            if (Parent.byClass(b, \"tagApproveIgnore\")) {\n                JSBNG__Event.kill(JSBNG__event);\n            }\n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        if (Parent.byClass(b, \"likeButton\")) {\n            DOM.JSBNG__find($(\"fbPhotoSnowboxFeedback\"), \"button.like_link\").click();\n        }\n         else if (Parent.byClass(b, \"commentButton\")) {\n            DOM.JSBNG__find(this.root, \"div.commentBox textarea\").JSBNG__focus();\n            this.root.scrollTop = this.root.scrollHeight;\n        }\n         else if (Parent.byClass(b, \"tagApproveIgnore\")) {\n            this.updateTagBox(JSBNG__event, b);\n        }\n        \n        \n    ;\n    ;\n    },\n    rotateListener: function(JSBNG__event) {\n        var a = JSBNG__event.getTarget();\n        if (Parent.byClass(a, \"rotateRight\")) {\n            this.rotate(\"right\");\n        }\n         else if (Parent.byClass(a, \"rotateLeft\")) {\n            this.rotate(\"left\");\n        }\n        \n    ;\n    ;\n    },\n    updateTagBox: function(JSBNG__event, c) {\n        var a;\n        if (Parent.byClass(c, \"approveTag\")) {\n            a = true;\n        }\n         else if (Parent.byClass(c, \"ignoreTag\")) {\n            a = false;\n        }\n         else return\n        \n    ;\n        this.unhiliteAllTags();\n        var b = Parent.byClass(c, \"tagBoxPending\");\n        CSS.addClass(b, \"tagBox tagBoxPendingResponse\");\n        CSS.removeClass(b, \"tagBoxPending\");\n        CSS.hide(DOM.JSBNG__find(b, \"span.tagForm\"));\n        if (a) {\n            CSS.show(DOM.JSBNG__find(b, \"span.tagApproved\"));\n        }\n         else CSS.show(DOM.JSBNG__find(b, \"span.tagIgnored\"));\n    ;\n    ;\n    },\n    rotate: function(c) {\n        var d = this.stream.getCursor();\n        if (this.getVideoOnStage()) {\n            var b = ((((c == \"left\")) ? 270 : 90));\n            Bootloader.loadComponents([\"video-rotate-snowbox\",], new VideoRotate(d, this.actionList).motionRotate(b));\n            return;\n        }\n    ;\n    ;\n        var a = {\n            fbid: d,\n            cs_ver: PhotosConst.VIEWER_SNOWBOX\n        };\n        a[c] = 1;\n        this.setLoadingState(PhotoSnowbox.STATE_IMAGE_DATA, true);\n        this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n        CSS.hide(this.image);\n        new AsyncRequest(\"/ajax/photos/photo/rotate/\").setAllowCrossPageTransition(true).setData(a).setErrorHandler(this.rotationError.bind(this, d)).setHandler(this.rotationComplete.bind(this, d)).setMethod(\"POST\").setReadOnly(false).send();\n    },\n    rotationComplete: function(a, b) {\n        this.storeResponseForRotate(a, b);\n        if (((a == this.stream.getCursor()))) {\n            this.setLoadingState(PhotoSnowbox.STATE_IMAGE_DATA, false);\n            this.switchImage(this.stream.getCurrentImageData().url);\n            this.swapData();\n        }\n    ;\n    ;\n        this.refreshOnClose = true;\n    },\n    storeResponseForRotate: function(a, c) {\n        this.storeFromResponse(c);\n        var b = this.stream.getImageData(a);\n        b.url = c.getPayload().new_urls[PhotosConst.SIZE_NORMAL];\n        b.dimensions = Vector2.deserialize(c.getPayload().dimensions);\n    },\n    rotationError: function(a, b) {\n        if (((a == this.stream.getCursor()))) {\n            this.setLoadingState(PhotoSnowbox.STATE_IMAGE_DATA, false);\n            this.switchImage(this.stream.getCurrentImageData().url);\n            AsyncResponse.defaultErrorHandler(b);\n        }\n    ;\n    ;\n    },\n    saveTagComplete: function(a) {\n        this.saveTagsFromPayload(a.getPayload());\n    },\n    saveTagsFromPayload: function(a) {\n        this.refreshOnClose = true;\n        this.storeFromData(a);\n        if (((((\"data\" in a)) && ((this.stream.getCursor() in a.data))))) {\n            this.swapData();\n        }\n    ;\n    ;\n    },\n    mouseLeaveListener: function(JSBNG__event) {\n        this.unhiliteAllTags();\n        this.hiliteLeftmostPendingTag();\n    },\n    mouseMoveListener: function(JSBNG__event) {\n        var b = JSBNG__event.getTarget();\n        var a = ((Parent.byClass(b, \"stageActions\") || Parent.byClass(b, \"stageWrapper\")));\n        if (!a) {\n            CSS.hide(this.pivotBar);\n        }\n    ;\n    ;\n        if (((this.hasPivotData() && !this.loadingStates.html))) {\n            CSS.show(this.pivotBar);\n        }\n    ;\n    ;\n        this.hiliteTagsOnMouseMove(JSBNG__event);\n    },\n    hasPivotData: function() {\n        var a = this.stream.getCurrentHtml();\n        return ((a && a.fbPhotoSnowboxPivots));\n    },\n    unhiliteAllTags: function() {\n        DOM.scry(this.stage, \"div.tagsWrapper div.hover\").each(function(a) {\n            CSS.removeClass(a, \"hover\");\n        });\n        this.hilitedTag = null;\n    },\n    switchHilitedTags: function(b) {\n        if (((this.switchTimer !== null))) {\n            JSBNG__clearTimeout(this.switchTimer);\n            this.switchTimer = null;\n        }\n    ;\n    ;\n        var a = ge(this.hilitedTag);\n        ((a && CSS.removeClass(a, \"hover\")));\n        this.unhiliteAllTags();\n        if (b) {\n            this.hilitedTag = b;\n            CSS.addClass($(this.hilitedTag), \"hover\");\n        }\n    ;\n    ;\n    },\n    hiliteLeftmostPendingTag: function() {\n        var a = ge(this.hilitedTag);\n        if (((a && CSS.hasClass(a, \"tagBoxPending\")))) {\n            return;\n        }\n    ;\n    ;\n        var b = DOM.scry(this.stage, \"div.tagsWrapper div.tagBoxPending\")[0];\n        if (b) {\n            this.switchHilitedTags(b.id);\n        }\n    ;\n    ;\n    },\n    hiliteTagsOnMouseMove: function(JSBNG__event) {\n        if (((!this.stream.getCurrentExtraData() || this.getVideoOnStage()))) {\n            return;\n        }\n    ;\n    ;\n        if (((this.switchTimer !== null))) {\n            return;\n        }\n    ;\n    ;\n        var i = Parent.byClass(JSBNG__event.getTarget(), \"tagBoxPending\");\n        var d = ((this.hilitedTag && CSS.hasClass($(this.hilitedTag), \"tagBoxPending\")));\n        var l = ((((!this.hilitedTag && i)) || ((!d && i))));\n        if (l) {\n            this.switchHilitedTags(i.id);\n            return;\n        }\n    ;\n    ;\n        if (((i && ((i.id == this.hilitedTag))))) {\n            return;\n        }\n    ;\n    ;\n        var a = 250;\n        var h = Vector2.getEventPosition(JSBNG__event);\n        var f = Vector2.getElementPosition(this.image);\n        var e = Vector2.getElementDimensions(this.image);\n        var j = this.stream.getCurrentImageData().dimensions;\n        var k = ((e.x / j.x));\n        var g = PhotosUtils.getNearestBox(h, f, j, k, ((PhotoSnowbox.MIN_TAG_DISTANCE * k)), this.stream.getCurrentExtraData().tagRects);\n        if (!g) {\n            if (!d) {\n                this.unhiliteAllTags();\n                this.hiliteLeftmostPendingTag();\n            }\n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        var b = null;\n        if (d) {\n            var c = {\n            };\n            c[this.hilitedTag] = this.stream.getCurrentExtraData().tagRects[this.hilitedTag];\n            b = PhotosUtils.getNearestBox(h, f, j, k, ((PhotoSnowbox.MIN_TAG_DISTANCE * k)), c);\n        }\n    ;\n    ;\n        if (((((b !== null)) && d))) {\n            return;\n        }\n    ;\n    ;\n        if (((this.hilitedTag != g))) {\n            if (d) {\n                this.switchTimer = this.switchHilitedTags.bind(this, g).defer(a);\n            }\n             else this.switchHilitedTags(g);\n        ;\n        }\n    ;\n    ;\n    },\n    getVideoOnStage: function() {\n        var a = ((this.stream && this.stream.getCurrentImageData()));\n        return ((a && a.video));\n    },\n    shouldGoForward: function(a, c) {\n        var d = ((((a == KEYS.RIGHT)) || Parent.byClass(c, \"next\")));\n        if (d) {\n            return true;\n        }\n    ;\n    ;\n        var b = ((((((this.getVideoOnStage() || CSS.hasClass(this.root, \"taggingMode\"))) || Parent.byClass(c, \"tagBoxPending\"))) || Parent.byClass(c, \"tagBoxPendingResponse\")));\n        if (b) {\n            return false;\n        }\n    ;\n    ;\n        return ((DOM.isNode(c) && Parent.byClass(c, \"stage\")));\n    },\n    pageListener: function(JSBNG__event) {\n        var a = JSBNG__Event.getKeyCode(JSBNG__event);\n        var b = JSBNG__event.getTarget();\n        if (((((a == KEYS.LEFT)) || Parent.byClass(b, \"prev\")))) {\n            this.page(-1);\n            user_action(b, \"a\", JSBNG__event);\n            return;\n        }\n    ;\n    ;\n        if (this.shouldGoForward(a, b)) {\n            this.page(1);\n            user_action(b, \"a\", JSBNG__event);\n        }\n    ;\n    ;\n    },\n    page: function(c, b) {\n        if (!this.stream.isValidMovement(c)) {\n            return;\n        }\n    ;\n    ;\n        this.lastPage = +new JSBNG__Date();\n        this.unhiliteAllTags();\n        var d = this.getVideoOnStage();\n        if (d) {\n            this.switchVideo(d, false);\n        }\n    ;\n    ;\n        Arbiter.inform(PhotoSnowbox.PAGE);\n        this.recacheData();\n        this.stream.moveCursor(c);\n        CSS.hide(this.image);\n        if (this.stream.errorInCurrent()) {\n            this.setLoadingState(PhotoSnowbox.STATE_HTML, true);\n            CSS.show(this.errorBox);\n            return;\n        }\n    ;\n    ;\n        var a = this.stream.getCurrentImageData();\n        if (a) {\n            if (a.url) {\n                this.switchImage(a.url, null, true);\n            }\n             else if (a.video) {\n                this.switchVideo(a.video, true);\n            }\n            \n        ;\n        ;\n            if (!b) {\n                this.replaceUrl = true;\n                goURI(a.info.permalink);\n            }\n        ;\n        ;\n        }\n         else {\n            this.setLoadingState(PhotoSnowbox.STATE_IMAGE_PIXELS, true);\n            this.setLoadingState(PhotoSnowbox.STATE_IMAGE_DATA, true);\n        }\n    ;\n    ;\n        if (this.stream.getCurrentHtml()) {\n            this.swapData();\n        }\n         else this.setLoadingState(PhotoSnowbox.STATE_HTML, true);\n    ;\n    ;\n        this.hiliteLeftmostPendingTag();\n        this.loadAds();\n    },\n    loadAds: function() {\n        var a = +new JSBNG__Date();\n        if (((((a - this.lastAdsLoad)) > PhotoSnowbox.ADS_REFRESH_RATE))) {\n            UIPagelet.loadFromEndpoint(\"WebEgoPane\", \"fbPhotoSnowboxAdsSide\", {\n                pid: 34,\n                data: []\n            }, {\n                crossPage: true\n            });\n            this.lastAdsLoad = a;\n        }\n    ;\n    ;\n    },\n    adjustForAdUnit: function() {\n        var b = this.sideAdUnit.childNodes;\n        var a = this.bottomAdUnit.childNodes;\n        if (CSS.hasClass(this.container, \"adsOnSide\")) {\n            if (((((a.length > 0)) && ((b.length === 0))))) {\n                DOM.setContent(this.sideAdUnit, $A(a));\n            }\n        ;\n        ;\n            DOM.empty(this.bottomAdUnit);\n        }\n         else if (((b.length > 0))) {\n            DOM.setContent(this.bottomAdUnit, $A(b));\n            DOM.empty(this.sideAdUnit);\n        }\n        \n    ;\n    ;\n    },\n    transitionHandler: function(c) {\n        if (((((c.getQueryData().closeTheater || c.getQueryData().permPage)) || this.returningToStart))) {\n            return false;\n        }\n    ;\n    ;\n        if (this.replaceUrl) {\n            this.replaceUrl = false;\n            this._uriStack.push(c.getQualifiedURI().toString());\n            PageTransitions.transitionComplete();\n            return true;\n        }\n    ;\n    ;\n        if (c.getQueryData().makeprofile) {\n            this.close();\n            return false;\n        }\n    ;\n    ;\n        var d = this._uriStack.length;\n        if (((((d >= 2)) && ((this._uriStack[((d - 2))] == c.getQualifiedURI().toString()))))) {\n            this._uriStack.pop();\n        }\n    ;\n    ;\n        var a = this.stream.getCursorForURI(c.getUnqualifiedURI().toString());\n        if (a) {\n            var b = this.stream.getRelativeMovement(a);\n            this.page(b, true);\n            PageTransitions.transitionComplete();\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    recacheData: function() {\n        if (!this.loadingStates.html) {\n            var a = this.stream.getCurrentHtml();\n            for (var b in a) {\n                a[b] = $A($(b).childNodes);\n                DOM.empty($(b));\n            };\n        ;\n        }\n    ;\n    ;\n    },\n    reloadIfTimeout: function() {\n        if (!image_has_loaded(this.image)) {\n            var a = this.makeNewImage(this.image.src, true);\n            JSBNG__Event.listen(a, \"load\", this.useImage.bind(this, a, null, true));\n        }\n    ;\n    ;\n    },\n    useImage: function(c, a, b) {\n        if (((b && image_has_loaded(this.image)))) {\n            return;\n        }\n    ;\n    ;\n        DOM.replace(this.image, c);\n        this.image = c;\n        this.adjustStageSize(a);\n    },\n    makeNewImage: function(c, a) {\n        if (this.imageLoadingTimer) {\n            JSBNG__clearTimeout(this.imageLoadingTimer);\n            this.imageLoadingTimer = null;\n        }\n         else if (!a) {\n            this.imageRefreshTimer = JSBNG__setTimeout(this.reloadIfTimeout.bind(this), PhotoSnowbox.LOADING_TIMEOUT);\n        }\n        \n    ;\n    ;\n        var b = $N(\"img\", {\n            className: \"spotlight\",\n            alt: \"\"\n        });\n        b.setAttribute(\"aria-describedby\", \"fbPhotosSnowboxCaption\");\n        b.setAttribute(\"aria-busy\", \"true\");\n        JSBNG__Event.listen(b, \"load\", async_callback(function() {\n            JSBNG__clearTimeout(this.imageRefreshTimer);\n            this.image.setAttribute(\"aria-busy\", \"false\");\n            this.setLoadingState(this.STATE_IMAGE_PIXELS, false);\n            (function() {\n                this.adjustStageSize();\n                this.adjustForNewData();\n            }).bind(this).defer();\n        }.bind(this), \"photo_theater\"));\n        b.src = c;\n        return b;\n    },\n    switchImage: function(d, b, c) {\n        CSS.hide(this.image);\n        CSS.hide(this.errorBox);\n        this.setLoadingState(this.STATE_IMAGE_PIXELS, true);\n        var a = ((this.stream && this.stream.getCurrentImageData()));\n        if (a) {\n            PhotoSnowboxLog.addPhotoView(a.info);\n        }\n    ;\n    ;\n        this.useImage(this.makeNewImage(d, false), b, false);\n        if (c) {\n            this.stream.preloadImages();\n        }\n    ;\n    ;\n    },\n    switchVideo: function(c, a) {\n        var b = ((\"swf_\" + c));\n        if (a) {\n            CSS.addClass(this.stageWrapper, \"showVideo\");\n            this.videoStage.id = c;\n            if (((window[b] && !ge(b)))) {\n                window[b].write(c);\n            }\n        ;\n        ;\n            this.adjustStageSizeForVideo.bind(this, b).defer();\n        }\n         else {\n            this.videoStage.id = \"fbVideoStage\";\n            ((window[b] && window[b].addVariable(\"video_autoplay\", 0)));\n            ((this.videoLoadTimer && JSBNG__clearTimeout(this.videoLoadTimer)));\n            DOM.empty(this.videoStage);\n            CSS.removeClass(this.stageWrapper, \"showVideo\");\n        }\n    ;\n    ;\n    },\n    checkVideoStatus: function(a) {\n        if (this.videoLoadTimer) {\n            JSBNG__clearTimeout(this.videoLoadTimer);\n        }\n    ;\n    ;\n        video = this.getVideoOnStage();\n        if (!video) {\n            return;\n        }\n         else {\n            currentSwfID = ((\"swf_\" + video));\n            if (((a !== currentSwfID))) {\n                return;\n            }\n        ;\n        ;\n            this.adjustStageSizeForVideo(a);\n        }\n    ;\n    ;\n    },\n    adjustStageSizeForVideo: function(a) {\n        var b = ge(a);\n        if (!b) {\n            this.videoLoadTimer = JSBNG__setTimeout(this.checkVideoStatus.bind(this, a), 200);\n        }\n         else this.adjustStageSize(new Vector2(b.width, b.height));\n    ;\n    ;\n    },\n    setErrorBoxContent: function(a) {\n        DOM.setContent(this.errorBox, a);\n    },\n    swapData: function() {\n        var b, c = this.stream.getCurrentHtml();\n        if (c) {\n            this.setLoadingState(PhotoSnowbox.STATE_HTML, false);\n            for (var d in c) {\n                b = ge(d);\n                ((b && DOM.setContent(b, c[d])));\n            };\n        ;\n            var e = DOM.scry(this.root, \"div.fbVideoTagApproval\")[0];\n            if (((e && ((e.children.length === 0))))) {\n                CSS.hide(e);\n            }\n        ;\n        ;\n            var a = DOM.scry($(\"fbPhotoSnowboxCaption\"), \"div.fbPhotoInlineCaptionEditor\");\n            if (a.length) {\n                new PhotoInlineCaptionEditor(\"snowbox\").init(a[0]);\n            }\n        ;\n        ;\n            Arbiter.inform(PhotoSnowbox.DATA_CHANGE, this.stream.getCurrentImageData().info, Arbiter.BEHAVIOR_STATE);\n            this.position = this.stream.getCursor();\n            if (ge(this.hilitedTag)) {\n                CSS.addClass($(this.hilitedTag), \"hover\");\n            }\n             else this.hiliteLeftmostPendingTag();\n        ;\n        ;\n        }\n    ;\n    ;\n        this.adjustForNewData();\n    },\n    updateTotalCount: function(c, b, a) {\n        element = ge(\"fbPhotoSnowboxPositionAndCount\");\n        ((element && DOM.setContent(element, a)));\n        this.stream.setTotalCount(c);\n        this.stream.setFirstCursorIndex(b);\n    },\n    addPhotoFbids: function(b, c, a) {\n        var d = ((this.stream.getCursor() === null));\n        this.stream.attachToFbidsList(b, c, a);\n        if (((a && d))) {\n            this.page(0);\n        }\n    ;\n    ;\n    },\n    storeFromResponse: function(a) {\n        ((window.ArbiterMonitor && ArbiterMonitor.stopTtiMeasurement()));\n        this.storeFromData(a.getPayload());\n    },\n    storeFromData: function(a) {\n        if (!this.isOpen) {\n            return;\n        }\n    ;\n    ;\n        var b = this.stream.storeToCache(a);\n        if (((\"error\" in b))) {\n            this.checkState(PhotoSnowbox.STATE_ERROR);\n            return;\n        }\n    ;\n    ;\n        if (((\"init\" in b))) {\n            this.initDataFetched(b.init);\n            if (this.openExplicitly) {\n                this.replaceUrl = true;\n                goURI(this.stream.getCurrentImageData().info.permalink);\n            }\n        ;\n        ;\n            CSS.conditionShow(this.stagePagers, this.stream.canPage());\n            this.ua.add_event(\"ufi\");\n        }\n         else if (!this.secondBatchArrived) {\n            CSS.conditionShow(this.stagePagers, this.stream.canPage());\n            this.secondBatchArrived = true;\n            this.ua.add_event(\"arrows\");\n        }\n        \n    ;\n    ;\n        if (((\"image\" in b))) {\n            this.checkState(PhotoSnowbox.STATE_IMAGE_DATA);\n        }\n    ;\n    ;\n        if (((\"data\" in b))) {\n            this.checkState(PhotoSnowbox.STATE_HTML);\n        }\n    ;\n    ;\n    },\n    deletePhoto: function(a) {\n        this.closeRefresh();\n    },\n    closeRefresh: function() {\n        this.refreshOnClose = true;\n        this.closeHandler();\n    }\n};\nvar Menu = function() {\n    var i = \"menu:mouseover\";\n    var a = null;\n    function b(k) {\n        return Parent.byClass(k, \"uiMenu\");\n    };\n;\n    function c(k) {\n        return Parent.byClass(k, \"uiMenuItem\");\n    };\n;\n    function d(k) {\n        if (JSBNG__document.activeElement) {\n            var l = c(JSBNG__document.activeElement);\n            return k.indexOf(l);\n        }\n    ;\n    ;\n        return -1;\n    };\n;\n    function e(k) {\n        return DOM.JSBNG__find(k, \"a.itemAnchor\");\n    };\n;\n    function f(k) {\n        return CSS.hasClass(k, \"checked\");\n    };\n;\n    function g(k) {\n        return !CSS.hasClass(k, \"disabled\");\n    };\n;\n    function h(JSBNG__event) {\n        var k = JSBNG__document.activeElement;\n        if (((((!k || !Parent.byClass(k, \"uiMenu\"))) || !DOM.isNode(k, [\"input\",\"textarea\",])))) {\n            var l = c(JSBNG__event.getTarget());\n            ((l && Menu.focusItem(l)));\n        }\n    ;\n    ;\n    };\n;\n    function j(k) {\n        Menu.inform(\"select\", {\n            menu: b(k),\n            item: k\n        });\n    };\n;\n    JSBNG__onloadRegister(function() {\n        var k = {\n        };\n        k.click = function(JSBNG__event) {\n            var n = c(JSBNG__event.getTarget());\n            if (((n && g(n)))) {\n                j(n);\n                var l = e(n);\n                var m = l.href;\n                var o = l.getAttribute(\"rel\");\n                return ((((o && ((o !== \"ignore\")))) || ((m && ((m.charAt(((m.length - 1))) !== \"#\"))))));\n            }\n        ;\n        ;\n        };\n        k.keydown = function(JSBNG__event) {\n            var u = JSBNG__event.getTarget();\n            if (((!a || DOM.isNode(u, [\"input\",\"textarea\",])))) {\n                return;\n            }\n        ;\n        ;\n            var q = JSBNG__Event.getKeyCode(JSBNG__event);\n            switch (q) {\n              case KEYS.UP:\n            \n              case KEYS.DOWN:\n                var m = Menu.getEnabledItems(a);\n                var o = d(m);\n                Menu.focusItem(m[((o + ((((q === KEYS.UP)) ? -1 : 1))))]);\n                return false;\n              case KEYS.SPACE:\n                var t = c(u);\n                if (t) {\n                    j(t);\n                    JSBNG__event.prevent();\n                }\n            ;\n            ;\n                break;\n              default:\n                var l = String.fromCharCode(q).toLowerCase();\n                var p = Menu.getEnabledItems(a);\n                var o = d(p);\n                var n = o;\n                var r = p.length;\n                while (((((~o && (((n = ((++n % r))) !== o)))) || ((!~o && ((++n < r))))))) {\n                    var s = Menu.getItemLabel(p[n]);\n                    if (((s && ((s.charAt(0).toLowerCase() === l))))) {\n                        Menu.focusItem(p[n]);\n                        return false;\n                    }\n                ;\n                ;\n                };\n            ;\n            };\n        ;\n        };\n        JSBNG__Event.listen(JSBNG__document.body, k);\n    });\n    return copy_properties(new Arbiter(), {\n        focusItem: function(k) {\n            if (((k && g(k)))) {\n                this._removeSelected(b(k));\n                CSS.addClass(k, \"selected\");\n                e(k).JSBNG__focus();\n            }\n        ;\n        ;\n        },\n        getEnabledItems: function(k) {\n            return Menu.getItems(k).filter(g);\n        },\n        getCheckedItems: function(k) {\n            return Menu.getItems(k).filter(f);\n        },\n        getItems: function(k) {\n            return DOM.scry(k, \"li.uiMenuItem\");\n        },\n        getItemLabel: function(k) {\n            return ((k.getAttribute(\"data-label\", 2) || \"\"));\n        },\n        isItemChecked: function(k) {\n            return CSS.hasClass(k, \"checked\");\n        },\n        register: function(k, l) {\n            k = b(k);\n            if (!DataStore.get(k, i)) {\n                DataStore.set(k, i, JSBNG__Event.listen(k, \"mouseover\", h));\n            }\n        ;\n        ;\n            if (((l !== false))) {\n                a = k;\n            }\n        ;\n        ;\n        },\n        setItemEnabled: function(l, k) {\n            if (((!k && !DOM.scry(l, \"span.disabledAnchor\")[0]))) {\n                DOM.appendContent(l, $N(\"span\", {\n                    className: ((DOM.JSBNG__find(l, \"a\").className + \" disabledAnchor\"))\n                }, HTML(e(l).innerHTML)));\n            }\n        ;\n        ;\n            CSS.conditionClass(l, \"disabled\", !k);\n        },\n        toggleItem: function(l) {\n            var k = !Menu.isItemChecked(l);\n            CSS.conditionClass(l, \"checked\", k);\n            e(l).setAttribute(\"aria-checked\", k);\n        },\n        unregister: function(l) {\n            l = b(l);\n            var k = DataStore.remove(l, i);\n            ((k && k.remove()));\n            a = null;\n            this._removeSelected(l);\n        },\n        _removeSelected: function(k) {\n            Menu.getItems(k).filter(function(l) {\n                return CSS.hasClass(l, \"selected\");\n            }).each(function(l) {\n                CSS.removeClass(l, \"selected\");\n            });\n        }\n    });\n}();\nfunction Overlay() {\n\n};\n;\n!function() {\n    var a = null;\n    function b(d, e) {\n        var c;\n        d.subscribe(\"show\", function() {\n            c = JSBNG__Event.listen(JSBNG__document.documentElement, \"keydown\", function(JSBNG__event) {\n                if (((((JSBNG__event.keyCode == KEYS.ESC)) && ((((JSBNG__document.activeElement == JSBNG__document.body)) || DOM.contains(e, JSBNG__document.activeElement)))))) {\n                    d.hide();\n                }\n            ;\n            ;\n            });\n        });\n        d.subscribe(\"hide\", function() {\n            c.remove();\n            c = null;\n        });\n    };\n;\n    copy_properties(Overlay, {\n        getInstance: function(c) {\n            var d = Parent.byClass(c, \"uiOverlay\");\n            return ((d ? DataStore.get(d, \"overlay\") : null));\n        }\n    });\n    Class.mixin(Overlay, \"Arbiter\", {\n        _root: null,\n        _transitionSubscription: null,\n        _hideOnSubmit: false,\n        _hideOnSuccess: true,\n        _fadeOnShow: true,\n        _fadeOnHide: true,\n        destroyOnHide: true,\n        init: function(c) {\n            this._transitionSubscription = Arbiter.subscribe(\"page_transition\", this.hide.shield(this), Arbiter.SUBSCRIBE_NEW);\n            this._root = HTML(c).getRootNode();\n            this._arrow = ((DOM.scry(this._root, \".uiOverlayArrow\")[0] || null));\n            this._overlay = ((DOM.scry(this._root, \"div.uiOverlay\")[0] || this._root));\n            CSS.hide(this._root);\n            DOM.appendContent(JSBNG__document.body, this._root);\n            DataStore.set(this._overlay, \"overlay\", this);\n            var d = DataStore.get(this._overlay, \"width\");\n            ((d && this.setWidth(d)));\n            this.setHideOnSubmit(((DataStore.get(this._overlay, \"hideonsubmit\") == \"true\")));\n            this.setHideOnSuccess(((DataStore.get(this._overlay, \"hideonsuccess\") != \"false\")));\n            this.setFadeOnShow(((DataStore.get(this._overlay, \"fadeonshow\") != \"false\")));\n            this.setFadeOnHide(((DataStore.get(this._overlay, \"fadeonhide\") != \"false\")));\n            this.setHideOnBlur(((DataStore.get(this._overlay, \"hideonblur\") == \"true\")));\n            this.setDestroyOnHide(((DataStore.get(this._overlay, \"destroyonhide\") != \"false\")));\n            this.setFixed(((DataStore.get(this._overlay, \"fixed\") == \"true\")));\n            JSBNG__Event.listen(this._overlay, {\n                click: this.click.bind(this),\n                submit: this.submit.bind(this),\n                mouseenter: this._onMouseEnter.bind(this),\n                mouseleave: this._onMouseLeave.bind(this)\n            });\n            Arbiter.subscribe(\"Hovercard/show\", this._onHovercardShow.bind(this));\n            Arbiter.subscribe(\"Hovercard/hide\", this._onHovercardHide.bind(this));\n            b(this, this._root);\n            return this;\n        },\n        setHideOnBlur: function(c) {\n            if (((!c && this._hideOnBlurToken))) {\n                this._removeHideOnBlurListener();\n                this.unsubscribe(this._hideOnBlurToken);\n                this._hideOnBlurToken = null;\n            }\n             else if (((c && !this._hideOnBlurToken))) {\n                var d = this;\n                var e = function() {\n                    (function() {\n                        d._hideOnBlurListener = JSBNG__Event.listen(JSBNG__document.documentElement, \"click\", function(JSBNG__event) {\n                            if (!DOM.contains(d._overlay, JSBNG__event.getTarget())) {\n                                d.setFadeOnHide(false).hide();\n                            }\n                        ;\n                        ;\n                        });\n                    }).defer();\n                };\n                this.subscribe(\"hide\", this._removeHideOnBlurListener.bind(this));\n                this._hideOnBlurToken = this.subscribe(\"show\", e);\n                ((this._shown && e.call(this)));\n            }\n            \n        ;\n        ;\n            return this;\n        },\n        _removeHideOnBlurListener: function() {\n            ((this._hideOnBlurListener && this._hideOnBlurListener.remove()));\n            this._hideOnBlurListener = null;\n        },\n        setDestroyOnHide: function(c) {\n            this.destroyOnHide = c;\n            return this;\n        },\n        setHideOnSubmit: function(c) {\n            this._hideOnSubmit = c;\n            return this;\n        },\n        setHideOnSuccess: function(c) {\n            this._hideOnSuccess = c;\n            return this;\n        },\n        setFadeOnShow: function(c) {\n            this._fadeOnShow = c;\n            return this;\n        },\n        setFadeOnHide: function(c) {\n            this._fadeOnHide = c;\n            return this;\n        },\n        setWidth: function(c) {\n            this.width = parseInt(c, 10);\n            return this;\n        },\n        setFixed: function(c) {\n            this.fixed = c;\n            return this;\n        },\n        show: function() {\n            if (!this._shown) {\n                CSS.show(this._root);\n                CSS.setStyle(this._overlay, \"opacity\", 0);\n                DOM.appendContent(JSBNG__document.body, this._root);\n                this.updatePosition();\n                if (((this._fadeOnShow !== false))) {\n                    animation(this._overlay).from(\"opacity\", 0).to(\"opacity\", 1).duration(100).JSBNG__ondone(CSS.setStyle.curry(this._overlay, \"opacity\", \"\")).go();\n                }\n                 else CSS.setStyle(this._overlay, \"opacity\", \"\");\n            ;\n            ;\n                this._shown = true;\n                Arbiter.inform(\"layer_shown\", {\n                    type: \"Overlay\"\n                });\n                Arbiter.inform(\"Overlay/show\", {\n                    overlay: this\n                });\n                this.inform(\"show\");\n            }\n        ;\n        ;\n            return this;\n        },\n        updatePosition: function() {\n            if (this.width) {\n                CSS.setStyle(this._overlay, \"width\", ((this.width + \"px\")));\n            }\n        ;\n        ;\n        },\n        hide: function() {\n            if (((!this._shown || ((this.inform(\"beforehide\") === false))))) {\n                return;\n            }\n        ;\n        ;\n            this._shown = false;\n            var c = function() {\n                if (this._root) {\n                    DOM.remove(this._root);\n                    CSS.setStyle(this._overlay, \"opacity\", \"\");\n                }\n            ;\n            ;\n                Arbiter.inform(\"layer_hidden\", {\n                    type: \"Overlay\"\n                });\n                Arbiter.inform(\"Overlay/hide\", {\n                    overlay: this\n                });\n                this.inform(\"hide\");\n                ((this.destroyOnHide && this.destroy()));\n            }.bind(this);\n            if (((this._fadeOnHide !== false))) {\n                animation(this._overlay).from(\"opacity\", 1).to(\"opacity\", 0).duration(250).JSBNG__ondone(c).go();\n            }\n             else c();\n        ;\n        ;\n        },\n        destroy: function() {\n            Arbiter.unsubscribe(this._transitionSubscription);\n            DOM.remove(this._root);\n            DataStore.remove(this._root, \"overlay\");\n            this._root = null;\n        },\n        click: function(d) {\n            var e = d.getTarget();\n            var c = ((((Parent.byTag(e, \"input\") || Parent.byTag(e, \"button\"))) || Parent.byTag(e, \"a\")));\n            if (c) {\n                a = c;\n                if (CSS.hasClass(c, \"uiOverlayCancelButton\")) {\n                    if (((this.inform(\"cancel\") !== false))) {\n                        this.hide();\n                    }\n                ;\n                ;\n                    d.prevent();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        submit: function(e) {\n            var f = e.getTarget();\n            if (((this.inform(\"submit\") === false))) {\n                e.kill();\n                return;\n            }\n        ;\n        ;\n            var g = function() {\n                if (((((this.inform(\"success\") !== false)) && this._hideOnSuccess))) {\n                    this.hide();\n                }\n            ;\n            ;\n            }.bind(this);\n            if (((Form.getAttribute(f, \"rel\") === \"async\"))) {\n                var h = ((Form.getAttribute(f, \"method\") || \"GET\")).toUpperCase();\n                var d = Form.serialize(f, a);\n                Form.setDisabled(f, true);\n                var i = ((Parent.byClass(a, \"stat_elem\") || f));\n                var c = ((Form.getAttribute(f, \"ajaxify\") || Form.getAttribute(f, \"action\")));\n                if (this._hideOnSubmit) {\n                    g();\n                    g = bagofholding;\n                }\n            ;\n            ;\n                new AsyncRequest(c).setData(d).setNectarModuleDataSafe(f).setReadOnly(((h == \"GET\"))).setMethod(h).setStatusElement(i).setRelativeTo(f).setHandler(g).setErrorHandler(function(j) {\n                    if (((this.inform(\"error\", {\n                        response: j\n                    }) !== false))) {\n                        AsyncResponse.defaultErrorHandler(j);\n                    }\n                ;\n                ;\n                }.bind(this)).setFinallyHandler(Form.setDisabled.bind(null, f, false)).send();\n                e.kill();\n            }\n             else g();\n        ;\n        ;\n        },\n        _onMouseEnter: function() {\n            this._fireMouseLeaveOnHovercardHide = false;\n            if (!this._layerHovercardNode) {\n                this.inform(\"mouseenter\");\n            }\n        ;\n        ;\n        },\n        _onMouseLeave: function() {\n            if (!this._layerHovercardNode) {\n                this.inform(\"mouseleave\");\n            }\n        ;\n        ;\n            this._fireMouseLeaveOnHovercardHide = !!this._layerHovercardNode;\n        },\n        _onHovercardShow: function(c, d) {\n            var e = d.node;\n            if (DOM.contains(this._root, e)) {\n                this._layerHovercardNode = e;\n            }\n        ;\n        ;\n        },\n        _onHovercardHide: function(c, d) {\n            if (((this._layerHovercardNode === d.node))) {\n                this._layerHovercardNode = null;\n                if (this._fireMouseLeaveOnHovercardHide) {\n                    this._onMouseLeave();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    });\n}();\nfunction ContextualDialogX() {\n    this.parent.construct(this);\n    return this;\n};\n;\nClass.extend(ContextualDialogX, \"Overlay\");\ncopy_properties(ContextualDialogX, {\n    ARROW_INSET: 22,\n    VARROW_HEIGHT: 16,\n    TOP_MARGIN: 8,\n    BOTTOM_MARGIN: 30,\n    HALO_WIDTH: 0,\n    getInstance: function(b) {\n        var a = DataStore.get(b, \"ContextualDialogX\");\n        return ((a || Overlay.getInstance(b)));\n    }\n});\nContextualDialogX.prototype = {\n    _scrollListener: null,\n    init: function(c) {\n        this.parent.init(c);\n        var b = DataStore.get.curry(this._root);\n        this.setAlignH(b(\"alignh\", \"left\"));\n        this.setOffsetX(b(\"offsetx\", 0));\n        this.setOffsetY(b(\"offsety\", 0));\n        this.setPosition(b(\"position\"));\n        var a = b(\"context\");\n        if (a) {\n            this.setContext($(a));\n        }\n         else {\n            a = b(\"contextselector\");\n            if (a) {\n                this.setContext(DOM.JSBNG__find(JSBNG__document, a));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this._content = DOM.scry(this._root, \".uiContextualDialogContent\")[0];\n        var e = null;\n        var d = null;\n        this.subscribe(\"show\", function() {\n            var f = this.updatePosition.shield(this);\n            e = JSBNG__Event.listen(window, \"resize\", f);\n            d = Arbiter.subscribe(\"reflow\", f);\n            this._setupScrollListener(this._scrollParent);\n        }.bind(this));\n        this.subscribe(\"hide\", function() {\n            e.remove();\n            Arbiter.unsubscribe(d);\n            this._teardownScrollListener();\n        }.bind(this));\n        Arbiter.subscribe(\"Hovercard/hide\", function(f, g) {\n            if (Hovercard.contains(this.getContext())) {\n                this.hide();\n            }\n        ;\n        ;\n        }.bind(this));\n    },\n    setAlignH: function(a) {\n        this.alignH = a;\n        return this;\n    },\n    getContent: function() {\n        return this._content;\n    },\n    getContext: function() {\n        return this.context;\n    },\n    setContext: function(a) {\n        a = $(a);\n        if (((this.context && ((this.context != a))))) {\n            DataStore.remove(this.context, \"ContextualDialogX\");\n        }\n    ;\n    ;\n        this.context = a;\n        var b = Parent.byClass(a, \"fbPhotoSnowbox\");\n        if (b) {\n            b.appendChild(this._root);\n        }\n    ;\n    ;\n        if (((this._scrollListener && ((this._scrollParent !== b))))) {\n            this._teardownScrollListener();\n            this._setupScrollListener(b);\n        }\n    ;\n    ;\n        this._scrollParent = b;\n        var c = OverlayZIndexHelper.getZIndex(a, b);\n        CSS.setStyle(this._root, \"z-index\", ((((c > 200)) ? ((c + 1)) : \"\")));\n        DataStore.set(this.context, \"ContextualDialogX\", this);\n        return this;\n    },\n    listen: function(b, a) {\n        return JSBNG__Event.listen(this._root, b, a);\n    },\n    setFixed: function(a) {\n        CSS.conditionClass(this._root, \"uiContextualDialogFixed\", a);\n        return this.parent.setFixed(a);\n    },\n    setOffsetX: function(a) {\n        this.offsetX = ((parseInt(a, 10) || 0));\n        return this;\n    },\n    setOffsetY: function(a) {\n        this.offsetY = ((parseInt(a, 10) || 0));\n        return this;\n    },\n    setPosition: function(a) {\n        this.position = a;\n        return this;\n    },\n    updatePosition: function() {\n        if (!this.context) {\n            return this;\n        }\n    ;\n    ;\n        this.parent.updatePosition();\n        var c = ((this.fixed ? \"viewport\" : \"JSBNG__document\"));\n        var g = Vector2.getElementPosition(this.context, c);\n        var h = this._scrollParent;\n        if (h) {\n            g = g.sub(Vector2.getElementPosition(h, \"JSBNG__document\")).add(h.scrollLeft, h.scrollTop);\n        }\n    ;\n    ;\n        var a = Vector2.getElementDimensions(this.context);\n        var k = ((((this.position == \"above\")) || ((this.position == \"below\"))));\n        var d = intl_locale_is_rtl();\n        if (((d != ((this.position == \"right\"))))) {\n            g = g.add(a.x, 0);\n        }\n    ;\n    ;\n        if (((this.position == \"below\"))) {\n            g = g.add(0, a.y);\n        }\n    ;\n    ;\n        var f = new Vector2(0, 0);\n        var b = ((this.width + ((2 * ContextualDialogX.HALO_WIDTH))));\n        if (((k && ((this.alignH == \"center\"))))) {\n            f = f.add(((((a.x - b)) / 2)), 0);\n        }\n         else {\n            f = f.sub(((k ? ContextualDialogX.HALO_WIDTH : 0)), ((k ? 0 : ContextualDialogX.HALO_WIDTH)));\n            var j = ((k ? a.x : a.y));\n            var e = ((2 * ((ContextualDialogX.ARROW_INSET + ContextualDialogX.HALO_WIDTH))));\n            if (((j < e))) {\n                var i = ((((j / 2)) - ContextualDialogX.ARROW_INSET));\n                f = f.add(((k ? i : 0)), ((k ? 0 : i)));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((k && ((this.alignH == \"right\"))))) {\n            f = f.mul(-1, 1).add(((a.x - b)), 0);\n        }\n    ;\n    ;\n        f = f.add(this.offsetX, this.offsetY);\n        if (d) {\n            f = f.mul(-1, 1);\n        }\n    ;\n    ;\n        g = g.add(f);\n        if (this.fixed) {\n            g = new Vector2(g.x, g.y, \"JSBNG__document\");\n        }\n    ;\n    ;\n        g.setElementPosition(this._root);\n        this._adjustVerticalPosition();\n        return this;\n    },\n    JSBNG__scrollTo: function() {\n        if (this.context) {\n            Bootloader.loadComponents(\"dom-scroll\", function() {\n                DOMScroll.JSBNG__scrollTo(this.context, true, true);\n            }.bind(this));\n        }\n    ;\n    ;\n    },\n    destroy: function() {\n        ((this.context && DataStore.remove(this.context, \"ContextualDialogX\")));\n        this.parent.destroy();\n    },\n    _adjustVerticalPosition: function() {\n        if (((((this.position != \"left\")) && ((this.position != \"right\"))))) {\n            return;\n        }\n    ;\n    ;\n        var c = Vector2.getElementPosition(this._root, \"viewport\").y;\n        var a = Vector2.getElementDimensions(this._overlay).y;\n        var e = Vector2.getViewportDimensions().y;\n        var d = ContextualDialogX.TOP_MARGIN;\n        var b = Math.min(Math.max(0, ((((((c + a)) + ContextualDialogX.BOTTOM_MARGIN)) - e))), Math.max(-d, ((c - d))), ((((a - ((2 * ContextualDialogX.ARROW_INSET)))) - ((2 * ContextualDialogX.HALO_WIDTH)))));\n        CSS.setStyle(this._overlay, \"JSBNG__top\", ((((-1 * b)) + \"px\")));\n        CSS.setStyle(this._arrow, \"marginTop\", ((b + \"px\")));\n    },\n    _setupScrollListener: function(a) {\n        this._scrollListener = JSBNG__Event.listen(((a || window)), \"JSBNG__scroll\", this._adjustVerticalPosition.shield(this));\n    },\n    _teardownScrollListener: function() {\n        this._scrollListener.remove();\n        this._scrollListener = null;\n    }\n};\nfunction Toggler() {\n    this.init();\n};\n;\n(function() {\n    var e = [];\n    var c;\n    function d() {\n        d = bagofholding;\n        JSBNG__Event.listen(JSBNG__document.documentElement, \"click\", function(JSBNG__event) {\n            var f = JSBNG__event.getTarget();\n            e.each(function(g) {\n                ((((((((((((g.active && !g.sticky)) && !DOM.contains(g.getActive(), f))) && !g.inTargetFlyout(f))) && !g.inTargetContextualDialog(f))) && g.inActiveDialog())) && g.hide()));\n            });\n        }, JSBNG__Event.Priority.URGENT);\n    };\n;\n    function a(g, f) {\n        if (((g instanceof Toggler))) {\n            return g;\n        }\n    ;\n    ;\n        return Toggler.getInstance(f);\n    };\n;\n    function b(g) {\n        var f = DOM.scry(g, \"a[rel=\\\"toggle\\\"]\");\n        if (((((f.length > 0)) && f[0].getAttribute(\"data-target\")))) {\n            return ge(f[0].getAttribute(\"data-target\"));\n        }\n    ;\n    ;\n    };\n;\n    Class.mixin(Toggler, \"Arbiter\", {\n        init: function() {\n            this.active = null;\n            this.togglers = {\n            };\n            this.setSticky(false);\n            e.push(this);\n            this.subscribe([\"show\",\"hide\",], Toggler.inform.bind(Toggler));\n            d();\n        },\n        show: function(h) {\n            var f = a(this, h);\n            var i = f.active;\n            if (((h !== i))) {\n                ((i && f.hide()));\n                f.active = h;\n                CSS.addClass(h, \"openToggler\");\n                var g = DOM.scry(h, \"a[rel=\\\"toggle\\\"]\");\n                if (((((g.length > 0)) && g[0].getAttribute(\"data-target\")))) {\n                    CSS.removeClass(ge(g[0].getAttribute(\"data-target\")), \"toggleTargetClosed\");\n                }\n            ;\n            ;\n                DOM.appendContent(h, f.getToggler(\"next\"));\n                DOM.prependContent(h, f.getToggler(\"prev\"));\n                f.inform(\"show\", f);\n            }\n        ;\n        ;\n        },\n        hide: function(i) {\n            var g = a(this, i);\n            var f = g.active;\n            if (((f && ((!i || ((i === f))))))) {\n                CSS.removeClass(f, \"openToggler\");\n                var h = DOM.scry(f, \"a[rel=\\\"toggle\\\"]\");\n                if (((((h.length > 0)) && h[0].getAttribute(\"data-target\")))) {\n                    CSS.addClass(ge(h[0].getAttribute(\"data-target\")), \"toggleTargetClosed\");\n                }\n            ;\n            ;\n                values(g.togglers).each(DOM.remove);\n                g.inform(\"hide\", g);\n                g.active = null;\n            }\n        ;\n        ;\n        },\n        toggle: function(g) {\n            var f = a(this, g);\n            if (((f.active === g))) {\n                f.hide();\n            }\n             else f.show(g);\n        ;\n        ;\n        },\n        getActive: function() {\n            return a(this).active;\n        },\n        inTargetFlyout: function(g) {\n            var f = b(this.getActive());\n            return ((f && DOM.contains(f, g)));\n        },\n        inTargetContextualDialog: function(i) {\n            var h = b(this.getActive());\n            var g = ContextualDialogX.getInstance(i);\n            var f = ((g && g.getContext()));\n            return ((((h && f)) && DOM.contains(h, f)));\n        },\n        inActiveDialog: function() {\n            var f = Dialog.getCurrent();\n            return ((!f || DOM.contains(f.getRoot(), this.getActive())));\n        },\n        getToggler: function(g) {\n            var f = a(this);\n            if (!f.togglers[g]) {\n                f.togglers[g] = $N(\"button\", {\n                    className: \"hideToggler\",\n                    JSBNG__onfocus: function() {\n                        var h = DOM.scry(f.active, \"a[rel=\\\"toggle\\\"]\")[0];\n                        ((h && h.JSBNG__focus()));\n                        f.hide();\n                    }\n                });\n            }\n        ;\n        ;\n            return this.togglers[g];\n        },\n        setSticky: function(g) {\n            var f = a(this);\n            g = ((g !== false));\n            if (((g !== f.sticky))) {\n                f.sticky = g;\n                if (g) {\n                    ((f._pt && Arbiter.unsubscribe(f._pt)));\n                }\n                 else f._pt = Arbiter.subscribe(\"page_transition\", f.hide.bind(f, null));\n            ;\n            ;\n            }\n        ;\n        ;\n            return f;\n        }\n    });\n    copy_properties(Toggler, Toggler.prototype);\n    copy_properties(Toggler, {\n        bootstrap: function(f) {\n            var g = f.parentNode;\n            Toggler.getInstance(g).toggle(g);\n        },\n        createInstance: function(g) {\n            var f = new Toggler().setSticky(true);\n            DataStore.set(g, \"toggler\", f);\n            return f;\n        },\n        getInstance: function(g) {\n            while (g) {\n                var f = DataStore.get(g, \"toggler\");\n                if (f) {\n                    return f;\n                }\n            ;\n            ;\n                if (CSS.hasClass(g, \"uiToggleContext\")) {\n                    return Toggler.createInstance(g);\n                }\n            ;\n            ;\n                g = g.parentNode;\n            };\n        ;\n            return (c = ((c || new Toggler())));\n        },\n        listen: function(h, g, f) {\n            return Toggler.subscribe($A(h), function(j, i) {\n                if (((i.getActive() === g))) {\n                    return f(j, i);\n                }\n            ;\n            ;\n            });\n        },\n        subscribe: (function(f) {\n            return function(h, g) {\n                h = $A(h);\n                if (h.contains(\"show\")) {\n                    e.each(function(i) {\n                        if (i.getActive()) {\n                            g.curry(\"show\", i).defer();\n                        }\n                    ;\n                    ;\n                    });\n                }\n            ;\n            ;\n                return f(h, g);\n            };\n        })(Toggler.subscribe.bind(Toggler))\n    });\n})();\nvar TooltipLink = {\n    setTooltipText: function(a, b) {\n        TooltipLink.setTooltipEnabled(a, ((((b !== null)) && ((b !== \"\")))));\n        a = Parent.byClass(a, \"uiTooltip\");\n        if (a) {\n            DOM.setContent(DOM.JSBNG__find(a, \"span.uiTooltipText\"), b);\n        }\n    ;\n    ;\n    },\n    setTooltipEnabled: function(b, a) {\n        b = Parent.byClass(b, \"uiTooltip\");\n        ((b && CSS.conditionClass(b, \"uiTooltipDisabled\", !a)));\n    }\n};\nvar Selector = function() {\n    var a;\n    var i = false;\n    function b(k) {\n        return Parent.byClass(k, \"uiSelector\");\n    };\n;\n    function c(k) {\n        return Parent.byClass(k, \"uiSelectorButton\");\n    };\n;\n    function e(k) {\n        return DOM.scry(k, \"select\")[0];\n    };\n;\n    function d(k) {\n        return DOM.JSBNG__find(k, \"div.uiSelectorMenuWrapper\");\n    };\n;\n    function f() {\n        f = bagofholding;\n        Menu.subscribe(\"select\", function(k, m) {\n            if (((((!a || !m)) || ((m.menu !== Selector.getSelectorMenu(a)))))) {\n                return;\n            }\n        ;\n        ;\n            var n = g(a);\n            var p = h(m.item);\n            if (p) {\n                var l = a;\n                var o = Selector.isOptionSelected(m.item);\n                var q = Selector.inform(\"select\", {\n                    selector: l,\n                    option: m.item\n                });\n                if (((q === false))) {\n                    return;\n                }\n            ;\n            ;\n                if (((n || !o))) {\n                    Selector.setSelected(l, Selector.getOptionValue(m.item), !o);\n                    Selector.inform(\"toggle\", {\n                        selector: l,\n                        option: m.item\n                    });\n                    Selector.inform(\"change\", {\n                        selector: l\n                    });\n                    Arbiter.inform(\"Form/change\", {\n                        node: l\n                    });\n                    if (j(l)) {\n                        DataStore.set(l, \"dirty\", true);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((!n || !p))) {\n                ((a && Selector.toggle(a)));\n            }\n        ;\n        ;\n        });\n    };\n;\n    function g(k) {\n        return !!k.getAttribute(\"data-multiple\");\n    };\n;\n    function h(k) {\n        return CSS.hasClass(k, \"uiSelectorOption\");\n    };\n;\n    function j(k) {\n        return !!k.getAttribute(\"data-autosubmit\");\n    };\n;\n    JSBNG__onloadRegister(function() {\n        var k = {\n        };\n        k.keydown = function(JSBNG__event) {\n            var m = JSBNG__event.getTarget();\n            if (DOM.isNode(m, [\"input\",\"textarea\",])) {\n                return;\n            }\n        ;\n        ;\n            switch (JSBNG__Event.getKeyCode(JSBNG__event)) {\n              case KEYS.DOWN:\n            \n              case KEYS.SPACE:\n            \n              case KEYS.UP:\n                i = true;\n                if (c(m)) {\n                    var l = b(m);\n                    Selector.toggle(l);\n                    return false;\n                }\n            ;\n            ;\n                break;\n              case KEYS.ESC:\n                i = true;\n                if (a) {\n                    Selector.toggle(a);\n                    return false;\n                }\n            ;\n            ;\n                break;\n              case KEYS.RETURN:\n                i = true;\n                break;\n            };\n        ;\n        };\n        k.keyup = function() {\n            !function() {\n                i = false;\n            }.defer();\n        };\n        JSBNG__Event.listen(JSBNG__document.body, k);\n        Toggler.subscribe([\"show\",\"hide\",], function(s, r) {\n            var o = b(r.getActive());\n            if (o) {\n                f();\n                var l = Selector.getSelectorButton(o);\n                var m = Selector.getSelectorMenu(o);\n                var p = ((s === \"show\"));\n                if (p) {\n                    a = o;\n                    if (CSS.hasClass(l, \"uiButtonDisabled\")) {\n                        Selector.setEnabled(o, false);\n                        return false;\n                    }\n                ;\n                ;\n                    m = ((m || Selector.loadMenu(o)));\n                    if (m) {\n                        Menu.register(m);\n                        if (i) {\n                            var n = Menu.getCheckedItems(m);\n                            if (!n.length) {\n                                n = Menu.getEnabledItems(m);\n                            }\n                        ;\n                        ;\n                            Menu.focusItem(n[0]);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n                 else {\n                    a = null;\n                    ((m && Menu.unregister(m)));\n                    ((i && l.JSBNG__focus()));\n                    if (((j(o) && DataStore.get(o, \"dirty\")))) {\n                        var q = DOM.scry(o, \"input.submitButton\")[0];\n                        ((q && q.click()));\n                        DataStore.remove(o, \"dirty\");\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n                CSS.conditionClass(Selector.getSelectorButton(o), \"selected\", p);\n                Selector.inform(((p ? \"open\" : \"close\")), {\n                    selector: o\n                });\n            }\n        ;\n        ;\n        });\n    });\n    return copy_properties(new Arbiter(), {\n        attachMenu: function(o, k, m) {\n            o = b(o);\n            if (o) {\n                ((a && Menu.unregister(Selector.getSelectorMenu(a))));\n                DOM.setContent(d(o), k);\n                ((a && Menu.register(Selector.getSelectorMenu(o))));\n                if (m) {\n                    var l = o.getAttribute(\"data-name\");\n                    ((l && m.setAttribute(\"JSBNG__name\", l)));\n                    if (!g(o)) {\n                        m.setAttribute(\"multiple\", false);\n                    }\n                ;\n                ;\n                    var n = e(o);\n                    if (n) {\n                        DOM.replace(n, m);\n                    }\n                     else DOM.insertAfter(o.firstChild, m);\n                ;\n                ;\n                }\n            ;\n            ;\n                return true;\n            }\n        ;\n        ;\n        },\n        getOption: function(m, n) {\n            var l = Selector.getOptions(m), k = l.length;\n            while (k--) {\n                if (((n === Selector.getOptionValue(l[k])))) {\n                    return l[k];\n                }\n            ;\n            ;\n            };\n        ;\n            return null;\n        },\n        getOptions: function(l) {\n            var k = Menu.getItems(Selector.getSelectorMenu(l));\n            return k.filter(h);\n        },\n        getEnabledOptions: function(l) {\n            var k = Menu.getEnabledItems(Selector.getSelectorMenu(l));\n            return k.filter(h);\n        },\n        getSelectedOptions: function(k) {\n            return Menu.getCheckedItems(Selector.getSelectorMenu(k));\n        },\n        getOptionText: function(k) {\n            return Menu.getItemLabel(k);\n        },\n        getOptionValue: function(l) {\n            var n = b(l);\n            var m = e(n);\n            var k = Selector.getOptions(n).indexOf(l);\n            return ((((k >= 0)) ? m.options[((k + 1))].value : \"\"));\n        },\n        getSelectorButton: function(k) {\n            return DOM.JSBNG__find(k, \"a.uiSelectorButton\");\n        },\n        getSelectorMenu: function(k) {\n            return DOM.scry(k, \"div.uiSelectorMenu\")[0];\n        },\n        getValue: function(o) {\n            var m = e(o);\n            if (!m) {\n                return null;\n            }\n        ;\n        ;\n            if (!g(o)) {\n                return m.value;\n            }\n        ;\n        ;\n            var p = [];\n            var l = m.options;\n            for (var k = 1, n = l.length; ((k < n)); k++) {\n                if (l[k].selected) {\n                    p.push(l[k].value);\n                }\n            ;\n            ;\n            };\n        ;\n            return p;\n        },\n        isOptionSelected: function(k) {\n            return Menu.isItemChecked(k);\n        },\n        listen: function(l, m, k) {\n            return this.subscribe(m, function(o, n) {\n                if (((n.selector === l))) {\n                    return k(n, o);\n                }\n            ;\n            ;\n            });\n        },\n        loadMenu: function(n) {\n            var m = Selector.getSelectorMenu(n);\n            if (!m) {\n                var l = Selector.getSelectorButton(n);\n                var k = l.getAttribute(\"ajaxify\");\n                if (k) {\n                    var o = HTML(((((((((((((\"\\u003Cdiv class=\\\"uiSelectorMenuWrapper uiToggleFlyout\\\"\\u003E\" + \"\\u003Cdiv class=\\\"uiMenu uiSelectorMenu loading\\\"\\u003E\")) + \"\\u003Cul class=\\\"uiMenuInner\\\"\\u003E\")) + \"\\u003Cli\\u003E\\u003Cspan\\u003E\\u003C/span\\u003E\\u003C/li\\u003E\")) + \"\\u003C/ul\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")));\n                    DOM.appendContent(l.parentNode, o);\n                    Bootloader.loadComponents(\"async\", function() {\n                        AsyncRequest.bootstrap(k, l);\n                    });\n                    m = Selector.getSelectorMenu(n);\n                    l.removeAttribute(\"JSBNG__onmouseover\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            return m;\n        },\n        setButtonLabel: function(n, l) {\n            var k = Selector.getSelectorButton(n);\n            var m = parseInt(k.getAttribute(\"data-length\"), 10);\n            l = ((((l || k.getAttribute(\"data-label\"))) || \"\"));\n            Button.setLabel(k, l);\n            if (((typeof l === \"string\"))) {\n                CSS.conditionClass(k, \"uiSelectorBigButtonLabel\", ((l.length > m)));\n                if (((m && ((l.length > m))))) {\n                    k.setAttribute(\"title\", l);\n                }\n                 else k.removeAttribute(\"title\");\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        setButtonTooltip: function(m, l) {\n            var k = Selector.getSelectorButton(m);\n            TooltipLink.setTooltipText(k, ((((l || k.getAttribute(\"data-tooltip\"))) || \"\")));\n        },\n        setEnabled: function(l, k) {\n            if (((((!k && a)) && ((b(l) === a))))) {\n                Selector.toggle(l);\n            }\n        ;\n        ;\n            Button.setEnabled(Selector.getSelectorButton(l), k);\n        },\n        setOptionEnabled: function(l, k) {\n            Menu.setItemEnabled(l, k);\n        },\n        setSelected: function(o, p, m) {\n            m = ((m !== false));\n            var l = Selector.getOption(o, p);\n            if (!l) {\n                return;\n            }\n        ;\n        ;\n            var k = Selector.isOptionSelected(l);\n            if (((m !== k))) {\n                if (((!g(o) && !k))) {\n                    var n = Selector.getSelectedOptions(o)[0];\n                    ((n && Menu.toggleItem(n)));\n                }\n            ;\n            ;\n                Menu.toggleItem(l);\n                Selector.updateSelector(o);\n            }\n        ;\n        ;\n        },\n        toggle: function(k) {\n            Toggler.toggle(DOM.scry(b(k), \"div.wrap\")[0]);\n        },\n        updateSelector: function(u) {\n            var r = Selector.getOptions(u);\n            var t = Selector.getSelectedOptions(u);\n            var o = e(u).options;\n            var q = [];\n            var w = [];\n            for (var n = 0, p = r.length; ((n < p)); n++) {\n                var s = t.contains(r[n]);\n                o[((n + 1))].selected = s;\n                if (s) {\n                    var v = Selector.getOptionText(r[n]);\n                    q.push(v);\n                    w.push(((r[n].getAttribute(\"data-tooltip\") || v)));\n                }\n            ;\n            ;\n            };\n        ;\n            o[0].selected = !t.length;\n            var l = CSS.hasClass(u, \"uiSelectorDynamicLabel\");\n            var m = CSS.hasClass(u, \"uiSelectorDynamicTooltip\");\n            if (((l || m))) {\n                if (g(u)) {\n                    var k = Selector.getSelectorButton(u);\n                    q = q.join(k.getAttribute(\"data-delimiter\"));\n                    w = w.join(k.getAttribute(\"data-delimiter\"));\n                }\n            ;\n            ;\n                ((l && Selector.setButtonLabel(u, q)));\n                ((m && Selector.setButtonTooltip(u, w)));\n            }\n        ;\n        ;\n        }\n    });\n}();\nvar DynamicIconSelector = function() {\n    JSBNG__onloadRegister(function() {\n        Selector.subscribe(\"change\", function(a, b) {\n            var c = b.selector;\n            if (CSS.hasClass(c, \"dynamicIconSelector\")) {\n                DynamicIconSelector.swapIcon(c);\n            }\n        ;\n        ;\n        });\n    });\n    return {\n        swapIcon: function(e) {\n            var d = Selector.getSelectedOptions(e)[0];\n            var c = ((d && DOM.scry(d, \".itemIcon\")[0]));\n            var a = Selector.getSelectorButton(e);\n            if (c) {\n                Button.setIcon(a, c.cloneNode(true));\n            }\n             else {\n                var b = DOM.scry(a, \".img\")[0];\n                ((b && DOM.remove(b)));\n            }\n        ;\n        ;\n            CSS.conditionClass(a, \"uiSelectorChevronOnly\", !c);\n        }\n    };\n}();\nvar PrivacyBaseValue = {\n    FRIENDS_MINUS_ACQUAINTANCES: 127,\n    FACEBOOK_EMPLOYEES: 112,\n    CUSTOM: 111,\n    OPEN: 100,\n    EVERYONE: 80,\n    NETWORKS_FRIENDS_OF_FRIENDS: 60,\n    NETWORKS_FRIENDS: 55,\n    FRIENDS_OF_FRIENDS: 50,\n    ALL_FRIENDS: 40,\n    SELF: 10,\n    NOBODY: 0\n};\nvar PrivacyFriendsValue = {\n    EVERYONE: 80,\n    NETWORKS_FRIENDS: 55,\n    FRIENDS_OF_FRIENDS: 50,\n    ALL_FRIENDS: 40,\n    SOME_FRIENDS: 30,\n    SELF: 10,\n    NO_FRIENDS: 0\n};\nvar PrivacySpecialPreset = {\n    ONLY_CORP_NETWORK: 200,\n    COLLEGE_NETWORK_FRIENDS_OF_FRIENDS: 201,\n    COLLEGE_NETWORK_FRIENDS: 202\n};\nvar PrivacyNetworkTypes = {\n    TYPE_COLLEGE: 1,\n    TYPE_HS: 2,\n    TYPE_CORP: 3,\n    TYPE_GEO: 4,\n    TYPE_MANAGED: 14,\n    TYPE_TEST: 50\n};\nvar PrivacyNetworksAll = 1;\ncopy_properties(PrivacyBaseValue, PrivacySpecialPreset);\nfunction PrivacyModel() {\n    this.value = PrivacyBaseValue.ALL_FRIENDS;\n    this.friends = PrivacyFriendsValue.NO_FRIENDS;\n    this.networks = [];\n    this.objects = [];\n    this.lists = [];\n    this.lists_x = [];\n    this.list_anon = 0;\n    this.ids_anon = [];\n    this.list_x_anon = 0;\n    this.ids_x_anon = [];\n    this.tdata = {\n    };\n    return this;\n};\n;\ncopy_properties(PrivacyModel.prototype, {\n    init: function(k, a, h, i, f, g, d, b, e, c, j) {\n        this.value = k;\n        this.friends = a;\n        this.networks = h.clone();\n        this.objects = i.clone();\n        this.lists = f.clone();\n        this.lists_x = g.clone();\n        this.list_anon = d;\n        this.ids_anon = b.clone();\n        this.list_x_anon = e;\n        this.ids_x_anon = c.clone();\n        j = ((j || {\n        }));\n        copy_properties(this.tdata, j);\n    },\n    clone: function() {\n        var a = new PrivacyModel();\n        a.init(this.value, this.friends, this.networks, this.objects, this.lists, this.lists_x, this.list_anon, this.ids_anon, this.list_x_anon, this.ids_x_anon, this.tdata);\n        return a;\n    },\n    getData: function() {\n        var b = [\"value\",\"friends\",\"networks\",\"objects\",\"lists\",\"lists_x\",\"list_anon\",\"ids_anon\",\"list_x_anon\",\"ids_x_anon\",];\n        var d = {\n        };\n        for (var c = 0; ((c < b.length)); ++c) {\n            var a = b[c];\n            d[a] = this[a];\n        };\n    ;\n        return d;\n    }\n});\nvar AudienceSelector = function() {\n    JSBNG__onloadRegister(function() {\n        Selector.subscribe(\"select\", function(a, b) {\n            if (!CSS.hasClass(b.selector, \"audienceSelector\")) {\n                return;\n            }\n        ;\n        ;\n            var e = Selector.getOptionValue(b.option);\n            if (((e == PrivacyBaseValue.CUSTOM))) {\n                Selector.toggle(b.selector);\n                return false;\n            }\n        ;\n        ;\n            if (CSS.hasClass(b.selector, \"dataTooltip\")) {\n                var c = DOM.JSBNG__find(b.option, \".itemAnchor\").getAttribute(\"data-tooltip\");\n                Selector.setButtonTooltip(b.selector, ((c || null)));\n            }\n        ;\n        ;\n            if (!CSS.hasClass(b.option, \"specialOption\")) {\n                return;\n            }\n        ;\n        ;\n            var d = DOM.JSBNG__find(b.option, \"a\").getAttribute(\"data-type\");\n            if (CSS.hasClass(b.option, \"moreOption\")) {\n                CSS.addClass(b.selector, d);\n                CSS.addClass(b.selector, \"showSecondaryOptions\");\n                return false;\n            }\n             else if (CSS.hasClass(b.option, \"returnOption\")) {\n                CSS.removeClass(b.selector, \"showSecondaryOptions\");\n                CSS.removeClass(b.selector, \"friendList\");\n                return false;\n            }\n            \n        ;\n        ;\n        });\n        Arbiter.subscribe(\"CustomPrivacyOption/update\", function(a, b) {\n            if (!CSS.hasClass(b.selector, \"audienceSelector\")) {\n                return;\n            }\n        ;\n        ;\n            Selector.setSelected(b.selector, Selector.getOptionValue(b.option));\n            DynamicIconSelector.swapIcon(b.selector);\n            Selector.setButtonTooltip(b.selector, b.tooltip);\n            Arbiter.inform(\"AudienceSelector/update\", b.selector);\n        });\n    });\n}();\nadd_properties(\"TypeaheadBehaviors\", {\n    buildBestAvailableNames: function(a) {\n        var b = a.getView();\n        b.subscribe(\"beforeRender\", function(c, e) {\n            for (var d = 0; ((d < e.results.length)); ++d) {\n                if (((e.results[d].localized_text == null))) {\n                    continue;\n                }\n            ;\n            ;\n                if (TypeaheadUtil.isQueryMatch(e.value, e.results[d].localized_text)) {\n                    e.results[d].text = e.results[d].localized_text;\n                }\n                 else e.results[d].text = e.results[d].additional_text;\n            ;\n            ;\n            };\n        ;\n        });\n    }\n});\nvar UFIOptimistic = {\n    COMMENT_SEND_EVENT: \"ufi/comment\",\n    _commentSeqNo: 0,\n    init: function(a) {\n        this._commentTemplate = a;\n        if (!this._loaded) {\n            JSBNG__Event.listen(JSBNG__document.documentElement, \"click\", this._clickHandler.bind(this), JSBNG__Event.Priority.URGENT);\n            this._loaded = true;\n        }\n    ;\n    ;\n    },\n    _clickHandler: function(JSBNG__event) {\n        var i = JSBNG__event.getTarget();\n        var l = ((((((i.JSBNG__name == \"comment\")) && i.parentNode)) && Parent.byClass(i, \"optimistic_submit\")));\n        if (!l) {\n            return true;\n        }\n    ;\n    ;\n        var e = i.form;\n        var k = DOM.JSBNG__find(e, \"textarea\");\n        if (Input.isEmpty(k)) {\n            return true;\n        }\n    ;\n    ;\n        fc_uncollapse(e);\n        var a = this._commentTemplate.render();\n        var j = XHPTemplate.getNode(a, \"text\");\n        DOM.setContent(j, HTML(htmlize(trim(k.value))));\n        var c = DOM.scry(e, \"ul.commentList\")[0];\n        if (!c) {\n            return true;\n        }\n    ;\n    ;\n        CSS.show(c.parentNode);\n        c.appendChild(a);\n        var b = c.lastChild;\n        var g = rand32();\n        b.id = ((((((\"optimistic_comment_\" + g)) + \"_\")) + this._commentSeqNo++));\n        var d = Form.serialize(e);\n        d.comment_replace = b.id;\n        d.comment = 1;\n        function h() {\n            new AsyncRequest(Form.getAttribute(e, \"action\")).setData(d).setRelativeTo(e).setErrorHandler(function(m) {\n                CSS.addClass(b, \"uiUfiCommentFailed\");\n                AsyncResponse.defaultErrorHandler(m);\n            }).send();\n        };\n    ;\n        JSBNG__Event.listen(XHPTemplate.getNode(a, \"retry_link\"), \"click\", h);\n        h();\n        k.value = k.style.height = \"\";\n        k.JSBNG__focus();\n        var f = ((window.MentionsInput && MentionsInput.getInstance(k)));\n        ((f && f.reset()));\n        Arbiter.inform(UFIOptimistic.COMMENT_SEND_EVENT, {\n            form: e\n        });\n        return false;\n    }\n};\nfunction ufi_add_ft_hidden_node(c) {\n    if (c.link_data) {\n        return;\n    }\n;\n;\n    var a = collect_data_attrib(c, \"ft\");\n    if (count(a)) {\n        var b = $N(\"input\", {\n            type: \"hidden\",\n            JSBNG__name: \"link_data\",\n            value: JSON.stringify(a)\n        });\n        c.appendChild(b);\n    }\n;\n;\n};\n;\nfunction ufi_add_all_link_data() {\n    Bootloader.loadComponents(\"dom-collect\", function() {\n        DOM.scry(JSBNG__document.body, \"form.commentable_item\").forEach(ufi_add_ft_hidden_node);\n    });\n};\n;\nJSBNG__onloadRegister(function() {\n    Selector.subscribe(\"close\", function(a, b) {\n        if (CSS.hasClass(b.selector, \"commentHideSelector\")) {\n            var c = Selector.getValue(b.selector);\n            ((c && Selector.setSelected.curry(b.selector, c, false).defer()));\n        }\n    ;\n    ;\n    });\n});\n(function() {\n    var b = 1, a = 2;\n    var g = {\n    };\n    var f = function() {\n        var j = DOM.scry(this.root, \"span.linkAttachment\")[0];\n        if (((!j && this.isMetaComposer))) {\n            j = DOM.scry(this.root, \"span.attachmentAcceptsLink\")[0];\n        }\n    ;\n    ;\n        if (!j) {\n            return;\n        }\n    ;\n    ;\n        var i = Parent.byTag(j, \"form\");\n        this.scraper = new URLScraper(this.input);\n        this.scraper.subscribe(\"match\", function(k, l) {\n            if (this.isMetaComposer) {\n                var m = this.form.xhpc_targetid;\n                var n = new URI(\"/ajax/metacomposer/attachment/link/scraper.php\");\n                n.addQueryData({\n                    scrape_url: encodeURIComponent(l.url),\n                    targetid: m.value\n                });\n                i.action = n.toString();\n            }\n             else {\n                CSS.show(j);\n                i.action = ((\"/ajax/composer/attachment/link/scraper.php?scrape_url=\" + encodeURIComponent(l.url)));\n            }\n        ;\n        ;\n            i.xhpc.value = j.id;\n            i.xhpc.disabled = false;\n            i.xhpc.click();\n        }.bind(this));\n        ((this.isMetaComposer && this.scraper.check()));\n    };\n    var e = function() {\n        var j = this.form.xhpc_targetid;\n        var k = j.value;\n        var i = Arbiter.subscribe(\"ComposerAudienceSelector/group\", function(m, n) {\n            j.value = n.group;\n        });\n        var l = Arbiter.subscribe(\"ComposerAudienceSelector/nongroup\", function() {\n            j.value = k;\n        });\n        JSBNG__onunloadRegister(Arbiter.unsubscribe.curry(i));\n        JSBNG__onunloadRegister(Arbiter.unsubscribe.curry(l));\n    };\n    var h = function(JSBNG__event, i) {\n        i = ((i || {\n        }));\n        i.evt = JSBNG__event;\n        i.flowID = this.flowID;\n        i.context = this.form.xhpc_context.value;\n        i.target = this.form.action.split(\"/\").pop();\n        i = {\n            data: JSON.stringify(i)\n        };\n        new AsyncSignal(\"/ajax/composer/logging.php\", i).send();\n    };\n    var d = function(i) {\n        this.flowID = ((new JSBNG__Date().getTime().toString() + ((rand32() + 1))));\n        this._logged_short = this._logged_long = false;\n        if (i) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__Event.listen(this.input, \"keypress\", function() {\n            var j = Input.getValue(this.input).length;\n            if (((!this._logged_short && ((j >= 2))))) {\n                h.call(this, \"typing\", {\n                    extra: \"short\"\n                });\n                this._logged_short = true;\n                return;\n            }\n        ;\n        ;\n            if (((!this._logged_long && ((j >= 15))))) {\n                h.call(this, \"typing\", {\n                    extra: \"long\"\n                });\n                this._logged_long = true;\n            }\n        ;\n        ;\n        }.bind(this));\n    };\n    var c = function(i) {\n        if (((this.inform(\"submit\") === false))) {\n            i.kill();\n            return false;\n        }\n    ;\n    ;\n        h.call(this, \"publish\");\n        if (this.submitHandler) {\n            return (new Function(this.submitHandler)).apply(this.form);\n        }\n    ;\n    ;\n    };\n    window.Composer = function(l, k, j, i) {\n        g[l.id] = this;\n        this.root = l;\n        this.resetCfg = k;\n        this.dataSource = i;\n        this.lazyEndpoint = ((this.resetCfg && this.resetCfg.lazyEndpoint));\n        Bootloader.loadComponents(\"dom\", function() {\n            this.JSBNG__focus = DOM.JSBNG__find(l, \"div.focus_target\");\n            this.form = DOM.JSBNG__find(l, \"form.attachmentForm\");\n            this.JSBNG__content = DOM.JSBNG__find(l, \"div.attachmentContent\");\n            this.isMetaComposer = j;\n            if (this.isMetaComposer) {\n                this.messageBox = DOM.JSBNG__find(l, \"div.uiMetaComposerMessageBox\");\n                this.metaArea = DOM.JSBNG__find(l, \"div.attachmentMetaArea\");\n                this.bottomArea = DOM.JSBNG__find(l, \"div.attachmentBottomArea\");\n                this.barArea = DOM.JSBNG__find(l, \"div.attachmentBarArea\");\n                this.blurb = DOM.JSBNG__find(l, \"div.uiMetaComposerMessageBox div.textBlurb\");\n                this.input = DOM.JSBNG__find(l, \"div.uiMetaComposerMessageBox textarea.input\");\n                this.button = DOM.JSBNG__find(l, \"div.uiMetaComposerMessageBox label.submitBtn\");\n                this.privacy = DOM.JSBNG__find(l, \"div.uiMetaComposerMessageBox li.privacyWidget\");\n            }\n             else {\n                this.blurb = DOM.JSBNG__find(l, \"div.uiComposerMessageBox div.textBlurb\");\n                this.input = DOM.JSBNG__find(l, \"div.uiComposerMessageBox textarea.input\");\n                this.button = DOM.JSBNG__find(l, \"div.uiComposerMessageBox label.submitBtn\");\n                this.privacy = DOM.JSBNG__find(l, \"div.uiComposerMessageBox li.privacyWidget\");\n            }\n        ;\n        ;\n            JSBNG__Event.listen(this.form, \"submit\", c.bind(this));\n            if (this.isMetaComposer) {\n                JSBNG__Event.listen(this.input, \"JSBNG__focus\", this.JSBNG__onFocus.bind(this));\n                if (Parent.byClass(this.input, \"child_was_focused\")) {\n                    this.JSBNG__onFocus.bind(this).defer();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            Arbiter.inform(((\"xhpc/construct/\" + l.id)), this, Arbiter.BEHAVIOR_STATE);\n        }.bind(this));\n    };\n    Class.mixin(Composer, \"Arbiter\", {\n        init: function(i) {\n            this.mentionsInput = i;\n            if (this.mentionsInput) {\n                this.mentionsInput.subscribe(\"init\", function() {\n                    var j = this.mentionsInput.getTypeahead().getView();\n                    j.subscribe([\"reset\",\"render\",], function(k) {\n                        CSS.conditionClass(this.root, \"uiComposerMention\", ((k == \"render\")));\n                    }.bind(this));\n                }.bind(this));\n                this.mentionsInput.subscribe(\"update\", function(k, j) {\n                    Arbiter.inform(\"Composer/mentions\", keys(j.mentioned));\n                });\n            }\n        ;\n        ;\n            f.call(this);\n            d.call(this);\n            if (this.isMetaComposer) {\n                e.call(this);\n            }\n        ;\n        ;\n            this.inform(\"init\", null, Arbiter.BEHAVIOR_PERSISTENT);\n        },\n        setBlurb: function(i) {\n            DOM.setContent(this.blurb, i);\n        },\n        setEnabled: function(i) {\n            Button.setEnabled(this.button, i);\n        },\n        setLoading: function(i) {\n            CSS.conditionClass(this.root, \"async_saving\", !!i);\n        },\n        setContentVisible: function(i) {\n            CSS.conditionClass(this.root, \"uiComposerHideContent\", !i);\n        },\n        setMessageBoxVisible: function(i) {\n            CSS.conditionClass(this.root, \"uiComposerHideMessageBox\", !i);\n        },\n        setInputVisible: function(i) {\n            CSS.conditionClass(this.root, \"uiComposerHideInput\", !i);\n        },\n        setTopicTaggerVisible: function(i) {\n            CSS.conditionClass(this.root, \"uiTagComposerHidden\", !i);\n        },\n        mutate: function(k) {\n            var j = ge(k.xhpc);\n            if (j) {\n                var l = DOM.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                if (((k.confirmAugmentation && ((l !== j))))) {\n                    return;\n                }\n            ;\n            ;\n                ((l && CSS.removeClass(l, \"uiComposerAttachmentSelected\")));\n                CSS.addClass(j, \"uiComposerAttachmentSelected\");\n                if (!k.disableCache) {\n                    JSBNG__Event.listen(j, \"click\", function(m) {\n                        $E(m).JSBNG__stop();\n                        k.disableCache = true;\n                        this.mutate(k);\n                    }.bind(this));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (!k.keepContentAreas) {\n                this.setContentVisible(false);\n                DOM.empty(this.JSBNG__content);\n                if (this.isMetaComposer) {\n                    ((this.mentionsInput && this.mentionsInput.setAuxContent(null)));\n                    DOM.empty(this.metaArea);\n                    DOM.empty(this.bottomArea);\n                    DOM.empty(this.barArea);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (k.JSBNG__content) {\n                DOM.setContent(this.JSBNG__content, HTML(k.JSBNG__content));\n                this.setContentVisible(true);\n            }\n        ;\n        ;\n            if (this.isMetaComposer) {\n                ((k.metaContent && DOM.setContent(this.metaArea, HTML(k.metaContent))));\n                ((k.bottomContent && DOM.setContent(this.bottomArea, HTML(k.bottomContent))));\n                ((k.barContent && DOM.setContent(this.barArea, HTML(k.barContent))));\n            }\n        ;\n        ;\n            this.setMessageBoxVisible(!k.messageBoxHidden);\n            CSS.conditionClass(this.root, \"uiComposerWhiteMessageBox\", ((((!k.messageBoxHidden && !k.inputHidden)) && !k.JSBNG__content)));\n            this.setInputVisible(!k.inputHidden);\n            CSS.conditionShow(this.privacy, !k.privacyWidgetHidden);\n            Input.setPlaceholder(this.input, k.placeholder);\n            Button.setLabel(this.button, k.buttonLabel);\n            this.setBlurb(HTML(k.blurb));\n            if (!this.isMetaComposer) {\n                CSS.conditionClass(DOM.scry(this.form, \".uiComposerMessageBox\")[0], \"uiCheckinComposer\", k.placeVisible);\n            }\n        ;\n        ;\n            if (k.autoscrape) {\n                ((this.scraper && this.scraper.enable()));\n            }\n             else ((this.scraper && this.scraper.disable()));\n        ;\n        ;\n            this.setEnabled(!k.disabled);\n            this.setTopicTaggerVisible(!k.hideTopicTagger);\n            this.form.setAttribute(\"action\", k.endpoint);\n            if (((k.formType == b))) {\n                this.form.setAttribute(\"rel\", \"async\");\n            }\n             else this.form.removeAttribute(\"rel\");\n        ;\n        ;\n            if (((k.formType == a))) {\n                this.form.target = k.iframeName;\n                this.form.enctype = this.form.encoding = \"multipart/form-data\";\n            }\n             else {\n                this.form.removeAttribute(\"target\");\n                this.form.removeAttribute(\"enctype\");\n                this.form.removeAttribute(\"encoding\");\n            }\n        ;\n        ;\n            this.submitHandler = k.submitHandler;\n            this.lazyEndpoint = k.lazyEndpoint;\n            ((k.attachmentJS && (new Function(k.attachmentJS)).apply(this)));\n            CSS.addClass(this.root, \"uiComposerInteracted\");\n            CSS.addClass(this.root, \"uiComposerOpen\");\n            if (k.messageBoxFocused) {\n                var i = JSBNG__document.activeElement;\n                if (((((i === JSBNG__document.body)) || Parent.byClass(i, \"attachmentLink\")))) {\n                    this.focusInput.bind(this).defer();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            Arbiter.inform(\"composer/mutate\", this);\n        },\n        subscribeToMutate: function(i) {\n            return Arbiter.subscribe(\"composer/mutate\", function(j, k) {\n                if (((k === this))) {\n                    i();\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        reset: function(j, i) {\n            if (!j) {\n                Input.reset(this.input);\n                ((this.mentionsInput && this.mentionsInput.reset()));\n            }\n        ;\n        ;\n            if (this.isMetaComposer) {\n                DOM.empty(this.metaArea);\n                DOM.empty(this.bottomArea);\n                DOM.empty(this.barArea);\n            }\n        ;\n        ;\n            if (this.resetCfg) {\n                this.mutate(this.resetCfg);\n            }\n             else {\n                var k = DOM.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                if (k) {\n                    CSS.removeClass(k, \"uiComposerAttachmentSelected\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            CSS.removeClass(this.root, \"uiComposerInteracted\");\n            CSS.setClass(this.JSBNG__focus, \"focus_target\");\n            this.setLoading(false);\n            d.call(this, true);\n            if (i) {\n                var l = DOM.scry(this.root, \".widget\")[0];\n                ((l && DOM.replace(l, i)));\n            }\n        ;\n        ;\n            Arbiter.inform(\"composer/reset\");\n        },\n        JSBNG__onFocus: function() {\n            if (this.lazyEndpoint) {\n                var i = DOM.JSBNG__find(this.root, \"form.attachmentSelectForm\");\n                var k = new URI(this.lazyEndpoint);\n                k.setQueryData({\n                    isAugmentation: true\n                });\n                i.action = k.toString();\n                var j = DOM.scry(this.root, \".uiComposerAttachmentSelected\")[0];\n                i.xhpc.value = ((j && j.id));\n                i.xhpc.click();\n                CSS.removeClass.curry(this.root, \"async_saving\").defer();\n            }\n        ;\n        ;\n            this.inform(\"JSBNG__focus\");\n        },\n        focusInput: function() {\n            Input.JSBNG__focus(this.input);\n        },\n        getInput: function() {\n            return this.input;\n        },\n        updateDataSourceToken: function(i) {\n            if (this.dataSource) {\n                this.dataSource.updateToken(i);\n            }\n        ;\n        ;\n        }\n    });\n    copy_properties(Composer, {\n        publish: function(j, i) {\n            i = ((i || {\n            }));\n            i.composer = Composer.getInstance($(j));\n            i.composer.reset(false, i.audienceMarkup);\n            i.audienceMarkup = null;\n            if (i.streamMarkup) {\n                i.streamStory = HTML(i.streamMarkup).getRootNode();\n            }\n        ;\n        ;\n            Arbiter.inform(\"composer/publish\", i);\n        },\n        getInstance: function(i) {\n            var j = Parent.byClass($(i), \"uiComposer\");\n            return ((j ? g[j.id] : null));\n        }\n    });\n})();\nfunction MetaComposerMessageBox() {\n\n};\n;\nMetaComposerMessageBox.prototype = {\n    init: function(b, a) {\n        this.inputContainer = DOM.scry(b, \"div.inputContainer\")[0];\n        this.textInput = DOM.scry(b, \"textarea.mentionsTextarea\")[0];\n        this.metaArea = DOM.scry(b, \"div.attachmentMetaArea\")[0];\n        this.bottomArea = DOM.scry(b, \"div.attachmentBottomArea\")[0];\n        this.barArea = DOM.scry(b, \"div.attachmentBarArea\")[0];\n        JSBNG__Event.listen(this.inputContainer, \"click\", function(c) {\n            var d = c.getTarget();\n            if (((!DOM.contains(this.metaArea, d) && ((d !== this.textInput))))) {\n                this.textInput.JSBNG__focus();\n            }\n        ;\n        ;\n        }.bind(this));\n    }\n};\nfunction MentionsInput(a) {\n    DataStore.set(a, \"MentionsInput\", this);\n    this._root = a;\n};\n;\nMentionsInput.getInstance = function(a) {\n    var b = Parent.byClass(a, \"uiMentionsInput\");\n    return ((b ? DataStore.get(b, \"MentionsInput\") : null));\n};\n(function() {\n    var a = \"@\\\\uff20\";\n    var e = \".,+*?$|#{}()\\\\^\\\\-\\\\[\\\\]\\\\\\\\/!@%&'\\\"~=\\u003C\\u003E_:;\";\n    var d = ((((\"\\\\b[A-Z][^ A-Z\" + e)) + \"]\"));\n    var c = ((((((((((\"(?:[\" + a)) + \"]([^\")) + a)) + e)) + \"]{0,20}))\"));\n    var b = ((((((((\"(?:(?:\" + d)) + \"+)|\")) + c)) + \")\"));\n    var f = ((((\"(?:\" + d)) + \"{4,})\"));\n    MentionsInput.prototype = {\n        _matcher: new RegExp(((c + \"$\"))),\n        _autoMatcher: new RegExp(((b + \"$\"))),\n        _userMatcher: new RegExp(((f + \"$\")))\n    };\n})();\nClass.mixin(MentionsInput, \"Arbiter\", {\n    init: function(a, b) {\n        this.init = bagofholding;\n        this._initialized = true;\n        this._typeahead = Typeahead.getInstance(DOM.JSBNG__find(this._root, \".mentionsTypeahead\"));\n        this._highlighter = DOM.JSBNG__find(this._root, \".highlighter\");\n        this._highlighterInner = this._highlighter.firstChild;\n        this._highlighterContent = DOM.JSBNG__find(this._root, \".highlighterContent\");\n        this._hiddenInput = DOM.JSBNG__find(this._root, \".mentionsHidden\");\n        this._input = this._typeahead.getCore().getElement();\n        this._placeholder = this._input.getAttribute(\"placeholder\");\n        this._maxMentions = ((a.max || 6));\n        if (((ua.firefox() < 4))) {\n            this._input.JSBNG__blur();\n            JSBNG__setTimeout(function() {\n                this._input.JSBNG__focus();\n            }.bind(this));\n        }\n    ;\n    ;\n        if (!this._hiddenInput.JSBNG__name) {\n            var c = this._input.JSBNG__name;\n            this._input.JSBNG__name = ((c + \"_text\"));\n            this._hiddenInput.JSBNG__name = c;\n        }\n    ;\n    ;\n        this._initEvents();\n        this._initTypeahead();\n        this.reset(b);\n        this.inform(\"init\", null, Arbiter.BEHAVIOR_STATE);\n    },\n    reset: function(b) {\n        if (!this._initialized) {\n            return;\n        }\n    ;\n    ;\n        this._mentioned = {\n        };\n        this._numMentioned = 0;\n        this._filterData = null;\n        ((this._hiddenInput && (this._hiddenInput.value = \"\")));\n        ((this._highlighterContent && DOM.empty(this._highlighterContent)));\n        ((this._highlighterAuxContent && DOM.remove(this._highlighterAuxContent)));\n        this._highlighterAuxContent = null;\n        Input.setPlaceholder(this._input, this._placeholder);\n        CSS.setStyle(this._typeahead.getElement(), \"height\", \"auto\");\n        if (b) {\n            Input.setValue(this._input, b.flattened);\n            for (var a in b.mention_data) {\n                this._addToken({\n                    uid: a,\n                    text: b.mention_data[a],\n                    type: \"unknown\"\n                });\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        this._updateTypeahead();\n        this._update();\n    },\n    getRawValue: function() {\n        return Input.getValue(this._hiddenInput);\n    },\n    getTypeahead: function() {\n        return this._typeahead;\n    },\n    _initEvents: function() {\n        var c = this._update.bind(this);\n        var a = c.defer.bind(c, 20);\n        var b = {\n            change: c,\n            keydown: a,\n            JSBNG__focus: this._updateWidth.bind(this)\n        };\n        if (ua.firefox()) {\n            b.keyup = c;\n        }\n    ;\n    ;\n        if (((ua.firefox() < 4))) {\n            b.keypress = b.keydown;\n            delete b.keydown;\n        }\n    ;\n    ;\n        JSBNG__Event.listen(this._input, b);\n    },\n    _initTypeahead: function() {\n        this._typeahead.subscribe(\"select\", function(c, d) {\n            var e = d.selected;\n            this._addToken({\n                uid: e.uid,\n                text: e.text,\n                type: e.type\n            });\n            this.updateValue();\n        }.bind(this));\n        var a = this._input;\n        var b = null;\n        this._typeahead.subscribe(\"render\", function(JSBNG__event) {\n            if (((b === null))) {\n                b = Input.getSubmitOnEnter(a);\n                Input.setSubmitOnEnter(a, false);\n            }\n        ;\n        ;\n        });\n        this._typeahead.subscribe(\"reset\", function(JSBNG__event) {\n            if (((b !== null))) {\n                Input.setSubmitOnEnter(a, b);\n                b = null;\n            }\n        ;\n        ;\n        });\n        this._typeahead.subscribe(\"query\", function() {\n            this._filterData = null;\n        }.bind(this));\n        this._typeahead.getCore().suffix = \"\";\n        this._typeahead.getData().setFilter(this._filterResults.bind(this));\n    },\n    _filterResults: function(d) {\n        if (((this._filterData === null))) {\n            var a = ((Input.JSBNG__getSelection(this._input).start || 0));\n            for (var c = 0; ((c < this._offsets.length)); c++) {\n                var e = this._offsets[c];\n                if (((((a > e[0])) && ((a <= e[1]))))) {\n                    this._filterData = {\n                        caretIsInsideMention: true\n                    };\n                    return false;\n                }\n            ;\n            ;\n            };\n        ;\n            var b = this._typeahead.getCore();\n            this._filterData = {\n                value: b.getValue(),\n                rawValue: b.getRawValue()\n            };\n        }\n    ;\n    ;\n        if (this._filterData.caretIsInsideMention) {\n            return false;\n        }\n    ;\n    ;\n        if (this._matcher.test(this._filterData.rawValue)) {\n            return true;\n        }\n    ;\n    ;\n        if (((((d.type != \"user\")) && !d.auto))) {\n            return false;\n        }\n    ;\n    ;\n        if (this._userMatcher.test(this._filterData.value)) {\n            return true;\n        }\n    ;\n    ;\n        return TypeaheadUtil.isExactMatch(this._filterData.value, this._typeahead.getData().getTextToIndex(d));\n    },\n    _addToken: function(a) {\n        this._mentioned[a.uid] = a;\n        this._numMentioned++;\n        this._updateTypeahead();\n    },\n    _removeToken: function(a) {\n        delete this._mentioned[a];\n        this._numMentioned--;\n        this._updateTypeahead();\n    },\n    _reduceToken: function(f, d) {\n        var e = d.split(\" \");\n        var b = [];\n        for (var a = 0; ((a < e.length)); a++) {\n            if (((f.indexOf(e[a]) != -1))) {\n                b.push(e[a]);\n            }\n        ;\n        ;\n        };\n    ;\n        e = b;\n        for (a = 1; ((a < e.length)); a++) {\n            for (var c = 1; ((c < ((e[((a - 1))].length + 1)))); c++) {\n                if (((f.indexOf(((e[((a - 1))].substr(0, c) + e[a]))) != -1))) {\n                    e.splice(((a - 1)), 1);\n                }\n            ;\n            ;\n            };\n        ;\n        };\n    ;\n        while (((f.indexOf(e.join(\" \")) == -1))) {\n            e.splice(0, 1);\n        ;\n        };\n    ;\n        return e.join(\" \");\n    },\n    _update: function() {\n        var a = Input.getValue(this._input);\n        if (((a == this._value))) {\n            return;\n        }\n    ;\n    ;\n        this._value = a;\n        this._updateTokens();\n        this.updateValue();\n    },\n    _updateTokens: function() {\n        var e = Input.getValue(this._input);\n        for (var d in this._mentioned) {\n            var a = this._mentioned[d];\n            var c = a.text;\n            var b;\n            if (((((a.type == \"user\")) && (((b = this._reduceToken(e, c)) !== \"\"))))) {\n                a.text = b;\n            }\n             else if (((((!c || ((e.indexOf(c) == -1)))) || ((typeof c !== \"string\"))))) {\n                this._removeToken(d);\n            }\n            \n        ;\n        ;\n        };\n    ;\n    },\n    updateValue: function() {\n        var f = Input.getValue(this._input);\n        var b = this._mentioned;\n        var c = [];\n        var a, d, e;\n        for (e in b) {\n            d = b[e].text;\n            f = f.replace(d, function(g, h) {\n                c.push([h,((h + d.length)),]);\n                return d;\n            });\n        };\n    ;\n        for (e in b) {\n            d = b[e].text;\n            f = f.replace(d, ((((\"@[\" + e)) + \":]\")));\n        };\n    ;\n        a = htmlize(f);\n        for (e in b) {\n            d = b[e].text;\n            a = a.replace(((((\"@[\" + e)) + \":]\")), ((((\"\\u003Cb\\u003E\" + htmlize(d))) + \"\\u003C/b\\u003E\")));\n            f = f.replace(((((\"@[\" + e)) + \":]\")), ((((((((\"@[\" + e)) + \":\")) + d)) + \"]\")));\n        };\n    ;\n        if (ua.ie()) {\n            a = a.replace(/ {2}/g, \"&nbsp; \");\n        }\n    ;\n    ;\n        this._offsets = c;\n        this._hiddenInput.value = f;\n        DOM.setContent(this._highlighterContent, HTML(a));\n        this._updateHeight();\n    },\n    _updateWidth: function() {\n        var a = CSS.getStyleFloat.curry(this._input);\n        var b = ((((((((this._input.offsetWidth - a(\"paddingLeft\"))) - a(\"paddingRight\"))) - a(\"borderLeftWidth\"))) - a(\"borderRightWidth\")));\n        if (ua.firefox()) {\n            b -= 2;\n        }\n    ;\n    ;\n        if (((ua.ie() <= 7))) {\n            b -= CSS.getStyleFloat(this._highlighterInner, \"paddingLeft\");\n            this._highlighter.style.zoom = 1;\n        }\n    ;\n    ;\n        this._highlighterInner.style.width = ((Math.max(b, 0) + \"px\"));\n    },\n    _updateHeight: function() {\n        if (this._highlighterAuxContent) {\n            var a = this._highlighter.offsetHeight;\n            var b = this._typeahead.getElement();\n            if (((a > b.offsetHeight))) {\n                CSS.setStyle(b, \"height\", ((a + \"px\")));\n                Arbiter.inform(\"reflow\");\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _updateTypeahead: function() {\n        var a = this._typeahead.getCore();\n        var b = null;\n        if (((!this._maxMentions || ((this._numMentioned < this._maxMentions))))) {\n            b = this._autoMatcher;\n        }\n    ;\n    ;\n        a.matcher = b;\n        a.setExclusions(keys(this._mentioned));\n        this.inform(\"update\", {\n            mentioned: this._mentioned\n        });\n    },\n    setAuxContent: function(a) {\n        if (this._highlighterContent) {\n            if (!this._highlighterAuxContent) {\n                this._highlighterAuxContent = $N(\"span\", {\n                    className: \"highlighterAuxContent\"\n                });\n                DOM.insertAfter(this._highlighterContent, this._highlighterAuxContent);\n            }\n        ;\n        ;\n            DOM.setContent(this._highlighterAuxContent, a);\n            if (a) {\n                Input.setPlaceholder(this._input, \"\");\n            }\n             else Input.setPlaceholder(this._input, this._placeholder);\n        ;\n        ;\n            this._updateHeight();\n        }\n    ;\n    ;\n    },\n    getAuxContentRoot: function() {\n        return this._highlighterAuxContent;\n    },\n    addMention: function(a) {\n        var b = Input.getValue(this._input);\n        Input.setValue(this._input, ((((b + \" \")) + a.text)));\n        this._mentioned[a.uid] = a;\n        this._update();\n    },\n    getMentions: function() {\n        return this._mentioned;\n    }\n});\nfunction ScrollableArea() {\n\n};\n;\ncopy_properties(ScrollableArea, {\n    getInstance: function(a) {\n        var b = Parent.byClass(a, \"uiScrollableArea\");\n        return ((b ? DataStore.get(b, \"ScrollableArea\") : null));\n    }\n});\nScrollableArea.prototype = {\n    init: function(a, b) {\n        b = ((b || {\n        }));\n        this._elem = a;\n        this._wrap = DOM.JSBNG__find(a, \"div.uiScrollableAreaWrap\");\n        this._body = DOM.JSBNG__find(this._wrap, \"div.uiScrollableAreaBody\");\n        this._track = DOM.JSBNG__find(a, \"div.uiScrollableAreaTrack\");\n        this._gripper = DOM.JSBNG__find(this._track, \"div.uiScrollableAreaGripper\");\n        this._options = b;\n        this.adjustGripper();\n        this._listeners = [JSBNG__Event.listen(this._wrap, \"JSBNG__scroll\", this._handleScroll.bind(this)),];\n        if (((b.fade !== false))) {\n            this._listeners.push(JSBNG__Event.listen(a, \"mouseenter\", this.adjustGripper.shield(this)), JSBNG__Event.listen(a, \"mouseenter\", this.showScrollbar.shield(this)), JSBNG__Event.listen(a, \"mousemove\", this._handleMousemove.bind(this)), JSBNG__Event.listen(a, \"mouseout\", this.hideScrollbar.shield(this)));\n        }\n    ;\n    ;\n        this.initDrag();\n        DataStore.set(this._elem, \"ScrollableArea\", this);\n        if (!b.persistent) {\n            JSBNG__onleaveRegister(this.destroy.bind(this));\n        }\n    ;\n    ;\n    },\n    initDrag: function() {\n        var a = new SimpleDrag(this._gripper);\n        a.subscribe(\"start\", function(b, JSBNG__event) {\n            if (!((((JSBNG__event.which && ((JSBNG__event.which === 1)))) || ((JSBNG__event.button && ((JSBNG__event.button === 1))))))) {\n                return;\n            }\n        ;\n        ;\n            var d = this._getPageY(JSBNG__event);\n            var e = this._gripper.offsetTop;\n            var f = a.subscribe(\"update\", function(g, JSBNG__event) {\n                var j = ((this._getPageY(JSBNG__event) - d));\n                var i = this._elem.clientHeight;\n                var h = this._body.offsetHeight;\n                var p = this._track.offsetHeight;\n                var k = ((((i / h)) * p));\n                var m = ((h - this._wrap.offsetHeight));\n                var l = ((e + j));\n                var n = ((p - k));\n                l = Math.max(Math.min(l, n), 0);\n                var o = ((((l / n)) * m));\n                this._wrap.scrollTop = o;\n            }.bind(this));\n            var c = a.subscribe(\"end\", function() {\n                a.unsubscribe(f);\n                a.unsubscribe(c);\n            });\n        }.bind(this));\n    },\n    adjustGripper: function() {\n        var b = this._elem.clientHeight;\n        var a = this._body.offsetHeight;\n        var e = this._track.offsetHeight;\n        var c = ((((b / a)) * e));\n        if (((c < e))) {\n            CSS.setStyle(this._gripper, \"height\", ((c + \"px\")));\n            var d = ((((this._wrap.scrollTop / a)) * e));\n            CSS.setStyle(this._gripper, \"JSBNG__top\", ((d + \"px\")));\n            CSS.show(this._gripper);\n        }\n         else CSS.hide(this._gripper);\n    ;\n    ;\n        this._checkContentBoundaries();\n        return this;\n    },\n    _checkContentBoundaries: function() {\n        var a = this._wrap.scrollTop;\n        var b = ((this._wrap.scrollHeight - this._wrap.clientHeight));\n        CSS.conditionClass(this._elem, \"contentBefore\", ((a > 0)));\n        CSS.conditionClass(this._elem, \"contentAfter\", ((a < b)));\n    },\n    destroy: function() {\n        this._listeners.forEach(function(a) {\n            a.remove();\n        });\n        this._listeners.length = 0;\n    },\n    _getPageX: function(JSBNG__event) {\n        return ((((JSBNG__event.pageX != null)) ? JSBNG__event.pageX : ((JSBNG__event.clientX + JSBNG__document.body.scrollLeft))));\n    },\n    _getPageY: function(JSBNG__event) {\n        return ((((JSBNG__event.pageY != null)) ? JSBNG__event.pageY : ((JSBNG__event.clientY + JSBNG__document.body.scrollTop))));\n    },\n    _handleMousemove: function(JSBNG__event) {\n        var a = Vector2.getElementPosition(this._track).x;\n        var b = Vector2.getElementDimensions(this._track).x;\n        if (((Math.abs(((((a + ((b / 2)))) - this._getPageX(JSBNG__event)))) < 25))) {\n            this.showScrollbar(false);\n        }\n         else this.hideScrollbar();\n    ;\n    ;\n    },\n    _handleScroll: function(JSBNG__event) {\n        this.adjustGripper();\n        if (((this._options.fade !== false))) {\n            this.showScrollbar();\n        }\n    ;\n    ;\n    },\n    hideScrollbar: function() {\n        if (!this._scrollbarVisible) {\n            return this;\n        }\n    ;\n    ;\n        this._scrollbarVisible = false;\n        if (this._hideTimeout) {\n            JSBNG__clearTimeout(this._hideTimeout);\n            this._hideTimeout = null;\n        }\n    ;\n    ;\n        this._hideTimeout = function() {\n            if (this._scrollbarAnimation) {\n                this._scrollbarAnimation.JSBNG__stop();\n                this._scrollbarAnimation = null;\n            }\n        ;\n        ;\n            this._scrollbarAnimation = animation(this._track).from(\"opacity\", 1).to(\"opacity\", 0).duration(250).JSBNG__ondone(CSS.addClass.curry(this._track, \"invisible_elem\")).go();\n        }.bind(this).defer(750);\n        return this;\n    },\n    showScrollbar: function(a) {\n        if (this._scrollbarVisible) {\n            return this;\n        }\n    ;\n    ;\n        this._scrollbarVisible = true;\n        if (this._hideTimeout) {\n            JSBNG__clearTimeout(this._hideTimeout);\n            this._hideTimeout = null;\n        }\n    ;\n    ;\n        if (this._scrollbarAnimation) {\n            this._scrollbarAnimation.JSBNG__stop();\n            this._scrollbarAnimation = null;\n        }\n    ;\n    ;\n        CSS.setStyle(this._track, \"opacity\", 1);\n        CSS.removeClass(this._track, \"invisible_elem\");\n        if (((a !== false))) {\n            this.hideScrollbar();\n        }\n    ;\n    ;\n        return this;\n    },\n    scrollToBottom: function() {\n        animation(this._wrap).to(\"scrollTop\", this._wrap.scrollHeight).ease(animation.ease.end).go();\n    }\n};\nfunction FutureSideNav() {\n    ((FutureSideNav.instance && FutureSideNav.instance.uninstall()));\n    FutureSideNav.instance = this;\n};\n;\nFutureSideNav.instance = null;\nFutureSideNav.getInstance = function() {\n    return ((FutureSideNav.instance || new FutureSideNav()));\n};\nFutureSideNav.prototype = {\n    init: function(c, b, a) {\n        this.root = c;\n        this.items = {\n        };\n        this.sections = {\n        };\n        this.editor = null;\n        this.editing = false;\n        this.selected = null;\n        this.loading = null;\n        this.keyParam = \"sk\";\n        this.defaultKey = b;\n        this.uri = URI.getRequestURI();\n        this.ajaxPipe = a;\n        this.ajaxPipeEndpoints = {\n        };\n        this.sidecol = true;\n        this._installed = true;\n        this._handlePageTransitions = true;\n        PageTransitions.registerHandler(function(d) {\n            return ((this._handlePageTransitions && this.handlePageTransition(d)));\n        }.bind(this));\n        this._eventHandlers = [];\n        this._arbiterSubscriptions = [Arbiter.subscribe(NavigationMessage.NAVIGATION_COMPLETED, this.navigationComplete.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_FAILED, this.navigationFailed.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_COUNT_UPDATE, this.navigationCountUpdate.bind(this)),Arbiter.subscribe(NavigationMessage.NAVIGATION_SELECT, this.navigationSelect.bind(this)),Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"nav_count\"), this.navigationCountUpdateFromPresence.bind(this)),];\n        this._explicitHover = [];\n        this._ensureHover(\"sideNavItem\");\n        this._eventHandlers.push(JSBNG__Event.listen(window, \"resize\", this._handleResize.bind(this)));\n        this._checkNarrow();\n        ((window.Selector && this._arbiterSubscriptions.push(Selector.subscribe([\"open\",\"close\",], function(f, d) {\n            var e = Parent.byClass(d.selector, \"sideNavItem\");\n            ((e && CSS.conditionClass(e, \"editMenuOpened\", ((f === \"open\")))));\n        }))));\n        JSBNG__onleaveRegister(this.uninstall.bind(this));\n    },\n    _handleResize: (function() {\n        var a;\n        return function() {\n            ((a && JSBNG__clearTimeout(a)));\n            a = this._checkNarrow.bind(this).defer(200);\n        };\n    })(),\n    _checkNarrow: function() {\n        CSS.conditionClass(this.root, \"uiNarrowSideNav\", ((Vector2.getElementPosition(this.root).x < 20)));\n    },\n    _ensureHover: function(a) {\n        if (((ua.ie() < 8))) {\n            Bootloader.loadComponents(\"explicit-hover\", function() {\n                this._explicitHover.push(new ExplicitHover(this.root, a));\n            }.bind(this));\n        }\n    ;\n    ;\n    },\n    uninstall: function() {\n        if (this._installed) {\n            this._installed = false;\n            this._handlePageTransitions = false;\n            this._arbiterSubscriptions.forEach(Arbiter.unsubscribe);\n            this._eventHandlers.forEach(function(a) {\n                a.remove();\n            });\n            this._explicitHover.forEach(function(a) {\n                a.uninstall();\n            });\n        }\n    ;\n    ;\n    },\n    initSection: function(b, a) {\n        this._initItems(a);\n        this._initSection(b);\n    },\n    addItem: function(a, b) {\n        this._initItem(a, b);\n    },\n    _initItems: function(b) {\n        var a = function(c, e) {\n            var d = this._initItem(c, e);\n            $(c.children).forEach(function(f) {\n                a(f, d);\n            });\n        }.bind(this);\n        $A(b).forEach(function(c) {\n            a(c, null);\n        });\n    },\n    _initItem: function(a, d) {\n        var b = this.items[a.id] = this._constructItem(a, d);\n        if (((b.equals(this.selected) || a.selected))) {\n            this.setSelected(b);\n        }\n    ;\n    ;\n        var c = b.getLinkNode();\n        ((c && this._eventHandlers.push(JSBNG__Event.listen(c, \"click\", function(JSBNG__event) {\n            return !this.editing;\n        }.bind(this)))));\n        return b;\n    },\n    _initSection: function(a) {\n        var b = this.sections[a.id] = this._constructSection(a);\n        this._eventHandlers.push(JSBNG__Event.listen(b.node, \"click\", this.handleSectionClick.bind(this, b)));\n        DOM.scry(b.node, \"div.bookmarksMenuButton\").forEach(CSS.show);\n        return b;\n    },\n    _constructItem: function(a, b) {\n        return new FutureSideNavItem(a, b);\n    },\n    _constructSection: function(a) {\n        return new FutureSideNavSection(a);\n    },\n    handleSectionClick: function(c, JSBNG__event) {\n        var b = this._getEventTarget(JSBNG__event, \"a\");\n        var a = this._getItemForNode(b);\n        if (!b) {\n            return;\n        }\n         else if (CSS.hasClass(b.parentNode, \"uiMenuItem\")) {\n            this._handleMenuClick(c, a, b.parentNode, JSBNG__event);\n        }\n         else this._handleLinkClick(c, b, JSBNG__event);\n        \n    ;\n    ;\n    },\n    _getEventTarget: function(JSBNG__event, a) {\n        var b = JSBNG__event.getTarget();\n        if (((b.tagName !== a.toUpperCase()))) {\n            return Parent.byTag(b, a);\n        }\n         else return b\n    ;\n    },\n    _handleMenuClick: function(c, a, b, JSBNG__event) {\n        if (CSS.hasClass(b, \"rearrange\")) {\n            this.beginEdit(c);\n        }\n    ;\n    ;\n    },\n    _handleLinkClick: function(b, a, JSBNG__event) {\n        if (CSS.hasClass(a, \"navEditDone\")) {\n            ((this.editing ? this.endEdit() : this.beginEdit(b)));\n            JSBNG__event.kill();\n        }\n    ;\n    ;\n    },\n    getItem: function(a) {\n        if (this._isCurrentPath(a)) {\n            return this._getItemForKey(((this._getKey(a.getQueryData()) || this.defaultKey)));\n        }\n         else return this._getItemForPath(a.getPath())\n    ;\n    },\n    getNodeForKey: function(b) {\n        var a = this._getItemForKey(b);\n        if (a) {\n            return a.node;\n        }\n    ;\n    ;\n    },\n    _isCurrentPath: function(a) {\n        return ((((a.getDomain() === this.uri.getDomain())) && ((a.getPath() === this.uri.getPath()))));\n    },\n    _getKey: function(a) {\n        return a[this.keyParam];\n    },\n    _getItemForNode: function(a) {\n        a = Parent.byClass(a, \"sideNavItem\");\n        return ((a && this.items[a.id]));\n    },\n    _getItemForKey: function(a) {\n        return this._findItem(function(b) {\n            return b.matchKey(a);\n        });\n    },\n    _getItemForPath: function(a) {\n        return this._findItem(function(b) {\n            return b.matchPath(a);\n        });\n    },\n    _findItem: function(a) {\n        for (var b in this.items) {\n            if (a(this.items[b])) {\n                return this.items[b];\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    removeItem: function(a) {\n        if (((a && this.items[a.id]))) {\n            DOM.remove(a.node);\n            delete this.items[a.id];\n            if (a.getTop().equals(((this.selected && this.selected.getTop())))) {\n                goURI(URI.getRequestURI(), true);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    removeItemByKey: function(a) {\n        this.removeItem(this._getItemForKey(a));\n    },\n    moveItem: function(d, b, c) {\n        var a = DOM.JSBNG__find(d.node, \"ul.uiSideNav\");\n        ((c ? DOM.prependContent : DOM.appendContent))(a, b.node);\n    },\n    setLoading: function(a) {\n        ((this.loading && this.loading.hideLoading()));\n        this.loading = a;\n        ((this.loading && this.loading.showLoading()));\n    },\n    setSelected: function(a) {\n        this.setLoading(null);\n        if (this.selected) {\n            this.selected.hideSelected();\n            this.selected.getTop().hideChildren();\n        }\n    ;\n    ;\n        this.selected = a;\n        if (this.selected) {\n            this.selected.showSelected();\n            this.selected.getTop().showChildren();\n        }\n    ;\n    ;\n    },\n    handlePageTransition: function(c) {\n        var a = this.getItem(c);\n        var b = ((((a && a.endpoint)) && this._doPageTransition(a, c)));\n        return b;\n    },\n    _doPageTransition: function(a, b) {\n        this.setLoading(a);\n        this._sendPageTransition(a.endpoint, copy_properties(this._getTransitionData(a, b), b.getQueryData()));\n        return true;\n    },\n    _sendPageTransition: function(b, a) {\n        a.endpoint = b;\n        Arbiter.inform(NavigationMessage.NAVIGATION_BEGIN, {\n            useAjaxPipe: this._useAjaxPipe(b),\n            params: a\n        });\n    },\n    _getTransitionData: function(b, c) {\n        var a = {\n        };\n        a.sidecol = this.sidecol;\n        a.path = c.getPath();\n        a[this.keyParam] = b.textKey;\n        a.key = b.textKey;\n        return a;\n    },\n    _useAjaxPipe: function(a) {\n        return ((this.ajaxPipe || this.ajaxPipeEndpoints[a]));\n    },\n    navigationComplete: function() {\n        ((this.loading && this.setSelected(this.loading)));\n        if (((Arbiter.inform(\"sidenav/scrolltop\") !== false))) {\n            DOMScroll.JSBNG__scrollTo(JSBNG__document.documentElement, false);\n        }\n    ;\n    ;\n    },\n    navigationFailed: function() {\n        this.setLoading(null);\n    },\n    navigationSelect: function(c, a) {\n        var b = this._getItemForKey(this._getKey(a));\n        if (a.asLoading) {\n            this.setLoading(b);\n        }\n         else this.setSelected(b);\n    ;\n    ;\n    },\n    navigationCountUpdate: function(c, a) {\n        var b = this._getItemForKey(((a && a.key)));\n        if (b) {\n            if (((typeof a.count !== \"undefined\"))) {\n                b.setCount(a.count, a.hide);\n            }\n             else if (((typeof a.increment !== \"undefined\"))) {\n                b.incrementCount(a.increment, a.hide);\n            }\n            \n        ;\n        }\n    ;\n    ;\n    },\n    navigationCountUpdateFromPresence: function(b, a) {\n        a = a.obj;\n        if (((((a && a.class_name)) && CSS.hasClass(this.root, a.class_name)))) {\n            this.navigationCountUpdate(b, a);\n        }\n    ;\n    ;\n    },\n    beginEdit: function(a) {\n        if (!this.editing) {\n            this.editing = true;\n            CSS.addClass(this.root, \"editMode\");\n            this._updateTrackingData();\n            Bootloader.loadComponents(\"sortable-side-nav-js\", this._initEditor.bind(this, a));\n        }\n    ;\n    ;\n    },\n    endEdit: function() {\n        if (this.editing) {\n            CSS.removeClass(this.root, \"editMode\");\n            this.editor.endEdit();\n            this.editor = null;\n            this.editing = false;\n            this._updateTrackingData();\n        }\n    ;\n    ;\n    },\n    _updateTrackingData: function(a) {\n        var c = ((this.root.getAttribute(\"data-gt\") || \"{}\"));\n        try {\n            c = JSON.parse(c);\n            if (this.editing) {\n                c.editing = true;\n            }\n             else delete c.editing;\n        ;\n        ;\n            this.root.setAttribute(\"data-gt\", JSON.stringify(c));\n        } catch (b) {\n        \n        };\n    ;\n    },\n    _initEditor: function(a) {\n        this.editor = a.getEditor();\n        this.editor.beginEdit();\n    }\n};\nfunction FutureSideNavSection(a) {\n    this.id = a.id;\n    this.node = ((this.node || $(a.id)));\n    this.editEndpoint = a.editEndpoint;\n};\n;\nFutureSideNavSection.prototype = {\n    equals: function(a) {\n        return ((a && ((a.id === this.id))));\n    },\n    getEditor: function() {\n        return new SortableSideNav(DOM.JSBNG__find(this.node, \"ul.uiSideNav\"), this.editEndpoint);\n    }\n};\nfunction FutureSideNavItem(a, c) {\n    this.id = a.id;\n    this.up = c;\n    this.endpoint = a.endpoint;\n    this.type = a.type;\n    this.node = ((a.node || $(a.id)));\n    this.paths = ((a.path ? $A(a.path) : []));\n    this.keys = ((a.key ? $A(a.key) : []));\n    var b = this._findKeys(this.keys);\n    this.numericKey = ((b.numeric || this.keys[0]));\n    this.textKey = ((b.text || this.keys[0]));\n    this._pathPattern = this._buildRegex(this.paths);\n    this._keyPattern = this._buildRegex(this.keys);\n    this.hideLoading();\n    this.hideSelected();\n};\n;\nFutureSideNavItem.prototype = {\n    equals: function(a) {\n        return ((a && ((a.id === this.id))));\n    },\n    getLinkNode: function() {\n        return ((DOM.scry(this.node, \"a.item\")[0] || DOM.scry(this.node, \"a.subitem\")[0]));\n    },\n    matchPath: function(a) {\n        return this._matchInput(this._pathPattern, a);\n    },\n    matchKey: function(a) {\n        return this._matchInput(this._keyPattern, a);\n    },\n    _matchInput: function(c, a) {\n        var b = ((c && c.exec(a)));\n        return ((b && b.slice(1)));\n    },\n    getTop: function() {\n        return ((this.isTop() ? this : this.up.getTop()));\n    },\n    isTop: function(a) {\n        return !this.up;\n    },\n    setCount: function(a, b) {\n        return this._updateCount(a, true);\n    },\n    incrementCount: function(a, b) {\n        return this._updateCount(a, false);\n    },\n    _updateCount: function(a, h, e) {\n        var c = DOM.scry(this.node, \"span.count\")[0];\n        var d = ((c && DOM.scry(c, \"span.countValue\")[0]));\n        if (d) {\n            var b = ((h ? 0 : parseInt(DOM.getText(d), 10)));\n            var i = Math.max(0, ((b + a)));\n            var f = ((this.isTop() ? \"hidden\" : \"hiddenSubitem\"));\n            DOM.setContent(d, i);\n            ((e && CSS.conditionClass(this.node, f, !i)));\n            CSS.conditionClass(c, \"hidden_elem\", !i);\n            if (this.isTop()) {\n                var g = DOM.scry(this.node, \"div.linkWrap\")[0];\n                if (g) {\n                    CSS.conditionClass(g, \"noCount\", !i);\n                    CSS.conditionClass(g, \"hasCount\", i);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    showLoading: function() {\n        CSS.addClass(this.node, \"loading\");\n    },\n    hideLoading: function() {\n        CSS.removeClass(this.node, \"loading\");\n    },\n    showSelected: function() {\n        CSS.addClass(this.node, \"selectedItem\");\n        ((CSS.hasClass(this.node, \"hider\") && CSS.addClass(this._getExpanderParent(), \"expandedMode\")));\n    },\n    hideSelected: function() {\n        CSS.removeClass(this.node, \"selectedItem\");\n    },\n    showChildren: function() {\n        CSS.addClass(this.node, \"open\");\n    },\n    hideChildren: function() {\n        CSS.removeClass(this.node, \"open\");\n    },\n    _getExpanderParent: function() {\n        return Parent.byClass(this.node, \"expandableSideNav\");\n    },\n    _buildRegex: function(a) {\n        if (a.length) {\n            var b = a.map(function(c) {\n                if (((typeof c === \"string\"))) {\n                    return c.replace(/([^a-z0-9_])/gi, \"\\\\$1\");\n                }\n                 else if (c.regex) {\n                    return c.regex;\n                }\n                \n            ;\n            ;\n            });\n            return new RegExp(((((\"^(?:\" + b.join(\"|\"))) + \")$\")));\n        }\n    ;\n    ;\n    },\n    _findKeys: function(c) {\n        var e = /^(app|group|fl)_/;\n        var a = {\n        };\n        for (var b = 0; ((b < c.length)); b++) {\n            var d = e.test(c[b]);\n            if (((d && !a.numeric))) {\n                a.numeric = c[b];\n            }\n             else if (((!d && !a.text))) {\n                a.text = c[b];\n            }\n            \n        ;\n        ;\n            if (((a.numeric && a.text))) {\n                break;\n            }\n        ;\n        ;\n        };\n    ;\n        return a;\n    }\n};\nfunction TypeaheadCore(a) {\n    copy_properties(this, a);\n};\n;\nClass.mixin(TypeaheadCore, \"Arbiter\", {\n    events: [\"JSBNG__blur\",\"JSBNG__focus\",\"unselect\",],\n    keepFocused: true,\n    resetOnSelect: false,\n    resetOnKeyup: true,\n    setValueOnSelect: false,\n    queryTimeout: 250,\n    preventFocusChangeOnTab: false,\n    init: function(b, d, c) {\n        this.init = bagofholding;\n        this.data = b;\n        this.view = d;\n        this.root = c;\n        this.element = DOM.JSBNG__find(c, \".textInput\");\n        var a = DOM.scry(this.element, \"input\")[0];\n        if (a) {\n            this.element = a;\n        }\n    ;\n    ;\n        this.inputWrap = DOM.JSBNG__find(c, \"div.wrap\");\n        this.hiddenInput = DOM.JSBNG__find(c, \"input.hiddenInput\");\n        this.value = \"\";\n        this.selectedText = null;\n        if (((this.setValueOnSelect && CSS.hasClass(this.inputWrap, \"selected\")))) {\n            this.selectedText = this.getValue();\n        }\n    ;\n    ;\n        this.initView();\n        this.initData();\n        this.initEvents();\n        this.initToggle();\n        this._exclusions = [];\n    },\n    initView: function() {\n        this.view.subscribe(\"highlight\", function() {\n            this.element.JSBNG__focus();\n        }.bind(this));\n        this.view.subscribe(\"select\", function(a, b) {\n            this.select(b.selected);\n        }.bind(this));\n        this.view.subscribe(\"afterSelect\", function() {\n            this.afterSelect();\n        }.bind(this));\n    },\n    initData: function() {\n        this.data.subscribe(\"respond\", function(a, b) {\n            if (((b.forceDisplay || ((((b.value == this.getValue())) && !this.element.disabled))))) {\n                this.view.render(b.value, b.results, b.isAsync);\n            }\n        ;\n        ;\n        }.bind(this));\n        this.data.subscribe(\"activity\", function(a, b) {\n            this.fetching = b.activity;\n            if (!this.fetching) {\n                ((this.nextQuery && this.performQuery()));\n            }\n        ;\n        ;\n        }.bind(this));\n    },\n    initEvents: function() {\n        JSBNG__Event.listen(this.view.getElement(), {\n            mouseup: this.viewMouseup.bind(this),\n            mousedown: this.viewMousedown.bind(this)\n        });\n        var a = {\n            JSBNG__blur: bind(this, \"JSBNG__blur\"),\n            JSBNG__focus: bind(this, \"JSBNG__focus\"),\n            click: bind(this, \"click\"),\n            keyup: bind(this, \"keyup\"),\n            keydown: bind(this, \"keydown\")\n        };\n        if (ua.firefox()) {\n            a.text = a.keyup;\n        }\n    ;\n    ;\n        if (((ua.firefox() < 4))) {\n            a.keypress = a.keydown;\n            delete a.keydown;\n        }\n    ;\n    ;\n        JSBNG__Event.listen(this.element, a);\n        JSBNG__Event.listen(this.element, \"keypress\", this.keypress.bind(this));\n    },\n    initToggle: function() {\n        var b = this.root.parentNode;\n        var d = ((((CSS.getStyle(b, \"position\") != \"static\")) ? b : this.root));\n        var c = this.view;\n        var a = \"uiTypeaheadFocused\";\n        this.subscribe(\"JSBNG__focus\", function() {\n            c.show();\n            CSS.addClass(d, a);\n        });\n        this.subscribe(\"JSBNG__blur\", function() {\n            c.hide();\n            CSS.removeClass(d, a);\n        });\n    },\n    viewMousedown: function() {\n        this.selecting = true;\n    },\n    viewMouseup: function() {\n        this.selecting = false;\n    },\n    JSBNG__blur: function() {\n        if (this.selecting) {\n            this.selecting = false;\n            return;\n        }\n    ;\n    ;\n        this.inform(\"JSBNG__blur\");\n    },\n    click: function() {\n        this.element.select();\n    },\n    JSBNG__focus: function() {\n        this.checkValue();\n        this.inform(\"JSBNG__focus\");\n    },\n    keyup: function() {\n        if (((this.resetOnKeyup && !this.getValue()))) {\n            this.view.reset();\n        }\n    ;\n    ;\n        this.checkValue();\n    },\n    keydown: function(JSBNG__event) {\n        if (((!this.view.isVisible() || this.view.isEmpty()))) {\n            this.checkValue.bind(this).defer();\n            return;\n        }\n    ;\n    ;\n        switch (JSBNG__Event.getKeyCode(JSBNG__event)) {\n          case KEYS.TAB:\n            this.handleTab(JSBNG__event);\n            return;\n          case KEYS.UP:\n            this.view.prev();\n            break;\n          case KEYS.DOWN:\n            this.view.next();\n            break;\n          case KEYS.ESC:\n            this.view.reset();\n            break;\n          default:\n            this.checkValue.bind(this).defer();\n            return;\n        };\n    ;\n        JSBNG__event.kill();\n    },\n    keypress: function(JSBNG__event) {\n        if (((this.view.JSBNG__getSelection() && ((JSBNG__Event.getKeyCode(JSBNG__event) == KEYS.RETURN))))) {\n            this.view.select();\n            JSBNG__event.kill();\n        }\n    ;\n    ;\n    },\n    handleTab: function(JSBNG__event) {\n        this.view.select();\n        ((this.preventFocusChangeOnTab && JSBNG__event.kill()));\n    },\n    select: function(a) {\n        if (((a && this.setValueOnSelect))) {\n            this.setValue(a.text);\n            this.setHiddenValue(a.uid);\n            this.selectedText = a.text;\n            CSS.addClass(this.inputWrap, \"selected\");\n        }\n    ;\n    ;\n    },\n    afterSelect: function() {\n        ((this.resetOnSelect ? this.reset() : this.view.reset()));\n        ((this.keepFocused ? this.element.JSBNG__focus() : this.element.JSBNG__blur()));\n    },\n    unselect: function() {\n        if (this.setValueOnSelect) {\n            this.selectedText = null;\n            CSS.removeClass(this.inputWrap, \"selected\");\n        }\n    ;\n    ;\n        this.setHiddenValue();\n        this.inform(\"unselect\", this);\n    },\n    setEnabled: function(b) {\n        var a = ((b === false));\n        this.element.disabled = a;\n        CSS.conditionClass(this.root, \"uiTypeaheadDisabled\", a);\n    },\n    reset: function() {\n        this.unselect();\n        this.setValue();\n        ((!this.keepFocused && Input.reset(this.element)));\n        this.view.reset();\n        this.inform(\"reset\");\n    },\n    getElement: function() {\n        return this.element;\n    },\n    setExclusions: function(a) {\n        this._exclusions = a;\n    },\n    getExclusions: function() {\n        return this._exclusions;\n    },\n    setValue: function(a) {\n        this.value = this.nextQuery = ((a || \"\"));\n        Input.setValue(this.element, this.value);\n    },\n    setHiddenValue: function(a) {\n        this.hiddenInput.value = ((((a || ((a === 0)))) ? a : \"\"));\n        Arbiter.inform(\"Form/change\", {\n            node: this.hiddenInput\n        });\n    },\n    getValue: function() {\n        return Input.getValue(this.element);\n    },\n    getHiddenValue: function() {\n        return ((this.hiddenInput.value || \"\"));\n    },\n    checkValue: function() {\n        var c = this.getValue();\n        if (((c == this.value))) {\n            return;\n        }\n    ;\n    ;\n        if (((this.selectedText && ((this.selectedText != c))))) {\n            this.unselect();\n        }\n    ;\n    ;\n        var b = +new JSBNG__Date();\n        var a = ((b - this.time));\n        this.time = b;\n        this.value = this.nextQuery = c;\n        this.performQuery(a);\n    },\n    performQuery: function(a) {\n        if (this.selectedText) {\n            return;\n        }\n    ;\n    ;\n        a = ((a || 0));\n        if (((this.fetching && ((a < this.queryTimeout))))) {\n            this.data.query(this.nextQuery, true, this._exclusions);\n        }\n         else {\n            this.data.query(this.nextQuery, false, this._exclusions);\n            this.nextQuery = null;\n        }\n    ;\n    ;\n    }\n});\nfunction TypeaheadAreaCore(a) {\n    this.parent.construct(this, a);\n    this.matcher = new RegExp(((this.matcher + \"$\")));\n    this.preventFocusChangeOnTab = true;\n};\n;\nClass.extend(TypeaheadAreaCore, \"TypeaheadCore\");\nTypeaheadAreaCore.prototype = {\n    prefix: \"\",\n    suffix: \", \",\n    matcher: \"\\\\b[^,]*\",\n    click: bagofholding,\n    select: function(a) {\n        this.parent.select(a);\n        var e = this.element.value;\n        var d = ((((this.prefix + a.text)) + this.suffix));\n        this.expandBounds(e, d);\n        var b = e.substring(0, this.start);\n        var c = e.substring(this.end);\n        this.element.value = ((((b + d)) + c));\n        Input.setSelection(this.element, ((b.length + d.length)));\n    },\n    expandBounds: function(g, f) {\n        g = g.toLowerCase().trim();\n        f = f.toLowerCase();\n        var b, e, c, d;\n        var a = /\\s/;\n        e = g.substring(this.start, this.end);\n        c = f.indexOf(e);\n        b = this.start;\n        while (((((b >= 0)) && ((c >= 0))))) {\n            d = g.charAt(((b - 1)));\n            if (((!d || a.test(d)))) {\n                this.start = b;\n            }\n        ;\n        ;\n            e = ((d + e));\n            c = f.indexOf(e);\n            b--;\n        };\n    ;\n        e = g.substring(this.start, this.end);\n        c = f.indexOf(e);\n        b = this.end;\n        while (((((b <= g.length)) && ((c >= 0))))) {\n            d = g.charAt(b);\n            if (((!d || a.test(d)))) {\n                this.end = b;\n            }\n        ;\n        ;\n            e = ((e + d));\n            c = f.indexOf(e);\n            b++;\n        };\n    ;\n    },\n    getRawValue: function() {\n        var a = ((Input.JSBNG__getSelection(this.element).start || 0));\n        return this.parent.getValue().substring(0, a);\n    },\n    getValue: function() {\n        var a = ((this.matcher && this.matcher.exec(this.getRawValue())));\n        if (!a) {\n            return \"\";\n        }\n    ;\n    ;\n        this.start = a.index;\n        this.end = ((a.index + a[0].length));\n        return ((a[1] || a[0]));\n    }\n};\nfunction TypeaheadView(a, b) {\n    this.element = this.JSBNG__content = $(a);\n    copy_properties(this, b);\n};\n;\nClass.mixin(TypeaheadView, \"Arbiter\", {\n    events: [\"highlight\",\"render\",\"reset\",\"select\",],\n    renderer: \"basic\",\n    autoSelect: false,\n    init: function() {\n        this.init = bagofholding;\n        this.initializeEvents();\n        this.reset();\n    },\n    initializeEvents: function() {\n        JSBNG__Event.listen(this.element, {\n            mouseup: this.mouseup.bind(this),\n            mouseover: this.mouseover.bind(this)\n        });\n    },\n    getElement: function() {\n        return this.element;\n    },\n    mouseup: function(JSBNG__event) {\n        this.select(true);\n        JSBNG__event.kill();\n    },\n    mouseover: function(JSBNG__event) {\n        if (this.visible) {\n            this.highlight(this.getIndex(JSBNG__event));\n        }\n    ;\n    ;\n    },\n    reset: function(a) {\n        if (!a) {\n            this.disableAutoSelect = false;\n        }\n    ;\n    ;\n        this.index = -1;\n        this.items = [];\n        this.results = [];\n        this.value = \"\";\n        this.JSBNG__content.innerHTML = \"\";\n        this.inform(\"reset\");\n        return this;\n    },\n    getIndex: function(JSBNG__event) {\n        return this.items.indexOf(Parent.byTag(JSBNG__event.getTarget(), \"li\"));\n    },\n    JSBNG__getSelection: function() {\n        var a = ((this.results[this.index] || null));\n        return ((this.visible ? a : null));\n    },\n    isEmpty: function() {\n        return !this.results.length;\n    },\n    isVisible: function() {\n        return this.visible;\n    },\n    show: function() {\n        CSS.show(this.element);\n        this.visible = true;\n        return this;\n    },\n    hide: function() {\n        CSS.hide(this.element);\n        this.visible = false;\n        return this;\n    },\n    render: function(h, e, f) {\n        this.value = h;\n        if (!e.length) {\n            this.reset(true);\n            return;\n        }\n    ;\n    ;\n        var c = {\n            results: e,\n            value: h\n        };\n        this.inform(\"beforeRender\", c);\n        e = c.results;\n        var d = this.getDefaultIndex(e);\n        if (((((this.index > 0)) && ((this.index !== this.getDefaultIndex(this.results)))))) {\n            var a = this.results[this.index];\n            for (var b = 0, g = e.length; ((b < g)); ++b) {\n                if (((a.uid == e[b].uid))) {\n                    d = b;\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        this.results = e;\n        DOM.setContent(this.JSBNG__content, this.buildResults(e));\n        this.items = this.getItems();\n        this.highlight(d, false);\n        this.inform(\"render\", e);\n    },\n    getItems: function() {\n        return DOM.scry(this.JSBNG__content, \"li\");\n    },\n    buildResults: function(d) {\n        var c;\n        var a = null;\n        if (((typeof this.renderer == \"function\"))) {\n            c = this.renderer;\n        }\n         else {\n            c = TypeaheadRenderers[this.renderer];\n            a = this.renderer;\n        }\n    ;\n    ;\n        c = c.bind(this);\n        var b = d.map(function(e, f) {\n            return ((e.node || c(e, f)));\n        });\n        return $N(\"ul\", {\n            className: a\n        }, b);\n    },\n    getDefaultIndex: function(b) {\n        var a = ((this.autoSelect && !this.disableAutoSelect));\n        return ((((((this.index < 0)) && !a)) ? -1 : 0));\n    },\n    next: function() {\n        this.highlight(((this.index + 1)));\n    },\n    prev: function() {\n        this.highlight(((this.index - 1)));\n    },\n    highlight: function(a, b) {\n        ((this.selected && CSS.removeClass(this.selected, \"selected\")));\n        if (((a > ((this.items.length - 1))))) {\n            a = -1;\n        }\n         else if (((a < -1))) {\n            a = ((this.items.length - 1));\n        }\n        \n    ;\n    ;\n        if (((((a >= 0)) && ((a < this.items.length))))) {\n            this.selected = this.items[a];\n            CSS.addClass(this.selected, \"selected\");\n        }\n    ;\n    ;\n        this.index = a;\n        this.disableAutoSelect = ((a == -1));\n        if (((b !== false))) {\n            this.inform(\"highlight\", {\n                index: a,\n                selected: this.results[a]\n            });\n        }\n    ;\n    ;\n    },\n    select: function(a) {\n        var b = this.index;\n        var c = this.results[b];\n        if (c) {\n            this.inform(\"select\", {\n                index: b,\n                clicked: !!a,\n                selected: c\n            });\n            this.inform(\"afterSelect\");\n        }\n    ;\n    ;\n    }\n});\nadd_properties(\"TypeaheadBehaviors\", {\n    hoistFriends: function(a) {\n        var b = a.getView();\n        b.subscribe(\"beforeRender\", function(c, f) {\n            var g = [];\n            var d = [];\n            for (var e = 0; ((e < f.results.length)); ++e) {\n                var h = f.results[e];\n                if (((((h.type == \"user\")) && h.bootstrapped))) {\n                    d.push(h);\n                }\n                 else g.push(h);\n            ;\n            ;\n            };\n        ;\n            f.results = d.concat(g);\n        });\n    }\n});\nadd_properties(\"TypeaheadRenderers\", {\n    compact: function(c, d) {\n        var e = [];\n        var f = c.photo;\n        if (f) {\n            if (((f instanceof Array))) {\n                f = $N(\"span\", {\n                    className: \"splitpics clearfix\"\n                }, [$N(\"span\", {\n                    className: \"splitpic leftpic\"\n                }, [$N(\"img\", {\n                    alt: \"\",\n                    src: f[0]\n                }),]),$N(\"span\", {\n                    className: \"splitpic\"\n                }, [$N(\"img\", {\n                    alt: \"\",\n                    src: f[1]\n                }),]),]);\n            }\n             else f = $N(\"img\", {\n                alt: \"\",\n                src: f\n            });\n        ;\n        ;\n            e.push(f);\n        }\n    ;\n    ;\n        if (c.text) {\n            e.push($N(\"span\", {\n                className: \"text\"\n            }, [c.text,]));\n        }\n    ;\n    ;\n        var g = c.subtext;\n        var a = c.category;\n        if (((g || a))) {\n            var b = [];\n            ((g && b.push(g)));\n            ((((g && a)) && b.push(\" \\u00b7 \")));\n            ((a && b.push(a)));\n            e.push($N(\"span\", {\n                className: \"subtext\"\n            }, b));\n        }\n    ;\n    ;\n        return $N(\"li\", {\n            className: ((c.type || \"\"))\n        }, e);\n    }\n});");
// 5055
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[1], o7,o22);
// undefined
o7 = null;
// 14272
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"Un380\",]);\n}\n;\n;\nvar ChatQuietLinks = {\n    silence: function(b) {\n        if (((((ua.firefox() >= 4)) || ua.JSBNG__chrome()))) {\n            var a = JSBNG__Event.listen(JSBNG__document, \"mousemove\", function() {\n                this._removeLinkHrefs(b);\n                a.remove();\n            }.bind(this));\n        }\n    ;\n    ;\n    },\n    _removeLinkHrefs: function(d) {\n        var c = DOM.scry(d, \"a\");\n        for (var b = 0; ((b < c.length)); b++) {\n            var a = c[b].getAttribute(\"href\");\n            if (((!a || ((a.charAt(0) == \"#\"))))) {\n                c[b].removeAttribute(\"href\");\n            }\n        ;\n        ;\n        };\n    ;\n    }\n};\nvar OrderedFriendsList = ((window.OrderedFriendsList || (function() {\n    var a = [];\n    var b = {\n    };\n    var c = false;\n    return copy_properties(new Arbiter(), {\n        init: function(d) {\n            this.init = bagofholding;\n            a = d;\n            a.forEach(function(f, e) {\n                b[f] = e;\n            });\n            c = true;\n            this.inform(\"initialized\", {\n            }, Arbiter.BEHAVIOR_PERSISTENT);\n        },\n        contains: function(d) {\n            return ((d in b));\n        },\n        compare: function(d, e) {\n            var h = OrderedFriendsList.getRank(d);\n            var i = OrderedFriendsList.getRank(e);\n            if (((h !== i))) {\n                return ((h - i));\n            }\n        ;\n        ;\n            var f = ((((ChatUserInfos[d] || {\n            })).JSBNG__name || \"~\")).toLowerCase();\n            var g = ((((ChatUserInfos[e] || {\n            })).JSBNG__name || \"~\")).toLowerCase();\n            if (((f !== g))) {\n                return ((((f < g)) ? -1 : 1));\n            }\n        ;\n        ;\n            return 0;\n        },\n        getList: function() {\n            var d = $A(a);\n            d = d.filter(function(e) {\n                return ((!ChatUserInfos[e] || ((ChatUserInfos[e].type == \"friend\"))));\n            });\n            return d;\n        },\n        getRank: function(d) {\n            return ((((d in b)) ? b[d] : a.length));\n        },\n        isReady: function() {\n            return c;\n        }\n    });\n})()));\ndefine(\"ChatOnlineFriends\", [], function() {\n    var a = function() {\n    \n    };\n    a.prototype = {\n        chatFriends: {\n        },\n        chatStatuses: [\"chatOnline\",\"chatIdle\",\"chatMobile\",\"chatOffline\",],\n        _subscribe: function(JSBNG__event, b) {\n            this._tokens.push(Arbiter.subscribe(JSBNG__event, b));\n        },\n        clickHandler: function(JSBNG__event) {\n            var d = JSBNG__event.getTarget();\n            var c = Parent.byClass(d, \"uiListItem\");\n            if (c) {\n                var b = this.chatFriends[c.id];\n                if (Chat.isOnline()) {\n                    Chat.openTab(b.user_id, b.JSBNG__name, \"friend\", \"JSBNG__online_friends\");\n                }\n                 else goURI(b.uri);\n            ;\n            ;\n                return false;\n            }\n        ;\n        ;\n        },\n        JSBNG__onunload: function() {\n            this._tokens.forEach(function(b) {\n                Arbiter.unsubscribe(b);\n            });\n        },\n        _setStatus: function(b, c) {\n            if (CSS.hasClass(b, c)) {\n                return;\n            }\n        ;\n        ;\n            this.chatStatuses.forEach(function(d) {\n                CSS.conditionClass(b, d, ((d == c)));\n            });\n        },\n        initTypeahead: function(c, b) {\n            c.subscribe(\"reset\", function() {\n                CSS.show(b);\n            });\n            c.subscribe(\"query\", function(d, e) {\n                if (e.value) {\n                    CSS.hide(b);\n                }\n                 else CSS.show(b);\n            ;\n            ;\n            });\n        },\n        init: function(e, f, b, d, c) {\n            this._initShared(e, f, b, c);\n            this._facepile = d.firstChild;\n            ((this._faceFutures && this._hideAllFaces()));\n            this._faceFutures = [];\n            OrderedFriendsList.subscribe(\"initialized\", function() {\n                this._orderedFriends = OrderedFriendsList.getList();\n                this._hashedFriends = Object.from(this._orderedFriends);\n                this._subscribe([\"available-list/initialized\",\"buddylist/availability-changed\",\"chat-options/initialized\",], this.update.shield(this));\n            }.bind(this));\n            JSBNG__Event.listen(d, \"click\", this.clickHandlerClientRendering.bind(this));\n            AvailableList.update();\n        },\n        _initShared: function(d, e, b, c) {\n            this.maxElements = d;\n            this._faceTmpl = c;\n            this._tokens = [];\n            JSBNG__onleaveRegister(this.JSBNG__onunload.bind(this));\n            this.initTypeahead(e, DOM.JSBNG__find(b, \"div.fbFriendsOnlineFacepile\"));\n        },\n        update: function() {\n            var h = ge(\"chatFriendsOnline\");\n            if (h) {\n                CSS.conditionClass(h, \"isOffline\", !Chat.isOnline());\n            }\n        ;\n        ;\n            if (((!Chat.isOnline() || !AvailableList.isReady()))) {\n                return;\n            }\n        ;\n        ;\n            AvailableList.getAvailableIDs().forEach(function(i) {\n                if (!this._hashedFriends[i]) {\n                    this._orderedFriends.push(i);\n                    this._hashedFriends[i] = true;\n                }\n            ;\n            ;\n            }.bind(this));\n            var c = 0;\n            for (var f = 0; ((f < this._orderedFriends.length)); f++) {\n                var e = this._orderedFriends[f];\n                var b = AvailableList.get(e);\n                var d = this._faceFutures[f];\n                var g = ((c < this.maxElements));\n                if (((b && g))) {\n                    if (!d) {\n                        d = this._makeFace(f);\n                        this._faceFutures[f] = d;\n                    }\n                ;\n                ;\n                    c++;\n                }\n            ;\n            ;\n                this._updateFace(d, g, this._mapChatStatus(b));\n            };\n        ;\n        },\n        _mapChatStatus: function(b) {\n            switch (b) {\n              case AvailableList.OFFLINE:\n                return \"chatOffline\";\n              case AvailableList.IDLE:\n                return \"chatIdle\";\n              case AvailableList.ACTIVE:\n                return \"chatOnline\";\n              case AvailableList.MOBILE:\n                return \"chatMobile\";\n            };\n        ;\n        },\n        _updateFace: function(c, d, b) {\n            ((c && c(function(e) {\n                this._setStatus(e, b);\n                CSS.conditionShow(e, d);\n            }.bind(this))));\n        },\n        _makeFace: function(d) {\n            var e = null;\n            var b = null;\n            var c = this._orderedFriends[d];\n            ChatUserInfoManager.get(c, function(k) {\n                b = this._faceTmpl.render();\n                DataStore.set(b, \"friendID\", c);\n                var j = XHPTemplate.getNode(b, \"img\");\n                var l = j.cloneNode(false);\n                l.setAttribute(\"src\", k.thumbSrc);\n                DOM.replace(j, l);\n                var f = XHPTemplate.getNode(b, \"anchor\");\n                TooltipLink.setTooltipText(f, k.JSBNG__name);\n                ((e && e(b)));\n                var g = false;\n                for (var i = ((d + 1)); ((((i < this._orderedFriends.length)) && !g)); i++) {\n                    var h = this._faceFutures[i];\n                    var m = ((h && h()));\n                    if (m) {\n                        this._facepile.insertBefore(b, m);\n                        g = true;\n                    }\n                ;\n                ;\n                };\n            ;\n                if (!g) {\n                    this._facepile.appendChild(b);\n                }\n            ;\n            ;\n            }.bind(this));\n            return function faceFuture(f) {\n                if (f) {\n                    if (b) {\n                        f(b);\n                    }\n                     else e = f;\n                ;\n                }\n            ;\n            ;\n                return b;\n            };\n        },\n        clickHandlerClientRendering: function(JSBNG__event) {\n            var d = JSBNG__event.getTarget();\n            var b = Parent.byClass(d, \"uiFacepileItem\");\n            if (b) {\n                var c = DataStore.get(b, \"friendID\");\n                if (((c && Chat.isOnline()))) {\n                    ChatUserInfoManager.get(c, function(e) {\n                        Chat.openTab(c, e.JSBNG__name, \"friend\", \"JSBNG__online_friends\");\n                    });\n                    return false;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        },\n        _hideAllFaces: function() {\n            this._faceFutures.forEach(function(b) {\n                ((b && b(function(c) {\n                    DOM.remove(c);\n                })));\n            });\n        }\n    };\n    return a;\n});\nvar ChatSidebar = ((window.ChatSidebar || (function() {\n    var b;\n    var h = false;\n    var i = false;\n    var k = false;\n    var j = false;\n    var n;\n    var m;\n    var p;\n    var s;\n    var t;\n    var l;\n    var a = 32;\n    function c(v, u) {\n        if (((v === PresenceMessage.SHUTDOWN))) {\n            DOM.setContent(m, u.reason);\n            CSS.addClass(p, \"error\");\n        }\n         else if (((v === channel.ON_IDLE))) {\n            DOM.setContent(m, ChatConfig.get(\"channel_on_idle\"));\n            CSS.addClass(p, \"error\");\n        }\n         else if (((((v === channel.ON_CONNECT)) || ((v === PresenceMessage.RESTARTED))))) {\n            CSS.removeClass(p, \"error\");\n            DOM.empty(m);\n            f();\n        }\n        \n        \n    ;\n    ;\n        o();\n    };\n;\n    function f() {\n        if (!Chat.isOnline()) {\n            var u = [\"\\u003Ca href=\\\"#\\\" onclick=\\\"Chat.goOnline(); return false;\\\"\\u003E\",_tx(\"available\"),\"\\u003C/a\\u003E\",].join(\"\");\n            DOM.setContent(m, HTML(_tx(\"You are unavailable to chat. Let friends see you as {=available}?\", {\n                \"=available\": u\n            })));\n            CSS.addClass(p, \"offline\");\n        }\n         else {\n            CSS.removeClass(p, \"offline\");\n            DOM.empty(m);\n        }\n    ;\n    ;\n        o();\n    };\n;\n    function e() {\n        var u = ((((PresencePrivacy.getDefaultPresence() !== PresencePrivacy.ONLINE)) && ((PresencePrivacy.getWhitelist().length < this._maxItems))));\n        if (!u) {\n            CSS.removeClass(p, \"offline\");\n            DOM.empty(m);\n        }\n         else {\n            var v = $N(\"a\", {\n                href: \"#\"\n            }, _tx(\"Go Online\"));\n            JSBNG__Event.listen(v, \"click\", function() {\n                PresencePrivacy.setDefaultPresence(PresencePrivacy.ONLINE);\n                return false;\n            });\n            var w = ((PresencePrivacy.isOfflineToAll() ? _tx(\"You are offline. \") : _tx(\"You are offline to most friends. \")));\n            DOM.setContent(m, w);\n            DOM.appendContent(m, v);\n            CSS.addClass(p, \"offline\");\n        }\n    ;\n    ;\n        o();\n    };\n;\n    function d() {\n        if (i) {\n            i = false;\n            o();\n        }\n    ;\n    ;\n    };\n;\n    function g() {\n        if (((!ChatSidebar.isVisible() && j))) {\n            return;\n        }\n    ;\n    ;\n        k = false;\n        CSS.hide(p);\n        CSS.removeClass(JSBNG__document.documentElement, \"sidebarMode\");\n        n.hide();\n        s.getCore().reset();\n        Arbiter.inform(\"sidebar/hide\", ChatSidebar);\n    };\n;\n    function o() {\n        OrderedFriendsList.subscribe(\"initialized\", function() {\n            var v = ChatSidebar.shouldShowSidebar();\n            CSS.conditionClass(JSBNG__document.documentElement, \"sidebarCapable\", v);\n            if (((ChatSidebar.isEnabled() && v))) {\n                CSS.setStyle(p, \"height\", ((t.y + \"px\")));\n                q();\n                var u = t.y;\n                $A(p.childNodes).forEach(function(w) {\n                    if (((w !== b))) {\n                        u -= Vector2.getElementDimensions(w).y;\n                    }\n                ;\n                ;\n                });\n                CSS.setStyle(b, \"height\", ((u + \"px\")));\n                this._maxItems = Math.floor(((((u - 8)) / a)));\n                n.setNumTopFriends(this._maxItems);\n                s.getData().setMaxResults(this._maxItems);\n            }\n             else g();\n        ;\n        ;\n            j = true;\n        });\n    };\n;\n    function q() {\n        if (ChatSidebar.isVisible()) {\n            return;\n        }\n    ;\n    ;\n        k = true;\n        CSS.show(p);\n        CSS.addClass(JSBNG__document.documentElement, \"sidebarMode\");\n        n.show();\n        Arbiter.inform(\"sidebar/show\", ChatSidebar);\n    };\n;\n    function r() {\n        chatOptions.setSetting(\"sidebar_mode\", ChatSidebar.isEnabled());\n        new AsyncRequest(\"/ajax/chat/settings.php\").setHandler(bagofholding).setErrorHandler(bagofholding).setData({\n            sidebar_mode: ChatSidebar.isEnabled()\n        }).setAllowCrossPageTransition(true).send();\n    };\n;\n    return {\n        init: function(v, u, w) {\n            ChatSidebar.init = bagofholding;\n            p = v;\n            n = u;\n            s = w;\n            b = DOM.JSBNG__find(v, \"div.fbChatSidebarBody\");\n            m = DOM.JSBNG__find(v, \"div.fbChatSidebarMessage div.message\");\n            u.setScrollContainer(DOM.JSBNG__find(b, \"div.uiScrollableAreaWrap\"));\n            u.subscribe([\"render\",\"show\",\"hide\",], debounce(function() {\n                var x = u.getRoot();\n                var y = ScrollableArea.getInstance(x);\n                ((y && y.adjustGripper()));\n            }));\n            ChatQuietLinks.silence(v);\n            JSBNG__Event.listen(window, \"resize\", o);\n            Arbiter.subscribe(\"page_transition\", d);\n            Arbiter.subscribe(\"chat/visibility-changed\", f);\n            Arbiter.subscribe(\"chat/option-changed\", function(y, x) {\n                if (((x.JSBNG__name == \"sidebar_mode\"))) {\n                    h = !!chatOptions.getSetting(\"sidebar_mode\");\n                    o();\n                }\n            ;\n            ;\n            });\n            if (ChatConfig.get(\"blackbird\")) {\n                PresencePrivacy.subscribe(\"privacy-changed\", e);\n            }\n        ;\n        ;\n            w.subscribe([\"respond\",\"reset\",], function(x, y) {\n                if (k) {\n                    if (((((((y && y.value)) && ((y.value === w.getCore().getValue())))) && w.getView().isVisible()))) {\n                        n.hide();\n                    }\n                     else n.show();\n                ;\n                }\n            ;\n            ;\n            });\n            w.getData().subscribe(\"beforeQuery\", o);\n            if (ChatConfig.get(\"channel_disconnect_warning\")) {\n                Arbiter.subscribe([PresenceMessage.RESTARTED,PresenceMessage.SHUTDOWN,], c);\n                if (ChatConfig.get(\"channel_disconnect_warning_internal\")) {\n                    Arbiter.subscribe([channel.ON_CONNECT,channel.ON_IDLE,], c);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            Arbiter.subscribe(\"buddylist-nub/initialized\", function(x, y) {\n                JSBNG__Event.listen(y.getButton(), \"click\", function(JSBNG__event) {\n                    ChatSidebar.enable();\n                    return !ChatSidebar.shouldShowSidebar();\n                });\n            });\n            Arbiter.subscribe(\"chat-options/initialized\", function(x, y) {\n                h = !!y.getSetting(\"sidebar_mode\");\n                f();\n                Arbiter.inform(\"sidebar/initialized\", ChatSidebar, Arbiter.BEHAVIOR_PERSISTENT);\n            });\n        },\n        disable: function() {\n            if (!ChatSidebar.isEnabled()) {\n                return;\n            }\n        ;\n        ;\n            h = false;\n            r();\n            g();\n        },\n        enable: function() {\n            if (ChatSidebar.isEnabled()) {\n                return;\n            }\n        ;\n        ;\n            h = true;\n            r();\n            o();\n            !function() {\n                if (ChatSidebar.isVisible()) {\n                    s.getCore().getElement().JSBNG__focus();\n                }\n            ;\n            ;\n            }.defer();\n        },\n        hide: function() {\n            i = true;\n            g();\n        },\n        getRoot: function() {\n            return p;\n        },\n        isEnabled: function() {\n            return h;\n        },\n        isViewportCapable: function() {\n            t = Vector2.getViewportDimensions();\n            return ((t.x > ChatConfig.get(\"sidebar.minimum_width\")));\n        },\n        shouldShowSidebar: function() {\n            return ((((ChatSidebar.isViewportCapable() && !i)) && ((OrderedFriendsList.getList().length > ChatConfig.get(\"sidebar.min_friends\")))));\n        },\n        isVisible: function() {\n            return k;\n        },\n        resize: o,\n        toggle: function() {\n            ((ChatSidebar.isEnabled() ? ChatSidebar.disable() : ChatSidebar.enable()));\n        }\n    };\n})()));\nadd_properties(\"TypeaheadBehaviors\", {\n    chatTypeahead: function(c) {\n        var a = c.getElement();\n        var b = c.getView().getElement();\n        c.subscribe(\"JSBNG__focus\", function() {\n            c.getData().refreshData();\n        });\n        c.subscribe(\"JSBNG__blur\", function(d) {\n            c.getCore().reset();\n        });\n        c.subscribe(\"respond\", function(d, e) {\n            if (((e.value && ((e.value === c.getCore().getValue()))))) {\n                if (!e.results.length) {\n                    var f = $N(\"div\", {\n                        className: \"noResults\"\n                    }, _tx(\"Friend not found.\"));\n                    DOM.setContent(b, f);\n                }\n            ;\n            ;\n                CSS.addClass(a, \"hasValue\");\n            }\n        ;\n        ;\n        });\n        c.subscribe(\"reset\", function() {\n            CSS.removeClass(a, \"hasValue\");\n        });\n        c.subscribe(\"select\", function(d, e) {\n            Chat.openTab(e.selected.uid, e.selected.text, e.selected.type, \"typeahead\");\n            Chat.goOnline();\n        });\n        c.subscribe(\"highlight\", function(d, f) {\n            if (((f.index >= 0))) {\n                var i = c.getView().getItems()[f.index];\n                if (i) {\n                    var h = JSBNG__Rect(i);\n                    var e = i.offsetParent;\n                    var g = h.boundWithin(JSBNG__Rect(e)).getPositionVector();\n                    h.getPositionVector().sub(g).scrollElementBy(e);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        });\n    }\n});\nfunction ChatTypeaheadCore(a) {\n    this.parent.construct(this, a);\n};\n;\nClass.extend(ChatTypeaheadCore, \"TypeaheadCore\");\nChatTypeaheadCore.prototype = {\n    handleTab: bagofholding,\n    keydown: function(JSBNG__event) {\n        var a = JSBNG__Event.getKeyCode(JSBNG__event);\n        if (((a === KEYS.ESC))) {\n            this.reset.shield(this).defer();\n            return JSBNG__event.kill();\n        }\n    ;\n    ;\n        return this.parent.keydown(JSBNG__event);\n    }\n};\nfunction ChatTypeaheadDataSource(a) {\n    this.parent.construct(this, a);\n    this.persistOnRefresh = ((a.persistOnRefresh !== false));\n    this.showOfflineUsers = !!a.showOfflineUsers;\n};\n;\nClass.extend(ChatTypeaheadDataSource, \"DataSource\");\nChatTypeaheadDataSource.prototype = {\n    init: function() {\n        OrderedFriendsList.subscribe(\"initialized\", function() {\n            this.parent.init();\n            var a = Arbiter.subscribe([\"available-list/initialized\",\"buddylist/availability-changed\",], this._update.shield(this));\n            if (!this.persistOnRefresh) {\n                JSBNG__onleaveRegister(function() {\n                    Arbiter.unsubscribe(a);\n                });\n            }\n        ;\n        ;\n        }.bind(this));\n    },\n    bootstrap: function() {\n        this.parent.bootstrap();\n        if (this.showOfflineUsers) {\n            if (ChatUserInfoManager.hasAll()) {\n                this._update();\n            }\n             else {\n                ChatUserInfoManager.fetchAll();\n                this.inform(\"activity\", {\n                    activity: true\n                });\n                var a = ChatUserInfoManager.subscribe(\"updated\", function() {\n                    this.inform(\"activity\", {\n                        activity: false\n                    });\n                    this._update();\n                }.bind(this));\n                if (!this.persistOnRefresh) {\n                    JSBNG__onleaveRegister(function() {\n                        ChatUserInfoManager.unsubscribe(a);\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        }\n    ;\n    ;\n    },\n    _update: function() {\n        var c = this.value;\n        this.dirty();\n        var b = keys(ChatUserInfos).filter(function(d) {\n            return ((ChatUserInfos[d].type === \"friend\"));\n        });\n        b.sort(OrderedFriendsList.compare);\n        var a = [];\n        b.forEach(function(e) {\n            if (((e == Env.user))) {\n                return;\n            }\n        ;\n        ;\n            var d = AvailableList.get(e);\n            if (((!this.showOfflineUsers && ((d !== AvailableList.ACTIVE))))) {\n                return;\n            }\n        ;\n        ;\n            var f = ChatUserInfos[e];\n            a.push({\n                uid: e,\n                text: f.JSBNG__name,\n                tokens: f.additionalName,\n                localized_text: f.JSBNG__name,\n                additional_text: f.additionalName,\n                photo: f.thumbSrc,\n                availability: d,\n                type: f.type\n            });\n        }.bind(this));\n        if (a.length) {\n            this.addEntries(a);\n        }\n    ;\n    ;\n        this.value = c;\n        ((c && this.respond(c, this.buildUids(c), true)));\n    },\n    refreshData: function() {\n        AvailableList.update();\n    }\n};\nadd_properties(\"TypeaheadRenderers\", {\n    chat: function(a, b) {\n        var d = \"offline\";\n        switch (a.availability) {\n          case AvailableList.ACTIVE:\n            d = \"active\";\n            break;\n          case AvailableList.IDLE:\n            d = \"idle\";\n            break;\n          case AvailableList.MOBILE:\n            d = \"mobile\";\n            break;\n        };\n    ;\n        if (((ChatConfig.get(\"blackbird\") && !PresencePrivacy.allows(a.uid)))) {\n            d = \"invis\";\n        }\n    ;\n    ;\n        var c = [];\n        if (a.photo) {\n            c.push($N(\"img\", {\n                alt: \"\",\n                src: a.photo\n            }));\n        }\n    ;\n    ;\n        if (a.text) {\n            c.push($N(\"span\", {\n                className: \"text\"\n            }, [a.text,]));\n        }\n    ;\n    ;\n        c.push($N(\"i\", {\n            className: d\n        }));\n        return $N(\"li\", {\n            className: ((\"clearfix \" + d))\n        }, c);\n    }\n});");
// 14366
o5.clientWidth = 1265;
// undefined
o5 = null;
// 14310
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[12], o19,o22);
// undefined
o19 = null;
// 14374
JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_505[0]();
// 14621
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"HKq5g\",]);\n}\n;\n;\nvar ChannelRebuildReasons = {\n    Unknown: 0,\n    AsyncError: 1,\n    TooLong: 2,\n    Refresh: 3,\n    RefreshDelay: 4,\n    UIRestart: 5,\n    NeedSeq: 6,\n    PrevFailed: 7,\n    IFrameLoadGiveUp: 8,\n    IFrameLoadRetry: 9,\n    IFrameLoadRetryWorked: 10,\n    PageTransitionRetry: 11,\n    IFrameLoadMaxSubdomain: 12,\n    NoChannelInfo: 13,\n    NoChannelHost: 14,\n    ChannelUnknown: 100,\n    ChannelNoCUser: 101,\n    ChannelInvalidCUser: 102,\n    ChannelInvalidChanstr: 103,\n    ChannelChDistribTimeout: 104,\n    ChannelGetChannelOther: 105,\n    ChannelNodeShutdown: 106,\n    ChannelTermination: 107,\n    ChannelUserMismatch: 108,\n    ChannelUserMismatchShady: 109,\n    ChannelBadXs: 110,\n    ChannelSeqNeg: 111,\n    ChannelSeqTooBig: 112,\n    ChannelSeqTooSmall: 113,\n    ChannelUnexpectedJoin: 114,\n    ChannelInvalidXsCookie: 115,\n    ChannelRelocate: 116,\n    ChannelWrongPartition: 117\n};\nvar CrossDocument = {\n};\n(function() {\n    CrossDocument.setListener = function(eventHandler) {\n        if (window.JSBNG__postMessage) {\n            if (window.JSBNG__addEventListener) {\n                window.JSBNG__addEventListener(\"message\", eventHandler, false);\n            }\n             else window.JSBNG__onmessage = eventHandler;\n        ;\n        ;\n        }\n         else if (JSBNG__document.JSBNG__postMessage) {\n            JSBNG__document.JSBNG__addEventListener(\"message\", eventHandler, false);\n        }\n        \n    ;\n    ;\n    };\n    CrossDocument.mkPostMessage = function(targetWindow, targetDocument, msgHandler) {\n        if (window.JSBNG__postMessage) {\n            if (((\"object\" == typeof window.JSBNG__postMessage))) {\n                return function(message, origin) {\n                    targetWindow.JSBNG__postMessage(message, origin);\n                };\n            }\n             else return bind(targetWindow, targetWindow.JSBNG__postMessage)\n        ;\n        }\n         else if (JSBNG__document.JSBNG__postMessage) {\n            return bind(targetDocument, targetDocument.JSBNG__postMessage);\n        }\n         else return bind(targetWindow, msgHandler)\n        \n    ;\n    };\n    CrossDocument.targetOrigin = function(parent) {\n        if (((window.JSBNG__postMessage || JSBNG__document.JSBNG__postMessage))) {\n            var parentLoc = parent.JSBNG__location;\n            var parentHost = parentLoc.hostname;\n            if (((((parentHost == \"facebook.com\")) || ((parentHost.substring(((parentHost.length - 13))) == \".facebook.com\"))))) {\n                return ((((parentLoc.protocol + \"//\")) + parentLoc.host));\n            }\n        ;\n        ;\n        }\n         else return null\n    ;\n    };\n    var _handleMessage = function(msgCallback, msgStr) {\n        if (((!msgStr || ((msgStr.charAt(0) != \"{\"))))) {\n            return;\n        }\n    ;\n    ;\n        var msg = eval(((((\"(\" + msgStr)) + \")\")));\n        return msgCallback(msg);\n    };\n    CrossDocument.mkEventHandler = function(msgCallback) {\n        return function(JSBNG__event) {\n            JSBNG__event = ((JSBNG__event || window.JSBNG__event));\n            var domain = ((JSBNG__event.domain || JSBNG__event.origin));\n            if (((((((domain.substring(((domain.length - 13))) != \".facebook.com\")) && ((domain.substring(((domain.length - 15))) != \"://facebook.com\")))) && ((domain != \"facebook.com\"))))) {\n                return;\n            }\n        ;\n        ;\n            return _handleMessage(msgCallback, JSBNG__event.data);\n        };\n    };\n    CrossDocument.mkMessageHandler = function(msgCallback) {\n        return function(msgStr) {\n            return _handleMessage(msgCallback, msgStr);\n        };\n    };\n})();\nvar ChatUserInfos = ((window.ChatUserInfos || {\n}));\nvar FriendLists = ((window.FriendLists || {\n    get: function(a) {\n        var b = FriendLists._map;\n        if (!b[a]) {\n            b[a] = [];\n        }\n    ;\n    ;\n        return b[a];\n    },\n    set: function(a, b) {\n        if (((b === undefined))) {\n            return;\n        }\n    ;\n    ;\n        var c = FriendLists.get(a);\n        c.length = 0;\n        c.push.apply(c, $A(b));\n    },\n    _map: {\n    }\n}));\nvar ChatConfig = ((window.ChatConfig || (function() {\n    var a = {\n    };\n    return {\n        get: function(c, b) {\n            return ((((c in a)) ? a[c] : b));\n        },\n        set: function(b) {\n            if (((arguments.length > 1))) {\n                var c = {\n                };\n                c[b] = arguments[1];\n                b = c;\n            }\n        ;\n        ;\n            copy_properties(a, b);\n        },\n        getDebugInfo: function() {\n            return a;\n        }\n    };\n})()));\nvar PresencePrivacy = ((window.PresencePrivacy || (function() {\n    var c = \"/ajax/chat/privacy/settings.php\";\n    var b = \"/ajax/chat/privacy/default_presence.php\";\n    var a = -1;\n    var h = {\n    };\n    var g;\n    var j = {\n    };\n    var i;\n    var o = [];\n    var m = false;\n    function e(r, s) {\n        if (((r == Env.user))) {\n            return;\n        }\n    ;\n    ;\n        switch (s) {\n          case PresencePrivacy.WHITELISTED:\n        \n          case PresencePrivacy.BLACKLISTED:\n        \n          case PresencePrivacy.UNLISTED:\n            break;\n          default:\n            return;\n        };\n    ;\n        h[r] = s;\n        PresencePrivacy.inform(\"privacy-changed\");\n    };\n;\n    function f(r) {\n        switch (r) {\n          case PresencePrivacy.ONLINE:\n        \n          case PresencePrivacy.OFFLINE_WHITELIST:\n        \n          case PresencePrivacy.OFFLINE_TO_ALL:\n            break;\n          default:\n            return;\n        };\n    ;\n        g = r;\n        PresencePrivacy.inform(\"privacy-changed\");\n        PresencePrivacy.inform(\"privacy-default-presence-changed\");\n    };\n;\n    function p(s, r) {\n        o.push({\n            uri: s,\n            data: r\n        });\n        if (!m) {\n            next = o.shift();\n            q(next.uri, next.data);\n        }\n    ;\n    ;\n    };\n;\n    function q(s, r) {\n        m = true;\n        r.window_id = presence.getWindowID();\n        new AsyncRequest().setURI(s).setData(r).setHandler(n.bind(this, s, r)).setErrorHandler(k.bind(this)).setTransportErrorHandler(k.bind(this)).setFinallyHandler(l.bind(this)).setAllowCrossPageTransition(true).send();\n    };\n;\n    function n(t, r, s) {\n        if (((t === c))) {\n            PresencePrivacy.inform(\"privacy-availability-changed\", {\n                user: r.user,\n                availability: s.payload.user_availability\n            });\n            j[r.user] = r.setting;\n        }\n         else {\n            PresencePrivacy.inform(\"privacy-default-presence-response\");\n            i = r.presence;\n        }\n    ;\n    ;\n    };\n;\n    function k(r) {\n        if (((g !== i))) {\n            g = i;\n            PresencePrivacy.inform(\"privacy-default-presence-changed\");\n        }\n    ;\n    ;\n        copy_properties(h, j);\n        o = [];\n        PresencePrivacy.inform(\"privacy-changed\");\n    };\n;\n    function l(r) {\n        m = false;\n        if (((o.length > 0))) {\n            next = o.shift();\n            q(next.uri, next.data);\n        }\n    ;\n    ;\n    };\n;\n    function d(u, r) {\n        var t = r.obj;\n        if (((t.window_id === presence.getWindowID()))) {\n            return;\n        }\n    ;\n    ;\n        var s = t.data;\n        if (((t.JSBNG__event === \"access_control_entry\"))) {\n            e(s.target_id, s.setting);\n            j[s.target_id] = s.setting;\n        }\n         else if (((t.JSBNG__event === \"default_presence\"))) {\n            f(s.presence);\n            i = s.presence;\n        }\n        \n    ;\n    ;\n    };\n;\n    return copy_properties(new Arbiter(), {\n        WHITELISTED: 1,\n        BLACKLISTED: -1,\n        UNLISTED: 0,\n        ONLINE: 1,\n        OFFLINE_WHITELIST: 0,\n        OFFLINE_TO_ALL: -1,\n        init: function(r, s) {\n            g = i = r;\n            h = copy_properties({\n            }, s);\n            j = copy_properties({\n            }, s);\n            m = false;\n            this.inform(\"privacy-changed\");\n            this.inform(\"privacy-default-presence-changed\");\n            Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"privacy_changed\"), d.bind(this));\n        },\n        setDefaultPresence: function(s) {\n            i = g;\n            f(s);\n            var r = {\n                presence: s\n            };\n            p(b, r);\n            return s;\n        },\n        getDefaultPresence: function() {\n            return g;\n        },\n        get: function(r) {\n            return ((h[r] || PresencePrivacy.UNLISTED));\n        },\n        allows: function(r) {\n            if (((this.getDefaultPresence() === PresencePrivacy.OFFLINE_TO_ALL))) {\n                return false;\n            }\n        ;\n        ;\n            return ((((this.getDefaultPresence() === PresencePrivacy.ONLINE)) ? ((h[r] != PresencePrivacy.BLACKLISTED)) : ((h[r] == PresencePrivacy.WHITELISTED))));\n        },\n        set: function(s, t) {\n            j[s] = h[s];\n            e(s, t);\n            var r = {\n                user: s,\n                setting: t\n            };\n            p(c, r);\n            return t;\n        },\n        allow: function(r) {\n            if (((this.getDefaultPresence() === PresencePrivacy.OFFLINE_TO_ALL))) {\n                this.setDefaultPresence(PresencePrivacy.OFFLINE_WHITELIST);\n                var u = this.getWhitelist();\n                for (var s = 0; ((s < u.length)); ++s) {\n                    PresencePrivacy.set(u[s], PresencePrivacy.UNLISTED);\n                ;\n                };\n            ;\n            }\n        ;\n        ;\n            var t = ((((this.getDefaultPresence() === PresencePrivacy.ONLINE)) ? PresencePrivacy.UNLISTED : PresencePrivacy.WHITELISTED));\n            return this.set(r, t);\n        },\n        disallow: function(r) {\n            var s = ((((this.getDefaultPresence() === PresencePrivacy.ONLINE)) ? PresencePrivacy.BLACKLISTED : PresencePrivacy.UNLISTED));\n            return this.set(r, s);\n        },\n        getBlacklist: function() {\n            var s = [];\n            for (var r in h) {\n                if (((h[r] === PresencePrivacy.BLACKLISTED))) {\n                    s.push(r);\n                }\n            ;\n            ;\n            };\n        ;\n            return s;\n        },\n        getWhitelist: function() {\n            var s = [];\n            for (var r in h) {\n                if (((h[r] === PresencePrivacy.WHITELISTED))) {\n                    s.push(r);\n                }\n            ;\n            ;\n            };\n        ;\n            return s;\n        },\n        isOfflineToAll: function() {\n            return ((((((this.getDefaultPresence() === PresencePrivacy.OFFLINE_WHITELIST)) && ((this.getWhitelist().length === 0)))) || ((this.getDefaultPresence() === PresencePrivacy.OFFLINE_TO_ALL))));\n        },\n        getMapForTest: function() {\n            return h;\n        },\n        setMapForTest: function(r) {\n            h = r;\n        }\n    });\n})()));\nvar AvailableList = ((window.AvailableList || (function() {\n    var b = 5;\n    var e = 60000;\n    var f = \"/ajax/chat/buddy_list.php\";\n    var d = 5000;\n    var c = 1800000;\n    var a = 6656;\n    var zg = 0;\n    var zn = false;\n    var y = 0;\n    var zf = false;\n    var zd = null;\n    var u = null;\n    var k = null;\n    var t = 0;\n    var s = 0;\n    var j = null;\n    var ze = {\n    };\n    var r = false;\n    var zb = {\n    };\n    var zc = {\n    };\n    var x = {\n    };\n    var l = null;\n    var v = {\n        0: 2,\n        1: 1,\n        \"-1\": 0,\n        2: 3\n    };\n    var zh = {\n        0: -1,\n        1: 1,\n        2: 0,\n        3: 2\n    };\n    function o() {\n        return ((Chat.isOnline() ? ((zn ? zd : u)) : null));\n    };\n;\n    function h(zp, zt, zq, zs) {\n        if (((zp == Env.user))) {\n            return;\n        }\n    ;\n    ;\n        switch (zt) {\n          case AvailableList.OFFLINE:\n        \n          case AvailableList.IDLE:\n        \n          case AvailableList.ACTIVE:\n        \n          case AvailableList.MOBILE:\n            break;\n          default:\n            return;\n        };\n    ;\n        var zr = ((AvailableList.get(zp) != zt));\n        if (zq) {\n            zb[zp] = zt;\n            zc[zp] = ((zs || ((presence.getTime() + e))));\n            delete ze[zp];\n        }\n         else ze[zp] = zt;\n    ;\n    ;\n        if (zr) {\n            zg++;\n            if (!k) {\n                k = zi.defer();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    };\n;\n    function w(zq, zr, zp) {\n        l({\n            observer: presence.user,\n            observee: zq,\n            JSBNG__status: zr,\n            latency: zp\n        });\n    };\n;\n    function zk(zp) {\n        j = zp;\n        Arbiter.inform(\"buddylist/count-changed\", zp);\n    };\n;\n    function zl(zp) {\n        s = new JSBNG__Date();\n        x = Object.from(zp);\n    };\n;\n    function zj(zs) {\n        if (((presence.isShutdown || !Chat.isOnline()))) {\n            AvailableList._poller.JSBNG__stop();\n            return;\n        }\n    ;\n    ;\n        t = new JSBNG__Date();\n        var zq = false;\n        if (((((new JSBNG__Date() - s)) > c))) {\n            zq = true;\n        }\n    ;\n    ;\n        zf = true;\n        var zp = [];\n        for (var zr in ChatUserInfos) {\n            zp.push(zr);\n        ;\n        };\n    ;\n        zs.setHandler(za).setErrorHandler(z).setOption(\"suppressErrorAlerts\", true).setOption(\"retries\", 1).setData({\n            user: Env.user,\n            popped_out: presence.poppedOut,\n            available_user_info_ids: zp,\n            force_render: true,\n            fetch_mobile: zq\n        }).setURI(f).setAllowCrossPageTransition(true);\n    };\n;\n    function za(zs) {\n        var zr = zs.getPayload();\n        var zp = zr.buddy_list;\n        if (!zp) {\n            z(zs);\n            return;\n        }\n    ;\n    ;\n        presence.updateServerTime(zr.time);\n        AvailableList.updateTime = presence.getTime();\n        y = 0;\n        zf = false;\n        if (zp.forcedRender) {\n            AvailableList.haveFullList = true;\n        }\n    ;\n    ;\n        if (((zp.availableCount != null))) {\n            zk(zp.availableCount);\n        }\n    ;\n    ;\n        if (((zp.mobile_friends != null))) {\n            zl(zp.mobile_friends);\n        }\n    ;\n    ;\n        var zu = zp.userInfos;\n        if (zu) {\n            copy_properties(ChatUserInfos, zu);\n        }\n    ;\n    ;\n        var zq = zp.nowAvailableList;\n        var zv = zp.wasAvailableIDs;\n        for (var zt in ze) {\n            if (((AvailableList.get(zt) !== AvailableList.OFFLINE))) {\n                zv.push(zt);\n            }\n        ;\n        ;\n        };\n    ;\n        if (zv) {\n            zv.forEach(function(zw) {\n                if (((((!((zq && ((zw in zq)))) && ((ze[zw] != AvailableList.OFFLINE)))) && ((((zw in zb)) && ((zb[zw] == AvailableList.OFFLINE))))))) {\n                    w(zw, AvailableList.OFFLINE, ((((presence.getTime() + e)) - zc[zw])));\n                }\n            ;\n            ;\n                ze[zw] = AvailableList.OFFLINE;\n            });\n            zi.defer();\n        }\n    ;\n    ;\n        r = zp.userIsIdle;\n        ((zq && AvailableList.addLegacyAvailableList(zq)));\n        if (zp.newAvailableList) {\n            AvailableList.presenceData = zp.newAvailableList;\n            AvailableList.haveFullList = true;\n        }\n    ;\n    ;\n        zo();\n        Arbiter.inform(\"buddylist/fl-changed\", {\n            flMode: zp.flMode,\n            flData: zp.flData\n        });\n        presenceCookieManager.store();\n    };\n;\n    function z(zp) {\n        if (presence.checkMaintenanceError(zp)) {\n            return;\n        }\n    ;\n    ;\n        y++;\n        zf = false;\n        if (((y >= b))) {\n            zk(0);\n            Arbiter.inform(\"buddylist/update-error\");\n        }\n    ;\n    ;\n    };\n;\n    function n() {\n        var zp = {\n        };\n        AvailableList.getAvailableIDs().forEach(function(zq) {\n            zp[zq] = {\n                i: ((AvailableList.isIdle(zq) ? 1 : 0))\n            };\n        });\n        return zp;\n    };\n;\n    function zo() {\n        if (AvailableList.haveFullList) {\n            Arbiter.inform(\"buddylist/updated\");\n        }\n    ;\n    ;\n    };\n;\n    function zi() {\n        k = null;\n        if (AvailableList.haveFullList) {\n            zk(AvailableList.getAvailableIDs().length);\n        }\n    ;\n    ;\n        Arbiter.inform(\"buddylist/availability-changed\");\n    };\n;\n    function i(zp, zr) {\n        for (var zq in zp) {\n            var zt;\n            var zs;\n            if (zr) {\n                zt = v[zp[zq].ol];\n                zs = zp[zq].exp;\n            }\n             else if (!zp[zq]) {\n                zt = AvailableList.OFFLINE;\n            }\n             else if (zp[zq].i) {\n                zt = AvailableList.IDLE;\n            }\n             else if (zp[zq].m) {\n                zt = AvailableList.MOBILE;\n            }\n             else zt = AvailableList.ACTIVE;\n            \n            \n            \n        ;\n        ;\n            h(zq, zt, zr, zs);\n            ((((zp[zq] && zp[zq].fl)) && FriendLists.set(zq, zp[zq].fl)));\n        };\n    ;\n    };\n;\n    function q() {\n        zm();\n        if (Chat.isOnline()) {\n            AvailableList.update();\n        }\n         else g();\n    ;\n    ;\n    };\n;\n    function g() {\n        AvailableList.haveFullList = false;\n        t = 0;\n        s = 0;\n        j = null;\n        ze = {\n        };\n        zb = {\n        };\n        zc = {\n        };\n        x = {\n        };\n        zg++;\n        zi();\n    };\n;\n    function zm() {\n        ((AvailableList._poller && AvailableList._poller.setTimePeriod(o())));\n    };\n;\n    function m() {\n        var zp = {\n        };\n        Chat.getActiveFriendChats().forEach(function(zt) {\n            var zs = AvailableList.get(zt);\n            if (zs) {\n                zp[zt] = {\n                    i: ((((zs == AvailableList.IDLE)) ? 1 : 0)),\n                    m: ((((zs == AvailableList.MOBILE)) ? 1 : 0))\n                };\n            }\n        ;\n        ;\n        });\n        var zq = {\n            ac: j,\n            ut: parseInt(((AvailableList.updateTime * 10223)), 10),\n            ud: ((zd * 10238)),\n            lc: 0\n        };\n        var zr = AvailableList.getLegacyOverlay();\n        if (!is_empty(zr)) {\n            zq.uo = zr;\n        }\n    ;\n    ;\n        if (!is_empty(zp)) {\n            zq.al = zp;\n        }\n    ;\n    ;\n        return zq;\n    };\n;\n    function p(zq, zp) {\n        zp.chat_config = ChatConfig.getDebugInfo();\n        zp.available_list_debug_info = {\n        };\n        AvailableList.getAvailableIDs().forEach(function(zr) {\n            zp.available_list_debug_info[zr] = AvailableList.getDebugInfo(zr);\n        });\n    };\n;\n    return {\n        OFFLINE: 0,\n        IDLE: 1,\n        ACTIVE: 2,\n        MOBILE: 3,\n        haveFullList: false,\n        init: function(zw, zr, zv, zu, zs, zp, zq, zt) {\n            l = EagleEye.createLogger(\"presence-status\", ((presence.sitevars.BUDDY_STATUS_LOG_FRAC || a)));\n            AvailableList.updateTime = zw;\n            AvailableList.haveFullList = zr;\n            if (((zr && zt))) {\n                zl(zt);\n            }\n        ;\n        ;\n            i(zv, true);\n            AvailableList.addLegacyAvailableList(zp);\n            zd = zu;\n            u = zs;\n            AvailableList._poller = new Poller(o(), zj, true);\n            Arbiter.subscribe(\"chat-options/initialized\", zm);\n            zk(zq);\n            Arbiter.subscribe(JSLogger.DUMP_EVENT, p);\n            Arbiter.subscribe(\"presence/restarted\", AvailableList.update);\n            Arbiter.subscribe(\"chat/visibility-changed\", q);\n            Arbiter.subscribe(\"presence-cookie-manager/initialized\", function(zx, zy) {\n                zy.register(\"bl\", m);\n            });\n            if (ChatConfig.get(\"blackbird\")) {\n                PresencePrivacy.subscribe(\"privacy-changed\", zi);\n                PresencePrivacy.subscribe(\"privacy-availability-changed\", function(zy, zx) {\n                    this.set(zx.user, zx.availability);\n                }.bind(this));\n                PresencePrivacy.subscribe(\"privacy-default-presence-response\", AvailableList.update);\n            }\n        ;\n        ;\n            if (AvailableList.haveFullList) {\n                t = new JSBNG__Date();\n            }\n             else if (zn) {\n                AvailableList.update();\n            }\n            \n        ;\n        ;\n            Arbiter.inform(\"available-list/initialized\", AvailableList, Arbiter.BEHAVIOR_PERSISTENT);\n        },\n        get: function(zp) {\n            if (((zp == Env.user))) {\n                return AvailableList.ACTIVE;\n            }\n        ;\n        ;\n            var zq = AvailableList.OFFLINE;\n            if (((((zp in zb)) && ((((presence.getTime() < zc[zp])) || !((zp in ze))))))) {\n                zq = zb[zp];\n            }\n             else if (((zp in ze))) {\n                zq = ze[zp];\n            }\n            \n        ;\n        ;\n            if (((ChatConfig.get(\"blackbird\") && !PresencePrivacy.allows(zp)))) {\n                zq = AvailableList.OFFLINE;\n            }\n        ;\n        ;\n            if (((zq == AvailableList.OFFLINE))) {\n                if (x[zp]) {\n                    zq = AvailableList.MOBILE;\n                }\n            ;\n            }\n        ;\n        ;\n            return zq;\n        },\n        isUserIdle: function() {\n            return r;\n        },\n        isReady: function() {\n            return AvailableList.haveFullList;\n        },\n        set: function(zq, zr, zp) {\n            ((zp && FriendLists.set(zq, $A(zp))));\n            h(zq, zr, true);\n            ((window.presence && presence.doSync()));\n        },\n        update: function() {\n            if (((((new JSBNG__Date() - t)) < d))) {\n                ((!zf && zo.defer()));\n                return;\n            }\n        ;\n        ;\n            zn = true;\n            zm();\n            ((AvailableList._poller && AvailableList._poller.requestNow()));\n        },\n        getRev: function() {\n            return zg;\n        },\n        isIdle: function(zp) {\n            return ((AvailableList.get(zp) == AvailableList.IDLE));\n        },\n        getCount: function() {\n            return j;\n        },\n        getAvailableIDs: function() {\n            var zp, zq = [];\n            for (zp in ze) {\n                if (((AvailableList.get(zp) !== AvailableList.OFFLINE))) {\n                    zq.push(zp);\n                }\n            ;\n            ;\n            };\n        ;\n            for (zp in zb) {\n                if (((zp in ze))) {\n                    continue;\n                }\n            ;\n            ;\n                if (((AvailableList.get(zp) !== AvailableList.OFFLINE))) {\n                    zq.push(zp);\n                }\n            ;\n            ;\n            };\n        ;\n            for (zp in x) {\n                if (((((zp in ze)) || ((zp in zb))))) {\n                    continue;\n                }\n            ;\n            ;\n                zq.push(zp);\n            };\n        ;\n            return zq;\n        },\n        getLegacyOverlay: function() {\n            var zq = {\n            };\n            for (var zp in zb) {\n                if (((zc[zp] > presence.getTime()))) {\n                    zq[zp] = {\n                        exp: zc[zp],\n                        fl: FriendLists.get(zp),\n                        ol: zh[zb[zp]]\n                    };\n                }\n            ;\n            ;\n            };\n        ;\n            return zq;\n        },\n        addLegacyOverlay: function(zp) {\n            i(zp, true);\n            ((window.presence && presence.doSync()));\n        },\n        addLegacyAvailableList: function(zp) {\n            i(zp, false);\n        },\n        getDebugInfo: function(zp) {\n            var zq;\n            if (ChatUserInfos[zp]) {\n                zq = ChatUserInfos[zp].JSBNG__name;\n            }\n        ;\n        ;\n            return {\n                id: zp,\n                presence: ze[zp],\n                overlay: zb[zp],\n                overlayTime: zc[zp],\n                mobile: x[zp],\n                JSBNG__name: zq\n            };\n        }\n    };\n})()));\nif (!window.Chat) {\n    var Chat = {\n        openTab: function(a, b, d, c) {\n            if (((((window.External && External.Chat)) && External.Chat.openWindow))) {\n                External.Chat.openWindow(a);\n            }\n        ;\n        ;\n            this._trackOpenTabClick(a, c);\n            Chat._withComponent(\"chatDisplay\", function(e) {\n                e.focusTab(a, true, b, b, d);\n            });\n        },\n        _trackOpenTabClick: function(b, c) {\n            if (((((((((c && ((c == \"ordered_list\")))) || ((c == \"more_online_friends\")))) || ((c == \"JSBNG__online_friends\")))) || ((c == \"typeahead\"))))) {\n                var a = {\n                    target: b,\n                    source: c\n                };\n                new AsyncSignal(\"/ajax/chat/ct.php\", a).send();\n            }\n        ;\n        ;\n        },\n        openMultichatTab: function(d, b, a, e, f, c) {\n            Chat._withComponent(\"chatDisplay\", function(g) {\n                g.createMultichatTab(d, b, a, e, f, true, c);\n            });\n        },\n        loadTabFragile: function(b, c, a, d) {\n            Chat._withComponent(\"chatDisplay\", function(e) {\n                e.loadTabFragile(b, c, a, d);\n            });\n        },\n        openBuddyList: function() {\n            Chat._withComponent(\"buddyListNub\", function(a) {\n                a.show();\n            });\n        },\n        closeBuddyList: function() {\n            Chat._withComponent(\"buddyListNub\", function(a) {\n                a.hide();\n            });\n        },\n        toggleSidebar: function() {\n            Chat._withComponent(\"sidebar\", function(a) {\n                a.toggle();\n            });\n        },\n        goOnline: function(a) {\n            Arbiter.subscribe(\"chat-options/initialized\", function(JSBNG__event, b) {\n                if (Chat.isOnline()) {\n                    ((a && a()));\n                }\n                 else {\n                    if (a) {\n                        var c = Arbiter.subscribe(\"chat/visibility-changed\", function() {\n                            Arbiter.unsubscribe(c);\n                            a();\n                        });\n                    }\n                ;\n                ;\n                    b.sendVisibility(true);\n                }\n            ;\n            ;\n            });\n        },\n        isOnline: function() {\n            return ((window.chatOptions && chatOptions.visibility));\n        },\n        squelchTab: function(a, b) {\n            Chat._withComponent(\"chatDisplay\", function(c) {\n                c.setSquelchedTab(a, true);\n                c.closeTab(a);\n            });\n        },\n        unsquelchTab: function(a) {\n            Chat._withComponent(\"chatDisplay\", function(b) {\n                b.setSquelchedTab(a, false);\n            });\n        },\n        enterErrorMode: function(a) {\n            Chat._withComponent(\"buddyList\", function(b) {\n                b.enterErrorMode(a);\n            });\n        },\n        getActiveChats: function() {\n            if (!window.chatDisplay) {\n                return [];\n            }\n        ;\n        ;\n            return keys(chatDisplay.tabs);\n        },\n        getActiveFriendChats: function() {\n            var a = this.getActiveChats();\n            return a.filter(function(b) {\n                return ((chatDisplay.tabs[b] && ((chatDisplay.tabs[b].getPostType() == \"friend\"))));\n            });\n        },\n        _componentInitEvents: {\n            buddyList: \"buddylist/initialized\",\n            chatDisplay: \"chat-display/loaded\",\n            buddyListDisplay: \"buddylist-display/initialized\",\n            buddyListNub: \"buddylist-nub/initialized\",\n            sidebar: \"sidebar/initialized\"\n        },\n        _withComponent: function(b, a) {\n            Arbiter.subscribe(Chat._componentInitEvents[b], function(JSBNG__event, c) {\n                a(c);\n            });\n        }\n    };\n    Chat._withComponent(\"buddyList\", function(a) {\n        Chat._buddyList = a;\n    });\n    copy_properties(Chat, {\n        updateUserInfo: function(a) {\n            ((Chat._buddyList && Chat._buddyList.updateUserInfos(a)));\n        },\n        setUserInfo: function(a, b) {\n            ChatUserInfos[a] = b;\n            Chat._withComponent(\"buddyList\", function(c) {\n                c.updateItemDisplay(a);\n            });\n        }\n    });\n}\n;\n;\n(function() {\n    var a = JSLogger.create(\"channel0\");\n    window.ChannelManager = function(c, f, e, b, d) {\n        this.user = f;\n        this.iframeLoadMaxRetries = 1;\n        this.iframeLoadMaxSubdomain = 6;\n        this.expectResponseTimeout = 5000;\n        this.retryInterval = e;\n        this.channelConfig = b;\n        this._init(c, d);\n        Arbiter.subscribe(JSLogger.DUMP_EVENT, function(JSBNG__event, g) {\n            g.transportVersion = 1;\n        });\n    };\n    ChannelManager.CONN_LOG_INTERVAL = 10000;\n    ChannelManager.prototype = {\n        _init: function(d, f) {\n            this.channelManagerId = rand32();\n            this.config = {\n            };\n            this.channel = {\n            };\n            this.isActionRequest = true;\n            this.isReady = false;\n            this.isRebuilding = false;\n            this.iframeIsLoaded = false;\n            this.iframeEverLoaded = false;\n            this.iframeCheckFailedCount = 0;\n            this.shouldClearSubdomain = false;\n            this.subframe = d;\n            JSBNG__Event.listen(this.subframe, \"load\", this._iframeLoadCheck.bind(this));\n            this.JSBNG__postMessage = null;\n            var b = presenceCookieManager.getSubCookie(\"ch\");\n            if (f) {\n                this.iframeSubdomain = null;\n            }\n             else {\n                this.iframeSubdomain = 0;\n                if (((b && b.sub))) {\n                    for (var c = 0; ((c < b.sub.length)); c++) {\n                        if (!b.sub[c]) {\n                            this.iframeSubdomain = c;\n                            break;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    if (((c == b.sub.length))) {\n                        if (((((c == this.iframeLoadMaxSubdomain)) && URI().isSecure()))) {\n                            this.iframeSubdomain = null;\n                            this._sendDummyReconnect(ChannelRebuildReasons.IFrameLoadMaxSubdomain);\n                        }\n                         else this.iframeSubdomain = b.sub.length;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.handleIframeEvent = CrossDocument.mkEventHandler(this._handleIframeMessage.bind(this));\n            this.handleIframeMessage = CrossDocument.mkMessageHandler(this._handleIframeMessage.bind(this));\n            CrossDocument.setListener(this.handleIframeEvent.bind(this));\n            presenceCookieManager.register(\"ch\", this._getCookieInfo.bind(this));\n            if (((typeof window.JSBNG__onpageshow != \"undefined\"))) {\n                JSBNG__Event.listen(window, \"pagehide\", this._onUnload.bind(this));\n                JSBNG__Event.listen(window, \"pageshow\", this.rebuild.bind(this, ChannelRebuildReasons.Refresh));\n            }\n             else JSBNG__onunloadRegister(this._onUnload.bind(this));\n        ;\n        ;\n            this._connLogger = EagleEye.createLogger(\"channel-connectivity\", this.getConfig(\"CONNECTIVITY_SAMPLING\", 17478));\n            this._connTime = Env.start;\n            this._connT = 2000;\n            this._connectivity = {\n            };\n            (this._connSample = this._connSample.bind(this))();\n            (this._connLog = this._connLog.bind(this))();\n            var e = 0;\n            UserActivity.subscribe(function() {\n                if (((((new JSBNG__Date() - e)) > 3000))) {\n                    e = new JSBNG__Date();\n                    this.setActionRequest(true);\n                }\n            ;\n            ;\n            }.bind(this));\n        },\n        _connSample: function() {\n            var b = new JSBNG__Date(), c = ((this._connState || \"idle\"));\n            var d = ((b - this._connTime));\n            this._connAdd(c, d);\n            this._connTime = b;\n            JSBNG__setTimeout(this._connSample, ((1000 * ((1 + Math.JSBNG__random())))), false);\n        },\n        _connAdd: function(b, c) {\n            this._connectivity[b] = ((((this._connectivity[b] || 0)) + c));\n        },\n        _connLog: function() {\n            this._connLogger(this._connectivity);\n            this._connectivity = {\n            };\n            this._connT = Math.min(60000, ((2 * this._connT)));\n            JSBNG__setTimeout(this._connLog, this._connT, false);\n        },\n        sendIframeMessage: function(c) {\n            if (!this.JSBNG__postMessage) {\n                return;\n            }\n        ;\n        ;\n            var d = JSON.stringify(c);\n            try {\n                this.JSBNG__postMessage(d, this.targetOrigin);\n            } catch (b) {\n                a.error(\"iframe_msg_error\", {\n                    msg: d,\n                    error: b.toString()\n                });\n            };\n        ;\n        },\n        _handleIframeMessage: function(i) {\n            var h = this.channel.currentSeq;\n            var d = {\n                old_seq: h\n            };\n            if (((\"seq\" in i))) {\n                d.new_seq = i.seq;\n                d.seq_gap = ((i.seq - h));\n                this.channel.currentSeq = i.seq;\n                presence.doSync();\n            }\n        ;\n        ;\n            switch (i.t) {\n              case \"init\":\n                this._connState = null;\n                this.iframeLoaded();\n                break;\n              case \"log\":\n                break;\n              case \"reconnect\":\n                if (window.loaded) {\n                    a.error(((\"refresh_\" + i.reason)));\n                    this.rebuild(i.reason);\n                    this.channel.shutdownHandler(true);\n                }\n            ;\n            ;\n                break;\n              case \"connectivity\":\n                delete i.t;\n                if (((\"state\" in i))) {\n                    this._connState = i.state;\n                    delete i.state;\n                }\n            ;\n            ;\n                for (var g in i) {\n                    this._connAdd(g, i[g]);\n                ;\n                };\n            ;\n                break;\n              case \"fullReload\":\n                a.error(\"full_reload\", d);\n                presenceCookieManager.clear();\n                Arbiter.inform(\"channel/invalid_history\");\n                break;\n              case \"msg\":\n                var b = this.channel;\n                var j = i.ms;\n                var k = ((b.currentSeq - j.length));\n                for (var f = 0; ((f < j.length)); f++, k++) {\n                    if (((k >= h))) {\n                        var c = j[f];\n                        try {\n                            b.msgHandler(b.JSBNG__name, c);\n                        } catch (e) {\n                            a.error(\"msg_handling_error\", {\n                                type: c.type,\n                                error: e.toString()\n                            });\n                        };\n                    ;\n                    }\n                ;\n                ;\n                };\n            ;\n                break;\n              default:\n                a.error(\"unknown_msg_type\", {\n                    type: i.t\n                });\n                presence.permaShutdown();\n                this.JSBNG__stop();\n                break;\n            };\n        ;\n        },\n        _onUnload: function() {\n            this.shouldClearSubdomain = true;\n            presence.doSync(true);\n        },\n        addChannel: function(b, e, c, g, f, d) {\n            if (this.channel.JSBNG__name) {\n                a.error(\"addchannel_called_twice\");\n                return;\n            }\n        ;\n        ;\n            this.channel = {\n                JSBNG__name: b,\n                currentSeq: e,\n                msgHandler: c,\n                startHandler: g,\n                shutdownHandler: f,\n                restartHandler: d\n            };\n            presence.doSync();\n        },\n        _getCookieInfo: function() {\n            var c = {\n            };\n            if (this.config.host) {\n                c.h = this.config.host;\n                if (this.config.port) {\n                    c.p = this.config.port;\n                }\n            ;\n            ;\n                if (((null !== this.iframeSubdomain))) {\n                    var b = presenceCookieManager.getSubCookie(\"ch\");\n                    var f = ((((b && b.sub)) ? b.sub : []));\n                    var e = f.length;\n                    if (this.shouldClearSubdomain) {\n                        f[this.iframeSubdomain] = 0;\n                    }\n                     else {\n                        f[this.iframeSubdomain] = 1;\n                        for (var d = e; ((d <= this.iframeSubdomain)); d++) {\n                            if (!f[d]) {\n                                f[d] = 0;\n                            }\n                        ;\n                        ;\n                        };\n                    ;\n                    }\n                ;\n                ;\n                    c.sub = f;\n                }\n            ;\n            ;\n                c[this.channel.JSBNG__name] = this.channel.currentSeq;\n            }\n        ;\n        ;\n            c.ri = this.retryInterval;\n            return c;\n        },\n        getConfig: function(d, c) {\n            var b = this.channelConfig;\n            return ((((b && ((d in b)))) ? b[d] : c));\n        },\n        JSBNG__stop: function() {\n            this.stopped = true;\n            this.setReady(false);\n        },\n        setReady: function(b) {\n            this.isReady = b;\n            var c = {\n                type: \"isReady\",\n                isReady: b,\n                isActionRequest: this.isActionRequest\n            };\n            if (((b && this.isActionRequest))) {\n                this.isActionRequest = false;\n            }\n        ;\n        ;\n            if (b) {\n                c.channelName = this.channel.JSBNG__name;\n                c.currentSeq = this.channel.currentSeq;\n                c.channelManagerId = this.channelManagerId;\n                c.channelConfig = this.channelConfig;\n            }\n        ;\n        ;\n            this.sendIframeMessage(c);\n        },\n        setActionRequest: function(b) {\n            this.sendIframeMessage({\n                type: \"isActionRequest\",\n                isActionRequest: b\n            });\n        },\n        expectResponse: function() {\n            this.sendIframeMessage({\n                type: \"expectResponse\",\n                newTimeout: this.expectResponseTimeout\n            });\n        },\n        _iframeUrl: function(b, d, c) {\n            var e;\n            if (((null === this.iframeSubdomain))) {\n                e = \"\";\n            }\n             else {\n                e = this.iframeSubdomain;\n                e += ((URI().isSecure() ? \"-\" : \".\"));\n            }\n        ;\n        ;\n            return new URI().setDomain(((((e + b)) + \".facebook.com\"))).setPort(d).setPath(c).setSecure(URI().isSecure()).toString();\n        },\n        iframeLoad: function(b, d) {\n            this.isReady = d;\n            this.iframeIsLoaded = false;\n            this.config = b;\n            var f = this._iframeUrl(b.host, b.port, b.path);\n            JSBNG__clearTimeout(this._checkTimer);\n            this._checkTimer = this._iframeCheck.bind(this).defer(this.getConfig(\"IFRAME_LOAD_TIMEOUT\", 30000), false);\n            var e = null;\n            if (((!ua.ie() || ((ua.ie() < 8))))) {\n                try {\n                    e = this.subframe.contentDocument;\n                } catch (c) {\n                \n                };\n            }\n        ;\n        ;\n            if (e) {\n                try {\n                    e.JSBNG__location.replace(f);\n                } catch (c) {\n                    a.error(\"error_setting_location\", {\n                        error: c.toString()\n                    });\n                };\n            ;\n            }\n             else if (this.subframe.contentWindow) {\n                this.subframe.src = f;\n            }\n             else if (this.subframe.JSBNG__document) {\n                this.subframe.src = f;\n            }\n             else a.error(\"error_setting_subframe_url\");\n            \n            \n        ;\n        ;\n            a.debug(\"iframe_location\", {\n                url: f\n            });\n        },\n        _iframeLoadCheck: function() {\n            try {\n                this.subframe.contentWindow.JSBNG__document.body.innerHTML;\n            } catch (b) {\n                a.error(\"iframe_load_check_error\", {\n                    count: this.iframeCheckFailedCount,\n                    error: b.toString()\n                });\n            };\n        ;\n        },\n        iframeLoaded: function() {\n            if (!this.iframeIsLoaded) {\n                this.iframeIsLoaded = true;\n                this.JSBNG__postMessage = CrossDocument.mkPostMessage(this.subframe.contentWindow, this.subframe.contentDocument, this.subframe.contentWindow.channelUplink.handleParentMessage);\n                this.targetOrigin = \"*\";\n                this.setReady(this.isReady);\n                if (this.iframeCheckFailedCount) {\n                    this.channel.restartHandler(false);\n                    this._sendDummyReconnect(ChannelRebuildReasons.IFrameLoadRetryWorked);\n                }\n                 else this.channel.startHandler();\n            ;\n            ;\n                this.iframeCheckFailedCount = 0;\n                this.iframeEverLoaded = true;\n            }\n        ;\n        ;\n        },\n        _iframeCheck: function() {\n            delete this._checkTimer;\n            if (!this.iframeIsLoaded) {\n                this.iframeCheckFailedCount++;\n                var b = this.config;\n                this.config = {\n                };\n                presenceCookieManager.store();\n                if (((this.iframeCheckFailedCount <= this.iframeLoadMaxRetries))) {\n                    this.rebuild(ChannelRebuildReasons.IFrameLoadRetry);\n                }\n                 else {\n                    this.channel.shutdownHandler();\n                    this._sendDummyReconnect(ChannelRebuildReasons.IFrameLoadGiveUp);\n                }\n            ;\n            ;\n            }\n             else this.retryInterval = 0;\n        ;\n        ;\n        },\n        _sendDummyReconnect: function(c) {\n            var b = new AsyncRequest().setURI(\"/ajax/presence/reconnect.php\").setData({\n                reason: c,\n                iframe_loaded: this.iframeEverLoaded\n            }).setOption(\"suppressErrorHandlerWarning\", true).setOption(\"retries\", 1).setMethod(\"GET\").setReadOnly(true).setAllowCrossPageTransition(true);\n            ((b.specifiesWriteRequiredParams() && b.send()));\n        },\n        _rebuildResponse: function(d) {\n            var c = d.getPayload();\n            if (!c.user_channel) {\n                a.error(\"invalid_channel_name\", {\n                    JSBNG__name: this.channel.JSBNG__name\n                });\n                presence.permaShutdown();\n                this.JSBNG__stop();\n                return;\n            }\n        ;\n        ;\n            var b = c.user_channel;\n            a.debug(\"rebuild_response\", {\n                channel: b,\n                seq: c.seq,\n                host: c.host,\n                port: c.port\n            });\n            this.channel.currentSeq = c.seq;\n            this.isRebuilding = false;\n            if (((((c.path != this.config.path)) || ((c.host != this.config.host))))) {\n                this.iframeLoad(c, true);\n            }\n             else this.setReady(true);\n        ;\n        ;\n            presenceCookieManager.store();\n            if (((typeof chatOptions != \"undefined\"))) {\n                chatOptions.setVisibility(c.visibility);\n            }\n        ;\n        ;\n            this.channel.restartHandler(true);\n        },\n        _retryRebuild: function(d, b) {\n            var e = this.getConfig(\"MAX_RETRY_INTERVAL\", 60000);\n            var f = this.getConfig(\"MIN_RETRY_INTERVAL\", 10000);\n            if (b) {\n                this.retryInterval = e;\n            }\n             else if (((this.retryInterval == 0))) {\n                this.retryInterval = f;\n            }\n             else this.retryInterval = Math.min(e, ((this.retryInterval * 2)));\n            \n        ;\n        ;\n            var c = ((((this.retryInterval * ((23979 + ((Math.JSBNG__random() * 23997)))))) | 0));\n            a.warn(\"manager_retrying\", {\n                delay: c\n            });\n            JSBNG__setTimeout(this._rebuildSend.bind(this, d), this.retryInterval, false);\n        },\n        _rebuildError: function(b, c) {\n            this.channel.shutdownHandler(true);\n            a.error(\"rebuild_error\", {\n                error: c.getErrorDescription()\n            });\n            if (presence.checkMaintenanceError(c)) {\n                a.warn(\"mgr_maint_check_giveup\");\n            }\n             else if (presence.checkLoginError(c)) {\n                if (presence.inPopoutWindow) {\n                    this._retryRebuild(ChannelRebuildReasons.PrevFailed, true);\n                }\n                 else a.warn(\"mgr_login_check_giveup\");\n            ;\n            ;\n            }\n             else this._retryRebuild(ChannelRebuildReasons.PrevFailed, false);\n            \n        ;\n        ;\n        },\n        _rebuildTransportError: function(b, c) {\n            this.channel.shutdownHandler(true);\n            a.error(\"rebuild_transport_error\", {\n                error: c.getErrorDescription()\n            });\n            this._retryRebuild(b, false);\n        },\n        _rebuildSend: function(c) {\n            if (!presence.hasUserCookie(true)) {\n                return;\n            }\n        ;\n        ;\n            if (((typeof c != \"number\"))) {\n                c = ChannelRebuildReasons.Unknown;\n            }\n        ;\n        ;\n            a.debug(\"sending_rebuild\");\n            var b = new AsyncRequest().setURI(\"/ajax/presence/reconnect.php\").setData({\n                reason: c,\n                iframe_loaded: this.iframeEverLoaded\n            }).setHandler(this._rebuildResponse.bind(this)).setErrorHandler(this._rebuildError.bind(this, c)).setTransportErrorHandler(this._rebuildTransportError.bind(this, c)).setOption(\"suppressErrorAlerts\", true).setOption(\"retries\", 1).setMethod(\"GET\").setReadOnly(true).setAllowCrossPageTransition(true);\n            return ((b.specifiesWriteRequiredParams() && b.send()));\n        },\n        rebuild: function(b) {\n            if (this.stopped) {\n                return;\n            }\n        ;\n        ;\n            if (this.isRebuilding) {\n                a.debug(\"already_rebuilding\");\n                return;\n            }\n        ;\n        ;\n            this.setReady(false);\n            this.isRebuilding = true;\n            a.debug(\"rebuilding\");\n            if (((b == ChannelRebuildReasons.RefreshDelay))) {\n                this.retryInterval = this.channelConfig.MAX_RETRY_INTERVAL;\n            }\n        ;\n        ;\n            JSBNG__setTimeout(this._rebuildSend.bind(this, b), this.retryInterval, false);\n        }\n    };\n}());\nfunction TinyPresence(g, c, b, a, e, d, f) {\n    this.user = g;\n    this.JSBNG__name = c;\n    this.firstName = b;\n    this.alias = a;\n    this.sitevars = f;\n    this.popoutURL = ((env_get(\"www_base\") + \"presence/popout.php\"));\n    this.updateServerTime(e);\n    this.pageLoadTime = this.getTime();\n    this._init(d);\n};\n;\nTinyPresence.prototype = {\n    cookiePollTime: 2000,\n    popoutHeartbeatTime: 1000,\n    popoutHeartbeatAllowance: 4000,\n    popoutHeartbeatFirstAllowance: 15000,\n    shutdownDelay: 5000,\n    restartDelay: 3000,\n    _init: function(a) {\n        this.stateStorers = [];\n        this.stateLoaders = [];\n        this._syncTimeout = null;\n        this.cookiePoller = null;\n        this.heartbeat = null;\n        this.stateUpdateTime = 0;\n        this.loaded = false;\n        this.isShutdown = false;\n        this.isShuttingDown = false;\n        this.isRestarting = false;\n        this.isPermaShutdown = false;\n        this.shutdownTime = 0;\n        this.justPoppedOut = false;\n        this.syncPaused = 0;\n        this.poppedOut = a;\n        this.inPopoutWindow = a;\n        presenceCookieManager.register(\"state\", this._getCookieData.bind(this));\n        Arbiter.subscribe(\"page_transition\", this.checkRebuild.bind(this));\n        this.load();\n    },\n    init: function() {\n        var b = {\n            ON_CONNECT: function() {\n                Arbiter.inform(PresenceMessage.STARTED, {\n                    sender: this\n                });\n                this._restart(0);\n            },\n            SHUTDOWN: function(d, c) {\n                switch (cause) {\n                  case channel.HINT_AUTH:\n                    return this.loginShutdown();\n                  case channel.HINT_CONN:\n                    return this.connectionShutdown();\n                  case channel.HINT_MAINT:\n                    return this.maintenanceShutdown();\n                  default:\n                    return this.permaShutdown();\n                };\n            ;\n            }\n        };\n        for (var a in b) {\n            Arbiter.subscribe(channel[a], b[a].bind(this));\n        ;\n        };\n    ;\n    },\n    getWindowID: function() {\n        if (!this.windowID) {\n            this.windowID = ((rand32() + 1));\n        }\n    ;\n    ;\n        return this.windowID;\n    },\n    updateServerTime: function(a) {\n        this.timeSkew = ((new JSBNG__Date().getTime() - a));\n    },\n    getTime: function() {\n        return ((new JSBNG__Date().getTime() - this.timeSkew));\n    },\n    debug: function(a) {\n    \n    },\n    warn: function(a) {\n        this.logError(((\"13003:warning:\" + a)));\n    },\n    error: function(a) {\n        this.logError(((\"13002:error:\" + a)));\n    },\n    logError: function(a) {\n        ((window.EagleEye && EagleEye.log(\"realtime-error\", {\n            data: a\n        })));\n    },\n    load: function() {\n        var b = presenceCookieManager.getSubCookie(\"state\");\n        if (!b) {\n            this.debug(\"presence: got null state cookie, loading with current state\");\n            this._load(this._getCookieData());\n            return;\n        }\n    ;\n    ;\n        try {\n            this._load(b);\n        } catch (a) {\n            this.error(((\"presence: got load exception: \" + a.toString())));\n            this._load(this._getCookieData());\n        };\n    ;\n    },\n    _load: function(b) {\n        this.syncPaused++;\n        this.stateUpdateTime = verifyNumber(b.ut);\n        this.popoutTime = verifyNumber(b.pt);\n        this.poppedOut = !!b.p;\n        if (this.poppedOut) {\n            if (this.inPopoutWindow) {\n                if (!this.heartbeat) {\n                    this.heartbeat = JSBNG__setInterval(this._popoutHeartbeat.bind(this), this.popoutHeartbeatTime);\n                }\n            ;\n            }\n        ;\n        ;\n        }\n         else if (this.inPopoutWindow) {\n            if (!this.loaded) {\n                this.poppedOut = true;\n                this.doSync();\n            }\n        ;\n        ;\n        }\n         else this.justPoppedOut = true;\n        \n    ;\n    ;\n        if (((!this.inPopoutWindow && !this.cookiePoller))) {\n            this.cookiePoller = JSBNG__setInterval(this._pollCookie.bind(this), this.cookiePollTime);\n        }\n    ;\n    ;\n        this.state = b;\n        for (var a = 0; ((a < this.stateLoaders.length)); a++) {\n            this.stateLoaders[a](b);\n        ;\n        };\n    ;\n        this.syncPaused--;\n        this._loaded();\n    },\n    _loaded: function() {\n        this.loaded = true;\n    },\n    _pollCookie: function() {\n        var e = presenceCookieManager.getSubCookie(\"state\");\n        if (!e) {\n            return;\n        }\n    ;\n    ;\n        var d = this.popoutTime;\n        if (((e.ut > this.stateUpdateTime))) {\n            this.load(e);\n            return;\n        }\n    ;\n    ;\n        if (((this.poppedOut && !this.inPopoutWindow))) {\n            var a = verifyNumber(e.pt);\n            var b = ((new JSBNG__Date().getTime() - a));\n            var c = ((this.popoutHeartbeatTime + this.popoutHeartbeatAllowance));\n            if (this.justPoppedOut) {\n                if (((a == d))) {\n                    c += this.popoutHeartbeatFirstAllowance;\n                }\n                 else this.justPoppedOut = false;\n            ;\n            }\n        ;\n        ;\n            this.popoutTime = a;\n            if (((b > c))) {\n                this.poppedOut = false;\n                this.doSync();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _popoutHeartbeat: function() {\n        this._pollCookie();\n        if (this.poppedOut) {\n            presenceCookieManager.store();\n        }\n    ;\n    ;\n    },\n    _getCookieData: function() {\n        var b = {\n            p: ((this.poppedOut ? 1 : 0)),\n            ut: this.stateUpdateTime,\n            pt: ((this.inPopoutWindow ? new JSBNG__Date().getTime() : this.popoutTime))\n        };\n        for (var a = 0; ((a < this.stateStorers.length)); a++) {\n            b = this.stateStorers[a](b);\n        ;\n        };\n    ;\n        this.state = b;\n        return this.state;\n    },\n    doSync: function(a) {\n        if (this.syncPaused) {\n            return;\n        }\n    ;\n    ;\n        if (a) {\n            this._doSync();\n        }\n         else if (!this._syncTimeout) {\n            this._syncTimeout = this._doSync.bind(this).defer();\n        }\n        \n    ;\n    ;\n    },\n    _doSync: function() {\n        JSBNG__clearTimeout(this._syncTimeout);\n        this._syncTimeout = null;\n        this.stateUpdateTime = new JSBNG__Date().getTime();\n        presenceCookieManager.store();\n        this._load(this.state);\n    },\n    pauseSync: function() {\n        this.syncPaused++;\n    },\n    resumeSync: function() {\n        this.syncPaused--;\n        this.doSync();\n    },\n    handleMsg: function(a, b) {\n        this._handleMsg.bind(this, a, b).defer();\n    },\n    _handleMsg: function(a, b) {\n        if (((typeof b == \"string\"))) {\n            if (((b == \"shutdown\"))) {\n                this.connectionShutdown();\n            }\n             else if (((b == \"restart\"))) {\n                if (this.isShutdown) {\n                    this.restart();\n                }\n            ;\n            }\n            \n        ;\n        ;\n            return;\n        }\n    ;\n    ;\n        if (this.isShutdown) {\n            return false;\n        }\n    ;\n    ;\n        if (!b.type) {\n            return;\n        }\n    ;\n    ;\n        Arbiter.inform(PresenceMessage.getArbiterMessageType(b.type), {\n            sender: this,\n            channel: a,\n            obj: b\n        });\n    },\n    checkRebuild: function() {\n        if (!window.channel_manager) {\n            if (((this.isShutdown && !this.isPermaShutdown))) {\n                channelManager.rebuild(ChannelRebuildReasons.PageTransitionRetry);\n            }\n        ;\n        }\n    ;\n    ;\n    },\n    getErrorDescription: function(a) {\n        var c = a.getError();\n        var b = a.getErrorDescription();\n        if (!b) {\n            b = _tx(\"An error occurred.\");\n        }\n    ;\n    ;\n        if (((c == 1357001))) {\n            b = _tx(\"Your session has timed out. Please log in.\");\n        }\n    ;\n    ;\n        return b;\n    },\n    checkLoginError: function(a) {\n        var b = a.getError();\n        if (((((((b == 1357001)) || ((b == 1357004)))) || ((b == 1348009))))) {\n            this.loginShutdown();\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    checkMaintenanceError: function(a) {\n        if (((a.getError() == 1356007))) {\n            this.maintenanceShutdown();\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    permaShutdown: function() {\n        this.isPermaShutdown = true;\n        var a = _tx(\"Facebook {Chat} is experiencing technical problems.\", {\n            Chat: _tx(\"Chat\")\n        });\n        this.shutdown(false, a, \"perma_shutdown\");\n    },\n    loginShutdown: function() {\n        var a = _tx(\"Your session has timed out. Please log in.\");\n        this.shutdown(false, a, \"login_shutdown\");\n    },\n    connectionShutdown: function(b) {\n        var a = _tx(\"Could not connect to Facebook {Chat} at this time.\", {\n            Chat: _tx(\"Chat\")\n        });\n        this.shutdown(b, a, \"connection_shutdown\");\n    },\n    maintenanceShutdown: function() {\n        var a = _tx(\"Facebook {Chat} is down for maintenance at this time.\", {\n            Chat: _tx(\"Chat\")\n        });\n        this.shutdown(false, a, \"maintenance_shutdown\");\n        channelManager.JSBNG__stop();\n    },\n    versionShutdown: function() {\n        var a = _tx(\"Please refresh the page to get the latest version of Facebook {Chat}.\", {\n            Chat: _tx(\"Chat\")\n        });\n        this.shutdown(false, a, \"version_shutdown\");\n        channelManager.JSBNG__stop();\n    },\n    shutdown: function(d, c, a) {\n        this.isRestarting = false;\n        this.isShuttingDown = true;\n        var b = new JSBNG__Date().getTime();\n        this.shutdownTime = b;\n        if (!d) {\n            this._shutdown(c, 0, a);\n        }\n         else JSBNG__setTimeout(this._shutdown.bind(this, c, b, a), this.shutdownDelay, false);\n    ;\n    ;\n    },\n    _shutdown: function(b, c, a) {\n        if (((!this.isShuttingDown && ((c == this.shutdownTime))))) {\n            return;\n        }\n    ;\n    ;\n        if (((c && this.isShutdown))) {\n            return;\n        }\n    ;\n    ;\n        if (((((typeof b != \"string\")) || !b))) {\n            b = _tx(\"Facebook {Chat} is experiencing technical problems.\", {\n                Chat: _tx(\"Chat\")\n            });\n        }\n    ;\n    ;\n        if (((((typeof a != \"string\")) || !a))) {\n            a = \"undefined\";\n        }\n    ;\n    ;\n        this.warn(((\"presence:displaying_shutdown:\" + a)));\n        if (this.isShutdown) {\n            return;\n        }\n    ;\n    ;\n        this.logError(((\"13001:shutdown:presence:\" + a)));\n        this.isShutdown = true;\n        Arbiter.inform(PresenceMessage.SHUTDOWN, {\n            sender: this,\n            reason: b\n        });\n    },\n    restart: function(a) {\n        this.isShuttingDown = false;\n        this.isRestarting = true;\n        if (!a) {\n            this._restart(0);\n        }\n         else this._restart.bind(this, this.shutdownTime).defer(this.restartDelay, false);\n    ;\n    ;\n    },\n    _restart: function(a) {\n        if (((!this.isRestarting || ((a && ((a != this.shutdownTime))))))) {\n            return;\n        }\n    ;\n    ;\n        this.debug(\"presence: restarting\");\n        this.isShutdown = false;\n        this.load();\n        Arbiter.inform(PresenceMessage.RESTARTED, {\n            sender: this\n        });\n    },\n    start: function() {\n        Arbiter.inform(PresenceMessage.STARTED, {\n            sender: this\n        });\n    },\n    registerStateStorer: function(a) {\n        this.stateStorers.push(a);\n    },\n    registerStateLoader: function(a) {\n        this.stateLoaders.push(a);\n    },\n    hasUserCookie: function(a) {\n        var b = ((this.user == getCookie(\"c_user\")));\n        if (((!b && a))) {\n            this.permaShutdown();\n        }\n    ;\n    ;\n        return b;\n    }\n};\nfunction Presence(g, c, b, a, e, d, f) {\n    this.parent.construct(this, g, c, b, a, e, d, f);\n};\n;\nClass.extend(Presence, \"TinyPresence\");\nPresence.prototype = {\n    minWidth: 100,\n    minHeight: 100,\n    defWidth: 900,\n    defHeight: 650,\n    defX: 30,\n    defY: 30,\n    _init: function(b) {\n        if (!b) {\n            this.holder = $(\"fbDockChat\");\n        }\n         else this.holder = JSBNG__document.body;\n    ;\n    ;\n        this.parent._init(b);\n        this.popoutWidth = this.defWidth;\n        this.popoutHeight = this.defHeight;\n        this.popoutClicked = false;\n        this.popinClicked = false;\n        if (this.inPopoutWindow) {\n            JSBNG__onbeforeunloadRegister(this.popin.bind(this, false));\n            JSBNG__onunloadRegister(this.popin.bind(this, false));\n        }\n    ;\n    ;\n        if (this.inPopoutWindow) {\n            JSBNG__Event.listen(window, \"resize\", this._windowOnResize.bind(this));\n            JSBNG__Event.listen(window, \"keypress\", this._documentKeyPress.bind(this));\n        }\n    ;\n    ;\n        var c = ua.safari();\n        this.isSafari2 = ((c && ((c < 500))));\n        var a = ua.firefox();\n        this.isFF2 = ((a && ((a < 3))));\n        this.isWindows = ua.windows();\n        if (this.inPopoutWindow) {\n            this._windowOnResize.bind(this).defer();\n            JSBNG__setTimeout(this._windowOnResize.bind(this), 3000, false);\n        }\n    ;\n    ;\n        define(\"PresenceCookie\", [], this);\n    },\n    _load: function(a) {\n        this.parent._load(a);\n        if (this.poppedOut) {\n            if (!this.inPopoutWindow) {\n                CSS.addClass(this.holder, \"popped_out\");\n            }\n        ;\n        ;\n        }\n         else {\n            if (this.inPopoutWindow) {\n                if (this.loaded) {\n                    if (!this.popinClicked) {\n                        window.close();\n                    }\n                ;\n                }\n            ;\n            }\n        ;\n        ;\n            CSS.removeClass(this.holder, \"popped_out\");\n        }\n    ;\n    ;\n        if (this.inPopoutWindow) {\n            this._handleResize.bind(this, 0, 0).defer();\n            JSBNG__setTimeout(this._handleResize.bind(this, 0, 0), 100, false);\n        }\n    ;\n    ;\n        this.parent._loaded();\n    },\n    _loaded: bagofholding,\n    _handleMsg: function(a, b) {\n        this.parent._handleMsg(a, b);\n        if (((((typeof b == \"string\")) || !b.type))) {\n            return;\n        }\n    ;\n    ;\n        if (this.isShutdown) {\n            return false;\n        }\n    ;\n    ;\n        if (((b.type == \"app_msg\"))) {\n            if (((b.event_name == \"beep_event\"))) {\n                if (!this.inPopoutWindow) {\n                    Bootloader.loadComponents(\"beeper\", function() {\n                        Beeper.ensureInitialized();\n                        LiveMessageReceiver.route(b);\n                    });\n                }\n            ;\n            ;\n            }\n             else LiveMessageReceiver.route(b);\n        ;\n        }\n    ;\n    ;\n    },\n    popout: function() {\n        if (((this.inPopoutWindow || this.poppedOut))) {\n            this.popin(true);\n            return;\n        }\n    ;\n    ;\n        if (this.popoutClicked) {\n            return;\n        }\n    ;\n    ;\n        this.popoutClicked = true;\n        var a = window.open(this.popoutURL, \"fbChatWindow\", ((((((((((((((((((((\"status=0,toolbar=0,location=0,menubar=0,\" + \"directories=0,resizable=1,scrollbars=0,\")) + \"width=\")) + this.popoutWidth)) + \",height=\")) + this.popoutHeight)) + \",\")) + \"left=\")) + this.defX)) + \",top=\")) + this.defY)));\n        CSS.removeClass(this.holder, \"popped_out\");\n        this.poppedOut = true;\n        this.justPoppedOut = true;\n        this.popoutTime = (new JSBNG__Date()).getTime();\n        this.doSync();\n        this.popoutClicked = false;\n    },\n    popin: function(a) {\n        if (((typeof a == \"undefined\"))) {\n            a = true;\n        }\n    ;\n    ;\n        if (this.inPopoutWindow) {\n            if (this.popinClicked) {\n                return;\n            }\n        ;\n        ;\n            this.popinClicked = true;\n        }\n    ;\n    ;\n        this.poppedOut = false;\n        this.doSync();\n        if (((this.inPopoutWindow && a))) {\n            window.close();\n        }\n    ;\n    ;\n    },\n    _windowOnResize: function() {\n        if (!this.inPopoutWindow) {\n            return;\n        }\n    ;\n    ;\n        this.contentResized = {\n        };\n        var a = Vector2.getViewportDimensions();\n        this._handleResize(((a.x - this.virtPopoutWidth)), ((a.y - this.virtPopoutHeight)));\n        if (this.inPopoutWindow) {\n            this.popoutHeight = a.y;\n        }\n    ;\n    ;\n    },\n    _handleResize: function(b, c) {\n        var a = ((this.loaded ? 100 : 10));\n        if (this.handleResizeTimer) {\n            JSBNG__clearTimeout(this.handleResizeTimer);\n        }\n    ;\n    ;\n        this.handleResizeTimer = JSBNG__setTimeout(function() {\n            this.virtPopoutWidth += b;\n            this.virtPopoutHeight += c;\n            this.popoutWidth = Math.max(this.virtPopoutWidth, this.minWidth);\n            this.popoutHeight = Math.max(this.virtPopoutHeight, this.minHeight);\n            Arbiter.inform(PresenceMessage.WINDOW_RESIZED, {\n                sender: this\n            });\n        }, a, false);\n    },\n    _documentKeyPress: function(a) {\n        if (!this.inPopoutWindow) {\n            return;\n        }\n    ;\n    ;\n        a = $E(a);\n        var b = ((a ? a.keyCode : -1));\n        if (((b == KEYS.ESC))) {\n            JSBNG__Event.kill(a);\n        }\n    ;\n    ;\n    },\n    renderLink: function(b, c, a) {\n        return ((((((((((((((\"\\u003Ca href=\\\"\" + b)) + \"\\\"\")) + ((this.inPopoutWindow ? \" target=\\\"_blank\\\"\" : \"\")))) + ((a ? a : \"\")))) + \"\\u003E\")) + c)) + \"\\u003C/a\\u003E\"));\n    },\n    _shutdown: function(c, d, b) {\n        this.parent._shutdown(c, d, b);\n        if (((((!this.isShuttingDown && ((d === this.shutdownTime)))) || ((d && this.isShutdown))))) {\n            return;\n        }\n    ;\n    ;\n        if (!this.inPopoutWindow) {\n            if (Chat.isOnline()) {\n                CSS.addClass(this.holder, \"presence_error\");\n            }\n        ;\n        ;\n            var a = $(\"fbChatErrorNub\");\n            TooltipLink.setTooltipText(DOM.JSBNG__find(a, \"a.fbNubButton\"), c);\n        }\n         else {\n            if (this.shutdownErrorDialog) {\n                this.shutdownErrorDialog.hide();\n            }\n        ;\n        ;\n            this.shutdownErrorDialog = ErrorDialog.show(_tx(\"Facebook Chat Error\"), c);\n        }\n    ;\n    ;\n    },\n    _restart: function(a) {\n        this.parent._restart(a);\n        if (((!this.isRestarting || ((a && ((a != this.shutdownTime))))))) {\n            return;\n        }\n    ;\n    ;\n        if (!this.inPopoutWindow) {\n            CSS.removeClass(this.holder, \"presence_error\");\n        }\n         else if (this.shutdownErrorDialog) {\n            this.shutdownErrorDialog.hide();\n        }\n        \n    ;\n    ;\n    },\n    isOnline: function() {\n        return ((this.state && this.state.vis));\n    }\n};\nfunction getFirstName(c) {\n    var d = c.split(\" \");\n    var b = d[0];\n    var a = b.length;\n    if (((((typeof d[1] != \"undefined\")) && ((((((a == 1)) || ((((a == 2)) && ((b.indexOf(\".\") != -1)))))) || ((((a == 3)) && ((b.toLowerCase() == \"the\"))))))))) {\n        b += ((\" \" + d[1]));\n    }\n;\n;\n    return b;\n};\n;\nfunction LiveMessageReceiver(a) {\n    this.eventName = a;\n    this.subs = null;\n    this.handler = bagofholding;\n    this.shutdownHandler = null;\n    this.restartHandler = null;\n    this.registered = false;\n    this.appId = 1;\n};\n;\nLiveMessageReceiver.prototype.setAppId = function(a) {\n    this.appId = a;\n    return this;\n};\nLiveMessageReceiver.prototype.setHandler = function(a) {\n    this.handler = a;\n    this._dirty();\n    return this;\n};\nLiveMessageReceiver.prototype.setRestartHandler = function(a) {\n    this.restartHandler = a.shield();\n    this._dirty();\n    return this;\n};\nLiveMessageReceiver.prototype.setShutdownHandler = function(a) {\n    this.shutdownHandler = a.shield();\n    this._dirty();\n    return this;\n};\nLiveMessageReceiver.prototype._dirty = function() {\n    if (this.registered) {\n        this.unregister();\n        this.register();\n    }\n;\n;\n};\nLiveMessageReceiver.prototype.register = function() {\n    var b = function(d, c) {\n        return this.handler(c);\n    }.bind(this);\n    var a = PresenceMessage.getAppMessageType(this.appId, this.eventName);\n    this.subs = {\n    };\n    this.subs.main = Arbiter.subscribe(a, b);\n    if (this.shutdownHandler) {\n        this.subs.shut = Arbiter.subscribe(PresenceMessage.SHUTDOWN, this.shutdownHandler);\n    }\n;\n;\n    if (this.restartHandler) {\n        this.subs.restart = Arbiter.subscribe(PresenceMessage.RESTARTED, this.restartHandler);\n    }\n;\n;\n    this.registered = true;\n    return this;\n};\nLiveMessageReceiver.prototype.unregister = function() {\n    if (!this.subs) {\n        return this;\n    }\n;\n;\n    for (var a in this.subs) {\n        if (this.subs[a]) {\n            Arbiter.unsubscribe(this.subs[a]);\n        }\n    ;\n    ;\n    };\n;\n    this.subs = null;\n    this.registered = false;\n    return this;\n};\nLiveMessageReceiver.route = function(b) {\n    var a = function(c) {\n        var d = PresenceMessage.getAppMessageType(b.app_id, b.event_name);\n        Arbiter.inform(d, c, Arbiter.BEHAVIOR_PERSISTENT);\n    };\n    if (b.hasCapture) {\n        new AsyncRequest().setHandler(function(c) {\n            a(c.getPayload());\n        }).setAllowCrossPageTransition(true).handleResponse(b.response);\n    }\n     else a(b.response);\n;\n;\n};");
// 14651
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[11], o18,o22);
// undefined
o18 = null;
// 14992
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"P5VoD\",]);\n}\n;\n;\nvar GenderConst = {\n    UNKNOWN: 0,\n    FEMALE_SINGULAR: 1,\n    MALE_SINGULAR: 2,\n    FEMALE_SINGULAR_GUESS: 3,\n    MALE_SINGULAR_GUESS: 4,\n    MIXED_SINGULAR: 5,\n    MIXED_PLURAL: 5,\n    NEUTER_SINGULAR: 6,\n    UNKNOWN_SINGULAR: 7,\n    FEMALE_PLURAL: 8,\n    MALE_PLURAL: 9,\n    NEUTER_PLURAL: 10,\n    UNKNOWN_PLURAL: 11\n};\nfunction TypingDetector(a) {\n    this._input = a;\n    this._ignoreKeys = {\n    };\n};\n;\nTypingDetector.INACTIVE = 0;\nTypingDetector.TYPING = 1;\nTypingDetector.QUITTING = 2;\nClass.mixin(TypingDetector, \"Arbiter\", {\n    _timeout: 7000,\n    _currentState: TypingDetector.INACTIVE,\n    init: function() {\n        this.init = bagofholding;\n        this.reset();\n        JSBNG__Event.listen(this._input, \"keyup\", this._update.bind(this));\n        JSBNG__onunloadRegister(this._onunload.bind(this));\n    },\n    reset: function() {\n        JSBNG__clearTimeout(this._checkTimer);\n        this._checkTimer = null;\n        this._lastKeystrokeAt = null;\n        this._currentState = TypingDetector.INACTIVE;\n    },\n    setIgnoreKeys: function(a) {\n        this._ignoreKeys = Object.from(a);\n    },\n    _onunload: function() {\n        if (((this._currentState == TypingDetector.TYPING))) {\n            this._transition(TypingDetector.QUITTING);\n        }\n    ;\n    ;\n    },\n    _update: function(JSBNG__event) {\n        var a = JSBNG__Event.getKeyCode(JSBNG__event);\n        var b = this._currentState;\n        if (!this._ignoreKeys[a]) {\n            if (((Input.getValue(this._input).trim().length === 0))) {\n                if (((b == TypingDetector.TYPING))) {\n                    this._transition(TypingDetector.INACTIVE);\n                }\n            ;\n            ;\n            }\n             else if (((b == TypingDetector.TYPING))) {\n                this._recordKeystroke();\n            }\n             else if (((b == TypingDetector.INACTIVE))) {\n                this._transition(TypingDetector.TYPING);\n                this._recordKeystroke();\n            }\n            \n            \n        ;\n        }\n    ;\n    ;\n    },\n    _transition: function(a) {\n        this.reset();\n        this._currentState = a;\n        this.inform(\"change\", a);\n    },\n    _recordKeystroke: function() {\n        this._lastKeystrokeTime = +new JSBNG__Date();\n        if (!this._checkTimer) {\n            this._checkTimer = this._checkTyping.bind(this).defer(this._timeout);\n        }\n    ;\n    ;\n    },\n    _checkTyping: function() {\n        var a = ((this._lastKeystrokeTime + this._timeout));\n        var b = +new JSBNG__Date();\n        if (((b > a))) {\n            this._transition(TypingDetector.INACTIVE);\n        }\n         else {\n            JSBNG__clearTimeout(this._checkTimer);\n            this._checkTimer = this._checkTyping.bind(this).defer(((((a - b)) + 10)));\n        }\n    ;\n    ;\n    }\n});\nvar Dock = copy_properties(new Arbiter(), {\n    MIN_HEIGHT: 140,\n    INITIAL_FLYOUT_HEIGHT_OFFSET: 10,\n    stateItems: [],\n    init: function(a) {\n        this.init = bagofholding;\n        this.rootEl = a;\n        this.calculateViewportDimensions();\n        this.calculateFlyoutHeightOffset();\n        ChatQuietLinks.silence(this.rootEl);\n        JSBNG__Event.listen(a, \"click\", this._onClick.bind(this));\n        JSBNG__Event.listen(window, \"resize\", this._onWindowResize.bind(this));\n        Arbiter.subscribe(\"page_transition\", this._onPageTransition.bind(this));\n        Toggler.subscribe([\"show\",\"hide\",], function(e, d) {\n            var b = d.getActive();\n            if (!DOM.contains(a, b)) {\n                return;\n            }\n        ;\n        ;\n            if (CSS.hasClass(b, \"fbNub\")) {\n                this.notifyNub(b, e);\n                if (((e === \"show\"))) {\n                    this._resizeNubFlyout(b);\n                }\n            ;\n            ;\n            }\n             else {\n                var c = Parent.byClass(b, \"fbNubFlyout\");\n                if (c) {\n                    CSS.conditionClass(c, \"menuOpened\", ((e === \"show\")));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }.bind(this));\n        this._adjustTooltips();\n        this.registerStateItems();\n        this.inform(\"init\", {\n        }, Arbiter.BEHAVIOR_PERSISTENT);\n    },\n    calculateViewportDimensions: function() {\n        return (this.viewportDimensions = Vector2.getViewportDimensions());\n    },\n    calculateFlyoutHeightOffset: function() {\n        this.flyoutHeightOffset = ((this.INITIAL_FLYOUT_HEIGHT_OFFSET + Vector2.getElementDimensions(this.rootEl).y));\n        var a = ge(\"blueBar\");\n        if (a) {\n            var b = ((CSS.getStyle(a, \"position\") === \"fixed\"));\n            this.flyoutHeightOffset += ((Vector2.getElementPosition(a, ((b ? \"viewport\" : null))).y + Vector2.getElementDimensions(a).y));\n        }\n    ;\n    ;\n    },\n    toggle: function(b) {\n        var a = this._findFlyout(b);\n        if (!a) {\n            return;\n        }\n    ;\n    ;\n        this.subscribe(\"init\", function() {\n            Toggler.getInstance(b).toggle(b);\n        });\n    },\n    show: function(a) {\n        this.subscribe(\"init\", function() {\n            Toggler.getInstance(a).show(a);\n        });\n    },\n    showNub: function(b) {\n        CSS.show(b);\n        var a = DOM.JSBNG__find(b, \"a.fbNubButton\");\n        this._adjustTooltip(a);\n    },\n    hide: function(a) {\n        this.subscribe(\"init\", function() {\n            var b = Toggler.getInstance(a);\n            ((DOM.contains(a, b.getActive()) && b.hide()));\n        });\n    },\n    hideNub: function(a) {\n        CSS.hide(a);\n        this.hide(a);\n    },\n    setUseMaxHeight: function(b, a) {\n        CSS.conditionClass(b, \"maxHeight\", ((a !== false)));\n        this._resizeNubFlyout(b);\n    },\n    _resizeNubFlyout: function(i) {\n        var e = this._findFlyout(i);\n        if (((!e || !CSS.hasClass(i, \"openToggler\")))) {\n            return;\n        }\n    ;\n    ;\n        var j = DOM.JSBNG__find(e, \"div.fbNubFlyoutOuter\");\n        var g = DOM.JSBNG__find(j, \"div.fbNubFlyoutInner\");\n        var b = DOM.JSBNG__find(g, \"div.fbNubFlyoutBody\");\n        CSS.setStyle(b, \"height\", \"auto\");\n        var l = Vector2.getElementPosition(e, \"viewport\");\n        var d = Vector2.getElementDimensions(e);\n        var a = Vector2.getElementDimensions(b);\n        var c = Vector2.getElementDimensions(b.firstChild);\n        var h = ((Math.max(this.MIN_HEIGHT, ((this.viewportDimensions.y - this.flyoutHeightOffset))) - ((((this.viewportDimensions.y - l.y)) - d.y))));\n        CSS.setStyle(e, \"max-height\", ((h + \"px\")));\n        CSS.setStyle(j, \"max-height\", ((h + \"px\")));\n        d = Vector2.getElementDimensions(e);\n        var m = Vector2.getElementDimensions(g);\n        var k = ((m.y - a.y));\n        if (((d.y > k))) {\n            CSS.setStyle(b, \"height\", ((((d.y - k)) + \"px\")));\n        }\n    ;\n    ;\n        CSS.removeClass(e, \"swapDirection\");\n        var f = Vector2.getElementPosition(e).x;\n        CSS.conditionClass(e, \"swapDirection\", function() {\n            if (((f < 0))) {\n                return true;\n            }\n        ;\n        ;\n            return ((((f + d.x)) > this.viewportDimensions.x));\n        }.bind(this)());\n        this.notifyNub(i, \"resize\");\n    },\n    resizeAllFlyouts: function() {\n        var b = DOM.scry(this.rootEl, \"div.fbNub.openToggler\"), a = b.length;\n        while (a--) {\n            this._resizeNubFlyout(b[a]);\n        ;\n        };\n    ;\n    },\n    _onClick: function(JSBNG__event) {\n        var c = JSBNG__event.getTarget(), b = Parent.byClass(c, \"fbNub\");\n        if (b) {\n            if (Parent.byClass(c, \"fbNubFlyoutTitlebar\")) {\n                var a = Parent.byTag(c, \"a\");\n                if (((!a || !a.rel))) {\n                    this.hide(b);\n                    return false;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.notifyNub(b, \"click\");\n        }\n    ;\n    ;\n    },\n    _onPageTransition: function() {\n        this._flushDockState();\n    },\n    _onWindowResize: function(JSBNG__event) {\n        this.calculateViewportDimensions();\n        this.resizeAllFlyouts();\n        this._adjustTooltips();\n    },\n    _adjustTooltip: function(a) {\n        var b = DOM.scry(a, \"span.uiTooltipWrap\")[0];\n        if (((b && !CSS.hasClass(b, \"center\")))) {\n            var c = Vector2.getElementPosition(a).x;\n            if (c) {\n                if (this._isRTL()) {\n                    c = ((this.viewportDimensions.x - c));\n                }\n            ;\n            ;\n                CSS.conditionClass(b, \"right\", ((c > ((this.viewportDimensions.x / 2)))));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _adjustTooltips: function() {\n        var a = DOM.scry(this.rootEl, \"a.fbNubButton.uiTooltip\");\n        a.each(this._adjustTooltip.bind(this));\n    },\n    _findFlyout: function(a) {\n        return (flyoutEl = ((CSS.hasClass(a, \"fbNubFlyout\") ? a : ((DOM.scry(a, \"div.fbNubFlyout\")[0] || null)))));\n    },\n    registerNubController: function(b, a) {\n        DataStore.set(b, \"dock:nub:controller\", a);\n        a.subscribe(a.FLYOUT_CONTENT_CHANGED, this._resizeNubFlyout.bind(this, b));\n    },\n    unregisterNubController: function(a) {\n        DataStore.remove(a, \"dock:nub:controller\");\n    },\n    notifyNub: function(c, d, b) {\n        var a = DataStore.get(c, \"dock:nub:controller\");\n        return ((a && ((a.inform(d, b) !== false))));\n    },\n    _getNubContainer: function(a, b) {\n        var c = DOM.scry(this.rootEl, ((\"div.fbDock .\" + a)))[0];\n        if (((!c && b))) {\n            c = DOM[((((a === \"lNubContainer\")) ? \"prependContent\" : \"appendContent\"))](this.rootEl.firstChild, HTML(((((\"\\u003Cdiv class=\\\"\" + a)) + \"\\\"\\u003E\\u003C/div\\u003E\"))))[0];\n        }\n    ;\n    ;\n        return ((c || null));\n    },\n    _getLeftNubContainer: function(a) {\n        return (this.leftNubContainer = ((this.leftNubContainer || this._getNubContainer(\"lNubContainer\", a))));\n    },\n    _getRightNubContainer: function(a) {\n        return (this.rightNubContainer = ((this.rightNubContainer || this._getNubContainer(\"rNubContainer\", a))));\n    },\n    registerStateItem: function(d, e, f) {\n        var c = ((((e === \"left\")) ? this._getLeftNubContainer(true) : this._getRightNubContainer(true)));\n        if (!c.firstChild) {\n            var a = ((((e === \"left\")) ? \"fbDockWrapperRight\" : \"fbDockWrapperLeft\"));\n            CSS.removeClass(this.rootEl, a);\n        }\n    ;\n    ;\n        var b = ((f ? \"lastChild\" : \"firstChild\"));\n        while (d[b]) {\n            this.stateItems.push(d[b]);\n            DOM[((f ? \"prependContent\" : \"appendContent\"))](c, d[b]);\n        };\n    ;\n        DOM.remove(d);\n        this._adjustTooltips();\n    },\n    registerStateItems: function() {\n        this.subscribe(\"init\", function() {\n            var a = window.DockStateItems;\n            while (((a && a.length))) {\n                this.registerStateItem.apply(this, a.shift());\n            ;\n            };\n        ;\n        }.bind(this));\n    },\n    _flushDockState: function() {\n        this.stateItems.each(DOM.remove);\n        this.stateItems = [];\n        var a = this._getLeftNubContainer();\n        if (((a && !a.firstChild))) {\n            CSS.addClass(this.rootEl, \"fbDockWrapperRight\");\n        }\n    ;\n    ;\n        var b = this._getRightNubContainer();\n        if (((b && !b.firstChild))) {\n            CSS.addClass(this.rootEl, \"fbDockWrapperLeft\");\n        }\n    ;\n    ;\n    },\n    _isRTL: function() {\n        if (((typeof this._rtl === \"undefined\"))) {\n            this._rtl = intl_locale_is_rtl();\n        }\n    ;\n    ;\n        return this._rtl;\n    }\n});\nfunction NubController() {\n\n};\n;\nClass.mixin(NubController, \"Arbiter\", {\n    FLYOUT_CONTENT_CHANGED: \"nub/flyout/content-changed\",\n    init: function(a) {\n        this.el = a;\n        Dock.registerNubController(a, this);\n    },\n    flyoutContentChanged: function() {\n        this.inform(this.FLYOUT_CONTENT_CHANGED);\n    },\n    hide: function() {\n        Dock.hide(this.el);\n    },\n    show: function() {\n        Dock.show(this.el);\n    }\n});\nfunction InstrumentedLogger(a) {\n    if (((this === window))) {\n        return new InstrumentedLogger(a);\n    }\n;\n;\n    if (InstrumentedLogger._instances[a]) {\n        return InstrumentedLogger._instances[a];\n    }\n;\n;\n    copy_properties(this, {\n        id: a,\n        _phases: {\n        }\n    });\n    return InstrumentedLogger._instances[a] = this;\n};\n;\ncopy_properties(InstrumentedLogger, {\n    _instances: {\n    }\n});\ncopy_properties(InstrumentedLogger.prototype, {\n    beginPhase: function(a) {\n        if (((this._phases[a] && this._phases[a].start))) {\n            this.endPhase(a);\n        }\n    ;\n    ;\n        if (((typeof (this._phases[a]) == \"undefined\"))) {\n            this._phases[a] = {\n                start: 0,\n                count: 0,\n                duration: 0\n            };\n        }\n    ;\n    ;\n        this._phases[a].start = new JSBNG__Date().getTime();\n        return this;\n    },\n    endPhase: function(a) {\n        var b = this._phases[a];\n        if (((b && b.start))) {\n            b.count++;\n            b.duration += ((new JSBNG__Date().getTime() - b.start));\n            b.start = null;\n        }\n    ;\n    ;\n        return this;\n    },\n    dumpAndReset: function() {\n        this.JSBNG__dump();\n        return this.reset();\n    },\n    JSBNG__dump: function() {\n        for (var b in this._phases) {\n            var c = this._phases[b];\n            var a = ((((this.id ? ((this.id + \"::\")) : \"\")) + b));\n        };\n    ;\n        return this;\n    },\n    get: function(a) {\n        if (this._phases[a]) {\n            return ((this._phases[a].duration / this._phases[a].count));\n        }\n    ;\n    ;\n        return 0;\n    },\n    reset: function() {\n        this._phases = {\n        };\n        return this;\n    }\n});\nInstrumentedLogger.prototype.b = InstrumentedLogger.prototype.beginPhase;\nInstrumentedLogger.prototype.e = InstrumentedLogger.prototype.endPhase;\nInstrumentedLogger.prototype.d = InstrumentedLogger.prototype.JSBNG__dump;\nInstrumentedLogger.prototype.D = InstrumentedLogger.prototype.dumpAndReset;\nInstrumentedLogger.prototype.r = InstrumentedLogger.prototype.reset;\nvar IL = InstrumentedLogger;\nfunction SidebarTicker() {\n\n};\n;\nSidebarTicker.prototype = {\n    init: function() {\n        this._ticker = $(\"pagelet_ticker\");\n        this._initSubscriptions();\n        CSS.addClass(JSBNG__document.documentElement, \"ticker\");\n        if (CSS.hasClass(JSBNG__document.documentElement, \"sidebarMode\")) {\n            this._onSidebarShow();\n        }\n    ;\n    ;\n        return this;\n    },\n    initResizeBehavior: function(c, a) {\n        var i = this._ticker;\n        var e = i.parentNode;\n        var d = this._saveResizedState.bind(this);\n        var h;\n        var j;\n        var f;\n        var g = function(l, JSBNG__event) {\n            h = JSBNG__event.clientY;\n            j = i.offsetHeight;\n            f = e.offsetHeight;\n        };\n        var k = function(n, JSBNG__event) {\n            var l = ((j + ((JSBNG__event.clientY - h))));\n            var m = ((100 - ((((((f - l)) / f)) * 100))));\n            m = Math.max(10, Math.min(90, m));\n            i.style.height = ((m + \"%\"));\n            if (((n == \"end\"))) {\n                d(m);\n                Arbiter.inform(\"Ticker/resized\");\n            }\n        ;\n        ;\n            a.resize();\n        };\n        var b = new SimpleDrag(c);\n        b.subscribe(\"start\", g);\n        b.subscribe([\"update\",\"end\",], k);\n    },\n    _saveResizedState: function(a) {\n        new AsyncRequest(\"/ajax/feed/ticker/resize\").setData({\n            height: ((\"\" + a))\n        }).setMethod(\"POST\").send();\n    },\n    _initSubscriptions: function() {\n        this._subscriptions = [Arbiter.subscribe(\"sidebar/show\", this._onSidebarShow.bind(this)),];\n    },\n    _onSidebarShow: function() {\n        TickerController.show(this._ticker);\n    }\n};\nfunction is_rtl(c) {\n    for (var b = 0; ((b < c.length)); b++) {\n        var a = c.charCodeAt(b);\n        if (((a >= 48))) {\n            return ((((a >= 1470)) && ((a <= 1920))));\n        }\n    ;\n    ;\n    };\n;\n    return false;\n};\n;\nvar Emote = {\n    _initialized: false,\n    _imageBase: null,\n    _emoteMap: null,\n    _emoteOrderMap: null,\n    _imageURLs: null,\n    _regex: null,\n    _mapOverlay: null,\n    initExtraEmoticons: function(a) {\n        Emote._mapOverlay = a;\n    },\n    _init: function() {\n        var f = env_get(\"static_base\");\n        Emote._imageBase = ((f + \"images/emote/\"));\n        Emote._blankImgSrc = ((f + \"images/blank.gif\"));\n        var a = [\"smile\",\"frown\",\"tongue\",\"grin\",\"gasp\",\"wink\",\"glasses\",\"sunglasses\",\"grumpy\",\"unsure\",\"cry\",\"devil\",\"angel\",\"kiss\",\"heart\",\"kiki\",\"squint\",\"confused\",\"upset\",\"pacman\",\"colonthree\",\"like\",];\n        Emote._emoteMap = {\n            \":-)\": [\"\\\\:\\\\-\\\\)\",\"smile\",],\n            \":)\": [\"\\\\:\\\\)\",\"smile\",],\n            \":]\": [\"\\\\:\\\\]\",\"smile\",],\n            \"=)\": [\"=\\\\)\",\"smile\",],\n            \":-(\": [\"\\\\:\\\\-\\\\(\",\"frown\",],\n            \":(\": [\"\\\\:\\\\(\",\"frown\",],\n            \":[\": [\"\\\\:\\\\[\",\"frown\",],\n            \"=(\": [\"=\\\\(\",\"frown\",],\n            \":-P\": [\"\\\\:\\\\-P\",\"tongue\",],\n            \":P\": [\"\\\\:P\",\"tongue\",],\n            \":-p\": [\"\\\\:\\\\-p\",\"tongue\",],\n            \":p\": [\"\\\\:p\",\"tongue\",],\n            \"=P\": [\"=P\",\"tongue\",],\n            \":-D\": [\"\\\\:\\\\-D\",\"grin\",],\n            \":D\": [\"\\\\:D\",\"grin\",],\n            \"=D\": [\"=D\",\"grin\",],\n            \":-O\": [\"\\\\:\\\\-O\",\"gasp\",],\n            \":O\": [\"\\\\:O\",\"gasp\",],\n            \":-o\": [\"\\\\:\\\\-o\",\"gasp\",],\n            \":o\": [\"\\\\:o\",\"gasp\",],\n            \";-)\": [\"\\\\;\\\\-\\\\)\",\"wink\",],\n            \";)\": [\"\\\\;\\\\)\",\"wink\",],\n            \"8-)\": [\"8\\\\-\\\\)\",\"glasses\",],\n            \"8)\": [\"8\\\\)\",\"glasses\",],\n            \"B-)\": [\"B\\\\-\\\\)\",\"glasses\",],\n            \"B)\": [\"B\\\\)\",\"glasses\",],\n            \"8-|\": [\"8\\\\-\\\\|\",\"sunglasses\",],\n            \"8|\": [\"8\\\\|\",\"sunglasses\",],\n            \"B-|\": [\"B\\\\-\\\\|\",\"sunglasses\",],\n            \"B|\": [\"B\\\\|\",\"sunglasses\",],\n            \"\\u003E:(\": [\"\\u003E\\\\:\\\\(\",\"grumpy\",],\n            \"\\u003E:-(\": [\"\\u003E\\\\:\\\\-\\\\(\",\"grumpy\",],\n            \":/\": [\"\\\\:/\",\"unsure\",],\n            \":-/\": [\"\\\\:\\\\-/\",\"unsure\",],\n            \":\\\\\": [\"\\\\:\\\\\\\\\",\"unsure\",],\n            \":-\\\\\": [\"\\\\:\\\\-\\\\\\\\\",\"unsure\",],\n            \":'(\": [\"\\\\:'\\\\(\",\"cry\",],\n            \"3:)\": [\"3\\\\:\\\\)\",\"devil\",],\n            \"3:-)\": [\"3\\\\:\\\\-\\\\)\",\"devil\",],\n            \"O:)\": [\"O\\\\:\\\\)\",\"angel\",],\n            \"O:-)\": [\"O\\\\:\\\\-\\\\)\",\"angel\",],\n            \":-*\": [\"\\\\:\\\\-\\\\*\",\"kiss\",],\n            \":*\": [\"\\\\:\\\\*\",\"kiss\",],\n            \"\\u003C3\": [\"\\u003C3\",\"heart\",],\n            \"&lt;3\": [\"&lt\\\\;3\",\"heart\",],\n            \"\\u2665\": [\"\\u2665\",\"heart\",],\n            \"^_^\": [\"\\\\^_\\\\^\",\"kiki\",],\n            \"-_-\": [\"\\\\-_\\\\-\",\"squint\",],\n            \"o.O\": [\"o\\\\.O\",\"confused\",],\n            \"O.o\": [\"O\\\\.o\",\"confused\",],\n            \"\\u003E:O\": [\"\\u003E\\\\:O\",\"upset\",],\n            \"\\u003E:-O\": [\"\\u003E\\\\:\\\\-O\",\"upset\",],\n            \"\\u003E:o\": [\"\\u003E\\\\:o\",\"upset\",],\n            \"\\u003E:-o\": [\"\\u003E\\\\:\\\\-o\",\"upset\",],\n            \"\\u003E_\\u003C\": [\"\\u003E_\\u003C\",\"upset\",],\n            \"\\u003E.\\u003C\": [\"\\u003E\\\\.\\u003C\",\"upset\",],\n            \":v\": [\"\\\\:v\",\"pacman\",],\n            \":|]\": [\"\\\\:\\\\|\\\\]\",\"robot\",],\n            \":3\": [\"\\\\:3\",\"colonthree\",],\n            \"\\u003C(\\\")\": [\"\\u003C\\\\(\\\\\\\"\\\\)\",\"penguin\",],\n            \":putnam:\": [\"\\\\:putnam\\\\:\",\"putnam\",],\n            \"(^^^)\": [\"\\\\(\\\\^\\\\^\\\\^\\\\)\",\"shark\",],\n            \":42:\": [\"\\\\:42\\\\:\",\"42\",],\n            \"(y)\": [\"\\\\(y\\\\)\",\"like\",],\n            \"(Y)\": [\"\\\\(Y\\\\)\",\"like\",]\n        };\n        if (Emote._mapOverlay) {\n            copy_properties(Emote._emoteMap, Emote._mapOverlay);\n        }\n    ;\n    ;\n        var d = [];\n        for (var c in Emote._emoteMap) {\n            d.push(Emote._emoteMap[c][0]);\n        ;\n        };\n    ;\n        var e = ((((\"(?:^|\\\\s|'|\\\"|\\\\.)(\" + d.join(\"|\"))) + \")(?:\\\\s|'|\\\"|\\\\.|,|!|\\\\?|\\u003Cbr\\u003E|$)\"));\n        Emote._regex = new RegExp(e);\n        Emote._emoteOrderMap = {\n        };\n        for (var b = 0; ((b < a.length)); b++) {\n            Emote._emoteOrderMap[a[b]] = b;\n        ;\n        };\n    ;\n        Emote._initialized = true;\n    },\n    htmlEmote: function(j, l) {\n        if (((typeof l != \"function\"))) {\n            l = htmlize;\n        }\n    ;\n    ;\n        if (!Emote._initialized) {\n            Emote._init();\n        }\n    ;\n    ;\n        var i = 0;\n        var k = j;\n        var h = [];\n        while (true) {\n            var e = Emote._regex.exec(k);\n            if (((!e || !e.length))) {\n                break;\n            }\n        ;\n        ;\n            var b = e[1];\n            var d = Emote._emoteMap[b][1];\n            var c = k.indexOf(b);\n            var a = k.substring(0, c);\n            if (a) {\n                h.push(l(a));\n            }\n        ;\n        ;\n            h.push(\"\\u003Cspan class=\\\"emote_text\\\"\\u003E\");\n            h.push(b);\n            h.push(\"\\u003C/span\\u003E\\u003Cimg \");\n            var f;\n            if (((typeof (f = Emote._emoteOrderMap[d]) == \"undefined\"))) {\n                h.push(\"class=\\\"emote_custom\\\" src=\\\"\");\n                h.push(Emote._imageBase);\n                h.push(d);\n                h.push(\".gif\\\" \");\n            }\n             else {\n                var g = ((f * -16));\n                h.push(\"class=\\\"emote_img\\\" src=\\\"\");\n                h.push(Emote._blankImgSrc);\n                h.push(\"\\\" style=\\\"background-position: \");\n                h.push(g);\n                h.push(\"px 0px\\\" \");\n            }\n        ;\n        ;\n            h.push(\"alt=\\\"\");\n            h.push(b);\n            h.push(\"\\\" /\\u003E\");\n            k = k.substring(((c + b.length)));\n        };\n    ;\n        if (k) {\n            h.push(l(k));\n        }\n    ;\n    ;\n        return h.join(\"\");\n    }\n};\nvar Sound = (function() {\n    var a = false;\n    var b = \"so_sound_player\";\n    function c(e) {\n        var f = URI(e);\n        if (!f.getDomain()) {\n            return URI(env_get(\"static_base\")).setPath(f.getPath()).toString();\n        }\n    ;\n    ;\n        return e;\n    };\n;\n    function d() {\n        var e = ((JSBNG__document[b] || window[b]));\n        if (e) {\n            if (((!e.playSound && e.length))) {\n                e = e[0];\n            }\n        ;\n        }\n    ;\n    ;\n        return ((((((e && e.playSound)) && e.loopSound)) ? e : null));\n    };\n;\n    return {\n        init: function() {\n            if (a) {\n                return;\n            }\n        ;\n        ;\n            a = true;\n            var e = JSBNG__document.createElement(\"div\");\n            e.id = \"sound_player_holder\";\n            JSBNG__document.body.appendChild(e);\n            try {\n                var player = new SWFObject(\"/swf/SoundPlayer.swf\", b, \"1px\", \"1px\", [\"9.0.159.0\",\"10.0.22.87\",], \"#ffffff\");\n                player.addParam(\"allowscriptaccess\", \"always\");\n                player.addParam(\"wmode\", \"transparent\");\n                player.addVariable(\"swf_id\", b);\n                player.fallback_html = \" \";\n                player.write(e.id);\n                window[b] = player;\n            } catch (f) {\n            \n            };\n        ;\n        },\n        play: function(h, j, g, f) {\n            Sound.init();\n            h = c(h);\n            var i = d();\n            if (((/\\.mp3$/.test(h) && i))) {\n                if (g) {\n                    i.loopSound(h, j);\n                }\n                 else i.playSound(h, j);\n            ;\n            ;\n            }\n             else {\n                if (f) {\n                    return;\n                }\n            ;\n            ;\n                var e = ge(\"sound\");\n                if (!e) {\n                    e = JSBNG__document.createElement(\"span\");\n                    e.setAttribute(\"id\", \"sound\");\n                    DOM.getRootElement().appendChild(e);\n                }\n            ;\n            ;\n                e.innerHTML = ((((((((\"\\u003Cembed src=\\\"\" + h)) + \"\\\" autostart=\\\"true\\\" loop=\\\"\")) + ((g ? \"true\" : \"false\")))) + \"\\\" hidden=\\\"true\\\" /\\u003E\"));\n            }\n        ;\n        ;\n        },\n        JSBNG__stop: function(f) {\n            f = c(f);\n            var g = d();\n            ((g && g.stopSound(f)));\n            var e = ge(\"sound\");\n            ((e && (e.innerHTML = \"\")));\n        }\n    };\n})();\nfunction Template(a) {\n    copy_properties(this, {\n        _templateSource: a\n    });\n};\n;\ncopy_properties(Template, {\n    _operatorRepeat: function(d, a) {\n        var f = \"\";\n        var c = d.match(/([^:]*):(.*)/);\n        if (!(!c)) {\n            if (!(!TemplateRegistry.hasTemplate(c[2]))) {\n                if (a[c[1]]) {\n                    var e = TemplateRegistry.getTemplate(c[2]);\n                    var b = $A(a[c[1]]);\n                    f += b.map(function(h, g) {\n                        return h.render(g);\n                    }.curry(e)).join(\" \");\n                }\n            ;\n            }\n        ;\n        }\n    ;\n    ;\n        return f;\n    }\n});\ncopy_properties(Template.prototype, {\n    getSource: function() {\n        return this._templateSource;\n    },\n    render: function(b) {\n        var a = function(d, c, f, e) {\n            switch (f) {\n              case \"H\":\n                return ((d[e] || \"\"));\n              case \"R\":\n                return Template._operatorRepeat(e, d);\n              default:\n                if (!d[e]) {\n                    return \"\";\n                }\n            ;\n            ;\n                return ((((window.HTML && HTML.isHTML(d[e]))) ? d[e].getContent() : htmlize(d[e])));\n            };\n        ;\n        }.curry(((b || {\n        })));\n        return this._templateSource.replace(/\\$(H|R)?{([^\\}]*)\\}/g, a);\n    }\n});\nvar TemplateRegistry = {\n    _storage: {\n    },\n    registerTemplate: function(a, b) {\n        if (((typeof (b) == \"string\"))) {\n            b = new Template(b);\n        }\n    ;\n    ;\n        this._storage[a] = b;\n        return this;\n    },\n    unregisterTemplate: function(a) {\n        delete this._storage[a];\n    },\n    hasTemplate: function(a) {\n        return ((a in this._storage));\n    },\n    getTemplate: function(a) {\n        if (this.hasTemplate(a)) {\n            return this._storage[a];\n        }\n    ;\n    ;\n        return null;\n    },\n    registerServerSideTemplate: function(d, b, e, c) {\n        b = ((b || bagofholding));\n        e = !!e;\n        c = !!c;\n        if (this.hasTemplate(d)) {\n            b();\n            return this;\n        }\n    ;\n    ;\n        var a = new AsyncRequest(d).setReadOnly(true).setMethod(\"GET\").setOption(\"asynchronous\", !e).setOption(\"suppressEvaluation\", !c);\n        if (!e) {\n            a.setErrorHandler(this._registerErrorHandler.bind(this, d)).setHandler(this._registerHandler.bind(this, d, c, b));\n        }\n    ;\n    ;\n        a.send();\n        if (e) {\n            var f = this._stripHasteComments(a.transport.responseText);\n            this.registerTemplate(d, new Template(f));\n            b();\n        }\n    ;\n    ;\n        return this;\n    },\n    _registerErrorHandler: function(a, b) {\n    \n    },\n    _registerHandler: function(c, b, a, e) {\n        var d = e.getPayload();\n        var f = null;\n        if (b) {\n            if (d.template) {\n                f = d.template;\n            }\n        ;\n        ;\n        }\n         else f = this._stripHasteComments(d.responseText);\n    ;\n    ;\n        if (f) {\n            this.registerTemplate(c, f);\n            a();\n        }\n    ;\n    ;\n    },\n    _stripHasteComments: function(a) {\n        return a.replace(/^\\s*\\/\\*\\*?(.|\\n)*\\*\\//m, \"\");\n    },\n    _onRegisterTemplate: function(b, a) {\n        if (((b == \"template/registerTemplate\"))) {\n            if (!((((!a || !a.JSBNG__name)) || !a.template))) {\n                this.registerTemplate(a.JSBNG__name, a.template);\n            }\n        ;\n        ;\n            return false;\n        }\n    ;\n    ;\n        return true;\n    }\n};\nArbiter.subscribe(\"template/registerTemplate\", TemplateRegistry._onRegisterTemplate.bind(TemplateRegistry), Arbiter.SUBSCRIBE_ALL);\n(function() {\n    var c = new JSBNG__Date();\n    var a = 2000;\n    var b = 10000;\n    {\n        function d() {\n            var f = new JSBNG__Date();\n            var e = ((((f - c)) - a));\n            c = f;\n            if (((e > b))) {\n                Arbiter.inform(\"time_check\", e);\n            }\n        ;\n        ;\n        };\n        ((window.top.JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88.push)((d)));\n    };\n;\n    JSBNG__setInterval(d, a);\n})();\nadd_properties(\"Messaging\", {\n    getUserThreadURI: function(a) {\n        return URI(env_get(\"www_base\")).setPath(((\"/messages/\" + a)));\n    },\n    getInboxThreadURI: function(a) {\n        return URI(env_get(\"www_base\")).setPath(((\"/messages/?action=read&tid=\" + a)));\n    },\n    markAsRead: function(a) {\n        a = $A(a);\n        new AsyncRequest().setURI(\"/ajax/messaging/async.php\").setData({\n            action: \"markRead\",\n            tids: a\n        }).setMethod(\"POST\").setHandler(bagofholding).setErrorHandler(bagofholding).send();\n        MessagingEvents.inform(\"mark-as-read\", {\n            tids: a\n        });\n    },\n    markUserThreadAsRead: function(a) {\n        new AsyncRequest().setURI(\"/ajax/messaging/async.php\").setData({\n            action: \"chatMarkRead\",\n            other_user: a\n        }).setMethod(\"POST\").setHandler(bagofholding).setErrorHandler(bagofholding).send();\n        MessagingEvents.inform(\"mark-as-read\", {\n            chat_ids: [a,]\n        });\n    },\n    unsubscribeFromThread: function(a) {\n        new AsyncRequest().setURI(\"/ajax/messaging/async.php\").setData({\n            action: \"unsubscribe\",\n            tids: a\n        }).setMethod(\"POST\").setHandler(bagofholding).setErrorHandler(bagofholding).send();\n    },\n    emoteContent: function(b, c) {\n        for (var a = 0; ((a < b.length)); a++) {\n            this._emoteNode(b[a], c);\n        ;\n        };\n    ;\n    },\n    _emoteNode: function(f, h) {\n        if (!DOM.isNode(f, \"#text\")) {\n            var a = $A(f.childNodes);\n            for (var d = 0; ((d < a.length)); d++) {\n                this._emoteNode(a[d], h);\n            ;\n            };\n        ;\n            return;\n        }\n    ;\n    ;\n        var g = f.nodeValue;\n        if (h) {\n            g = f.nodeValue.replace(/\\n/g, \" \");\n        }\n    ;\n    ;\n        var b = Emote.htmlEmote(g);\n        if (((!b || ((b == f.nodeValue))))) {\n            return;\n        }\n    ;\n    ;\n        var c = HTML(b).getNodes();\n        if (((!c || !c.length))) {\n            return;\n        }\n    ;\n    ;\n        for (var e = c.length; e--; ) {\n            DOM.insertAfter(f, c[e]);\n        ;\n        };\n    ;\n        DOM.remove(f);\n    }\n});\nvar MusicLogger = {\n    log: function(c, b, a) {\n        if (((b === MusicConstants.OP.PLAY))) {\n            new AsyncRequest().setURI(\"/ajax/music/log.php\").setData({\n                provider: c,\n                data: JSON.stringify(a)\n            }).send();\n        }\n    ;\n    ;\n    }\n};\nvar Music = {\n    providers: {\n    },\n    queuedCommand: null,\n    lastStatus: {\n    },\n    _searching: {\n    },\n    lastProviderPlaying: null,\n    init: function(a, c) {\n        for (var b in a) {\n            this.providers[b] = copy_properties(((this.providers[b] || {\n                offline: true\n            })), a[b]);\n            var d = this.getRemoteClass(b);\n            d.setTokens(this.providers[b].tokens);\n            ((c && d.reconnect(this.providers[b].tokens)));\n        };\n    ;\n        this.listenForScrobble();\n        return this;\n    },\n    persistSearchingFor: function(c, b) {\n        this._searching[c] = true;\n        var a;\n        if (this.providers[c]) {\n            a = this.getRemoteClass(c);\n        }\n    ;\n    ;\n        ((((a && a.persistSearchingFor)) && a.persistSearchingFor(b)));\n        return this;\n    },\n    getRemoteClass: function(a) {\n        if (!this.providers[a]) {\n            return null;\n        }\n    ;\n    ;\n        if (!this.providers[a].instance) {\n            switch (a) {\n              case MusicProviders.SPOTIFY:\n                if (window.SpotifyRemote) {\n                    var c = new SpotifyRemote();\n                    c.init(this._receiveUpdate.bind(this, a), this.providers[a]);\n                    this.providers[a].instance = c;\n                }\n            ;\n            ;\n                break;\n              default:\n                if (window.WebBridgeRemote) {\n                    var b = new WebBridgeRemote(this._receiveUpdate.bind(this, a), a, this.providers[a]);\n                    this.providers[a].instance = b;\n                }\n            ;\n            ;\n                break;\n            };\n        }\n    ;\n    ;\n        return this.providers[a].instance;\n    },\n    listenForScrobble: function() {\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"music_scrobbling\"), function(b, a) {\n            if (a.obj.provider_name) {\n                ((a.obj.provider_data && this.init(a.obj.provider_data)));\n                this._resetQueuedCommand(a.obj.provider_name);\n                this.goOnline(a.obj.provider_name);\n            }\n        ;\n        ;\n        }.bind(this));\n        this.listenForScrobble = bagofholding;\n    },\n    setTokens: function(a, b) {\n        this.getRemoteClass(a).setTokens(b);\n        return this;\n    },\n    goOnline: function(b) {\n        var c = ((b in this.providers));\n        if (this._isOffline(b)) {\n            var a = this.isManualPlay(b);\n            var d = ((c && this.getRemoteClass(b)));\n            ((d && d.attemptGoOnline(a)));\n            if (((((!this._searching[b] && a)) && ((!d || !d.serviceRunning()))))) {\n                this.persistSearchingFor(b, 60);\n                this.launchPlayNowDialog(b, this.queuedCommand.data);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return this;\n    },\n    goOffline: function(c, a, b) {\n        if (this.providers[c]) {\n            this._resetQueuedCommand(c);\n            this._searching[c] = null;\n            this.getRemoteClass(c).goOffline();\n        }\n    ;\n    ;\n        return this;\n    },\n    allProvidersOffline: function() {\n        for (var a in this.providers) {\n            if (!this._isOffline(a)) {\n                return false;\n            }\n        ;\n        ;\n        };\n    ;\n        return true;\n    },\n    allProvidersPaused: function() {\n        for (var b in this.providers) {\n            var a = this._getLastStatus(b);\n            if (((a && a.playing))) {\n                return false;\n            }\n        ;\n        ;\n        };\n    ;\n        return true;\n    },\n    playPauseSongList: function(b, e, c, d, a) {\n        copy_properties(((a || {\n        })), {\n            song_list: c,\n            title: ((d || \"\"))\n        });\n        return this.playPauseSong(b, e, a);\n    },\n    playPauseSong: function(f, h, a) {\n        if (!f) {\n            f = this.lastProviderPlaying;\n        }\n    ;\n    ;\n        var g = this.providers[f];\n        var b = ((g ? this._getLastStatus(f) : {\n        }));\n        var d = ((b.track && MusicConstants.sameURLs(h, b.track.uri)));\n        var c = ((b.context && MusicConstants.sameURLs(h, b.context.uri)));\n        var e = ((d || c));\n        if (((b.playing && e))) {\n            this.pause(f, h, a);\n        }\n         else if (e) {\n            this.resume(f, h, a);\n        }\n         else this.playSong(f, h, a);\n        \n    ;\n    ;\n        return ((g && this.getRemoteClass(f).serviceRunning()));\n    },\n    pauseOtherProviders: function(a) {\n        for (var b in this.providers) {\n            if (((((b != a)) && !this._isOffline(b)))) {\n                this.pause(b);\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    launchProviderOrPlay: function(f, i, e, b, g, h, d) {\n        if (g) {\n            if (window.MusicDiagnostics) {\n                MusicDiagnostics.userAction.curry(g, MusicDiagnostics.SWITCHED_PROVIDER).defer();\n            }\n        ;\n        ;\n            this.goOffline(g);\n        }\n    ;\n    ;\n        if (!this._isOffline(f)) {\n            this.playSong(f, i, e);\n            var a = Dialog.getCurrent();\n            ((a && a.hide()));\n        }\n         else if (((f == MusicProviders.SPOTIFY))) {\n            this.persistSearchingFor(f, 60);\n            this.launchPlayNowDialog(f, {\n                context: e,\n                uri: i\n            }, true);\n        }\n         else {\n            this.persistSearchingFor(f, 60);\n            var c = {\n            };\n            c[f] = b;\n            this.init(c);\n            this.getRemoteClass(f).launch(i, e, h, d);\n            this.playSongSafeQueue(f, i, e);\n        }\n        \n    ;\n    ;\n    },\n    launchPlayNowDialog: function(c, a, d) {\n        if (d) {\n            this._logPlaySong(c, a);\n            this.queuedCommand = {\n                provider: c,\n                op: MusicConstants.OP.PLAY,\n                data: a\n            };\n        }\n    ;\n    ;\n        var e = copy_properties({\n            url: ((a.uri || a.url))\n        }, a);\n        delete e.uri;\n        if (this.providers[c]) {\n            this.getRemoteClass(c).launchPlayNowDialog(e);\n        }\n         else {\n            var b;\n            if (((c === MusicProviders.SPOTIFY))) {\n                b = \"/ajax/music/spotify_play_now.php?init_only\";\n            }\n             else b = \"/ajax/music/web_bridge_play_now.php?init_only\";\n        ;\n        ;\n            Dialog.bootstrap(b, e);\n        }\n    ;\n    ;\n    },\n    playSongSafeQueue: function(b, c, a) {\n        if (((((!this._isOffline(b) || !this.queuedCommand)) || ((this.queuedCommand.provider !== b))))) {\n            this.playSong(b, c, a);\n        }\n         else ((this.providers[b] && this.goOnline(b)));\n    ;\n    ;\n    },\n    playSong: function(b, c, a) {\n        a = copy_properties(((a || {\n        })), {\n            uri: c\n        });\n        this._logPlaySong(b, a);\n        this._sendOP(b, MusicConstants.OP.PLAY, a);\n    },\n    pause: function(b, c, a) {\n        a = copy_properties(((a || {\n        })), {\n            uri: ((c || null))\n        });\n        this._sendOP(b, MusicConstants.OP.PAUSE, a);\n    },\n    resume: function(b, c, a) {\n        a = copy_properties(((a || {\n        })), {\n            uri: c\n        });\n        this._sendOP(b, MusicConstants.OP.RESUME, a);\n    },\n    reInform: function(d) {\n        var b = [];\n        for (var a = 0; ((a < d.length)); a++) {\n            var c = d[a];\n            if (((this.providers[c] && !this._isOffline(c)))) {\n                if (((c == this.lastProviderPlaying))) {\n                    b.push(c);\n                }\n                 else b.unshift(c);\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        for (var a = 0; ((a < b.length)); a++) {\n            var c = b[a];\n            this._receive_STATUS_CHANGE_OP(c, MusicConstants.STATUS_CHANGE_OP.STATUS, this.lastStatus[c], {\n            });\n        };\n    ;\n        return this;\n    },\n    isManualPlay: function(a) {\n        return !!((this.queuedCommand && ((this.queuedCommand.provider === a))));\n    },\n    isPlaying: function(b, c) {\n        var a = this.getLastStatus(b);\n        return ((((a.playing && a.track)) && ((!c || MusicConstants.sameURLs(a.track.uri, c)))));\n    },\n    getLastStatus: function(a) {\n        var b = this.providers[a];\n        return ((b ? this._getLastStatus(a) : {\n        }));\n    },\n    _resetQueuedCommand: function(a) {\n        if (((!a || ((this.queuedCommand && ((this.queuedCommand.provider == a))))))) {\n            this.queuedCommand = null;\n        }\n    ;\n    ;\n    },\n    _receiveUpdate: function(d, c, a) {\n        if (a) {\n            a.provider = d;\n        }\n         else a = {\n            provider: d\n        };\n    ;\n    ;\n        var b = bagofholding;\n        if (MusicConstants.DIAGNOSTIC_EVENT[c]) {\n            b = this._receiveDIAG_EVENT;\n        }\n         else if (MusicConstants.STATUS_CHANGE_OP[c]) {\n            b = this._receive_STATUS_CHANGE_OP;\n        }\n         else !MusicConstants.OP[c];\n        \n    ;\n    ;\n        b.call(this, d, c, a);\n    },\n    _receiveDIAG_EVENT: function(d, c, a) {\n        var b = MusicConstants.DIAGNOSTIC_EVENT;\n        if (((c === b.ONLINE))) {\n            this._setOffline(d, false);\n            if (this.queuedCommand) {\n                this._replayQueuedCommand.bind(this, this.queuedCommand.provider, this.queuedCommand.op, this.queuedCommand.data).defer();\n            }\n        ;\n        ;\n            this._resetQueuedCommand();\n        }\n         else if (((c === b.IFRAME_POLLING))) {\n            this._setLastStatus(d, {\n            });\n        }\n         else if (((((c === b.RELAUNCH)) && a.last_sent))) {\n            this.launchPlayNowDialog(d, a.last_sent, true);\n        }\n        \n        \n    ;\n    ;\n        MusicEvents.inform(b[c], a);\n        if (((c === b.OFFLINE))) {\n            this._setOffline(d, true);\n            this._setLastStatus(d, {\n            });\n            if (this.allProvidersOffline()) {\n                MusicEvents.inform(MusicConstants.DIAGNOSTIC_EVENT.ALL_OFFLINE);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _receive_STATUS_CHANGE_OP: function(e, c, a, b) {\n        b = ((b || this._getLastStatus(e)));\n        var d;\n        for (d in b) {\n            if (((typeof a[d] === \"undefined\"))) {\n                a[d] = null;\n            }\n        ;\n        ;\n        };\n    ;\n        var g;\n        var f = {\n        };\n        this._setLastStatus(e, a);\n        for (d in a) {\n            g = MusicConstants.STATUS_CHANGE_EVENT[d];\n            if (g) {\n                if (((!f[g] && !are_equal(b[d], a[d])))) {\n                    if (a.playing) {\n                        if (((this.lastProviderPlaying != e))) {\n                            this.pauseOtherProviders(e);\n                        }\n                    ;\n                    ;\n                        this.lastProviderPlaying = e;\n                    }\n                     else if (this.allProvidersPaused()) {\n                        MusicEvents.inform(MusicConstants.DIAGNOSTIC_EVENT.ALL_PAUSED);\n                    }\n                    \n                ;\n                ;\n                    MusicEvents.inform(g, a);\n                    f[g] = 1;\n                }\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    _replayQueuedCommand: function(c, b, a) {\n        if (((((b === MusicConstants.OP.PLAY)) && this.isPlaying(c, a.uri)))) {\n            return;\n        }\n    ;\n    ;\n        this._sendOP(c, b, a);\n    },\n    _sendOP: function(c, b, a) {\n        if (((!this.providers[c] || this._isOffline(c)))) {\n            if (!a._never_queue) {\n                this.queuedCommand = {\n                    op: b,\n                    data: a,\n                    provider: c\n                };\n            }\n        ;\n        ;\n            this.goOnline(c);\n            return;\n        }\n    ;\n    ;\n        MusicLogger.log(c, b, a);\n        var d = copy_properties({\n        }, a);\n        delete d.timestamp;\n        delete d.profile_id;\n        this.getRemoteClass(c).send(b, d);\n    },\n    _isOffline: function(a) {\n        if (!this.providers[a]) {\n            return true;\n        }\n    ;\n    ;\n        return this.providers[a].offline;\n    },\n    _setOffline: function(c, a) {\n        if (!this.providers[c]) {\n            return this;\n        }\n    ;\n    ;\n        this._searching[c] = null;\n        this.providers[c].offline = a;\n        if (((!a && !this.lastProviderPlaying))) {\n            this.lastProviderPlaying = c;\n        }\n         else if (((a && ((this.lastProviderPlaying == c))))) {\n            this.lastProviderPlaying = null;\n            for (var b in this.providers) {\n                if (this.isPlaying(b)) {\n                    this.lastProviderPlaying = b;\n                    break;\n                }\n                 else if (!this._isOffline(b)) {\n                    this.lastProviderPlaying = b;\n                }\n                \n            ;\n            ;\n            };\n        ;\n        }\n        \n    ;\n    ;\n        return this;\n    },\n    _getLastStatus: function(a) {\n        if (!this.providers[a]) {\n            return {\n            };\n        }\n    ;\n    ;\n        return ((this.lastStatus[a] || {\n        }));\n    },\n    _setLastStatus: function(a, b) {\n        if (!this.providers[a]) {\n            return this;\n        }\n    ;\n    ;\n        this.lastStatus[a] = b;\n        return this;\n    },\n    _logPlaySong: function(b, a) {\n        if (window.MusicDiagnostics) {\n            MusicDiagnostics.userAction.curry(b, MusicDiagnostics.PLAY_SONG, a).defer();\n        }\n    ;\n    ;\n    }\n};\n(function() {\n    window.MusicLiveListen = function() {\n        MusicLiveListen._instance = this;\n        this._listeningWith = false;\n        MusicEvents.subscribe([MusicConstants.DIAGNOSTIC_EVENT.ONLINE,MusicConstants.DIAGNOSTIC_EVENT.OFFLINE,MusicConstants.STATUS_CHANGE_EVENT.track,MusicConstants.STATUS_CHANGE_EVENT.playing,], this._onlineStatusChange.bind(this));\n        Arbiter.subscribe([\"chat-display/loaded\",], this._chatDisplayLoaded.bind(this));\n    };\n    copy_properties(MusicLiveListen, {\n        _instance: null,\n        REASONABLE_SYNC_LATENCY: 20,\n        END_OF_SONG_WINDOW: 10,\n        MAX_PLAY_REQUESTS_TRIES: 10,\n        SONG_UPDATE: \"song_update\",\n        BEGIN_SESSION: \"begin_session\",\n        END_SESSION: \"end_session\",\n        LISTENER_ADD: \"listener_add\",\n        LISTENER_REMOVE: \"listener_remove\",\n        getInstance: function() {\n            if (MusicLiveListen._instance) {\n                return MusicLiveListen._instance;\n            }\n        ;\n        ;\n            return new MusicLiveListen();\n        }\n    });\n    copy_properties(MusicLiveListen.prototype, {\n        _session: null,\n        _listeningWith: false,\n        _queuedSong: null,\n        _queuedSongRetryCount: 0,\n        _timeSkew: null,\n        _currentSong: null,\n        _newSessionActor: null,\n        handlePrimerResponse: function(b, a) {\n            this._handleNewSession(a, true, b);\n        },\n        handleOnloadSession: function(a) {\n            this._handleNewSession(a, false);\n        },\n        handleUpdate: function(a) {\n            switch (a.action) {\n              case MusicLiveListen.SONG_UPDATE:\n                if (!this._listeningWith) {\n                    break;\n                }\n            ;\n            ;\n                if (((!this._session || ((a.session.session_id != this._session.session_id))))) {\n                    this._handleNewSession(a, false);\n                    break;\n                }\n            ;\n            ;\n                this._handleSongUpdate(a.song);\n                break;\n              case MusicLiveListen.BEGIN_SESSION:\n                this._handleNewSession(a, false);\n                break;\n              case MusicLiveListen.END_SESSION:\n                if (((this._session && ((a.session.session_id == this._session.session_id))))) {\n                    this._handleEndSession();\n                }\n            ;\n            ;\n                break;\n              case MusicLiveListen.LISTENER_ADD:\n            \n              case MusicLiveListen.LISTENER_REMOVE:\n                MusicEvents.inform(MusicConstants.LIVE_LISTEN_OP.LISTENER_UPDATE, a, Arbiter.BEHAVIOR_PERSISTENT);\n                break;\n            };\n        ;\n        },\n        isLeader: function() {\n            return ((this._listeningWith && this._session.is_leader));\n        },\n        _handleNewSession: function(b, a, c) {\n            if (b.providers) {\n                Music.init(b.providers);\n            }\n        ;\n        ;\n            this._timeSkew = ((+new JSBNG__Date() - b.session.server_time));\n            this._session = b.session;\n            this._currentSong = null;\n            this._queuedSong = null;\n            this._queuedSongRetryCount = 0;\n            if (b.actor) {\n                this._newSessionActor = b.actor;\n            }\n        ;\n        ;\n            this._setListeningWith(true, this._session.is_leader, c);\n            Music.goOnline(this._session.provider);\n            ((b.song && this._handleSongUpdate(b.song, a)));\n            this._initLiveListenChat();\n        },\n        _getServerTime: function() {\n            var a = +new JSBNG__Date();\n            return ((this._timeSkew ? ((a - this._timeSkew)) : a));\n        },\n        _onlineStatusChange: function(c, a) {\n            if (((!a || ((((((this._session && this._session.provider)) && a.provider)) && ((this._session.provider != a.provider))))))) {\n                return;\n            }\n        ;\n        ;\n            if (!((((((c == MusicConstants.DIAGNOSTIC_EVENT.OFFLINE)) && this._listeningWith)) && !this.isLeader()))) {\n                if (((((((c == MusicConstants.DIAGNOSTIC_EVENT.ONLINE)) || ((c == MusicConstants.STATUS_CHANGE_EVENT.track)))) || ((c == MusicConstants.STATUS_CHANGE_EVENT.playing))))) {\n                    if (this._session) {\n                        this._setListeningWith(true, this.isLeader());\n                    }\n                ;\n                ;\n                    if (((this._listeningWith && this._queuedSong))) {\n                        var b = Music.getLastStatus(this._session.provider);\n                        if (!is_empty(b)) {\n                            if (((((b.track && b.track.track_type)) && ((b.track.track_type == \"ad\"))))) {\n                                return;\n                            }\n                        ;\n                        ;\n                            this._queuedSongRetryCount++;\n                            if (((this._queuedSongRetryCount > MusicLiveListen.MAX_PLAY_REQUESTS_TRIES))) {\n                                this._queuedSong = null;\n                                this._queuedSongRetryCount = 0;\n                            }\n                             else this._handleSongUpdate(this._queuedSong);\n                        ;\n                        ;\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n            ;\n            }\n        ;\n        ;\n        },\n        _chatDisplayLoaded: function(b, a) {\n            this._chatDisplay = ((a ? a : null));\n            if (this._chatDisplay) {\n                this._initLiveListenChat();\n            }\n        ;\n        ;\n        },\n        _initLiveListenChat: function() {\n            if (Chat.isOnline()) {\n                if (((this._chatDisplay && this._session))) {\n                    var a = Chat.getActiveChats();\n                    for (var b = 0; ((b < a.length)); b++) {\n                        if (((a[b] == this._session.session_id))) {\n                            return;\n                        }\n                    ;\n                    ;\n                    };\n                ;\n                    Chat.openTab(this._session.session_id, this._session.chat_name, \"livelisten\");\n                }\n            ;\n            ;\n            }\n             else if (!this.isLeader()) {\n                Chat.goOnline(this._initLiveListenChat.bind(this));\n            }\n            \n        ;\n        ;\n        },\n        endSession: function(a) {\n            if (((!this._session || ((a && ((this._session.session_id != a))))))) {\n                return;\n            }\n        ;\n        ;\n            new AsyncRequest().setURI(\"/ajax/music/live_listen_unsubscribe.php\").setData({\n                session_id: this._session.session_id\n            }).setHandler(bagofholding).setAllowCrossPageTransition(true).send();\n            this._handleEndSession(true);\n        },\n        _handleEndSession: function(a) {\n            if (!this._session) {\n                return;\n            }\n        ;\n        ;\n            if (((!this.isLeader() && a))) {\n                Music.pause(this._session.provider);\n            }\n        ;\n        ;\n            this._setListeningWith(false);\n            this._session = null;\n            this._currentSong = null;\n            this._queuedSong = null;\n            this._newSessionActor = null;\n            this._queuedSongRetryCount = 0;\n        },\n        _handleSongUpdate: function(j, d) {\n            if (this.isLeader()) {\n                MusicEvents.inform(MusicConstants.LIVE_LISTEN_OP.SONG_PLAYING, {\n                    song: j,\n                    session: this._session\n                }, Arbiter.BEHAVIOR_PERSISTENT);\n                return;\n            }\n        ;\n        ;\n            if (((((this._currentSong && ((j.created < this._currentSong.created)))) || ((this._queuedSong && ((j.created < this._queuedSong.created))))))) {\n                return;\n            }\n        ;\n        ;\n            if (((this._queuedSong && ((this._queuedSong.url != j.url))))) {\n                this._queuedSongRetryCount = 0;\n            }\n        ;\n        ;\n            this._queuedSong = j;\n            if (((!d && is_empty(Music.getLastStatus(this._session.provider))))) {\n                Music.goOnline(j.provider);\n                return;\n            }\n        ;\n        ;\n            var c = false;\n            var k = this._getServerTime();\n            var h = ((j.duration - ((j.expires - Math.ceil(((k / 1000)))))));\n            if (((h < MusicLiveListen.REASONABLE_SYNC_LATENCY))) {\n                h = 0;\n            }\n        ;\n        ;\n            if (((!d && ((h >= ((j.duration - MusicLiveListen.END_OF_SONG_WINDOW))))))) {\n                if (Music.isPlaying(this._session.provider, j.url)) {\n                    this._setCurrentSong(j);\n                    Music.pause(this._session.provider);\n                }\n            ;\n            ;\n                return;\n            }\n             else if (Music.isPlaying(this._session.provider, j.url)) {\n                var b = this._currentSong;\n                this._setCurrentSong(j);\n                var e = Music.getLastStatus(this._session.provider);\n                var a = ((j.duration - e.expires_in));\n                a = ((((a < 0)) ? 0 : a));\n                var f = MusicLiveListen.REASONABLE_SYNC_LATENCY;\n                var i = ((((((h - f)) < 0)) ? 0 : ((h - f))));\n                if (((((a && ((((a < ((h + f)))) && ((a >= i)))))) && ((((b && ((b.url == j.url)))) && ((b.expires > j.expires))))))) {\n                    Music.pause(this._session.provider);\n                    return;\n                }\n                 else return\n            ;\n            }\n            \n        ;\n        ;\n            if (window.MusicDiagnostics) {\n                var g = {\n                    url: j.url,\n                    offset: h\n                };\n                MusicDiagnostics.userAction.curry(j.provider, MusicDiagnostics.LIVE_LISTEN_PLAY, g).defer();\n            }\n        ;\n        ;\n            if (Music.playPauseSongList(j.provider, j.url, [j.url,], \"\", {\n                offset: h,\n                _never_queue: true\n            }, true)) {\n                this._setListeningWith(true, this.isLeader());\n                MusicEvents.inform(MusicConstants.LIVE_LISTEN_OP.SONG_PLAYING, {\n                    song: j,\n                    session: this._session\n                }, Arbiter.BEHAVIOR_PERSISTENT);\n            }\n             else if (!d) {\n                Music.goOnline(j.provider);\n            }\n             else {\n                Music.persistSearchingFor(j.provider, 600);\n                Music.launchPlayNowDialog(j.provider, {\n                    uri: j.url\n                }, false);\n            }\n            \n        ;\n        ;\n        },\n        _setCurrentSong: function(a) {\n            if (((this._queuedSong.url == a.url))) {\n                this._currentSong = a;\n                this._queuedSong = null;\n                this._queuedSongRetryCount = 0;\n            }\n        ;\n        ;\n        },\n        _setListeningWith: function(c, b, d) {\n            var a = ((this._session ? {\n                session: this._session\n            } : {\n            }));\n            if (d) {\n                a.listen_to = d;\n            }\n        ;\n        ;\n            if (((c && this._newSessionActor))) {\n                a.actor = this._newSessionActor;\n            }\n        ;\n        ;\n            this._listeningWith = c;\n            if (c) {\n                if (b) {\n                    MusicEvents.inform(MusicConstants.LIVE_LISTEN_OP.NOW_LEADING, a, Arbiter.BEHAVIOR_PERSISTENT);\n                }\n                 else MusicEvents.inform(MusicConstants.LIVE_LISTEN_OP.NOW_LISTENING, a, Arbiter.BEHAVIOR_PERSISTENT);\n            ;\n            ;\n            }\n             else MusicEvents.inform(MusicConstants.LIVE_LISTEN_OP.END_SESSION, a);\n        ;\n        ;\n        }\n    });\n    window.Panda = window.MusicLiveListen;\n})();");
// 15037
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[14], o21,o22);
// undefined
o21 = null;
// 15064
geval("if (window.CavalryLogger) {\n    CavalryLogger.start_js([\"JYRWp\",]);\n}\n;\n;\nfunction BuddyListNub() {\n    this.parent.construct(this);\n};\n;\nClass.extend(BuddyListNub, \"NubController\");\ncopy_properties(BuddyListNub, {\n    ITEM_HEIGHT: 32,\n    TYPEAHEAD_MIN_FRIENDS: 10,\n    TYPEAHEAD_MIN_FRIENDS_FLMODE: 20\n});\nBuddyListNub.prototype = {\n    init: function(b, a, d) {\n        this.parent.init(b);\n        this.root = b;\n        this.buddyList = a;\n        this.typeahead = d;\n        this.button = DOM.JSBNG__find(b, \"a.fbNubButton\");\n        this.label = DOM.JSBNG__find(b, \"span.label\");\n        if (ChatConfig.get(\"sidebar\")) {\n            this.body = DOM.scry(b, \"div.fbNubFlyoutBody\")[0];\n            var c = DOM.JSBNG__find(b, \"div.fbNubFlyoutTitlebar\");\n            Toggler.createInstance(c).setSticky(false);\n            a.setScrollContainer(this.body);\n        }\n         else this.throbber = DOM.scry(b, \"img.throbber\")[0];\n    ;\n    ;\n        a.subscribe(\"content-changed\", this.flyoutContentChanged.bind(this));\n        Arbiter.subscribe(\"buddylist/count-changed\", this._updateCount.bind(this));\n        Arbiter.subscribe(\"chat/connect\", this._handleConnect.bind(this));\n        Arbiter.subscribe(\"chat/visibility-changed\", this._handleVisibility.bind(this));\n        if (((ChatConfig.get(\"channel_disconnect_warning\") && ChatConfig.get(\"channel_disconnect_warning_internal\")))) {\n            Arbiter.subscribe([channel.ON_CONNECT,channel.ON_IDLE,channel.ON_SHUTDOWN,], this._handleChannelStateChange.bind(this));\n        }\n    ;\n    ;\n        JSBNG__Event.listen(b, \"keydown\", this._onKeyDown.bind(this));\n        JSBNG__Event.listen(this.button, \"click\", this.JSBNG__onButtonClick.bind(this));\n        d.subscribe([\"respond\",\"reset\",], function(e, f) {\n            if (this._isOpen) {\n                if (((((((f && f.value)) && ((f.value === d.getCore().getValue())))) && d.getView().isVisible()))) {\n                    if (ChatConfig.get(\"sidebar\")) {\n                        Dock.setUseMaxHeight(this.root, false);\n                    }\n                ;\n                ;\n                    this.buddyList.hide();\n                }\n                 else this._showBuddyList();\n            ;\n            ;\n                this.flyoutContentChanged();\n            }\n        ;\n        ;\n        }.bind(this));\n        this.subscribe(\"show\", this.JSBNG__onShow.bind(this));\n        this.subscribe(\"hide\", this.JSBNG__onHide.bind(this));\n        this.subscribe(\"resize\", this.JSBNG__onResize.bind(this));\n        if (ChatConfig.get(\"sidebar\")) {\n            Arbiter.subscribe(\"sidebar/show\", this.hide.bind(this));\n        }\n         else {\n            Arbiter.subscribe(\"chat-options/initialized\", function(e, f) {\n                this.setSticky(!!f.getSetting(\"sticky_buddylist\"));\n            }.bind(this));\n            Arbiter.subscribe(\"chat/option-changed\", function(e, f) {\n                ((((f.JSBNG__name === \"sticky_buddylist\")) && this.setSticky(!!f.value)));\n            }.bind(this));\n            presence.registerStateStorer(this._storeState.bind(this));\n            presence.registerStateLoader(this._loadState.bind(this));\n            this._loadState(presence.state);\n        }\n    ;\n    ;\n        Arbiter.inform(\"buddylist-nub/initialized\", this, Arbiter.BEHAVIOR_PERSISTENT);\n    },\n    getButton: function() {\n        return this.button;\n    },\n    getRoot: function() {\n        return this.root;\n    },\n    getSticky: function() {\n        return !!this._sticky;\n    },\n    _handleConnect: function(a) {\n        this._setLabel(_tx(\"Chat\"), true);\n    },\n    _handleVisibility: function() {\n        var a = Chat.isOnline();\n        if (!a) {\n            this._setLabel(_tx(\"{Chat} (Offline)\", {\n                Chat: _tx(\"Chat\")\n            }));\n            this.hide();\n        }\n         else this._setLabel(_tx(\"Chat\"));\n    ;\n    ;\n        CSS.conditionClass(presence.holder, \"offline\", !a);\n    },\n    _handleChannelStateChange: function(a) {\n        if (((((a === channel.ON_IDLE)) || ((a === channel.ON_SHUTDOWN))))) {\n            this._setLabel(ChatConfig.get(\"buddy_list_channel_down\"));\n            CSS.addClass(presence.holder, \"channelDown\");\n        }\n         else if (((a === channel.ON_CONNECT))) {\n            CSS.removeClass(presence.holder, \"channelDown\");\n            this._handleVisibility();\n        }\n        \n    ;\n    ;\n    },\n    _loadState: function(b) {\n        var a = !!b.blo;\n        if (!presence.poppedOut) {\n            if (a) {\n                this.show();\n            }\n             else this.hide();\n        ;\n        }\n    ;\n    ;\n    },\n    JSBNG__onButtonClick: function() {\n        this._calculateAvailableCount();\n        this._conditionallyShowTypeahead();\n        if (CSS.shown(this.typeahead.getElement())) {\n            var a = this.subscribe(\"show\", function() {\n                this.typeahead.getCore().getElement().JSBNG__focus();\n            }.bind(this));\n            this.unsubscribe.bind(this, a).defer();\n        }\n    ;\n    ;\n    },\n    JSBNG__onHide: function() {\n        this._isOpen = false;\n        this.buddyList.subscribe(\"initialized\", function() {\n            if (this._buddyListRenderSubscription) {\n                this.buddyList.unsubscribe(this._buddyListRenderSubscription);\n            }\n        ;\n        ;\n            this.buddyList.hide();\n        }.bind(this));\n        this.typeahead.getCore().reset();\n        presence.doSync();\n    },\n    _onKeyDown: function(JSBNG__event) {\n        var a = JSBNG__Event.getKeyCode(JSBNG__event);\n        if (((((a === KEYS.ESC)) && !CSS.hasClass(this.root, \"menuOpened\")))) {\n            this.hide();\n            return false;\n        }\n    ;\n    ;\n    },\n    JSBNG__onResize: function() {\n        if (ChatConfig.get(\"sidebar\")) {\n            var a = ((Vector2.getElementDimensions(this.body).y - 5));\n            this.buddyList.setNumTopFriends(Math.floor(((a / BuddyListNub.ITEM_HEIGHT))));\n        }\n    ;\n    ;\n    },\n    _showBuddyList: function() {\n        if (ChatConfig.get(\"sidebar\")) {\n            this._buddylistRenderSubscription = this.buddyList.subscribe(\"render\", Dock.setUseMaxHeight.bind(Dock, this.root, false));\n        }\n    ;\n    ;\n        this.buddyList.show();\n    },\n    JSBNG__onShow: function() {\n        this._isOpen = true;\n        Chat.goOnline(function() {\n            this.buddyList.subscribe(\"initialized\", this._showBuddyList.bind(this));\n            presence.doSync();\n        }.bind(this));\n    },\n    _setLabel: function(a, c) {\n        var b = this.label.cloneNode(true);\n        DOM.setContent(b, a);\n        DOM.replace(this.label, b);\n        this.label = b;\n        ((this.throbber && CSS.conditionShow(this.throbber, !!c)));\n    },\n    setSticky: function(a) {\n        if (!this._toggler) {\n            this._toggler = Toggler.createInstance(this.root);\n        }\n    ;\n    ;\n        this._toggler.setSticky(a);\n        this._sticky = a;\n    },\n    _storeState: function(a) {\n        a.blo = ((this._isOpen ? 1 : 0));\n        return a;\n    },\n    _calculateAvailableCount: function() {\n        this._availableCount = AvailableList.getAvailableIDs().filter(function(a) {\n            return ((AvailableList.get(a) === AvailableList.ACTIVE));\n        }).length;\n    },\n    _conditionallyShowTypeahead: function() {\n        var a = ((this.buddyList.flMode ? BuddyListNub.TYPEAHEAD_MIN_FRIENDS_FLMODE : BuddyListNub.TYPEAHEAD_MIN_FRIENDS));\n        CSS.conditionShow(this.typeahead.getElement(), ((this._availableCount >= a)));\n    },\n    _updateCount: function() {\n        if (!Chat.isOnline()) {\n            return;\n        }\n    ;\n    ;\n        this._calculateAvailableCount();\n        var a = _tx(\"{Chat} {number-available}\", {\n            Chat: _tx(\"Chat\"),\n            \"number-available\": [\"\\u003Cspan class=\\\"count\\\"\\u003E\",\"(\\u003Cstrong\\u003E\",this._availableCount,\"\\u003C/strong\\u003E)\",\"\\u003C/span\\u003E\",].join(\"\")\n        });\n        this._setLabel(HTML(a));\n        this._conditionallyShowTypeahead();\n    }\n};\nfunction ChatTabActions(a) {\n    this._container = a;\n    this._actions = {\n    };\n    this._actionOrder = [];\n    this._visibilityChanged = false;\n    this._anyVisible = false;\n    this.actionClass = \"action\";\n};\n;\ncopy_properties(ChatTabActions.prototype, {\n    anyVisible: function() {\n        return this._anyVisible;\n    },\n    appendAction: function(c, b, a) {\n        this._addAction(c, b, a);\n        this._actionOrder.push(c);\n        return this;\n    },\n    prependAction: function(c, b, a) {\n        this._addAction(c, b, a);\n        this._actionOrder.unshift(c);\n        return this;\n    },\n    removeAction: function(a) {\n        delete this._actions[a];\n        return this;\n    },\n    setVisible: function(b, c) {\n        var a = this._actions[b];\n        if (((a && ((a.visible != c))))) {\n            a.visible = c;\n            this._visibilityChanged = true;\n        }\n    ;\n    ;\n        return this;\n    },\n    refresh: function() {\n        if (this._visibilityChanged) {\n            this._render();\n            this._visibilityChanged = false;\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    _render: function() {\n        DOM.empty(this._container);\n        var c = this._actions;\n        var b = this._actionOrder;\n        this._anyVisible = false;\n        var d = [];\n        for (var e = 0; ((e < b.length)); ++e) {\n            var a = c[b[e]];\n            if (a.visible) {\n                if (this._anyVisible) {\n                    d.push($N(\"span\", {\n                        className: \"divider\"\n                    }, HTML(\" &middot; \")));\n                }\n            ;\n            ;\n                d.push(a.create_element());\n                this._anyVisible = true;\n            }\n        ;\n        ;\n        };\n    ;\n        DOM.appendContent(this._container, d);\n        this._container.style.display = ((this._anyVisible ? \"block\" : \"none\"));\n    },\n    _addAction: function(c, b, a) {\n        if (((typeof b == \"string\"))) {\n            var d = b;\n            b = function() {\n                return $N(\"a\", {\n                    className: this.actionClass,\n                    href: \"#\"\n                }, d);\n            }.bind(this);\n        }\n    ;\n    ;\n        this._actions[c] = {\n            create_element: function() {\n                var e = b();\n                JSBNG__Event.listen(e, \"click\", a);\n                return e;\n            },\n            visible: false\n        };\n        this._visibilityChanged = true;\n    }\n});\nvar ChatUserInfoManager = ((window.ChatUserInfoManager || (function() {\n    var a = new Arbiter();\n    var b = {\n    };\n    var k = [];\n    var f = false;\n    var h = false;\n    function c() {\n        if (((!k.length || f))) {\n            return;\n        }\n    ;\n    ;\n        f = true;\n        e.defer();\n    };\n;\n    function d(m, l) {\n        a.inform(\"fetch\");\n        new AsyncRequest().setURI(m).setData(l).setHandler(function(n) {\n            j(n, l.ids);\n        }).setErrorHandler(i).setAllowCrossPageTransition(true).setMethod(\"GET\").setReadOnly(true).send();\n    };\n;\n    function e() {\n        var l = k;\n        k = [];\n        d(\"/ajax/chat/user_info.php\", {\n            ids: l\n        });\n    };\n;\n    function g() {\n        f = false;\n        c();\n    };\n;\n    function j(o, n) {\n        var p = ((n ? Object.from(n) : {\n        }));\n        for (var m in o.payload) {\n            var r = o.payload[m];\n            if (!r.type) {\n                r.type = \"friend\";\n            }\n        ;\n        ;\n            ChatUserInfos[m] = r;\n            var l = b[m];\n            if (l) {\n                delete b[m];\n                l.forEach(function(s) {\n                    try {\n                        s(r, m);\n                    } catch (t) {\n                    \n                    };\n                ;\n                });\n            }\n        ;\n        ;\n            delete p[m];\n        };\n    ;\n        for (var q in p) {\n            delete b[q];\n        ;\n        };\n    ;\n        g();\n        a.inform(\"updated\");\n    };\n;\n    function i() {\n        g();\n    };\n;\n    return copy_properties(a, {\n        get: function(m, l) {\n            l = ((l || bagofholding));\n            if (ChatUserInfos[m]) {\n                l(ChatUserInfos[m], m);\n            }\n             else {\n                if (!b[m]) {\n                    b[m] = [];\n                    k.push(m);\n                    c();\n                }\n            ;\n            ;\n                b[m].push(l);\n            }\n        ;\n        ;\n        },\n        hasAll: function() {\n            return h;\n        },\n        fetchAll: function() {\n            if (!h) {\n                d(\"/ajax/chat/user_info_all.php\", {\n                    viewer: Env.user\n                });\n                h = true;\n            }\n        ;\n        ;\n        }\n    });\n})()));\nfunction VideoEvents() {\n\n};\n;\nFunction.mixin(VideoEvents, \"Arbiter\", {\n    ACTIVATING: \"videochat/activating\",\n    LOGGING_IN: \"videochat/logging_in\",\n    GETTING_TOKEN: \"videochat/getting_token\",\n    CONNECTING: \"videochat/connecting\",\n    SLOW_CONDITIONS: \"videochat/slow_conditions\",\n    CALL_INCOMING: \"videochat/call_incoming\",\n    CALL_CONNECTED: \"videochat/call_connected\",\n    GOT_CALLEE: \"videochat/got_callee\",\n    CALL_HANDLED: \"videochat/call_handled\",\n    CALLEE_ANSWERING: \"videochat/callee_answering\",\n    FATAL_ERROR: \"videochat/fatal_error\",\n    CALL_IN_PROGRESS: \"videochat/call_in_progress\",\n    NOT_AVAILABLE: \"videochat/not_available\",\n    SERVER_ERROR: \"videochat/server_error\",\n    ACTIVATE_FAILED: \"videochat/activate_failed\",\n    ACTIVATE_TIMED_OUT: \"videochat/activate_failed_time\",\n    FATAL_PLUGIN_ERROR: \"videochat/plugin_fatality\",\n    SILENT_PLUGIN_ERROR: \"videochat/plugin_silent_fatality\",\n    START_CALL_UI: \"videochat/start_call_ui\",\n    START_CALL: \"videochat/start_call\",\n    ANSWER_CALL: \"videochat/answer_call\",\n    IGNORE_CALL: \"videochat/ignore_call\",\n    CANCEL_CALL: \"videochat/cancel_call\",\n    INSTALL_COMPLETED: \"videochat/install_completed\",\n    log: function(a) {\n        ((((window.JSBNG__console && JSBNG__console.log)) && JSBNG__console.log(a)));\n    },\n    warn: function(a) {\n        ((((window.JSBNG__console && JSBNG__console.warn)) && JSBNG__console.warn(a)));\n    },\n    error: function(a) {\n        ((((window.JSBNG__console && JSBNG__console.error)) && JSBNG__console.error(a)));\n    }\n});\nLogMessageType = {\n    VIDEO_CALL: 0,\n    THREAD_NAME: 4,\n    THREAD_IMAGE: 5\n};\n(function() {\n    if (window.ChatSendQueue) {\n        return;\n    }\n;\n;\n    window.ChatSendQueue = function(l, k) {\n        this._id = l;\n        this._handler = k;\n        this._messages = [];\n        this._timeout = null;\n        this._started = false;\n    };\n    var j = JSLogger.create(\"chat_msg\"), e = \"pending\", h = \"sent\", a = \"acked\", c = \"delivered\", d = 3, g = false, i = 1000, b = 10000, f = 20000;\n    copy_properties(ChatSendQueue.prototype, {\n        _indexOf: function(l) {\n            for (var k = 0; ((k < this._messages.length)); k++) {\n                if (((this._messages[k].id == l))) {\n                    return k;\n                }\n            ;\n            ;\n            };\n        ;\n            return -1;\n        },\n        _setExpiration: function(k) {\n            var l = (new JSBNG__Date()).getTime();\n            if (((k.state == e))) {\n                k.expiration = ((l + f));\n            }\n             else k.expiration = ((l + b));\n        ;\n        ;\n            return true;\n        },\n        _setState: function(k, l) {\n            k.state = l;\n            return this._setExpiration(k);\n        },\n        _onTimeout: function() {\n            var l = (new JSBNG__Date()).getTime();\n            if (this._handler.isTransportAvailable()) {\n                if (!this._started) {\n                    this._started = true;\n                    this._startedTime = l;\n                    this._messages.filter(this._setExpiration);\n                }\n            ;\n            ;\n            }\n             else if (((this._messages.length > 0))) {\n                j.warn(\"queued_send\");\n                this._started = false;\n                JSBNG__clearTimeout(this._timeout);\n                this._timeout = this._onTimeout.bind(this).defer(i, g);\n                return;\n            }\n            \n        ;\n        ;\n            var n = 0;\n            var m = null;\n            var k = 0;\n            this._messages = this._messages.filter(function(o) {\n                if (((o.expiration < l))) {\n                    j.error(((\"drop_\" + o.state)), {\n                        id: o.id\n                    });\n                    this._handler.JSBNG__onTimeout(o.id, o.state, o.msg);\n                    return false;\n                }\n            ;\n            ;\n                if (((!k || ((k > o.expiration))))) {\n                    k = o.expiration;\n                }\n            ;\n            ;\n                if (((o.state == h))) {\n                    n++;\n                }\n                 else if (((((o.state == e)) && !m))) {\n                    m = o;\n                }\n                \n            ;\n            ;\n                return true;\n            }.bind(this));\n            if (((((n === 0)) && m))) {\n                this._setState(m, h);\n                this._setExpiration(m);\n                j.log(\"send\", {\n                    id: m.id,\n                    retries: m.retries\n                });\n                this._handler.sendToServer(m.id, m.msg);\n            }\n        ;\n        ;\n            if (this._timeout) {\n                JSBNG__clearTimeout(this._timeout);\n                this._timeout = null;\n            }\n        ;\n        ;\n            if (k) {\n                k = Math.min(i, ((k - l)));\n                this._timeout = this._onTimeout.bind(this).defer(k, g);\n            }\n        ;\n        ;\n        },\n        _logAckStatus: function(k, l) {\n            var m = function() {\n                var n = ((\"send_t\" + l));\n                j.bump(n);\n                if (((k.state == \"delivered\"))) {\n                    j.bump(((n + \"_ack\")));\n                }\n            ;\n            ;\n            }.bind(this);\n            JSBNG__setTimeout(m, ((l * 1000)), false);\n        },\n        sendToServer: function(p, n, l) {\n            l = ((l || b));\n            var q = (new JSBNG__Date()).getTime();\n            var o = {\n                id: p,\n                state: e,\n                msg: n,\n                retries: ChatConfig.get(\"ChatSendQueue.NumRetries\", d),\n                now: q,\n                times: [{\n                    created: q\n                },]\n            };\n            this._setExpiration(o);\n            this._messages.push(o);\n            var k = ChatConfig.get(\"ack_checks\", [2,5,10,20,]);\n            for (var m = 0; ((m < k.length)); m++) {\n                this._logAckStatus(o, k[m]);\n            ;\n            };\n        ;\n            j.debug(\"queue\", {\n                id: p\n            });\n            this._onTimeout();\n        },\n        JSBNG__onSend: function(o, l, k) {\n            j.debug(\"JSBNG__on_send\", {\n                id: o,\n                error: l\n            });\n            var p = (new JSBNG__Date()).getTime();\n            var m = this._indexOf(o);\n            if (((m >= 0))) {\n                var n = this._messages[m];\n                n.times.push({\n                    JSBNG__on_send: p\n                });\n                if (((n.state == a))) {\n                    j.warn(\"JSBNG__on_send_already_acked\", {\n                        id: o\n                    });\n                }\n                 else {\n                    if (((n.state == e))) {\n                        j.warn(\"JSBNG__on_send_pending\", {\n                            id: o\n                        });\n                    }\n                ;\n                ;\n                    if (!l) {\n                        this._setState(n, a);\n                    }\n                     else if (((((l == \"transport_error\")) && ((n.retries > 0))))) {\n                        j.warn(\"JSBNG__on_send_retrying\", {\n                            id: o\n                        });\n                        n.retries--;\n                        this._setState(n, e);\n                    }\n                     else {\n                        j.error(\"drop_error\", {\n                            id: o,\n                            state: n.state,\n                            error: l\n                        });\n                        this._messages.splice(m, 1);\n                        this._handler.JSBNG__onTimeout(n.id, n.state, n.msg, l, k);\n                    }\n                    \n                ;\n                ;\n                }\n            ;\n            ;\n            }\n             else j.warn(\"JSBNG__on_send_unknown\", {\n                id: o\n            });\n        ;\n        ;\n            this._onTimeout();\n        },\n        JSBNG__onReceive: function(n) {\n            var o = (new JSBNG__Date()).getTime();\n            var k = false;\n            for (var l = 0; ((l < this._messages.length)); l++) {\n                var m = this._messages[l];\n                if (((m.id != n))) {\n                    continue;\n                }\n            ;\n            ;\n                k = true;\n                m.times.push({\n                    JSBNG__on_receive: o\n                });\n                if (((m.state != a))) {\n                    j.warn(\"JSBNG__on_receive_out_of_order\", {\n                        id: n,\n                        state: m.state\n                    });\n                }\n            ;\n            ;\n                this._messages.splice(l, 1);\n                this._setState(m, c);\n                j.log(\"JSBNG__on_delivered\", {\n                    id: n\n                });\n                this._handler.JSBNG__onDelivered(m.id, m.msg);\n                break;\n            };\n        ;\n            if (!k) {\n                j.warn(\"JSBNG__on_receive_unknown\", {\n                    id: n\n                });\n            }\n        ;\n        ;\n            this._onTimeout();\n            return k;\n        },\n        forEach: function(k) {\n            this.inForEach = true;\n            this._messages = this._messages.filter(function(l) {\n                return !k(l.id, l.msg, l.state);\n            }.bind(this));\n            this.inForEach = false;\n            this._onTimeout();\n        },\n        findById: function(l) {\n            var k = this._indexOf(l);\n            return ((((k < 0)) ? null : this._messages[k].msg));\n        },\n        discard: function(m) {\n            if (this.inForEach) {\n                throw \"discard cannot be called from within a forEach call.\";\n            }\n             else if (((m === undefined))) {\n                if (((this._messages.length > 0))) {\n                    j.log(\"discard\", {\n                        id: \"all\"\n                    });\n                }\n            ;\n            ;\n                this._messages = [];\n                JSBNG__clearTimeout(this._timeout);\n                this._timeout = null;\n            }\n             else {\n                var k = this._indexOf(m);\n                if (((k >= 0))) {\n                    var l = this._messages[k];\n                    j.log(\"discard\", {\n                        id: m\n                    });\n                    this._messages.splice(k, 1);\n                    this._onTimeout();\n                }\n            ;\n            ;\n            }\n            \n        ;\n        ;\n        },\n        JSBNG__onDump: function(l, k) {\n            k.pending_messages = ((k.pending_messages || []));\n            k.pending_messages.push({\n                id: this._id,\n                messages: this._messages\n            });\n            k.channel_start_time = this._startedTime;\n        }\n    });\n})();\nfunction ChatLiveListenTab(a, c, e, g, f, d) {\n    this._renderedSongs = {\n    };\n    this._renderedListenerUpdates = {\n    };\n    this._facepileHandlers = [];\n    this._sessionEnded = false;\n    this._facepileRequest = false;\n    this._hasBeginSessionItem = false;\n    this.parent.construct(this, a, c, e, e, f, d);\n    var h = this.chatDisplay.tabs;\n    for (var b in h) {\n        if (((((h[b].getPostType() == \"livelisten\")) && ((b != c))))) {\n            this.chatDisplay.closeTab(b);\n        }\n    ;\n    ;\n    };\n;\n};\n;\nClass.extend(ChatLiveListenTab, \"ChatGroupTab\");\nChatLiveListenTab.prototype = {\n    rendererName: \"chat-livelisten-tab\",\n    getPostType: function() {\n        return \"livelisten\";\n    },\n    getTabMsgType: function() {\n        return \"livelisten_msg\";\n    },\n    loadData: function() {\n        this.parent.loadData();\n        MusicEvents.subscribe([MusicConstants.LIVE_LISTEN_OP.NOW_LEADING,MusicConstants.LIVE_LISTEN_OP.NOW_LISTENING,], this._handleNewSessionUpdate.bind(this));\n        MusicEvents.subscribe([MusicConstants.LIVE_LISTEN_OP.END_SESSION,], this._handleEndSession.bind(this));\n        MusicEvents.subscribe([MusicConstants.LIVE_LISTEN_OP.SONG_PLAYING,], this._handleSongUpdate.bind(this));\n        MusicEvents.subscribe([MusicConstants.LIVE_LISTEN_OP.LISTENER_UPDATE,], this._handleListenerUpdate.bind(this));\n    },\n    _handleSongUpdate: function(d, a) {\n        var c = ((a.song ? a.song : {\n        }));\n        if (((((((((((((a.session && ((a.session.session_id == this.id)))) && c.title)) && c.artist)) && c.artist_url)) && c.published)) && ((c.published >= a.session.creation_time))))) {\n            var b = {\n                to: a.session.session_id,\n                from: a.session.leader,\n                type: \"logmessage\",\n                time: ((c.published * 1000)),\n                musicMsg: {\n                    title: c.title,\n                    url: c.url,\n                    artist: c.artist,\n                    artist_url: c.artist_url,\n                    music_type: \"song\"\n                }\n            };\n            this.newLogMessage(b);\n        }\n    ;\n    ;\n    },\n    _handleListenerUpdate: function(e, a) {\n        if (((((a.session && ((a.session.session_id == this.id)))) && a.actor))) {\n            var d = ((a.actor.time * 1000));\n            var c = {\n                to: a.session.session_id,\n                from: a.actor.id,\n                type: \"logmessage\",\n                time: d,\n                musicMsg: {\n                    actor: a.actor,\n                    music_type: \"listener_update\"\n                }\n            };\n            if (!((this._renderedListenerUpdates[d] && ((this._renderedListenerUpdates[d] == a.actor.id))))) {\n                this._setUpdateFacepiles(true);\n                if (a.session.chat_name) {\n                    this.updateName(a.session.chat_name);\n                    var b = DOM.JSBNG__find(this.getTabDOM(), \"span.titlebarText\");\n                    if (b) {\n                        DOM.setContent(b, a.session.chat_name);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.newLogMessage(c);\n        }\n    ;\n    ;\n    },\n    _handleNewSessionUpdate: function(c, a) {\n        if (((((((a.session && ((a.session.session_id == this.id)))) && a.actor)) && a.actor.time))) {\n            var b = {\n                to: a.session.session_id,\n                from: a.actor.id,\n                type: \"logmessage\",\n                time: ((a.actor.time * 1000)),\n                musicMsg: {\n                    actor: a.actor,\n                    music_type: \"begin_session\"\n                }\n            };\n            this.newLogMessage(b);\n        }\n    ;\n    ;\n    },\n    _setHistory: function(b) {\n        this._renderedSongs = {\n        };\n        this._renderedListenerUpdates = {\n        };\n        this._hasBeginSessionItem = false;\n        for (var a = 0; ((a < b.length)); a++) {\n            if (((b[a].msg && b[a].msg.music_type))) {\n                b[a].type = \"logmessage\";\n                var c = b[a].msg;\n                b[a].musicMsg = c;\n                delete b[a].msg;\n            }\n        ;\n        ;\n        };\n    ;\n        return this.parent._setHistory(b);\n    },\n    close: function() {\n        this.parent.close();\n        ((Panda && Panda.getInstance().endSession(this.id)));\n    },\n    _renderLogMessage: function(a) {\n        if (presence.inPopoutWindow) {\n            return;\n        }\n    ;\n    ;\n        var b = a.musicMsg;\n        if (((b && ((b.music_type == \"song\"))))) {\n            this._renderSongItem(b.title, b.url, b.artist, b.artist_url, a.time);\n        }\n         else if (((b && ((b.music_type == \"listener_update\"))))) {\n            this._renderListenerUpdateItem(b.actor, a.time);\n        }\n         else if (((b && ((b.music_type == \"begin_session\"))))) {\n            this._renderBeginSessionItem(b.actor, a.time);\n        }\n        \n        \n    ;\n    ;\n    },\n    _renderSongItem: function(e, g, a, c, d) {\n        if (((this._renderedSongs[d] && ((this._renderedSongs[d] == g))))) {\n            return;\n        }\n    ;\n    ;\n        this._renderedSongs[d] = g;\n        var f = presence.renderLink(g, htmlize(e), \"target=\\\"_blank\\\"\");\n        var b = presence.renderLink(c, htmlize(a));\n        this._renderLiveListenLogItem(HTML(_tx(\"{title} by {artist} on {provider}\", {\n            title: f,\n            artist: b,\n            provider: \"Spotify\"\n        })), d, \"songIcon\");\n    },\n    _renderListenerUpdateItem: function(a, f) {\n        if (((this._renderedListenerUpdates[f] && ((this._renderedListenerUpdates[f] == a.id))))) {\n            return;\n        }\n    ;\n    ;\n        var d = ((a.action == MusicLiveListen.LISTENER_ADD));\n        var c = null;\n        var b = presence.renderLink(a.url, htmlize(a.JSBNG__name));\n        var e = presence.renderLink(a.leader_profile_url, htmlize(a.leader_name));\n        if (d) {\n            if (((presence.user == a.id))) {\n                c = _tx(\"You are now listening to music with {name}. You will hear all the music that they play, unless you close this conversation, or start playing your own music.\", {\n                    JSBNG__name: e\n                });\n            }\n             else c = _tx(\"{name} started listening.\", {\n                JSBNG__name: b\n            });\n        ;\n        ;\n        }\n         else if (((((a.leader_id == a.id)) && ((presence.user != a.leader_id))))) {\n            c = _tx(\"{name} left the conversation. You will no longer hear the songs they play.\", {\n                JSBNG__name: e\n            });\n        }\n         else if (((((presence.user == a.id)) && ((a.id != a.leader_id))))) {\n            c = _tx(\"You are no longer listening to music with {name}.\", {\n                JSBNG__name: e\n            });\n        }\n         else if (((presence.user != a.id))) {\n            c = _tx(\"{name} stopped listening.\", {\n                JSBNG__name: b\n            });\n        }\n        \n        \n        \n    ;\n    ;\n        if (c) {\n            this._renderedListenerUpdates[f] = a.id;\n            this._renderLiveListenLogItem(c, f, ((d ? \"addActionIcon\" : \"leaveActionIcon\")));\n        }\n    ;\n    ;\n    },\n    _renderBeginSessionItem: function(a, c) {\n        if (this._hasBeginSessionItem) {\n            return;\n        }\n    ;\n    ;\n        var b = null;\n        if (((a.id == presence.user))) {\n            b = _tx(\"You are now listening to music with {name}. You will hear all the music that they play, unless you close this conversation, or start playing your own music.\", {\n                JSBNG__name: presence.renderLink(a.leader_profile_url, htmlize(a.leader_name))\n            });\n        }\n         else if (((a.leader_id == presence.user))) {\n            b = _tx(\"{name} is listening to music with you. When you play new songs, they will hear them too. If you'd ever like people in this conversation to stop listening with you, just close this chat window.\", {\n                JSBNG__name: presence.renderLink(a.url, htmlize(a.JSBNG__name))\n            });\n        }\n        \n    ;\n    ;\n        if (b) {\n            this._hasBeginSessionItem = true;\n            this._renderLiveListenLogItem(b, c, \"addActionIcon\");\n        }\n    ;\n    ;\n    },\n    _renderLiveListenLogItem: function(a, g, c) {\n        var f = this.chatDisplay.templates[\"chat-msg-event\"].render();\n        var h = XHPTemplate.getNode(f, \"timestamp\");\n        var e = this.chatDisplay.renderServerTime(g);\n        DOM.setContent(h, e);\n        this._checkDateBreak(g);\n        var b = XHPTemplate.getNode(f, \"icon\");\n        CSS.addClass(b, c);\n        var d = XHPTemplate.getNode(f, \"message\");\n        DOM.appendContent(d, HTML(a));\n        DOM.appendContent(this.chatConvContent, f);\n        this.currentMsgGroup = null;\n    },\n    _sendFacepileRequest: function() {\n        this._lastUpdateRequestTimeMS = (new JSBNG__Date()).getTime();\n        new AsyncRequest().setData({\n            id: this.id\n        }).setURI(\"/ajax/livelisten/chat/update_facepiles.php\").setHandler(this._renderFacepile.bind(this)).send();\n    },\n    getProfileURI: function() {\n        return;\n    },\n    JSBNG__focus: function() {\n        this.parent.JSBNG__focus();\n        if (this._sessionEnded) {\n            this._handleEndSession();\n        }\n    ;\n    ;\n    },\n    _handleEndSession: function() {\n        this._sessionEnded = true;\n        CSS.hide(this.chatInfo);\n        this.handleResize();\n        this._setUpdateFacepiles(false);\n        var a = this.chatDisplay.templates[\"chat-msg-error\"].render();\n        CSS.addClass(a, \"pas\");\n        DOM.setContent(XHPTemplate.getNode(a, \"message\"), _tx(\"Everyone has left this conversation, so it is now inactive.\"));\n        this.openSheet(a, true);\n    }\n};\nfunction TypingIndicator(a, b, d, c) {\n    this.id = a;\n    this.input = b;\n    this.source = d;\n    this.callback = null;\n    Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"typ\"), this.JSBNG__onTyping.bind(this));\n    this.remoteState = TypingDetector.INACTIVE;\n    this.notifyTimer = null;\n    c = ((c || {\n    }));\n    this.notifyDelay = ((c.notifyDelay || this.notifyDelay));\n    this._typingDetector = new TypingDetector(b);\n    this._typingDetector.init(c);\n    this._typingDetector.subscribe(\"change\", this._stateChange.bind(this));\n};\n;\ncopy_properties(TypingIndicator.prototype, {\n    notifyDelay: 1000,\n    setIgnoreEnter: function(a) {\n        var b = ((a ? [KEYS.RETURN,] : []));\n        this._typingDetector.setIgnoreKeys(b);\n    },\n    resetState: function() {\n        presence.debug(\"typing: ** RESET **\");\n        this.remoteState = TypingIndicator.INACTIVE;\n        this._typingDetector.reset();\n        JSBNG__clearTimeout(this.notifyTimer);\n        this.notifyTimer = null;\n    },\n    _stateChange: function(a, b) {\n        if (((b == TypingDetector.ACTIVE))) {\n            presence.debug(((((((\"typing:\" + this.currentState)) + \" -\\u003E \")) + b)));\n        }\n    ;\n    ;\n        if (((b != TypingDetector.QUITTING))) {\n            JSBNG__clearTimeout(this.notifyTimer);\n            this.notifyTimer = this._notifyState.shield(this, b).defer(this.notifyDelay);\n        }\n         else this._notifyState(b, true);\n    ;\n    ;\n    },\n    _notifyState: function(c, b) {\n        var d = this.id;\n        if (((Chat.isOnline() && ((c != this.remoteState))))) {\n            this.remoteState = c;\n            presence.debug(((((\"typing: notifyState(\" + c)) + \")\")));\n            if (!channelManager.iframeEverLoaded) {\n                return;\n            }\n        ;\n        ;\n            var a = {\n                typ: c,\n                to: d,\n                source: this.source\n            };\n            new AsyncRequest().setHandler(this._onTypResponse.bind(this, d)).setErrorHandler(bagofholding).setData(a).setURI(\"/ajax/messaging/typ.php\").setAllowCrossPageTransition(true).setOption(\"asynchronous\", !b).send();\n        }\n    ;\n    ;\n    },\n    _onTypResponse: function(c, b) {\n        var a = ((b.getPayload() || {\n        }));\n        if (a.offline) {\n            AvailableList.set(c, AvailableList.OFFLINE);\n        }\n    ;\n    ;\n    },\n    setCallback: function(a) {\n        this.callback = a;\n    },\n    JSBNG__onTyping: function(b, a) {\n        ((this.callback && this.callback(a.obj)));\n    }\n});\nfunction ChatThreadTab(a, e, f, b, d, c) {\n    this.parent.construct(this, a, e, f, b, d, c);\n};\n;\nClass.extend(ChatThreadTab, \"ChatTab\");\nChatThreadTab.prototype = {\n    rendererName: \"chat-thread-tab\",\n    msgGroupRendererName: \"chat-msg-thread-with-tooltip\",\n    hasThread: true,\n    _lastStatusUpdateTime: 0,\n    _participantStatuses: null,\n    _toolbarUpdateTimeoutID: null,\n    getPostType: function() {\n        return \"thread\";\n    },\n    getTabMsgType: function() {\n        return \"thread_msg\";\n    },\n    getAvailability: function() {\n        return AvailableList.ACTIVE;\n    },\n    _handleStatusChange: function() {\n        var a = false;\n        if (((this._participantStatuses === null))) {\n            a = true;\n        }\n         else for (var c in this._participantStatuses) {\n            if (((this._participantStatuses[c] != AvailableList.get(c)))) {\n                a = true;\n                break;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (a) {\n            var b = Math.floor(((ChatConfig.get(\"chat_tab_user_status_update_variation_range_ms\") * Math.JSBNG__random())));\n            this._toolbarUpdateTimeoutID = JSBNG__setTimeout(this._sendToolbarUpdateRequest.bind(this), b, false);\n        }\n    ;\n    ;\n    },\n    close: function() {\n        this.parent.close();\n        if (this._toolbarUpdateTimeoutID) {\n            JSBNG__clearTimeout(this._toolbarUpdateTimeoutID);\n        }\n    ;\n    ;\n    },\n    _sendToolbarUpdateRequest: function() {\n        this._toolbarUpdateTimeoutID = null;\n        var a = (new JSBNG__Date()).getTime();\n        if (((((a - this._lastStatusUpdateTime)) > ChatConfig.get(\"chat_tab_user_status_update_min_interval_ms\")))) {\n            new AsyncRequest().setData({\n                id: this.id,\n                has_thread: this.getHasThread()\n            }).setURI(\"/ajax/chat/multichat/update_toolbar.php\").setErrorHandler(this._onUpdateError.bind(this)).send();\n        }\n    ;\n    ;\n    },\n    _onUpdateError: function(b) {\n        var a = this.chatDisplay.templates[\"chat-sheet-notice\"].render();\n        DOM.setContent(XHPTemplate.getNode(a, \"text\"), b.errorDescription);\n        this.openSheet(a, true);\n    },\n    setParticipantStatuses: function(a) {\n        this._participantStatuses = a;\n    },\n    refreshStatusUpdateTime: function() {\n        this._lastStatusUpdateTime = (new JSBNG__Date()).getTime();\n    },\n    addRecipients: function(b) {\n        this.parent.addRecipients(b);\n        if (!this.getHasThread()) {\n            for (var a = 0; ((a < b.length)); a++) {\n                this.pendingNewRecipients.push(b[a]);\n            ;\n            };\n        }\n    ;\n    ;\n        return this;\n    },\n    showSendAsMessageLinks: bagofholding,\n    getSendData: function(a) {\n        send_data = this.parent.getSendData(a);\n        if (((((this.pendingNewRecipients.length > 0)) || !this.hasThread))) {\n            send_data.new_thread = true;\n            if (((this.pendingNewRecipients.length > 0))) {\n                send_data.new_recips = this.pendingNewRecipients;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return send_data;\n    },\n    reloadHistoryOnRestart: function() {\n        return this.getHasThread();\n    },\n    isCanonical: function() {\n        return false;\n    },\n    _buildUI: function() {\n        var c = this.parent._buildUI();\n        var b = XHPTemplate.getNode(c, \"dropdown\");\n        if (b) {\n            var a = XHPTemplate.getNode(c, \"addToThreadLink\");\n            if (a) {\n                this._handlers.push(JSBNG__Event.listen(a, \"click\", this.showAddFriendFromIcon.bind(this)));\n            }\n        ;\n        ;\n            var d = XHPTemplate.getNode(c, \"unsubscribeLink\");\n            if (d) {\n                this._handlers.push(JSBNG__Event.listen(d, \"click\", this.unsubscribeFromThread.bind(this)));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return c;\n    },\n    unsubscribeFromThread: function() {\n        if (this.getHasThread()) {\n            Messaging.unsubscribeFromThread(this.id);\n        }\n    ;\n    ;\n        this.chatDisplay.closeTab(this.id);\n    },\n    showAddFriendFromIcon: function() {\n        this.showAddFriend();\n        return false;\n    },\n    _messagingMarkThreadAsRead: function(a) {\n        Messaging.markAsRead(a);\n    },\n    getConversationURI: bagof(\"\"),\n    getProfileURI: function() {\n        return Messaging.getInboxThreadURI(this.id);\n    },\n    setHasThread: function(a) {\n        this.hasThread = a;\n        if (!a) {\n            this.historyLoaded = true;\n        }\n    ;\n    ;\n        this.setShowConversationLink(a);\n    },\n    setShowConversationLink: function(b) {\n        var a = XHPTemplate.getNode(this.tabHandle, \"conversationLink\");\n        if (a) {\n            if (b) {\n                CSS.show(a);\n            }\n             else CSS.hide(a);\n        ;\n        }\n    ;\n    ;\n    },\n    getHasThread: function() {\n        return this.hasThread;\n    }\n};\nfunction ChatGroupTab(a, b, d, f, e, c) {\n    this.parent.construct(this, a, b, d, d, e, c);\n    this._facepileHandlers = [];\n};\n;\nClass.extend(ChatGroupTab, \"ChatTab\");\nChatGroupTab.prototype = {\n    rendererName: \"chat-group-tab\",\n    msgGroupRendererName: \"chat-msg-group-with-tooltip\",\n    getPostType: function() {\n        return \"group\";\n    },\n    getTabMsgType: function() {\n        return \"group_msg\";\n    },\n    JSBNG__focus: function(c, a, b) {\n        this.parent.JSBNG__focus(c, a, b);\n        this._setUpdateFacepiles(true);\n    },\n    unfocus: function() {\n        this.parent.unfocus();\n        this._setUpdateFacepiles(false);\n    },\n    close: function() {\n        this.parent.close();\n        this._setUpdateFacepiles(false);\n        this._removeFacepileHandlers();\n    },\n    _facepilesToken: null,\n    _lastUpdateRequestTimeMS: 0,\n    _memberStatuses: null,\n    _setUpdateFacepiles: function(a) {\n        if (a) {\n            if (!this._facepilesToken) {\n                this._facepilesToken = JSBNG__setInterval(this._sendFacepileRequest.bind(this), ChatConfig.get(\"group_chat_facepile_update_interval_ms\"), false);\n                this._sendFacepileRequest();\n            }\n        ;\n        ;\n        }\n         else if (this._facepilesToken) {\n            JSBNG__clearInterval(this._facepilesToken);\n            this._facepilesToken = null;\n        }\n        \n    ;\n    ;\n    },\n    _resetUpdateFacepiles: function() {\n        this._setUpdateFacepiles(false);\n        this._setUpdateFacepiles(true);\n    },\n    _sendFacepileRequest: function() {\n        this._lastUpdateRequestTimeMS = (new JSBNG__Date()).getTime();\n        new AsyncRequest().setData({\n            id: this.id\n        }).setURI(\"/ajax/groups/chat/update_facepiles.php\").setHandler(this._renderFacepile.bind(this)).send();\n    },\n    _renderFacepile: function(b) {\n        this._removeFacepileHandlers();\n        var a = b.getPayload();\n        this._updateMemberStatuses(a.statuses);\n        if (a.response_html) {\n            DOM.setContent(this.chatInfo, HTML(a.response_html));\n        }\n    ;\n    ;\n        if (a.facepile_click_info) {\n            a.facepile_click_info.each(function(d) {\n                var c = DOM.scry($(d.id), \"a\");\n                if (c.length) {\n                    this._facepileHandlers.push(JSBNG__Event.listen(c[0], \"click\", function() {\n                        chatDisplay.focusTab(d.uid, true, d.JSBNG__name, d.firstName);\n                        return false;\n                    }));\n                }\n            ;\n            ;\n            }.bind(this));\n        }\n    ;\n    ;\n        this.handleResize();\n    },\n    _updateMemberStatuses: function(a) {\n        this._memberStatuses = a;\n    },\n    _removeFacepileHandlers: function() {\n        while (this._facepileHandlers.length) {\n            this._facepileHandlers.pop().remove();\n        ;\n        };\n    ;\n    },\n    showSendAsMessageLinks: bagofholding,\n    playSound: bagofholding,\n    _buildUI: function() {\n        var d = this.parent._buildUI();\n        var c = XHPTemplate.getNode(d, \"reportLink\");\n        if (c) {\n            CSS.addClass(c, \"hidden_elem\");\n        }\n    ;\n    ;\n        this.chatInfo = XHPTemplate.getNode(d, \"facepileHolder\");\n        var a = XHPTemplate.getNode(d, \"dropdown\");\n        if (a) {\n            var b = XHPTemplate.getNode(d, \"muteGroupLink\");\n            if (b) {\n                b.setAttribute(\"href\", URI(b.href).addQueryData({\n                    id: this.id\n                }));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    isCanonical: function() {\n        return false;\n    },\n    getAvailability: function() {\n        return AvailableList.ACTIVE;\n    },\n    _handleStatusChange: function() {\n        if (((this.focused && this._memberStatuses))) {\n            var c = Object.keys(this._memberStatuses);\n            var a = false;\n            for (var b = 0; ((b < c.length)); b++) {\n                if (((this._memberStatuses[c[b]] != AvailableList.get(c[b])))) {\n                    a = true;\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            var d = (new JSBNG__Date()).getTime();\n            if (((a && ((((d - this._lastUpdateRequestTimeMS)) > ChatConfig.get(\"chat_tab_user_status_update_min_interval_ms\")))))) {\n                this._resetUpdateFacepiles();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    mentionsUser: function(a) {\n        if (((a.from == presence.user))) {\n            return false;\n        }\n    ;\n    ;\n        var b = a.msg.text;\n        if (((((presence.alias !== \"\")) && ((b.indexOf(presence.alias) != -1))))) {\n            return true;\n        }\n    ;\n    ;\n        if (((((presence.firstName !== \"\")) && ((b.toLowerCase().indexOf(presence.firstName.toLowerCase()) != -1))))) {\n            return true;\n        }\n    ;\n    ;\n        return false;\n    },\n    newMsg: function(a) {\n        if (this.mentionsUser(a)) {\n            this.parent.playSound();\n        }\n    ;\n    ;\n        this.parent.newMsg(a);\n    },\n    getConversationURI: bagof(\"\"),\n    getProfileURI: function() {\n        return URI(env_get(\"www_base\")).setPath(\"/\").setQueryData({\n            sk: ((\"group_\" + this.id))\n        });\n    }\n};\nfunction ChatTab(a, d, f, b, h, e) {\n    this.inDock = !presence.inPopoutWindow;\n    this.chatDisplay = a;\n    this.id = d;\n    this.JSBNG__name = ((f || \"\"));\n    this.firstName = ((b || this._guessFirstName()));\n    this.tabRef = ((((\"chatDisplay.tabs[\" + this.id)) + \"]\"));\n    this.tabDisabled = false;\n    this.numMissed = ((h || 0));\n    this.missedTime = e;\n    this.focused = false;\n    this.lastLogItem = null;\n    this.historyLoaded = false;\n    this.failedSentMsgs = [];\n    this.historyRequestID = 0;\n    this.bounceAnimation = null;\n    this.pendingNewRecipients = [];\n    this.allRecipients = [];\n    this.minTextHeight = ((presence.inPopoutWindow ? this.minTextHeightPopout : this.minTextHeightPopin));\n    this.lastMessageAt = null;\n    this._handlers = [];\n    this._subscriptions = [];\n    var i = this;\n    var c = {\n        isTransportAvailable: function() {\n            return channelManager.iframeEverLoaded;\n        },\n        sendToServer: function(k, j) {\n            i._sendMessage(j);\n        },\n        JSBNG__onTimeout: this._handleSendErrors.bind(this),\n        JSBNG__onDelivered: function(k, j) {\n            i._setMsgInfoMarkup(k, \"\");\n        }\n    };\n    this.queue = new ChatSendQueue(this.id, c);\n    this._buildUI();\n    this.loadData();\n    this.timeBuilt = new JSBNG__Date();\n    this._handleStatusChange(true);\n    this._textareaListener = null;\n    this.isWindowFocused = true;\n    this.resetAutoCloseTimeout(true);\n    this._handlers.push(JSBNG__Event.listen(window, \"JSBNG__blur\", this._onWindowBlur.bind(this)), JSBNG__Event.listen(window, \"JSBNG__focus\", this._onWindowFocus.bind(this)));\n    this._subscriptions.push(Arbiter.subscribe([\"chat/visibility-changed\",\"buddylist/availability-changed\",], this._handleStatusChange.shield(this)));\n    this._enableJSLoggerDump();\n    if (ChatConfig.get(\"blackbird\")) {\n        this._blacklistSheetOpen = false;\n        PresencePrivacy.subscribe([\"privacy-changed\",\"privacy-availability-changed\",], this._handleStatusChange.shield(this));\n    }\n;\n;\n    if (this.inDock) {\n        var g = new NubController();\n        g.init(this.tabHandle);\n        g.subscribe(\"show\", function() {\n            if (((this.chatDisplay.focused != this.id))) {\n                this.chatDisplay.focusTab(this.id);\n            }\n        ;\n        ;\n        }.bind(this));\n        g.subscribe(\"hide\", function() {\n            if (this.focused) {\n                this.chatDisplay.unfocus();\n            }\n        ;\n        ;\n        }.bind(this));\n        g.subscribe(\"resize\", this.scrollToBottom.bind(this));\n    }\n;\n;\n    this._subscriptions.push(Arbiter.subscribe(\"overflow-applied-to-body\", this.scrollToBottom.bind(this)));\n    this._messagingToken = MessagingEvents.subscribe(\"read\", function(j, k) {\n        if (((k.chat_ids && k.chat_ids.contains(this.id)))) {\n            this._clearMessagingMarkAsRead();\n            if (k.mark_as_read) {\n                this._markRead();\n            }\n        ;\n        ;\n            this.chatDisplay.doStopBlinking();\n        }\n    ;\n    ;\n    }.bind(this));\n    Sound.init();\n};\n;\nClass.mixin(ChatTab, \"Arbiter\", {\n    currentMsgGroup: null,\n    rendererName: \"chat-tab\",\n    msgGroupRendererName: \"chat-msg-group\",\n    pendingToLogCompareWindow: 60000,\n    resendDelay: 5000,\n    handleWidth: 150,\n    popinWidth: 258,\n    popinHeight: 250,\n    popoutWidthOffset: 180,\n    flPopoutWidthOffset: 200,\n    minTextHeightPopin: 13,\n    minTextHeightPopout: 32,\n    maxTextHeight: 77,\n    msgBunchTime: 300000,\n    maxHandleLen: 16,\n    maxTitleLen: 20,\n    bounceDuration: 50,\n    _ACTION_LOG_SUBSCRIBE: 1,\n    _ACTION_LOG_UNSUBSCRIBE: 2,\n    _getJSLogger: function() {\n        if (!ChatTab._jslogger) {\n            ChatTab._jslogger = JSLogger.create(\"chat_tab\");\n        }\n    ;\n    ;\n        return ChatTab._jslogger;\n    },\n    _enableJSLoggerDump: function() {\n        this._subscriptions.push(Arbiter.subscribe(JSLogger.DUMP_EVENT, function(f, a) {\n            var d = [\"id\",\"JSBNG__name\",\"inDock\",\"numMissed\",\"focused\",\"lastLogItem\",\"historyLoaded\",\"failedSentMsgs\",\"timeBuilt\",\"isWindowFocused\",\"allRecipients\",\"focused\",];\n            var b = {\n            };\n            var e = this;\n            var c = ((a.other_uids || []));\n            c.push(this.id);\n            a.other_uids = c;\n            d.forEach(function(g) {\n                b[g] = e[g];\n            });\n            b.selfAvailableListDebugInfo = AvailableList.getDebugInfo(presence.user);\n            b.otherAvailableListDebugInfo = AvailableList.getDebugInfo(this.id);\n            this.queue.JSBNG__onDump(f, a);\n            a[this.id] = {\n                tab_info: b\n            };\n        }.bind(this)));\n    },\n    _onWindowFocus: function(JSBNG__event) {\n        this.isWindowFocused = true;\n        if (this.focused) {\n            this._markRead();\n        }\n    ;\n    ;\n    },\n    _onWindowBlur: function(JSBNG__event) {\n        this.isWindowFocused = false;\n    },\n    isTabVisible: function() {\n        return ((this.focused && ((presence.inPopoutWindow || !presence.poppedOut))));\n    },\n    start: function() {\n    \n    },\n    restart: function() {\n        if (this.reloadHistoryOnRestart()) {\n            if (this.focused) {\n                this.getHistory(true);\n            }\n             else this.historyLoaded = false;\n        ;\n        }\n    ;\n    ;\n        this.handleResize.bind(this).defer();\n    },\n    reloadHistoryOnRestart: function() {\n        return true;\n    },\n    loadData: function() {\n        if (this.chatDisplay.histories[this.id]) {\n            this._setHistory(this.chatDisplay.histories[this.id]);\n        }\n    ;\n    ;\n        if (!this.JSBNG__name) {\n            ChatUserInfoManager.get(this.id, function(a) {\n                this.updateName(a.JSBNG__name, a.firstName);\n            }.bind(this));\n        }\n    ;\n    ;\n    },\n    _onHistoryInitialHandler: function(a, b) {\n        if (((a != this.historyRequestID))) {\n            presence.debug(\"tabs: got old history async, ignoring\");\n            return false;\n        }\n    ;\n    ;\n        return null;\n    },\n    _compareHistoryMessages: function(b, a) {\n        var c = Math.abs(((b.time - a.time)));\n        if (((((c < this.pendingToLogCompareWindow)) && ((b.text == a.msg.text))))) {\n            this._setMsgInfoMarkup(b.msgID, \"\");\n        }\n    ;\n    ;\n        return false;\n    },\n    _onHistoryResponse: function(a, j) {\n        var b = j.getPayload();\n        var k = b.userInfo;\n        var h = b.JSBNG__history;\n        this._getJSLogger().log(\"history_send_responded\", {\n            request_id: this.historyRequestID,\n            from_restart: a\n        });\n        if (k) {\n            this.updateName(k.JSBNG__name, k.firstName);\n            Chat.setUserInfo(this.id, k);\n        }\n    ;\n    ;\n        if (!h) {\n            return;\n        }\n    ;\n    ;\n        if (((h.length > 0))) {\n            var c;\n            for (c = ((h.length - 1)); ((c >= 0)); c--) {\n                var g = h[c];\n                if (((g.to != this.chatDisplay.user))) {\n                    this.queue.forEach(function(m, l) {\n                        this._compareHistoryMessages(l, g);\n                    }.bind(this));\n                }\n            ;\n            ;\n            };\n        ;\n            var e = h[((h.length - 1))].time;\n            this.queue.forEach(function(m, l) {\n                if (((l.time < e))) {\n                    l.time = (++e);\n                }\n            ;\n            ;\n            });\n        }\n    ;\n    ;\n        var i = this.chatDisplay.histories[this.id];\n        if (i) {\n            if (((h.length > 0))) {\n                var d = h[((h.length - 1))];\n                var f = d.time;\n                for (var c = 0; ((c < i.length)); c++) {\n                    var g = i[c];\n                    if (((g.time > f))) {\n                        h.push(g);\n                    }\n                ;\n                ;\n                };\n            ;\n            }\n             else h = i;\n        ;\n        }\n    ;\n    ;\n        this._setHistory(h);\n        this.chatDisplay.histories[this.id] = h;\n    },\n    getHistory: function(a) {\n        var b = ++(this.historyRequestID);\n        this._getJSLogger().log(\"history_sent\", {\n            request_id: b,\n            from_restart: a\n        });\n        new AsyncRequest().setInitialHandler(this._onHistoryInitialHandler.bind(this, b)).setHandler(this._onHistoryResponse.bind(this, a)).setErrorHandler(bagofholding).setMethod(\"GET\").setReadOnly(true).setOption(\"suppressErrorAlerts\", true).setData({\n            type: this.getPostType(),\n            id: this.id\n        }).setURI(\"/ajax/chat/history.php\").setAllowCrossPageTransition(true).send();\n    },\n    getPostType: function() {\n        return \"friend\";\n    },\n    _setHistory: function(d) {\n        this.lastLogItem = null;\n        DOM.empty(this.chatConvContent);\n        var f = 0;\n        var i = [];\n        Array.prototype.push.apply(i, this.failedSentMsgs);\n        this.queue.forEach(function(k, j) {\n            i.push(j);\n        });\n        var e = 0;\n        for (var a = 0; ((a < d.length)); a++) {\n            var b = d[a];\n            var c = this.getMessageTypeInfo(b.type);\n            if (c.unknown) {\n                continue;\n            }\n        ;\n        ;\n            for (; ((f < i.length)); f++) {\n                var g = i[f];\n                var h = this.getMessageTypeInfo(g.type);\n                if (((((g.time > e)) && ((g.time <= b.time))))) {\n                    if (h.visible) {\n                        this.renderMsg(presence.user, this.id, g.time, g, g.msgID, g.isError, g.infoMarkup);\n                    }\n                ;\n                ;\n                }\n                 else break;\n            ;\n            ;\n            };\n        ;\n            if (c.msg) {\n                this.renderMsg(b.from, b.to, b.time, b.msg, b.msgId);\n            }\n             else if (c.logMessage) {\n                this._renderLogMessage(b);\n            }\n             else if (c.actionLog) {\n                this._renderActionLogMessage(b.actor, b.new_recipients, b.action, b.time);\n            }\n            \n            \n        ;\n        ;\n            this.lastLogItem = b;\n            e = b.time;\n        };\n    ;\n        for (; ((f < i.length)); f++) {\n            var g = i[f];\n            if (this.getMessageTypeInfo(g.type).visible) {\n                this.renderMsg(presence.user, this.id, g.time, g, g.msgID, g.isError, g.infoMarkup);\n                this.lastLogItem = {\n                    type: g.type,\n                    from: presence.user,\n                    to: this.id,\n                    time: g.time,\n                    msg: g\n                };\n            }\n        ;\n        ;\n        };\n    ;\n        this.scrollToBottom();\n        this.historyLoaded = true;\n    },\n    addRecipients: function(b) {\n        for (var a = 0; ((a < b.length)); a++) {\n            this.allRecipients.push(b[a]);\n        ;\n        };\n    ;\n        return this;\n    },\n    setRecipients: function(a) {\n        this.allRecipients = a;\n        return this;\n    },\n    getRecipients: function() {\n        return this.allRecipients;\n    },\n    newActionLogMsg: function(c) {\n        var d = ((c.time || presence.getTime()));\n        var b = {\n            type: \"actionlog\",\n            action: c.actionType,\n            time: c.timestampMsec,\n            actor: c.actorInfo,\n            new_recipients: c.newRecipientsInfo\n        };\n        var a = this.isUserScrolled();\n        this._renderActionLogMessage(c.actorInfo, c.newRecipientsInfo, c.actionType, c.timestampMsec);\n        ((!a && this.scrollToBottom()));\n        this.lastLogItem = b;\n        this.chatDisplay.addToHistory(this.id, b);\n    },\n    _renderActionLogMessage: function(b, e, i, g) {\n        var a = this.chatDisplay.templates[\"chat-msg-event\"].render();\n        var c = XHPTemplate.getNode(a, \"icon\");\n        var d = XHPTemplate.getNode(a, \"message\");\n        var h = XHPTemplate.getNode(a, \"timestamp\");\n        var f = this.chatDisplay.renderServerTime(g);\n        DOM.setContent(h, f);\n        this._checkDateBreak(g);\n        switch (i) {\n          case this._ACTION_LOG_SUBSCRIBE:\n            if (((!e || ((e.length === 0))))) {\n                return;\n            }\n        ;\n        ;\n            CSS.addClass(c, \"addActionIcon\");\n            DOM.setContent(d, HTML(this._getSubscribeMessage(this.chatDisplay.user, b, e)));\n            break;\n          case this._ACTION_LOG_UNSUBSCRIBE:\n            CSS.addClass(c, \"leaveActionIcon\");\n            DOM.setContent(d, HTML(this._getUnsubscribeMessage(this.chatDisplay.user, b)));\n            break;\n          default:\n            return;\n        };\n    ;\n        DOM.appendContent(this.chatConvContent, a);\n        this.currentMsgGroup = null;\n    },\n    _getSubscribeMessage: function(c, a, b) {\n        var d = this._indexOfUser(c, b);\n        if (((a.fbid && ((a.fbid == c))))) {\n            switch (b.length) {\n              case 1:\n                return _tx(\"You added {subscriber1}.\", {\n                    subscriber1: this._getLinkifiedName(c, b[0])\n                });\n              case 2:\n                return _tx(\"You added {subscriber1} and {subscriber2}.\", {\n                    subscriber1: this._getLinkifiedName(c, b[0]),\n                    subscriber2: this._getLinkifiedName(c, b[1])\n                });\n              case 3:\n                return _tx(\"You added {subscriber1}, {subscriber2} and {subscriber3}.\", {\n                    subscriber1: this._getLinkifiedName(c, b[0]),\n                    subscriber2: this._getLinkifiedName(c, b[1]),\n                    subscriber3: this._getLinkifiedName(c, b[2])\n                });\n              default:\n                return _tx(\"You added {subscriber1}, {subscriber2} and {more_people}.\", {\n                    subscriber1: this._getLinkifiedName(c, b[0]),\n                    subscriber2: this._getLinkifiedName(c, b[1]),\n                    more_people: ((b.length - 2))\n                });\n            };\n        ;\n        }\n         else if (((d != -1))) {\n            b.splice(d, 1);\n            switch (b.length) {\n              case 0:\n                return _tx(\"{actor} added you.\", {\n                    actor: this._getLinkifiedName(c, a)\n                });\n              case 1:\n                return _tx(\"{actor} added you and {subscriber2}.\", {\n                    actor: this._getLinkifiedName(c, a),\n                    subscriber2: this._getLinkifiedName(c, b[0])\n                });\n              case 2:\n                return _tx(\"{actor} added you, {subscriber2} and {subscriber3}.\", {\n                    actor: this._getLinkifiedName(c, a),\n                    subscriber2: this._getLinkifiedName(c, b[0]),\n                    subscriber3: this._getLinkifiedName(c, b[1])\n                });\n              default:\n                return _tx(\"{actor} added you, {subscriber2} and {more_people}.\", {\n                    actor: this._getLinkifiedName(c, a),\n                    subscriber2: this._getLinkifiedName(c, b[0]),\n                    more_people: ((b.length - 1))\n                });\n            };\n        ;\n        }\n         else switch (b.length) {\n          case 1:\n            return _tx(\"{actor} added {subscriber1}.\", {\n                actor: this._getLinkifiedName(c, a),\n                subscriber1: this._getLinkifiedName(c, b[0])\n            });\n          case 2:\n            return _tx(\"{actor} added {subscriber1} and {subscriber2}.\", {\n                actor: this._getLinkifiedName(c, a),\n                subscriber1: this._getLinkifiedName(c, b[0]),\n                subscriber2: this._getLinkifiedName(c, b[1])\n            });\n          case 3:\n            return _tx(\"{actor} added {subscriber1}, {subscriber2} and {subscriber3}.\", {\n                actor: this._getLinkifiedName(c, a),\n                subscriber1: this._getLinkifiedName(c, b[0]),\n                subscriber2: this._getLinkifiedName(c, b[1]),\n                subscriber3: this._getLinkifiedName(c, b[2])\n            });\n          default:\n            return _tx(\"{actor} added {subscriber1}, {subscriber2} and {more_people}.\", {\n                actor: this._getLinkifiedName(c, a),\n                subscriber1: this._getLinkifiedName(c, b[0]),\n                subscriber2: this._getLinkifiedName(c, b[1]),\n                more_people: ((b.length - 2))\n            });\n        }\n        \n    ;\n    ;\n    },\n    _indexOfUser: function(b, c) {\n        for (var a = 0; ((a < c.length)); a++) {\n            if (((c[a].fbid && ((c[a].fbid == b))))) {\n                return a;\n            }\n        ;\n        ;\n        };\n    ;\n        return -1;\n    },\n    _getUnsubscribeMessage: function(b, a) {\n        if (((a.fbid && ((a.fbid == b))))) {\n            return _tx(\"You left the conversation.\");\n        }\n         else return _tx(\"{actor} left the conversation.\", {\n            actor: this._getLinkifiedName(b, a)\n        })\n    ;\n    },\n    _getLinkifiedName: function(b, a) {\n        if (!a.fbid) {\n            return htmlize(a.JSBNG__name);\n        }\n         else return presence.renderLink(a.href, htmlize(a.JSBNG__name))\n    ;\n    },\n    clearHistory: function() {\n        new AsyncRequest().setHandler(bagofholding).setErrorHandler(bagofholding).setData({\n            clear_history_id: this.id\n        }).setURI(this.chatDisplay.settingsURL).setAllowCrossPageTransition(true).send();\n        this.failedSentMsgs = [];\n        this.queue.discard();\n        this._setHistory(this.chatDisplay.histories[this.id] = []);\n    },\n    reportLinkAction: function() {\n        Bootloader.loadComponents(\"dialog\", (function() {\n            var a = URI(this.chatDisplay.reportURL).addQueryData({\n                id: this.id\n            }).addQueryData({\n                src: \"top_report_link\"\n            });\n            Dialog.bootstrap(a.toString(), null, false);\n        }).bind(this));\n    },\n    _onSendServerDialogCancel: function(a) {\n        this.queue.JSBNG__onSend(a, \"transport_error\");\n    },\n    _showPayloadWarning: function(a, c) {\n        var b = c.getPayload();\n        if (((b && b.warning))) {\n            var d = this._renderMsgWarning(((((((\"title\" in b.warning)) ? ((b.warning.title + \"\\u003Cbr /\\u003E\")) : \"\")) + b.warning.body)));\n            this._setMsgInfoMarkup(a, d, \"msg_warning\");\n        }\n    ;\n    ;\n    },\n    getTabMsgType: function() {\n        return \"msg\";\n    },\n    _onSendResponse: function(b, a, d) {\n        this.queue.JSBNG__onSend(b);\n        this._showPayloadWarning(b, d);\n        var c = {\n            type: this.getTabMsgType(),\n            msg: a,\n            from: presence.user,\n            to: this.id,\n            time: a.time\n        };\n        this.chatDisplay.addToHistory(this.id, c);\n    },\n    showVideoCallout: function(a) {\n        var c = DOM.scry(this.tabHandle, \".video\");\n        var b = {\n            recipient_id: this.id,\n            alt: !!a\n        };\n        if (((c.length == 1))) {\n            new AsyncRequest().setData(b).setRelativeTo(c[0]).setURI(\"/ajax/chat/video/callout.php\").setAllowCrossPageTransition(true).send();\n        }\n    ;\n    ;\n    },\n    showOrcaCallout: function(b) {\n        var c = DOM.scry(this.tabHandle, \".titlebar\");\n        if (((c.length > 0))) {\n            var a = {\n                sender_id: b\n            };\n            new AsyncRequest().setData(a).setRelativeTo(c[0]).setURI(\"/ajax/chat/orca/callout.php\").setAllowCrossPageTransition(true).send();\n        }\n    ;\n    ;\n    },\n    _onSendTransportError: function(a, b) {\n        this.queue.JSBNG__onSend(a, \"transport_error\", b);\n    },\n    _handleSendErrors: function(e, h, d, b, g) {\n        var f = ((g ? g.getPayload() : null));\n        var a = null;\n        if (b) {\n            a = _tx(\"An error occurred.\");\n            if (((g && ((b != \"transport_error\"))))) {\n                a = presence.getErrorDescription(g);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((b == 1356002))) {\n            chatOptions.setVisibility(false);\n            presence.doSync();\n        }\n         else if (((b == 1356008))) {\n            a = f.error.title;\n            ErrorDialog.show(f.error.title, f.error.body);\n        }\n         else if (((b == 1356026))) {\n            a = f.error.title;\n            (new Function(f.do_onload))();\n        }\n         else if (((b == 1356038))) {\n            ErrorDialog.show(g.errorSummary, g.errorDescription);\n        }\n         else if (b) {\n            ErrorDialog.show(g.errorSummary, g.errorDescription);\n            return;\n        }\n        \n        \n        \n        \n    ;\n    ;\n        if (a) {\n            var c = this._renderMsgError(a);\n            this._setMsgInfoMarkup(d.msgID, c, \"msg_error\");\n        }\n    ;\n    ;\n    },\n    _onSendError: function(a, b) {\n        this.queue.JSBNG__onSend(a, b.getError(), b);\n    },\n    _renderMsgWarning: function(b) {\n        var a = this.chatDisplay.templates[\"chat-msg-warning\"].render();\n        DOM.setContent(XHPTemplate.getNode(a, \"message\"), b);\n        return a;\n    },\n    _renderMsgError: function(a) {\n        var b = this.chatDisplay.templates[\"chat-msg-error\"].render();\n        DOM.setContent(XHPTemplate.getNode(b, \"message\"), a);\n        return b;\n    },\n    _createMessage: function(e, c) {\n        var b = (((((new JSBNG__Date()).getTime() + \":\")) + ((rand32() + 1))));\n        var f = presence.getTime();\n        var a = new JSBNG__Date().getTime();\n        if (((this.lastLogItem && ((f < this.lastLogItem.time))))) {\n            f = ((this.lastLogItem.time + 1));\n        }\n    ;\n    ;\n        var d = {\n            text: e,\n            msgID: b,\n            type: c,\n            created: a,\n            time: f,\n            asyncSuccess: false,\n            isError: false,\n            errorMarkup: \"\"\n        };\n        return d;\n    },\n    _updateChatActivity: function(b, a) {\n        this.lastLogItem = {\n            type: b.type,\n            from: presence.user,\n            to: this.id,\n            time: b.time,\n            msg: a\n        };\n    },\n    sendInput: function() {\n        var d = this.chatInput.value;\n        if (/^\\s*$/.test(((d || \"\")))) {\n            return;\n        }\n    ;\n    ;\n        this.chatInput.value = \"\";\n        var c = this._createMessage(d, \"msg\");\n        this.queue.sendToServer(c.msgID, c);\n        var b = {\n            text: d\n        };\n        var a = this.isUserScrolled();\n        this.renderMsg(presence.user, this.id, c.time, b, c.msgID);\n        ((!a && this.scrollToBottom()));\n        this._updateChatActivity(c, b);\n        ((this.typingIndicator && this.typingIndicator.resetState()));\n    },\n    _sendMessage: function(b) {\n        b.time = presence.getTime();\n        if (((this.lastLogItem && ((b.time < this.lastLogItem.time))))) {\n            b.time = ((this.lastLogItem.time + 1));\n        }\n    ;\n    ;\n        JSBNG__clearTimeout(this.resendTimeout);\n        this.resendTimeout = null;\n        var c = this.getSendData(b);\n        channelManager.expectResponse();\n        Arbiter.inform(\"chat/message-sent\", c);\n        var a = b.msgID;\n        new AsyncRequest().setServerDialogCancelHandler(this._onSendServerDialogCancel.bind(this, a)).setHandler(this._onSendResponse.bind(this, a, b)).setErrorHandler(this._onSendError.bind(this, a)).setTransportErrorHandler(this._onSendTransportError.bind(this, a)).setData(c).setURI(\"/ajax/chat/send.php\").setAllowCrossPageTransition(true).send();\n        this.pendingNewRecipients = [];\n    },\n    getSendData: function(e) {\n        var c = this.chatDisplay.histories[this.id];\n        var d = null;\n        var a = this.getAvailability();\n        var h = ((a == AvailableList.OFFLINE));\n        var g = ((a == AvailableList.IDLE));\n        var f = {\n            msg_id: e.msgID,\n            client_time: e.time,\n            to: this.id,\n            num_tabs: this.chatDisplay.numTabs,\n            pvs_time: d,\n            msg_text: e.text,\n            to_offline: h,\n            to_idle: g,\n            window_id: presence.getWindowID(),\n            popped_out: presence.inPopoutWindow\n        };\n        if (h) {\n            var b = AvailableList.getDebugInfo(this.id);\n            f.overlay = b.overlay;\n            f.overlayTime = b.overlayTime;\n            f.presence = b.presence;\n            f.presenceTime = presence.getTime();\n            f.clock = (new JSBNG__Date()).getTime();\n        }\n    ;\n    ;\n        if (ChatConfig.get(\"sidebar\")) {\n            f.sidebar_launched = true;\n            if (window.ChatSidebar) {\n                f.sidebar_enabled = ChatSidebar.isEnabled();\n                f.sidebar_capable = ChatSidebar.isViewportCapable();\n                f.sidebar_should_show = ChatSidebar.shouldShowSidebar();\n                f.sidebar_visible = ChatSidebar.isVisible();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return f;\n    },\n    _setMsgInfoMarkup: function(d, c, a) {\n        var b = ge(((((((\"msg_\" + this.id)) + \"_\")) + d)));\n        if (!b) {\n            return;\n        }\n    ;\n    ;\n        DOM.insertAfter(b, c);\n        ((a && CSS.addClass(b, a)));\n        this.scrollToBottom();\n    },\n    tabHitAreaOnClick: function() {\n        if (this.suppressHeaderCollapse) {\n            return;\n        }\n    ;\n    ;\n        if (presence.inPopoutWindow) {\n            this.chatDisplay.focusTab(this.id, true, this.JSBNG__name, this.firstName);\n        }\n         else this.chatDisplay.toggleTab(this.id, true, this.JSBNG__name, this.firstName);\n    ;\n    ;\n        this.chatDisplay.doStopBlinking();\n    },\n    tabXOnClick: function(a) {\n        this.chatDisplay.closeTab(this.id);\n        this.chatDisplay.doStopBlinking();\n        $E(a).kill();\n        return false;\n    },\n    headerLinkMouseOver: function() {\n        CSS.addClass(this.chatHeader, \"suppress_hover\");\n        this.suppressHeaderCollapse = true;\n    },\n    headerLinkMouseOut: function() {\n        CSS.removeClass(this.chatHeader, \"suppress_hover\");\n        this.suppressHeaderCollapse = false;\n    },\n    chatConvOnMouseDown: function(JSBNG__event) {\n        if (((JSBNG__event.button != 0))) {\n            return;\n        }\n    ;\n    ;\n        this.chatDisplay.doStopBlinking();\n    },\n    chatConvOnMouseUp: function() {\n        if (((DOM.JSBNG__getSelection() == \"\"))) {\n            this.focusChatInput(true);\n        }\n    ;\n    ;\n    },\n    focusChatInput: function(a) {\n        if (this.isTabVisible()) {\n            if (((a || this.canStealFocus()))) {\n                this.chatInput.JSBNG__focus();\n            }\n        ;\n        }\n    ;\n    ;\n    },\n    canStealFocus: function() {\n        if (((undefined != JSBNG__document.activeElement))) {\n            var a = JSBNG__document.activeElement;\n            if (a) {\n                var b = ((((((\"INPUT\" == a.nodeName)) || ((\"TEXTAREA\" == a.nodeName)))) || ((((\"DIV\" == a.nodeName)) && ((a.contentEditable == \"true\"))))));\n                return !b;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        return false;\n    },\n    displayPrivacyLinkInGearMenu: function() {\n        var a;\n        if (!this.isBlocked()) {\n            ChatUserInfoManager.get(this.id, function(b) {\n                a = _tx(\"Go Offline to {name}\", {\n                    JSBNG__name: b.firstName\n                });\n            });\n        }\n         else ChatUserInfoManager.get(this.id, function(b) {\n            a = _tx(\"Go Online to {name}\", {\n                JSBNG__name: b.firstName\n            });\n        });\n    ;\n    ;\n        DOM.setContent(XHPTemplate.getNode(this.tabHandle, \"privacyLink\"), a);\n    },\n    togglePrivacy: function() {\n        if (!ChatConfig.get(\"blackbird\")) {\n            return;\n        }\n    ;\n    ;\n        if (this.isBlocked()) {\n            PresencePrivacy.allow(this.id);\n            this.closeSheet();\n        }\n         else PresencePrivacy.disallow(this.id);\n    ;\n    ;\n        this.displayPrivacyLinkInGearMenu();\n    },\n    showAddFriendFromActionMenu: function() {\n        this.showAddFriend();\n        return true;\n    },\n    showAddFriend: function() {\n        if (((this._sheetOpen && DOM.scry(this._sheetEl, \".addFriends\").length))) {\n            return;\n        }\n    ;\n    ;\n        var a = {\n            canonical: this.isCanonical(),\n            id: this.id\n        };\n        if (this.isCanonical()) {\n            a.recipient_id = this.id;\n        }\n         else {\n            a.thread_id = this.id;\n            a.recipients = this.getRecipients();\n        }\n    ;\n    ;\n        new AsyncRequest().setURI(\"/ajax/chat/show_add_friends.php\").setData(a).setHandler(bagofholding).setErrorHandler(bagofholding).setAllowCrossPageTransition(true).send();\n    },\n    _buildUI: function() {\n        var m = this.chatDisplay.templates[this.rendererName].render();\n        this.nubNameNode = XHPTemplate.getNode(m, \"JSBNG__name\");\n        this.titlebarTextNode = XHPTemplate.getNode(m, \"titlebarText\");\n        this._updateName();\n        this._sheetEl = XHPTemplate.getNode(m, \"sheet\");\n        var b = XHPTemplate.getNode(m, \"chatConv\");\n        var f = XHPTemplate.getNode(m, \"closeButton\");\n        var c = XHPTemplate.getNode(m, \"input\");\n        this._handlers.push(JSBNG__Event.listen(b, \"mousedown\", this.chatConvOnMouseDown.bind(this)), JSBNG__Event.listen(b, \"mouseup\", this.chatConvOnMouseUp.bind(this)), JSBNG__Event.listen(f, \"click\", this.tabXOnClick.bind(this)), JSBNG__Event.listen(c, \"keydown\", this.inputKeyDown.bind(this)), JSBNG__Event.listen(c, \"click\", this.chatDisplay.doStopBlinking.bind(this.chatDisplay)));\n        var i = XHPTemplate.getNode(m, \"maximizeButton\");\n        if (i) {\n            this._handlers.push(JSBNG__Event.listen(i, \"click\", this.maximizeOnClick.bind(this)));\n        }\n    ;\n    ;\n        ChatQuietLinks.silence(m);\n        this.tabHandle = m;\n        this.statusEl = XHPTemplate.getNode(m, \"JSBNG__status\");\n        this.tabCount = XHPTemplate.getNode(m, \"numMessages\");\n        this.chatWrapper = XHPTemplate.getNode(m, \"chatWrapper\");\n        this.chatConv = b;\n        this.chatConvContent = XHPTemplate.getNode(m, \"conversation\");\n        this.chatInput = c;\n        var d = ge(\"fbDockChatTabs\");\n        DOM.prependContent(d, this.tabHandle);\n        if (ChatConfig.get(\"typing_notifications\")) {\n            this.typingIndicator = new TypingIndicator(this.id, c, \"chat\");\n            var o = XHPTemplate.getNode(m, \"typingIndicator\");\n            if (o) {\n                var j;\n                ChatUserInfoManager.get(this.id, function(p) {\n                    j = _tx(\"{name} is typing...\", {\n                        JSBNG__name: p.firstName\n                    });\n                    DOM.setContent(o, j);\n                });\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        this._updateNumMissedDisplay();\n        this.videoCallLink = XHPTemplate.getNode(m, \"videoCallLink\");\n        if (this.videoCallLink) {\n            this._handlers.push(JSBNG__Event.listen(this.videoCallLink, \"click\", function() {\n                var p = this.getAvailability();\n                if (this._isVideoCallAvail(p)) {\n                    VideoEvents.inform(VideoEvents.START_CALL_UI, {\n                        idTarget: this.id\n                    });\n                    ((this.focused && this.chatDisplay.unfocus()));\n                }\n            ;\n            ;\n                return false;\n            }.bind(this)));\n            this._callIncomingToken = VideoEvents.subscribe(VideoEvents.CALL_INCOMING, function(p, q) {\n                if (((((((q.idTarget == this.id)) && this.focused)) && /^\\s*$/.test(((this.chatInput.value || \"\")))))) {\n                    this.chatDisplay.unfocus();\n                }\n            ;\n            ;\n            }.bind(this));\n        }\n    ;\n    ;\n        var h = XHPTemplate.getNode(m, \"dropdown\");\n        if (h) {\n            Toggler.createInstance(h).setSticky(false);\n            var g = XHPTemplate.getNode(m, \"conversationLink\");\n            if (g) {\n                if (this.isCanonical()) {\n                    g.href = Messaging.getUserThreadURI(this.id);\n                }\n                 else g.href = Messaging.getInboxThreadURI(this.id);\n            ;\n            }\n        ;\n        ;\n            var l = XHPTemplate.getNode(m, \"reportSpamLink\");\n            if (l) {\n                this._handlers.push(JSBNG__Event.listen(l, \"click\", this.reportLinkAction.bind(this)));\n            }\n        ;\n        ;\n            var e = XHPTemplate.getNode(m, \"clearWindowLink\");\n            if (e) {\n                this._handlers.push(JSBNG__Event.listen(e, \"click\", this.clearHistory.bind(this)));\n            }\n        ;\n        ;\n            var a = XHPTemplate.getNode(m, \"addFriendLink\");\n            if (a) {\n                this._handlers.push(JSBNG__Event.listen(a, \"click\", this.showAddFriendFromActionMenu.bind(this)));\n            }\n        ;\n        ;\n            if (ChatConfig.get(\"blackbird\")) {\n                var k = XHPTemplate.getNode(m, \"privacyLink\");\n                if (k) {\n                    this._handlers.push(JSBNG__Event.listen(k, \"click\", this.togglePrivacy.bind(this)));\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var n = XHPTemplate.getNode(m, \"titlebarCloseButton\");\n        this._handlers.push(JSBNG__Event.listen(n, \"click\", this.tabXOnClick.bind(this)));\n        return m;\n    },\n    isCanonical: function() {\n        return true;\n    },\n    _updateName: function() {\n        var a = this.nubNameNode.cloneNode(true);\n        DOM.setContent(a, this.JSBNG__name);\n        DOM.replace(this.nubNameNode, a);\n        this.nubNameNode = a;\n        DOM.setContent(this.titlebarTextNode, this.JSBNG__name);\n    },\n    _guessFirstName: function() {\n        if (((typeof (this.JSBNG__name) == \"string\"))) {\n            return getFirstName(this.JSBNG__name);\n        }\n    ;\n    ;\n        return this.JSBNG__name;\n    },\n    maximizeOnClick: function() {\n        var a = this.getConversationURI();\n        if (a) {\n            goURI(a);\n            ((this.focused && this.chatDisplay.unfocus()));\n        }\n    ;\n    ;\n        return false;\n    },\n    getConversationURI: function() {\n        return Messaging.getUserThreadURI(this.id);\n    },\n    getProfileURI: function() {\n        return URI(env_get(\"www_base\")).setPath(\"/profile.php\").setQueryData({\n            id: this.id\n        });\n    },\n    show: function() {\n        CSS.show(this.tabHandle);\n    },\n    hide: function() {\n        CSS.hide(this.tabHandle);\n    },\n    inputKeyDown: function(JSBNG__event) {\n        this.chatDisplay.doStopBlinking();\n        if (!this._textareaListener) {\n            var c = DataStore.get(this.chatInput, \"DOMControl\");\n            this._textareaListener = c.subscribe(\"resize\", this.handleResize.bind(this));\n        }\n    ;\n    ;\n        switch (JSBNG__event.keyCode) {\n          case KEYS.RETURN:\n            if (!JSBNG__event.shiftKey) {\n                this.sendInput();\n                JSBNG__event.kill();\n                return;\n            }\n        ;\n        ;\n            break;\n          case KEYS.ESC:\n            var a = ((this.chatDisplay.getNextTabId(this.id, true) || this.chatDisplay.getNextTabId(this.id, false)));\n            this.chatDisplay.closeTab(this.id);\n            if (a) {\n                this.chatDisplay.focusTab(a, true);\n            }\n        ;\n        ;\n            return JSBNG__event.kill();\n          case KEYS.TAB:\n            var b = JSBNG__event.shiftKey;\n            var d = presence.inPopoutWindow;\n            var a = this.chatDisplay.getNextTabId(this.id, b, d);\n            if (a) {\n                this.chatDisplay.focusTab(a, true);\n                return JSBNG__event.kill();\n            }\n        ;\n        ;\n            break;\n        };\n    ;\n    },\n    updateName: function(b, a) {\n        this.JSBNG__name = b;\n        this.firstName = ((a || this._guessFirstName()));\n        this._updateName();\n    },\n    trimName: function(a) {\n        var b = this.JSBNG__name;\n        if (((b.length > a))) {\n            b = ((b.substring(0, ((a - 2))) + \"...\"));\n        }\n    ;\n    ;\n        return b;\n    },\n    _handleStatusChange: function(f, JSBNG__event) {\n        var e = Chat.isOnline();\n        var a = ((e ? this.getAvailability() : AvailableList.OFFLINE));\n        var b = ((this._availability !== a));\n        var c = this.isBlocked();\n        var d = ((this._blocked != c));\n        if (((!b && !d))) {\n            return;\n        }\n    ;\n    ;\n        if (d) {\n            this.displayPrivacyLinkInGearMenu();\n        }\n    ;\n    ;\n        var g = ((!f || chatDisplay.loadedInitialTabs));\n        if (((this._blocked && !c))) {\n            g = false;\n        }\n    ;\n    ;\n        this._availability = a;\n        this._blocked = c;\n        var h;\n        if (g) {\n            ChatUserInfoManager.get(this.id, function(m) {\n                if (e) {\n                    if (((a === AvailableList.ACTIVE))) {\n                        var l = (((new JSBNG__Date()).getTime() - this.timeBuilt.getTime()));\n                        var i = ChatConfig.get(\"available_sheet_min_tab_age_ms\");\n                        if (((!f && ((l > i))))) {\n                            h = _tx(\"{name} is now available.\", {\n                                JSBNG__name: m.firstName\n                            });\n                        }\n                         else h = null;\n                    ;\n                    ;\n                    }\n                     else if (((((a === AvailableList.OFFLINE)) || ((a == AvailableList.MOBILE))))) {\n                        if (ChatConfig.get(\"titan\")) {\n                            var k = \"offline\";\n                            if (c) {\n                                k = \"blocked\";\n                            }\n                             else if (((a == AvailableList.MOBILE))) {\n                                k = \"mobile\";\n                            }\n                            \n                        ;\n                        ;\n                            switch (m.gender) {\n                              case GenderConst.FEMALE_SINGULAR:\n                            \n                              case GenderConst.FEMALE_SINGULAR_GUESS:\n                                switch (k) {\n                                  case \"offline\":\n                                    h = _tx(\"{name} is unavailable, but you can still send her a message.\", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                  case \"mobile\":\n                                    h = _tx(\"Your messages will be sent to {name}'s phone.\", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                  case \"blocked\":\n                                    h = _tx(\"{name} sees you as offline on chat, but you can still send her a message. \", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                };\n                            ;\n                                break;\n                              case GenderConst.MALE_SINGULAR:\n                            \n                              case GenderConst.MALE_SINGULAR_GUESS:\n                                switch (k) {\n                                  case \"offline\":\n                                    h = _tx(\"{name} is unavailable, but you can still send him a message.\", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                  case \"mobile\":\n                                    h = _tx(\"Your messages will be sent to {name}'s phone.\", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                  case \"blocked\":\n                                    h = _tx(\"{name} sees you as offline on chat, but you can still send him a message. \", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                };\n                            ;\n                                break;\n                              default:\n                                switch (k) {\n                                  case \"offline\":\n                                    h = _tx(\"{name} is unavailable, but you can still send them a message.\", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                  case \"mobile\":\n                                    h = _tx(\"Your messages will be sent to {name}'s phone.\", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                  case \"blocked\":\n                                    h = _tx(\"{name} sees you as offline on chat, but you can still send them a message. \", {\n                                        JSBNG__name: m.firstName\n                                    });\n                                    break;\n                                };\n                            ;\n                                break;\n                            };\n                        ;\n                        }\n                         else h = _tx(\"{name} is offline.\", {\n                            JSBNG__name: m.firstName\n                        });\n                    ;\n                    }\n                    \n                ;\n                }\n            ;\n            ;\n                if (h) {\n                    var j = this.chatDisplay.templates[\"chat-sheet-notice\"].render();\n                    DOM.setContent(XHPTemplate.getNode(j, \"text\"), h);\n                    if (c) {\n                        this._blackSheetOpen = true;\n                        this._appendGoOnlineLink(j, m.firstName);\n                    }\n                ;\n                ;\n                    if (f) {\n                        this.setSheet(j, c);\n                    }\n                     else if (((this._blackSheetOpen && !c))) {\n                        this._blackSheetOpen = false;\n                        this.closeSheet(this.openSheet.bind(this, j));\n                    }\n                     else this.openSheet(j, c);\n                    \n                ;\n                ;\n                }\n                 else this.closeSheet();\n            ;\n            ;\n            }.bind(this));\n        }\n    ;\n    ;\n        if (((e && ((a != AvailableList.ACTIVE))))) {\n            if (presence.inPopoutWindow) {\n                CSS.removeClass(this.popoutTab, \"typing\");\n            }\n        ;\n        ;\n            CSS.removeClass(this.tabHandle, \"typing\");\n        }\n    ;\n    ;\n        if (((((e && a)) && !c))) {\n            this._enableTab(a);\n        }\n         else this._disableTab();\n    ;\n    ;\n        this._updateVideoCallLink(a);\n    },\n    _appendGoOnlineLink: function(b, a) {\n        var d = $N(\"a\", {\n            href: \"#\",\n            classname: \"unlistLink\"\n        }, _tx(\"Go Online to {name}\", {\n            JSBNG__name: a\n        }));\n        JSBNG__Event.listen(d, \"click\", (function() {\n            this.togglePrivacy();\n            return false;\n        }).bind(this));\n        var c = XHPTemplate.getNode(b, \"text\");\n        DOM.appendContent(c, $N(\"br\"));\n        DOM.appendContent(c, d);\n    },\n    _isVideoCallAvail: function(a) {\n        return ((((a == AvailableList.ACTIVE)) || ((a == AvailableList.IDLE))));\n    },\n    _updateVideoCallLink: function(a) {\n        if (this.videoCallLink) {\n            if (this._isVideoCallAvail(a)) {\n                TooltipLink.setTooltipText(this.videoCallLink, _tx(\"Start a video call\"));\n            }\n             else {\n                TooltipLink.setTooltipText(this.videoCallLink, _tx(\"{firstname} is currently unavailable for video calling\", {\n                    firstname: this.firstName\n                }));\n                this._hideVideoCallouts();\n            }\n        ;\n        }\n    ;\n    ;\n    },\n    _enableTab: function(a) {\n        this.tabDisabled = false;\n        var c = ((a == AvailableList.IDLE));\n        var d = ((a == AvailableList.MOBILE));\n        var b = ((a == AvailableList.ACTIVE));\n        if (presence.inPopoutWindow) {\n            CSS.removeClass(this.popoutTab, \"disabled\");\n            CSS.removeClass(this.popoutTab, \"blocked\");\n            CSS.conditionClass(this.popoutTab, \"idle\", c);\n            CSS.conditionClass(this.popoutTab, \"active\", b);\n            CSS.conditionClass(this.popoutTab, \"mobile\", d);\n        }\n    ;\n    ;\n        CSS.removeClass(this.tabHandle, \"disabled\");\n        CSS.removeClass(this.tabHandle, \"blocked\");\n        CSS.conditionClass(this.tabHandle, \"idle\", c);\n        CSS.conditionClass(this.tabHandle, \"mobile\", d);\n        CSS.conditionClass(this.tabHandle, \"active\", b);\n    },\n    _disableTab: function() {\n        this.tabDisabled = true;\n        if (presence.inPopoutWindow) {\n            CSS.addClass(this.popoutTab, \"disabled\");\n            CSS.conditionClass(this.popoutTab, \"blocked\", this.isBlocked());\n            CSS.removeClass(this.popoutTab, \"idle\");\n            CSS.removeClass(this.popoutTab, \"active\");\n            CSS.removeClass(this.popoutTab, \"mobile\");\n        }\n    ;\n    ;\n        CSS.addClass(this.tabHandle, \"disabled\");\n        CSS.conditionClass(this.tabHandle, \"blocked\", this.isBlocked());\n        CSS.removeClass(this.tabHandle, \"idle\");\n        CSS.removeClass(this.tabHandle, \"active\");\n        CSS.removeClass(this.tabHandle, \"mobile\");\n        this._hideCallouts();\n    },\n    _hideCallouts: function() {\n        this._hideVideoCallouts();\n        var c = DOM.scry(JSBNG__document, \"div.multiChatCallout\");\n        for (var b = 0; ((b < c.length)); b++) {\n            DOM.remove(c[b]);\n        ;\n        };\n    ;\n        var d = DOM.scry(JSBNG__document, \"div.orcaCallout\");\n        for (var a = 0; ((a < d.length)); a++) {\n            DOM.remove(d[a]);\n        ;\n        };\n    ;\n    },\n    _hideVideoCallouts: function() {\n        var b = DOM.scry(JSBNG__document, \"div.videoChatCallout\");\n        for (var a = 0; ((a < b.length)); a++) {\n            DOM.remove(b[a]);\n        ;\n        };\n    ;\n    },\n    handleResize: function() {\n        var a = this.isUserScrolled();\n        Dock._resizeNubFlyout(this.tabHandle);\n        ((!a && this.scrollToBottom()));\n    },\n    resizeSheet: function() {\n        if (((((!this._sheetEl || !this.focused)) || !this._sheetOpen))) {\n            return;\n        }\n    ;\n    ;\n        var a = Vector2.getElementDimensions(this.chatConvContent);\n        a.setElementWidth(this._sheetEl);\n    },\n    setSheet: function(a, b) {\n        if (!this._sheetEl) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__clearTimeout(this._sheetCloseTimeout);\n        DOM.setContent(this._sheetEl, a);\n        CSS.setStyle(this._sheetEl, \"bottom\", \"0px\");\n        CSS.show(this._sheetEl);\n        this._sheetOpen = true;\n        this.resizeSheet();\n        if (!b) {\n            this._sheetCloseTimeout = this.closeSheet.shield(this).defer(5000, false);\n        }\n    ;\n    ;\n        this._sheetKeepOpen = !!b;\n    },\n    openSheet: function(b, d, a) {\n        if (!this._sheetEl) {\n            return;\n        }\n    ;\n    ;\n        if (this._sheetOpen) {\n            var e = $N(\"div\", {\n                className: \"hidden_elem\"\n            }, b);\n            DOM.appendContent(this._sheetEl, e);\n            if (((this._sheetKeepOpen && !d))) {\n                return;\n            }\n        ;\n        ;\n            b = $A(e.childNodes);\n            this.closeSheet(this.openSheet.bind(this, b, d, a));\n            return;\n        }\n    ;\n    ;\n        this.inform(\"sheet/open\");\n        if (!this.focused) {\n            this.setSheet(b, d);\n            ((a && a()));\n            this.closeSheet();\n            return;\n        }\n    ;\n    ;\n        CSS.setStyle(this._sheetEl, \"visibility\", \"hidden\");\n        this.setSheet(b, d);\n        var c = Vector2.getElementDimensions(this._sheetEl).y;\n        CSS.addClass(this.tabHandle, \"sheetSlide\");\n        CSS.setStyle(this._sheetEl, \"bottom\", ((c + \"px\")));\n        CSS.setStyle(this._sheetEl, \"visibility\", \"\");\n        this._sheetAnimation = animation(this._sheetEl).to(\"bottom\", 0).duration(150).ease(animation.ease.both).JSBNG__ondone(function() {\n            CSS.removeClass(this.tabHandle, \"sheetSlide\");\n            this._sheetAnimation = null;\n            ((a && a()));\n        }.bind(this)).go();\n    },\n    closeSheet: function(a) {\n        if (!this._sheetEl) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__clearTimeout(this._sheetCloseTimeout);\n        if (!this._sheetOpen) {\n            ((a && a()));\n            return;\n        }\n    ;\n    ;\n        this.inform(\"sheet/close\");\n        this._sheetOpen = this._sheetKeepOpen = false;\n        if (!this.focused) {\n            CSS.hide(this._sheetEl);\n            ((a && a()));\n            return;\n        }\n    ;\n    ;\n        ((this._sheetAnimation && this._sheetAnimation.JSBNG__stop()));\n        CSS.addClass(this.tabHandle, \"sheetSlide\");\n        this._sheetAnimation = animation(this._sheetEl).to(\"bottom\", ((Vector2.getElementDimensions(this._sheetEl).y + \"px\"))).duration(100).ease(animation.ease.begin).JSBNG__ondone(function() {\n            CSS.hide(this._sheetEl);\n            CSS.removeClass(this.tabHandle, \"sheetSlide\");\n            this._sheetAnimation = null;\n            ((a && a()));\n        }.bind(this)).go();\n    },\n    isUserScrolled: function() {\n        return ((this.chatConv.scrollHeight > ((this.chatConv.scrollTop + this.chatConv.clientHeight))));\n    },\n    scrollToBottom: function() {\n        if (!this.focused) {\n            return;\n        }\n    ;\n    ;\n        this.chatConv.scrollTop = this.chatConv.scrollHeight;\n        this.resizeSheet();\n    },\n    unfocus: function() {\n        if (!this.focused) {\n            return;\n        }\n    ;\n    ;\n        this.focused = false;\n        this.resetAutoCloseTimeout(true);\n        if (this.inDock) {\n            Dock.hide(this.tabHandle);\n        }\n         else CSS.removeClass(this.tabHandle, \"focused\");\n    ;\n    ;\n        this._hideCallouts();\n        this.inform(\"unfocus\");\n    },\n    JSBNG__focus: function(c, a, b) {\n        if (!this.focused) {\n            this.focused = true;\n            this.clearAutoCloseTimeout();\n            this._isFragileMode = false;\n            this._markRead();\n            if (this.inDock) {\n                Dock.show(this.tabHandle);\n            }\n             else CSS.addClass(this.tabHandle, \"focused\");\n        ;\n        ;\n            if (!this.historyLoaded) {\n                this.getHistory(false);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (!c) {\n            this._onFocusUIActions(b);\n        }\n    ;\n    ;\n        this.inform(\"JSBNG__focus\");\n    },\n    _onFocusUIActions: function(a) {\n        this.handleResize();\n        this.scrollToBottom();\n        this.focusChatInput(a);\n    },\n    _startBounce: function() {\n        var a = -8;\n        this.bounceAnimation = animation(this.tabCount).to(\"JSBNG__top\", -16).duration(((this.bounceDuration + 40))).checkpoint().to(\"JSBNG__top\", a).duration(this.bounceDuration).checkpoint().to(\"JSBNG__top\", -16).duration(((this.bounceDuration + 40))).checkpoint().to(\"JSBNG__top\", a).duration(this.bounceDuration).checkpoint().to(\"JSBNG__top\", -12).duration(this.bounceDuration).checkpoint().to(\"JSBNG__top\", -10).duration(this.bounceDuration).checkpoint().to(\"JSBNG__top\", a).duration(this.bounceDuration).checkpoint().go();\n    },\n    _stopBounce: function() {\n        if (this.bounceAnimation) {\n            this.bounceAnimation.JSBNG__stop();\n            this.bounceAnimation = null;\n        }\n    ;\n    ;\n    },\n    close: function() {\n        if (this.inDock) {\n            Dock.unregisterNubController(this.tabHandle);\n        }\n    ;\n    ;\n        while (this._handlers.length) {\n            this._handlers.pop().remove();\n        ;\n        };\n    ;\n        this._subscriptions.each(Arbiter.unsubscribe);\n        MessagingEvents.unsubscribe(this._messagingToken);\n        ((this._callIncomingToken && VideoEvents.unsubscribe(this._callIncomingToken)));\n        if (this._textareaListener) {\n            var a = DataStore.get(this.chatInput, \"DOMControl\");\n            a.unsubscribe(this._textareaListener);\n            delete this._textareaListener;\n            this._textareaListener = null;\n        }\n    ;\n    ;\n        this.clearAutoCloseTimeout();\n        this.tabHandle.parentNode.removeChild(this.tabHandle);\n        this._hideCallouts();\n    },\n    newTyping: function(d) {\n        var b = d.from;\n        var g = d.to;\n        var h = d.st;\n        var a = d.fl;\n        var e = d.offline;\n        var c = d.from_mobile;\n        if (((!ChatConfig.get(\"typing_notifications\") || ((((new JSBNG__Date() - this.lastMessageAt)) < this.typingIndicator.notifyDelay))))) {\n            return;\n        }\n    ;\n    ;\n        presence.debug(((((((\"typing from \" + b)) + \": \")) + h)));\n        var f = ((((((h == TypingDetector.TYPING)) && ((this.numMissed === 0)))) && ((!e || c))));\n        if (((g != this.id))) {\n            if (presence.inPopoutWindow) {\n                CSS.conditionClass(this.popoutTab, \"typing\", f);\n            }\n        ;\n        ;\n            CSS.conditionClass(this.tabHandle, \"typing\", f);\n            if (!c) {\n                AvailableList.set(this.id, AvailableList.ACTIVE, a);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    newMsg: function(e) {\n        var a = e.from;\n        var j = e.to;\n        var k = e.type;\n        var c = e.msg;\n        var i = c.time;\n        var d = c.msgID;\n        var f = ((a == this.chatDisplay.user));\n        var g;\n        f = ((f && ((!e.window_id || ((e.window_id == presence.getWindowID()))))));\n        g = ((!f && this.chatDisplay.addToHistory(this.id, e)));\n        if (this.autoCloseTimeoutID) {\n            this.resetAutoCloseTimeout(false);\n        }\n    ;\n    ;\n        this.lastMessageAt = new JSBNG__Date();\n        if (((a != this.chatDisplay.user))) {\n            var h = ((this.chatDisplay.isSquelched() || this.chatDisplay.isSquelchedTab(this.id)));\n            this._isFragileMode = false;\n            if (h) {\n                this._markRead(i);\n            }\n             else {\n                if (this.focused) {\n                    this._markRead(i);\n                    if (!this.isWindowFocused) {\n                        this.playSound();\n                    }\n                ;\n                ;\n                }\n                 else this._markUnread(i);\n            ;\n            ;\n                this._messagingMarkAsRead();\n            }\n        ;\n        ;\n            if (presence.inPopoutWindow) {\n                CSS.removeClass(this.popoutTab, \"typing\");\n            }\n        ;\n        ;\n            CSS.removeClass(this.tabHandle, \"typing\");\n        }\n         else if (f) {\n            this._markRead();\n            this.queue.JSBNG__onReceive(d);\n        }\n        \n    ;\n    ;\n        g = ((this.getMessageTypeInfo(k).visible && g));\n        if (g) {\n            var b = this.isUserScrolled();\n            this.renderMsg(a, j, i, c, d);\n            ((!b && this.scrollToBottom()));\n            this.lastLogItem = e;\n        }\n    ;\n    ;\n    },\n    getInputElem: function() {\n        return this.chatInput;\n    },\n    _messagingMarkAsRead: function() {\n        if (!ChatConfig.get(\"titan\")) {\n            return;\n        }\n    ;\n    ;\n        this._clearMessagingMarkAsRead();\n        var a = chatOptions.getSetting(\"idle_cutoff\");\n        if (((a && UserActivity.isActive(a)))) {\n            this._messagingMarkThreadAsRead(this.id);\n        }\n         else this._pendingMessagingMarkAsRead = UserActivity.subscribe(this._messagingMarkAsRead.bind(this));\n    ;\n    ;\n    },\n    _messagingMarkThreadAsRead: function(a) {\n        Messaging.markUserThreadAsRead(a);\n    },\n    _clearMessagingMarkAsRead: function() {\n        if (this._pendingMessagingMarkAsRead) {\n            UserActivity.unsubscribe(this._pendingMessagingMarkAsRead);\n            delete this._pendingMessagingMarkAsRead;\n        }\n    ;\n    ;\n    },\n    _markRead: function() {\n        this._updateNumMissed(0);\n        this._stopBounce();\n    },\n    _markUnread: function(a) {\n        this._updateNumMissed(((this.numMissed + 1)), a);\n        this._startBounce();\n        this.playSound();\n    },\n    squelch: function() {\n        this._markRead();\n    },\n    _updateNumMissed: function(a, b) {\n        if (((((a == this.numMissed)) || ((b && ((b <= this.missedTime))))))) {\n            return;\n        }\n    ;\n    ;\n        if (((a > 99))) {\n            a = 99;\n        }\n    ;\n    ;\n        this.numMissed = a;\n        this.missedTime = b;\n        this._updateNumMissedDisplay();\n    },\n    _updateNumMissedDisplay: function() {\n        DOM.setContent(this.tabCount, this.numMissed);\n        if (this.inDock) {\n            ((window.chatTabSlider && chatTabSlider.updateMissedCount()));\n        }\n    ;\n    ;\n        CSS.conditionClass(this.tabHandle, \"highlight\", ((this.numMissed > 0)));\n        CSS.conditionShow(this.tabCount, ((this.numMissed > 0)));\n    },\n    _checkDateBreak: function(d) {\n        var c = new JSBNG__Date();\n        c.setTime(d);\n        var b = new JSBNG__Date();\n        if (this.lastLogItem) {\n            b.setTime(this.lastLogItem.time);\n        }\n    ;\n    ;\n        var a = null;\n        if (((((!this.lastLogItem || ((c.getDate() !== b.getDate())))) || ((c.getMonth() !== b.getMonth()))))) {\n            a = this.chatDisplay.templates[\"chat-msg-date-break\"].render();\n            DOM.setContent(a, renderDate(c, !presence.inPopoutWindow));\n            DOM.appendContent(this.chatConvContent, a);\n            this.currentMsgGroup = null;\n        }\n    ;\n    ;\n    },\n    _renderLogMessage: function(a) {\n        if (presence.inPopoutWindow) {\n            return;\n        }\n    ;\n    ;\n        var c = this.chatDisplay.templates[\"chat-msg-event\"].render();\n        var d = XHPTemplate.getNode(c, \"timestamp\");\n        var b = this.chatDisplay.renderServerTime(a.time);\n        DOM.setContent(d, b);\n        this._checkDateBreak(a.time);\n        switch (a.log_type) {\n          case LogMessageType.VIDEO_CALL:\n            this._renderVideoMsg(c, a.videoMsg, a.params);\n            break;\n          case LogMessageType.THREAD_NAME:\n            this._renderThreadNameMsg(c, a);\n            break;\n          case LogMessageType.THREAD_IMAGE:\n            this._renderThreadImageMsg(c, a);\n            break;\n        };\n    ;\n    },\n    _renderVideoMsg: function(c, a, b) {\n        ChatUserInfoManager.get(this.id, function(d) {\n            this._renderVideoMsgWithName(c, a, b, d.firstName);\n        }.bind(this));\n    },\n    _renderVideoMsgWithName: function(h, f, g, b) {\n        var d = XHPTemplate.getNode(h, \"icon\");\n        CSS.addClass(d, \"videoCallIcon\");\n        var e = XHPTemplate.getNode(h, \"message\");\n        var a = true;\n        if (((f == \"missed-call\"))) {\n            Bootloader.loadComponents(\"VideoChatPlugin\", function() {\n                DOM.setContent(e, _tx(\"You missed a call from {firstname}. \", {\n                    firstname: b\n                }));\n                if (((ChatConfig.get(\"video.can_call\", false) && VideoChatPlugin.isSupported()))) {\n                    var j = $N(\"a\", {\n                        href: \"#\",\n                        className: \"callBackLink\"\n                    }, _tx(\"Call Back\"));\n                    j.setAttribute(\"data-gt\", JSON.stringify({\n                        videochat: \"clicked_callback_link\"\n                    }));\n                    JSBNG__Event.listen(j, \"click\", (function() {\n                        VideoEvents.inform(VideoEvents.START_CALL_UI, {\n                            idTarget: this.id\n                        });\n                        ((this.focused && this.chatDisplay.unfocus()));\n                        return false;\n                    }).bind(this));\n                    DOM.appendContent(e, j);\n                }\n            ;\n            ;\n                DOM.appendContent(this.chatConvContent, h);\n            }.bind(this));\n            a = false;\n        }\n         else {\n            var c = ((((f == \"caller-history\")) || ((((f == \"connected-call\")) && ((g.to == presence.user))))));\n            var i = ((c ? _tx(\"You called {firstname}.\", {\n                firstname: b\n            }) : _tx(\"{firstname} called you.\", {\n                firstname: b\n            })));\n            DOM.setContent(e, HTML(i));\n        }\n    ;\n    ;\n        ((a && DOM.appendContent(this.chatConvContent, h)));\n        this.currentMsgGroup = null;\n    },\n    _renderThreadNameMsg: function(f, e) {\n        var b = XHPTemplate.getNode(f, \"icon\");\n        CSS.addClass(b, \"editNameIcon\");\n        var a = this._getLinkifiedName(this.chatDisplay.user, e.actor_info);\n        var d = null;\n        if (e.cleared) {\n            d = _tx(\"{actor} removed the conversation name.\", {\n                actor: a\n            });\n        }\n         else {\n            var g = ((((\"\\u003Cb\\u003E\" + e.thread_name)) + \"\\u003C/b\\u003E\"));\n            d = _tx(\"{actor} named the conversation: {name}.\", {\n                actor: a,\n                JSBNG__name: g\n            });\n        }\n    ;\n    ;\n        var c = XHPTemplate.getNode(f, \"message\");\n        DOM.setContent(c, HTML(d));\n        DOM.appendContent(this.chatConvContent, f);\n    },\n    _renderThreadImageMsg: function(f, e) {\n        var b = XHPTemplate.getNode(f, \"icon\");\n        CSS.addClass(b, \"changePictureIcon\");\n        var a = this._getLinkifiedName(this.chatDisplay.user, e.actor_info);\n        var d = null;\n        if (e.cleared) {\n            d = _tx(\"{actor} removed the conversation picture.\", {\n                actor: a\n            });\n        }\n         else d = _tx(\"{actor} changed the conversation picture.\", {\n            actor: a\n        });\n    ;\n    ;\n        var c = XHPTemplate.getNode(f, \"message\");\n        DOM.setContent(c, HTML(d));\n        DOM.appendContent(this.chatConvContent, f);\n    },\n    renderMsg: function(g, w, v, m, p, i, d) {\n        this._checkDateBreak(v);\n        var k = this.chatDisplay.templates[\"chat-msg\"].render();\n        k.id = ((((((\"msg_\" + this.id)) + \"_\")) + p));\n        CSS.addClass(k, ((is_rtl(m.text) ? \"direction_rtl\" : \"direction_ltr\")));\n        var h = ((m.text.substr(0, 4) == \"?OTR\"));\n        var s = false;\n        CSS.conditionClass(k, \"cyphertext\", h);\n        if (h) {\n            DOM.setContent(k, _tx(\"[encrypted message]\"));\n        }\n         else {\n            var n = [];\n            var o = m.text;\n            var u;\n            var q;\n            var j;\n            if (m.spoof) {\n                q = new RegExp(\"^\\\\s*\\u003C([^\\u003C\\u003E]+?)\\u003E\\\\s+\");\n                j = o.match(q);\n                if (j) {\n                    o = o.substr(j[0].length);\n                    d = this._renderMsgWarning(j[1]);\n                }\n            ;\n            ;\n                if (m.subject) {\n                    j = m.subject.match(q);\n                    if (j) {\n                        m.subject = m.subject.substr(j[0].length);\n                        d = this._renderMsgWarning(j[1]);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (m.subject) {\n                var t = this.chatDisplay.templates[\"chat-msg-subject\"].render();\n                DOM.setContent(t, m.subject);\n                DOM.appendContent(k, t);\n                this.currentMsgGroup = null;\n            }\n        ;\n        ;\n            if (((((m.truncated || m.JSBNG__forward)) || m.attachment))) {\n                q = new RegExp(((((((\"(?:\\\\.{3}\\\\s+)?\" + \"(?:\\u003C([^\\u003C\\u003E]+?)\\u003E\\\\s+)?\")) + \"(?:\\u003C([^\\u003C\\u003E]+?)\\u003E\\\\s+)?\")) + \"(\\\\S+)\\\\s*$\")));\n                j = o.match(q);\n                if (j) {\n                    o = o.substr(0, o.lastIndexOf(j[0]));\n                    var u = j[3];\n                    if (m.truncated) {\n                        n.push(HTML(\"&hellip; \"));\n                        var l = $N(\"a\", {\n                            href: u,\n                            className: \"more\"\n                        }, _tx(\"See All\"));\n                        n.push(l);\n                    }\n                ;\n                ;\n                    if (m.JSBNG__forward) {\n                        var f = this.chatDisplay.templates[\"chat-msg-forward\"].render();\n                        f.href = u;\n                        var e = XHPTemplate.getNode(f, \"label\");\n                        DOM.setContent(e, j[1]);\n                        n.push($N(\"div\", f));\n                        s = true;\n                    }\n                ;\n                ;\n                    if (m.attachment) {\n                        var b = this.chatDisplay.templates[\"chat-msg-attachment\"].render();\n                        b.href = u;\n                        var a = XHPTemplate.getNode(b, \"label\");\n                        DOM.setContent(a, ((j[2] || j[1])));\n                        n.push($N(\"div\", b));\n                        s = true;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            if (((!s && URLScraper.match(o)))) {\n                s = true;\n            }\n        ;\n        ;\n            if (((!this.chatDisplay.user || ((this.chatDisplay.user == g))))) {\n                s = false;\n            }\n        ;\n        ;\n            n.unshift(HTML(this._renderMsgHtmlize(o)));\n            DOM.appendContent(k, n);\n        }\n    ;\n    ;\n        var c = this.getCurrentMsgGroup(g, w, v);\n        if (((s && ChatConfig.get(\"report\")))) {\n            CSS.show(XHPTemplate.getNode(c, \"reportLinkWithDot\"));\n            var r = URI(this.chatDisplay.reportURL).addQueryData({\n                id: g\n            }).addQueryData({\n                src: \"timestamp_report_link\"\n            });\n            reportLink = XHPTemplate.getNode(c, \"reportLink\");\n            reportLink.setAttribute(\"href\", r);\n        }\n    ;\n    ;\n        this.addMessageToGroup(k, c);\n        ((d && this.addMessageToGroup(d, c)));\n    },\n    _renderMsgHtmlize: function(a) {\n        return html_hyperlink(((a || \"\")), Emote.htmlEmote, null, true);\n    },\n    newVideoMsg: function(d, b) {\n        this.clearAutoCloseTimeout();\n        var c = ((b.time || presence.getTime()));\n        var a = {\n            type: \"logmessage\",\n            log_type: LogMessageType.VIDEO_CALL,\n            videoMsg: d,\n            time: c,\n            params: b\n        };\n        if (((d === \"missed-call\"))) {\n            if (this.focused) {\n                this._markRead(c);\n                this._messagingMarkAsRead();\n                if (!this.isWindowFocused) {\n                    this.playSound();\n                }\n            ;\n            ;\n            }\n             else this._markUnread(c);\n        ;\n        }\n    ;\n    ;\n        this.newLogMessage(a);\n    },\n    newLogMessage: function(b) {\n        var a = this.isUserScrolled();\n        this._renderLogMessage(b);\n        ((!a && this.scrollToBottom()));\n        this.lastLogItem = b;\n        this.chatDisplay.addToHistory(this.id, b);\n    },\n    playSound: function() {\n        if (((ChatConfig.get(\"sound_enabled\") && chatOptions.getSetting(\"sound\")))) {\n            Sound.play(\"/sound/pling.mp3\", true);\n        }\n    ;\n    ;\n    },\n    getMessageTypeInfo: function(a) {\n        if (((a == \"logmessage\"))) {\n            return {\n                visible: true,\n                user: false,\n                preserveHistory: true,\n                logMessage: true\n            };\n        }\n         else if (((a == \"actionlog\"))) {\n            return {\n                visible: true,\n                user: false,\n                preserveHistory: false,\n                actionLog: true\n            };\n        }\n         else return {\n            visible: true,\n            user: true,\n            preserveHistory: false,\n            msg: true\n        }\n        \n    ;\n    },\n    addMessageToGroup: function(b, a) {\n        DOM.appendContent(XHPTemplate.getNode(a, \"messages\"), b);\n    },\n    getCurrentMsgGroup: function(a, i, g) {\n        if (((((((!this.currentMsgGroup || !this.lastLogItem)) || ((this.lastLogItem.from != a)))) || ((((g - this.lastLogItem.time)) > this.msgBunchTime))))) {\n            var c = this.chatDisplay.templates[this.msgGroupRendererName].render();\n            var d = XHPTemplate.getNode(c, \"profileLink\");\n            var e = XHPTemplate.getNode(c, \"profilePhoto\");\n            var f = function(j) {\n                if (CSS.hasClass(d, \"profileTooltipLink\")) {\n                    TooltipLink.setTooltipText(d, j);\n                }\n                 else if (j) {\n                    e.setAttribute(\"title\", j);\n                }\n                 else e.removeAttribute(\"title\");\n                \n            ;\n            ;\n            };\n            var b = ((a == this.chatDisplay.user));\n            ((!b && f(\"\")));\n            ChatUserInfoManager.get(a, function(k) {\n                e.src = k.thumbSrc;\n                if (k.exist) {\n                    var j = env_get(\"www_base\");\n                    if (k.vanity) {\n                        j += k.vanity;\n                    }\n                     else j += ((\"profile.php?id=\" + a));\n                ;\n                ;\n                    d.setAttribute(\"href\", j);\n                }\n            ;\n            ;\n                ((!b && f(k.JSBNG__name)));\n            });\n            var h = this.chatDisplay.renderServerTime(g);\n            DOM.setContent(XHPTemplate.getNode(c, \"timestamp\"), h);\n            DOM.appendContent(this.chatConvContent, c);\n            this.currentMsgGroup = c;\n        }\n    ;\n    ;\n        return this.currentMsgGroup;\n    },\n    getAvailability: function() {\n        return AvailableList.get(this.id);\n    },\n    isBlocked: function() {\n        return ((ChatConfig.get(\"blackbird\") && !PresencePrivacy.allows(this.id)));\n    },\n    getTabDOM: function() {\n        return this.tabHandle;\n    },\n    _isFragileMode: false,\n    setFragileMode: function() {\n        this._isFragileMode = true;\n        this._subscriptions.push(Arbiter.subscribe(\"page_transition\", this._removeFragileTab.bind(this)));\n    },\n    isFragileMode: function() {\n        return this._isFragileMode;\n    },\n    _removeFragileTab: function() {\n        if (!this._isFragileMode) {\n            return;\n        }\n    ;\n    ;\n        this.chatDisplay.closeTab(this.id);\n    },\n    resetAutoCloseTimeout: function(a) {\n        if (((this.getPostType() == \"group\"))) {\n            return;\n        }\n    ;\n    ;\n        if (this.autoCloseTimeoutID) {\n            JSBNG__clearTimeout(this.autoCloseTimeoutID);\n        }\n    ;\n    ;\n        var b = ChatConfig.get(\"tab_auto_close_timeout_ms\");\n        var c = Math.floor(((ChatConfig.get(\"tab_auto_close_timeout_variation_range_ms\") * Math.JSBNG__random())));\n        this.autoCloseTimeoutID = JSBNG__setTimeout(this._autoCloseTab.shield(this), ((b + c)), false);\n        if (a) {\n            this.staleTime = (new JSBNG__Date()).getTime();\n        }\n    ;\n    ;\n    },\n    clearAutoCloseTimeout: function() {\n        if (((this.getPostType() == \"group\"))) {\n            return;\n        }\n    ;\n    ;\n        if (this.autoCloseTimeoutID) {\n            JSBNG__clearTimeout(this.autoCloseTimeoutID);\n            delete this.autoCloseTimeoutID;\n        }\n    ;\n    ;\n        this.staleTime = null;\n    },\n    _autoCloseTab: function() {\n        if (!this.staleTime) {\n            this.staleTime = (new JSBNG__Date()).getTime();\n        }\n    ;\n    ;\n        if (((((((ChatConfig.get(\"tab_auto_close_enabled\") && !this.focused)) && this.chatDisplay.isUserIdle())) && !this.chatDisplay.inNLatestActiveTabs(this.id, ChatConfig.get(\"tab_auto_close_min_tab_count\"))))) {\n            this.chatDisplay.closeTab(this.id);\n            delete this.autoCloseTimeoutID;\n        }\n         else this.resetAutoCloseTimeout(false);\n    ;\n    ;\n    }\n});\nfunction renderDate(a, e) {\n    if (e) {\n        var f = new JSBNG__Date();\n        f.setHours(0);\n        f.setMinutes(0);\n        f.setSeconds(0);\n        f.setMilliseconds(0);\n        var b = ((((((24 * 60)) * 60)) * 1000));\n        var c = ((f.getTime() - a.getTime()));\n        if (((c <= 0))) {\n            return _tx(\"Today\");\n        }\n         else if (((c < b))) {\n            return _tx(\"Yesterday\");\n        }\n        \n    ;\n    ;\n    }\n;\n;\n    var d = \"\";\n    switch (a.getMonth()) {\n      case 0:\n        d = _tx(\"January\");\n        break;\n      case 1:\n        d = _tx(\"February\");\n        break;\n      case 2:\n        d = _tx(\"March\");\n        break;\n      case 3:\n        d = _tx(\"April\");\n        break;\n      case 4:\n        d = _tx(\"May\");\n        break;\n      case 5:\n        d = _tx(\"June\");\n        break;\n      case 6:\n        d = _tx(\"July\");\n        break;\n      case 7:\n        d = _tx(\"August\");\n        break;\n      case 8:\n        d = _tx(\"September\");\n        break;\n      case 9:\n        d = _tx(\"October\");\n        break;\n      case 10:\n        d = _tx(\"November\");\n        break;\n      case 11:\n        d = _tx(\"December\");\n        break;\n    };\n;\n    return _tx(\"{month} {date}\", {\n        month: d,\n        date: a.getDate()\n    });\n};\n;\nJSBNG__onloadRegister(function() {\n    if (ua.firefox()) {\n        var a = function() {\n            return ((((CSS.getStyle(JSBNG__document.body, \"overflowX\") + \" \")) + CSS.getStyle(JSBNG__document.body, \"overflowY\")));\n        };\n        var b = a();\n        JSBNG__document.body.JSBNG__addEventListener(\"DOMAttrModified\", function(JSBNG__event) {\n            if (((((JSBNG__event.getTarget() === JSBNG__document.body)) && ((((JSBNG__event.attrName === \"class\")) || ((JSBNG__event.attrName === \"style\"))))))) {\n                var c = a();\n                if (((c !== b))) {\n                    b = c;\n                    Arbiter.inform(\"overflow-applied-to-body\");\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }, false);\n    }\n;\n;\n});\nfunction ChatDisplayInterim(e, c, a, d, b, g) {\n    this.histories = e;\n    this.user = presence.user;\n    var i = env_get(\"www_base\");\n    this.messageURL = ((i + \"ajax/messaging/composer.php\"));\n    this.settingsURL = \"/ajax/chat/settings.php\";\n    this.tabsURL = \"/ajax/chat/tabs.php\";\n    this.visibilityURL = \"/ajax/chat/visibility.php\";\n    this.reportURL = \"/ajax/chat/report.php\";\n    this.templates = g;\n    this.JSBNG__controllers = copy_properties({\n        friend: \"ChatTab\",\n        group: \"ChatGroupTab\",\n        thread: \"ChatThreadTab\",\n        livelisten: \"ChatLiveListenTab\"\n    }, b);\n    this._shortTabTypes = {\n        friend: \"f\",\n        group: \"g\",\n        livelisten: \"l\",\n        thread: \"t\"\n    };\n    this._tabTypes = {\n    };\n    for (var f in this._shortTabTypes) {\n        var h = this._shortTabTypes[f];\n        this._tabTypes[h] = f;\n    };\n;\n    this.renderServerTime = ((ChatConfig.get(\"24h_times\") ? this._renderServerTime24hr : this._renderServerTime12hr));\n    this.jabberSquelchInterval = 300000;\n    this._squelchUntil = null;\n    this._squelchedIds = {\n    };\n    this._reportedLatencies = 0;\n    this._jslog = JSLogger.create(\"chat_display\");\n    this._init(a, d);\n};\n;\nChatDisplayInterim.prototype = {\n    maxNumTabs: 20,\n    _init: function(a, b) {\n        this.loaded = false;\n        this.tabs = {\n        };\n        this.tabList = [];\n        this.numTabs = 0;\n        this.lastFocused = null;\n        this.newMsgNames = [];\n        this.newMsgNamesIndex = 0;\n        this.blinkingTimer = null;\n        this.uiChangeTime = 0;\n        this.uiCookieCacheTime = ((((Env.rep_lag + presence.sitevars.CHAT_UI_COOKIE_CACHE_WINDOW)) * 1000));\n        this.initialFocusedChat = b;\n        this.initialActiveChats = a;\n        presence.registerStateStorer(this._store.bind(this));\n        presence.registerStateLoader(this._load.bind(this));\n        var c = [\"unfocus_chat\",\"focus_chat\",\"close_chat\",\"group_msg\",\"livelisten_msg\",\"thread_msg\",\"msg\",\"typ\",\"video\",\"chat_event\",\"buddylist_overlay\",\"start_multichat\",\"show_multichat_callout\",\"update_multichat_participants\",\"livelisten_update\",].map(PresenceMessage.getArbiterMessageType);\n        Arbiter.subscribe(c, this._handlePresenceMessage.bind(this));\n        Arbiter.subscribe(PresenceMessage.STARTED, this.start.bind(this));\n        Arbiter.subscribe(PresenceMessage.SHUTDOWN, this.shutdown.bind(this));\n        Arbiter.subscribe(PresenceMessage.RESTARTED, this.restart.bind(this));\n        Arbiter.subscribe(PresenceMessage.WINDOW_RESIZED, this.handleResize.bind(this));\n        Arbiter.subscribe(channel.ON_INVALID_HISTORY, this.handleInvalidHistory.bind(this));\n        Arbiter.subscribe(channel.ON_CONNECT, function(e, d) {\n            ((((d <= 1)) ? this.start() : this.restart()));\n        }.bind(this));\n        Arbiter.subscribe(channel.ON_SHUTDOWN, this.shutdown.bind(this));\n        JSBNG__Event.listen(window, \"JSBNG__focus\", this.JSBNG__onWindowFocus.bind(this));\n        JSBNG__Event.listen(window, \"JSBNG__blur\", this.JSBNG__onWindowBlur.bind(this));\n        Arbiter.subscribe(\"chat/visibility-changed\", this._handleVisibilityChange.shield(this));\n        Arbiter.subscribe(\"time_check\", function(d, e) {\n            if (((this.focused && ((e > 30000))))) {\n                this._jslog.log(\"time_check_refresh\");\n                this.tabs[this.focused].getHistory();\n            }\n        ;\n        ;\n        }.bind(this));\n    },\n    _handleVisibilityChange: function() {\n        var a = Chat.isOnline();\n        if (!a) {\n            this.closeAllTabs();\n        }\n    ;\n    ;\n    },\n    JSBNG__onWindowFocus: function() {\n        this.isWindowFocused = true;\n        this.doStopBlinking();\n    },\n    JSBNG__onWindowBlur: function() {\n        this.isWindowFocused = false;\n    },\n    start: function() {\n        for (var a in this.tabs) {\n            this.tabs[a].start();\n        ;\n        };\n    ;\n    },\n    shutdown: function() {\n        this._stopBlinking();\n    },\n    restart: function() {\n        for (var a in this.tabs) {\n            this.tabs[a].restart();\n        ;\n        };\n    ;\n    },\n    loadInitialUserInfo: function(c, d, a, b, e) {\n        if (ChatUserInfos[c]) {\n            return;\n        }\n    ;\n    ;\n        if (!e) {\n            this._jslog.log(\"initial_info_no_type\");\n            e = \"friend\";\n        }\n    ;\n    ;\n        ChatUserInfos[c] = {\n            JSBNG__name: d,\n            firstName: a,\n            thumbSrc: \"\",\n            gender: ((b || GenderConst.UNKNOWN)),\n            type: e\n        };\n    },\n    _loadTabs: function(e, d) {\n        var f = {\n        };\n        e.each(function(h) {\n            f[h.i] = h;\n        });\n        for (var b in this.tabs) {\n            if (((((!f[b] && !this.tabs[b].isFragileMode())) && ((b != d))))) {\n                this._closeTab(b);\n            }\n        ;\n        ;\n        };\n    ;\n        for (var a = 0, c = e.length; ((a < c)); a++) {\n            var g = e[a];\n            this._deserializeTab(g);\n        };\n    ;\n        if (((((presence.inPopoutWindow && !d)) && e.length))) {\n            d = e[0].i;\n        }\n    ;\n    ;\n        Arbiter.subscribe(\"chat-tab-slider/loaded\", function(i, h) {\n            if (((d != this.focused))) {\n                this._unfocus();\n                if (((d && !this.isSquelchedTab(d)))) {\n                    this._focusTab(d);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            h.addTab();\n        }.bind(this));\n        this.loadedInitialTabs = true;\n    },\n    _deserializeTab: function(f) {\n        var b = f.i;\n        if (this.tabs[b]) {\n            return;\n        }\n    ;\n    ;\n        if (this.isSquelchedTab(b)) {\n            this._jslog.log(\"load_tabs_squelched\", {\n                tab_id: b\n            });\n            return;\n        }\n    ;\n    ;\n        var d, a, g;\n        if (((b in ChatUserInfos))) {\n            d = ChatUserInfos[b].JSBNG__name;\n            a = ChatUserInfos[b].firstName;\n            g = ChatUserInfos[b].type;\n        }\n         else {\n            d = f.n;\n            a = f.fn;\n            if (!f.y) {\n                this._jslog.log(\"load_tab_no_type\", {\n                    tab_id: b\n                });\n                f.y = \"friend\";\n            }\n        ;\n        ;\n            g = f.y;\n        }\n    ;\n    ;\n        var e = ((f.m || 0));\n        var c = ((f.t || 0));\n        this.createTab(g, b, d, a, e, c);\n    },\n    load: function() {\n        Arbiter.subscribe(\"available-list/initialized\", function() {\n            this._load(presence.state);\n            presence.doSync();\n            Arbiter.inform(\"chat-display/loaded\", this, Arbiter.BEHAVIOR_PERSISTENT);\n        }.bind(this));\n    },\n    loadTabFragile: function(b, d, a, e) {\n        if (presence.isOnline()) {\n            if (!this.tabs[b]) {\n                var c = {\n                    i: b,\n                    n: d,\n                    fn: a,\n                    y: e\n                };\n                this._deserializeTab(c);\n                this.tabs[b].setFragileMode();\n                this._jslog.log(\"load_fragile\", c);\n            }\n        ;\n        ;\n        }\n         else this._jslog.log(\"no_load_fragile_offline\");\n    ;\n    ;\n    },\n    _load: function(f) {\n        var c = false;\n        if (f) {\n            if (((this.blinkingTimer && f.sb))) {\n                this._stopBlinking();\n            }\n        ;\n        ;\n            this._squelchUntil = f.sq;\n            var h = ((verifyNumber(f.uct) * 1000));\n            var g = ((h > this.uiChangeTime));\n            this.uiChangeTime = Math.max(this.uiChangeTime, h);\n            if (((!this.loaded || ((ChatConfig.get(\"chat_client_tabs\") && g))))) {\n                var d = presence.getTime();\n                if (((((((d - this.uiChangeTime)) < this.uiCookieCacheTime)) || ChatConfig.get(\"chat_client_tabs\")))) {\n                    this._jslog.log(\"load_cookie_tabs\", {\n                        tabs: f.t,\n                        focused: f.f,\n                        age: ((d - h))\n                    });\n                    if (f.t) {\n                        var e = ((((d - f.ut)) > ((((60 * 60)) * 1000))));\n                        for (var a = 0, b = f.t.length; ((a < b)); a++) {\n                            if (e) {\n                                f.t[a].m = 0;\n                            }\n                        ;\n                        ;\n                            var i = ((f.t[a].y || \"f\"));\n                            f.t[a].y = this._tabTypes[i];\n                        };\n                    ;\n                        this._loadTabs(f.t, ((f.f || null)));\n                        c = true;\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        if (((!this.loaded && !c))) {\n            this._jslog.log(\"load_server_tabs\", {\n                tabs: this.initialActiveChats,\n                focused: this.initialFocusedChat\n            });\n            this._loadTabs(this.initialActiveChats, ((this.initialFocusedChat || null)));\n            this.initialFocusedChat = this.initialActiveChats = false;\n        }\n    ;\n    ;\n        this.loaded = true;\n    },\n    _store: function(d) {\n        d.sb = ((((this.blinkingTimer == null)) ? 1 : 0));\n        var e = this.getSquelchUntil();\n        if (((e !== null))) {\n            d.sq = e;\n        }\n    ;\n    ;\n        d.t = [];\n        d.f = null;\n        d.uct = 0;\n        var c = presence.getTime();\n        if (((((((c - this.uiChangeTime)) < this.uiCookieCacheTime)) || ChatConfig.get(\"chat_save_client_tabs\")))) {\n            for (var a = 0, b = this.tabList.length; ((a < b)); a++) {\n                var g = this.tabList[a];\n                if (!g.isFragileMode()) {\n                    var f = {\n                        i: g.id\n                    };\n                    if (g.numMissed) {\n                        f.m = g.numMissed;\n                    }\n                ;\n                ;\n                    var h = this._shortTabTypes[g.getPostType()];\n                    if (((h && ((h != \"f\"))))) {\n                        f.y = h;\n                    }\n                ;\n                ;\n                    d.t.push(f);\n                }\n            ;\n            ;\n            };\n        ;\n            if (((((this.focused && this.tabs[this.focused])) && !this.tabs[this.focused].isFragileMode()))) {\n                d.f = this.focused;\n            }\n        ;\n        ;\n            d.uct = Math.floor(((this.uiChangeTime * 77461)));\n        }\n    ;\n    ;\n        return d;\n    },\n    handleResize: function() {\n        if (!this.focused) {\n            return;\n        }\n    ;\n    ;\n        var a = this.tabs[this.focused];\n        a.handleResize();\n    },\n    handleInvalidHistory: function() {\n        var a = ((this.focused && this.tabs[this.focused]));\n        if (a) {\n            a.getHistory(true);\n        }\n    ;\n    ;\n    },\n    _sendTabStateChange: function(a) {\n        if (ChatConfig.get(\"chat_save_client_tabs\")) {\n            presence.doSync();\n        }\n    ;\n    ;\n        a.window_id = presence.getWindowID();\n        new AsyncRequest().setURI(this.tabsURL).setData(a).setHandler(this._onCheckTabStateChangeResponse.bind(this, a)).setErrorHandler(bagofholding).setAllowCrossPageTransition(true).send();\n    },\n    _sendDeferredTabStateChange: function(a) {\n        JSBNG__clearTimeout(this._deferredTabStateChange);\n        this._deferredTabStateChange = this._sendTabStateChange.bind(this, a).defer();\n    },\n    _onCheckTabStateChangeResponse: function(b, d) {\n        var a = ((((b && b.focus_chat)) || null));\n        var e = ((a && AvailableList.get(a)));\n        var c = d.getPayload();\n        if (((c && c.overlay))) {\n            AvailableList.addLegacyOverlay(c.overlay);\n            if (((e && !AvailableList.get(a)))) {\n                presence.error(((\"presence:ol_on_to_off:id=\" + a)));\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    reloadTabs: function() {\n        for (var a in this.tabs) {\n            this.tabs[a].loadData();\n        ;\n        };\n    ;\n    },\n    _closeTab: function(a) {\n        if (!this.tabs[a]) {\n            return;\n        }\n    ;\n    ;\n        var c = this.tabList.indexOf(this.tabs[a]);\n        if (((this.focused == a))) {\n            if (presence.inPopoutWindow) {\n                var b = this.tabList.length;\n                var d = this.tabList[((((((c + ((c ? -1 : 1)))) + b)) % b))].id;\n                if (((d != a))) {\n                    this.focusTab(d);\n                }\n                 else this.focused = null;\n            ;\n            ;\n            }\n             else this.focused = null;\n        ;\n        }\n    ;\n    ;\n        this.tabs[a].close();\n        this.tabList.splice(c, 1);\n        delete this.tabs[a];\n        this.numTabs--;\n        Arbiter.inform(\"chat/conversation-closed\", {\n            id: a\n        });\n        ((window.chatTabSlider && chatTabSlider.close()));\n    },\n    uiChanged: function() {\n        this.uiChangeTime = presence.getTime();\n        presence.doSync();\n    },\n    closeTab: function(a) {\n        this._closeTab(a);\n        this._sendTabStateChange({\n            close_chat: a\n        });\n        this.uiChanged();\n        this.doStopBlinking();\n    },\n    closeAllTabs: function() {\n        for (var a in this.tabs) {\n            this._closeTab(a);\n        ;\n        };\n    ;\n        this.uiChanged();\n        this.doStopBlinking();\n    },\n    _unfocus: function(b) {\n        var a = this.focused;\n        if (((!a || ((b && ((a != b))))))) {\n            return false;\n        }\n    ;\n    ;\n        this.focused = null;\n        if (presence.inPopoutWindow) {\n            this.tabs[a].deselectPopoutChat();\n        }\n    ;\n    ;\n        this.tabs[a].unfocus();\n        Arbiter.inform(\"chat/conversation-unfocused\", {\n            id: a,\n            conversation: this.tabs[a]\n        });\n        return true;\n    },\n    unfocus: function(a, b) {\n        if (((this._unfocus(a) && ((b !== false))))) {\n            this._sendDeferredTabStateChange({\n                unfocus_chat: 1\n            });\n            this.uiChanged();\n            this.doStopBlinking();\n        }\n    ;\n    ;\n        this.lastFocused = null;\n    },\n    unfocusNoSync: function() {\n        this._unfocus();\n    },\n    refocus: function() {\n        if (((!this.lastFocused || !this.tabs[this.lastFocused]))) {\n            return null;\n        }\n    ;\n    ;\n        this._focusTab(this.lastFocused);\n    },\n    _focusTab: function(d, b, e, a, f) {\n        if (!this.tabs[d]) {\n            if (((ChatUserInfos[d] && ChatUserInfos[d].JSBNG__name))) {\n                e = ChatUserInfos[d].JSBNG__name;\n                a = ChatUserInfos[d].firstName;\n                f = ChatUserInfos[d].type;\n            }\n        ;\n        ;\n            if (!f) {\n                this._jslog.log(\"tab_focus_no_type\", {\n                    tab_id: d\n                });\n                f = \"friend\";\n            }\n        ;\n        ;\n            this.createTab(f, d, e, a);\n            ((window.chatTabSlider && chatTabSlider.addTab(d)));\n        }\n    ;\n    ;\n        ((window.chatTabSlider && chatTabSlider.gotoTab(d)));\n        if (((this.focused != d))) {\n            if (this.focused) {\n                this.tabs[this.focused].unfocus();\n                if (presence.inPopoutWindow) {\n                    this.tabs[this.focused].deselectPopoutChat();\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            this.focused = d;\n            this.lastFocused = d;\n        }\n    ;\n    ;\n        var c = ((!presence.inPopoutWindow && presence.poppedOut));\n        this.tabs[d].JSBNG__focus(c, this.loaded, b);\n        if (presence.inPopoutWindow) {\n            this.tabs[d].selectPopoutChat();\n        }\n    ;\n    ;\n        Arbiter.inform(\"chat/conversation-focused\", {\n            id: d,\n            conversation: this.tabs[d]\n        });\n        return this.tabs[d];\n    },\n    focusTab: function(d, c, e, b, g) {\n        presence.pauseSync();\n        var f = this._focusTab(d, c, e, b, g);\n        var a = {\n            focus_chat: d,\n            tab_type: f.getPostType()\n        };\n        this._sendDeferredTabStateChange(a);\n        this.uiChanged();\n        this.doStopBlinking();\n        presence.resumeSync();\n    },\n    toggleTab: function(c, b, d, a) {\n        if (((this.focused == c))) {\n            this.unfocus();\n        }\n         else this.focusTab(c, b, d, a);\n    ;\n    ;\n    },\n    getNextTabId: function(a, e, f) {\n        if (!((a in this.tabs))) {\n            return -1;\n        }\n    ;\n    ;\n        var c = this.tabList.indexOf(this.tabs[a]);\n        if (!presence.inPopoutWindow) {\n            e = !e;\n        }\n    ;\n    ;\n        if (!f) {\n            if (((((((c === 0)) && e)) || ((((c === ((this.tabList.length - 1)))) && !e))))) {\n                return 0;\n            }\n        ;\n        }\n    ;\n    ;\n        var d = a;\n        if (((c >= 0))) {\n            if (e) {\n                c--;\n            }\n             else c++;\n        ;\n        ;\n            var b = this.tabList.length;\n            d = this.tabList[((((c + b)) % b))].id;\n        }\n    ;\n    ;\n        return d;\n    },\n    _handleBlinking: function(a, c) {\n        var b = ((a == this.user));\n        if (b) {\n            this.doStopBlinking(true);\n        }\n         else if (this.isWindowFocused) {\n            JSBNG__setTimeout(this.doStopBlinking.bind(this, true), 500, false);\n        }\n         else {\n            this.newMsgNames.push(c);\n            if (!this.blinkingTimer) {\n                this.blinkingTimer = this._doBlink.bind(this).defer(3000, false);\n            }\n        ;\n        ;\n        }\n        \n    ;\n    ;\n    },\n    _doBlink: function() {\n        JSBNG__clearTimeout(this.blinkingTimer);\n        if (this._isBlinking) {\n            DocumentTitle.set(DocumentTitle.get());\n            this._isBlinking = false;\n        }\n         else {\n            if (((this.newMsgNames && ((this.newMsgNames.length > 0))))) {\n                if (((this.newMsgNamesIndex >= this.newMsgNames.length))) {\n                    this.newMsgNamesIndex = 0;\n                }\n            ;\n            ;\n                var a = this.newMsgNames[this.newMsgNamesIndex++];\n                if (a.groupMsg) {\n                    DocumentTitle.set(_tx(\"{senderName} messaged {groupName}\", {\n                        senderName: a.fromName,\n                        groupName: a.toName\n                    }), true);\n                }\n                 else DocumentTitle.set(_tx(\"{name} messaged you\", {\n                    JSBNG__name: a.fromName\n                }), true);\n            ;\n            ;\n            }\n             else DocumentTitle.set(_tx(\"New message!\"), true);\n        ;\n        ;\n            this._isBlinking = true;\n        }\n    ;\n    ;\n        this.blinkingTimer = this._doBlink.bind(this).defer(1500, false);\n    },\n    doStopBlinking: function(a) {\n        if (((this.blinkingTimer || a))) {\n            this._stopBlinking();\n            presence.doSync();\n        }\n    ;\n    ;\n    },\n    _stopBlinking: function() {\n        if (this.blinkingTimer) {\n            if (this._isBlinking) {\n                this._doBlink();\n            }\n        ;\n        ;\n            JSBNG__clearTimeout(this.blinkingTimer);\n            this.blinkingTimer = null;\n            this.newMsgNames = [];\n            this.newMsgNamesIndex = 0;\n        }\n    ;\n    ;\n    },\n    _isChatMessage: function(a) {\n        return ((((((((a.type == \"msg\")) || ((a.type == \"group_msg\")))) || ((a.type == \"livelisten_msg\")))) || ((a.type == \"thread_msg\"))));\n    },\n    _ignoreSelfMessage: function(a) {\n        return !this._isChatMessage(a);\n    },\n    _handlePresenceMessage: function(o, a) {\n        if (!Chat.isOnline()) {\n            this._jslog.error(\"offline_message\", {\n                type: o\n            });\n            return;\n        }\n    ;\n    ;\n        var i = a.obj;\n        var p = i.window_id;\n        if (((((!p && i.msg)) && i.msg.window_id))) {\n            p = i.msg.window_id;\n        }\n    ;\n    ;\n        if (((((presence.getWindowID() && ((p == presence.getWindowID())))) && this._ignoreSelfMessage(i)))) {\n            return;\n        }\n    ;\n    ;\n        var f = null;\n        if (((i.from == this.user))) {\n            f = ((i.id || i.to));\n            var e = !!i.csid;\n            this._jslog.log(\"message_echo_from_non_web\", {\n                type: o\n            });\n            this.setSquelched(e);\n            if (e) {\n                this._closeTab(f);\n            }\n        ;\n        ;\n        }\n         else f = ((i.id || i.from));\n    ;\n    ;\n        var m = this.tabs[f];\n        var n = ((((ChatUserInfos[f] && ChatUserInfos[f].type)) || i.tab_type));\n        var k = this.isSquelched();\n        var l = this.isSquelchedTab(f);\n        if (((k || l))) {\n            this._jslog.log(\"message_to_squelched\", {\n                type: i.type,\n                id: f,\n                is_squelched: k,\n                is_squelched_tab: l\n            });\n        }\n    ;\n    ;\n        switch (i.type) {\n          case \"unfocus_chat\":\n            this._unfocus();\n            break;\n          case \"focus_chat\":\n            if (((!k && !l))) {\n                this._focusTab(f, undefined, undefined, undefined, n);\n            }\n        ;\n        ;\n            break;\n          case \"close_chat\":\n            this._closeTab(f);\n            break;\n          case \"thread_msg\":\n        \n          case \"group_msg\":\n        \n          case \"livelisten_msg\":\n        \n          case \"msg\":\n            var c = ((i.from == this.user));\n            var h = false;\n            var g, b, d;\n            if (((((n == \"group\")) || ((n == \"livelisten\"))))) {\n                g = i.to_name;\n                b = g;\n                d = GenderConst.UNKNOWN_PLURAL;\n            }\n             else if (c) {\n                g = i.to_name;\n                b = ((i.to_first_name ? i.to_first_name : getFirstName(g)));\n                d = i.to_gender;\n            }\n             else {\n                g = i.from_name;\n                b = ((i.from_first_name ? i.from_first_name : getFirstName(g)));\n                d = i.from_gender;\n            }\n            \n        ;\n        ;\n            this.loadInitialUserInfo(f, g, b, d, n);\n            if (((((((((!k && !l)) && !c)) && !m)) && ((!ChatConfig.get(\"blackbird\") || PresencePrivacy.allows(i.from)))))) {\n                m = this.createTab(n, f, g, b);\n                h = true;\n                ((window.chatTabSlider && chatTabSlider.addTab(f)));\n            }\n        ;\n        ;\n            i.time = i.msg.time;\n            if (m) {\n                m.newMsg(i);\n            }\n        ;\n        ;\n            if (h) {\n                if (!this.focused) {\n                    this.focusTab(f);\n                }\n                 else m.getHistory();\n            ;\n            }\n        ;\n        ;\n            if (m) {\n                if (((!c && i.show_orca_callout))) {\n                    m.showOrcaCallout(i.from);\n                }\n            ;\n            ;\n                if (((i.type == \"thread_msg\"))) {\n                    m.setHasThread(true);\n                    this.updateMultichatToolbar(f, i.nub_name, i.titlebar, i.tooltip, i.statuses);\n                    this.setTabRecipients(f, i.recipients);\n                }\n            ;\n            ;\n                if (((presence.inPopoutWindow || !presence.poppedOut))) {\n                    this._handleBlinking(i.from, {\n                        toName: ((i.to_first_name ? i.to_first_name : getFirstName(i.to_name))),\n                        fromName: ((i.from_first_name ? i.from_first_name : getFirstName(i.from_name))),\n                        groupMsg: ((i.type == \"group_msg\"))\n                    });\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n            break;\n          case \"typ\":\n            if (((!k || ((this.focused == f))))) {\n                ((m && m.newTyping(i)));\n            }\n        ;\n        ;\n            break;\n          case \"video\":\n            this._newVideoMessage(i);\n            break;\n          case \"chat_event\":\n            this._newChatEventMessage(i);\n            break;\n          case \"buddylist_overlay\":\n            for (var j in i.overlay) {\n                ChatUserInfoManager.get(j, function() {\n                    var q = {\n                    };\n                    q[j] = i.overlay[j];\n                    AvailableList.addLegacyOverlay(q);\n                });\n            ;\n            };\n        ;\n            break;\n          case \"start_multichat\":\n            this.createMultichatTab(f, i.recipients, i.nub_name, i.titlebar, i.tooltip, false, i.statuses);\n            break;\n          case \"show_multichat_callout\":\n            this.showMultichatCallout(f);\n            break;\n          case \"update_multichat_participants\":\n            this.updateMultichatToolbar(f, i.nub_name, i.titlebar, i.tooltip, i.statuses);\n            this.setTabRecipients(f, i.recipients);\n            if (((typeof i.actionType != \"undefined\"))) {\n                ((m && m.newActionLogMsg(i)));\n            }\n        ;\n        ;\n            break;\n          case \"livelisten_update\":\n            Bootloader.loadComponents(\"Panda\", function() {\n                Panda.getInstance().handleUpdate(i);\n            });\n            break;\n          default:\n            break;\n        };\n    ;\n    },\n    _newVideoMessage: function(a) {\n        Arbiter.subscribe(\"video-chat/initialized\", function(c, b) {\n            var e = a.from;\n            var f = a.message_type;\n            var g = a.parameters;\n            var d = a.fl;\n            b.handleMessage(e, f, g);\n            if (((((e != this.user)) && ((f == b.START_SESSION))))) {\n                this.loadInitialUserInfo(e, g.JSBNG__name, g.firstName, g.gender, \"friend\");\n                AvailableList.set(e, AvailableList.ACTIVE, d);\n            }\n        ;\n        ;\n        }.bind(this));\n    },\n    _newChatEventMessage: function(a) {\n        if (presence.inPopoutWindow) {\n            return;\n        }\n    ;\n    ;\n        if (((a.log_type == LogMessageType.VIDEO_CALL))) {\n            this._handleVideoEvent(a.from, a.event_name, ((a.parameters || {\n            })));\n        }\n         else {\n            var b = this.tabs[a.to];\n            ((b && b.newLogMessage(a)));\n        }\n    ;\n    ;\n    },\n    _handleVideoEvent: function(b, a, c) {\n        if (!ChatConfig.get(\"video.can_be_called\", false)) {\n            return;\n        }\n    ;\n    ;\n        var d = this.tabs[b];\n        switch (a) {\n          case \"missed-call\":\n            ChatUserInfoManager.get(b, function(e) {\n                if (!d) {\n                    d = this.createTab(\"friend\", b, e.JSBNG__name, e.firstName);\n                }\n            ;\n            ;\n                if (!this.focused) {\n                    this._focusTab(b);\n                }\n            ;\n            ;\n                d.newVideoMsg(a, c);\n            }.bind(this));\n            break;\n          case \"connected-call\":\n            if (((b == this.user))) {\n                d = this.tabs[c.to];\n            }\n        ;\n        ;\n            ((d && d.newVideoMsg(a, c)));\n            break;\n        };\n    ;\n    },\n    _getBucketDescription: function(d) {\n        var a = [500,1000,2000,3000,5000,];\n        var b = [\"half_s\",\"1s\",\"2s\",\"3s\",\"5s\",];\n        for (var c = 0; ((c < a.length)); c++) {\n            if (((d < a[c]))) {\n                return b[c];\n            }\n        ;\n        ;\n        };\n    ;\n        return \"over_5s\";\n    },\n    reportLatency: function(b) {\n        if (((this._reportedLatencies < 5))) {\n            var a = this._getBucketDescription(b);\n            presence.warn(((((((((((\"presence:latency_\" + a)) + \":delay=\")) + b)) + \",sent=\")) + this._reportedLatencies)));\n            this._reportedLatencies++;\n        }\n    ;\n    ;\n    },\n    getHistory: function(b, a) {\n        a = ((a || false));\n        if (((!this.histories[b] && a))) {\n            this.histories[b] = [];\n        }\n    ;\n    ;\n        return this.histories[b];\n    },\n    addToHistory: function(f, h) {\n        var c = this.getHistory(f, true);\n        var i = true;\n        var g = null;\n        for (var e = ((c.length - 1)); ((e >= 0)); e--) {\n            var b = c[e];\n            if (this._isChatMessage(b)) {\n                if (!g) {\n                    g = c[e];\n                }\n            ;\n            ;\n                if (((((((((b.msg && b.msg.msgID)) && h.msg)) && ((b.msg.msgID == h.msg.msgID)))) && ((b.msg.text == h.msg.text))))) {\n                    return false;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n        if (((g && ((h.time <= g.time))))) {\n            var a = false;\n            for (e = 0; ((e < c.length)); e++) {\n                if (((this._isChatMessage(c[e]) && ((h.time == c[e].time))))) {\n                    a = true;\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            if (a) {\n                presence.warn(\"tabs: already had this msg\");\n                return;\n            }\n        ;\n        ;\n            for (e = ((c.length - 1)); ((e >= 0)); e--) {\n                var d = c[e];\n                if (((this._isChatMessage(d) && ((((d.to != h.to)) || ((!d.time || ((d.time < h.time))))))))) {\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n            presence.warn(\"tabs: merging new msg due to out-of-order server timestamp\");\n            if (((e == ((c.length - 1))))) {\n                c.push(h);\n            }\n             else {\n                c.splice(((e + 1)), 0, h);\n                var j = this.tabs[f];\n                if (j) {\n                    j._setHistory(c);\n                }\n            ;\n            ;\n                i = false;\n            }\n        ;\n        ;\n        }\n         else this.histories[f].push(h);\n    ;\n    ;\n        return i;\n    },\n    _renderServerTime12hr: function(d) {\n        var e = new JSBNG__Date();\n        e.setTime(((d + presence.timeSkew)));\n        var b = e.getHours();\n        var a = \"am\";\n        if (((b >= 12))) {\n            a = \"pm\";\n            b -= 12;\n        }\n    ;\n    ;\n        if (((b == 0))) {\n            b = 12;\n        }\n    ;\n    ;\n        var c = e.getMinutes();\n        if (((c < 10))) {\n            c = ((\"0\" + c));\n        }\n    ;\n    ;\n        var f = ((((((b + \":\")) + c)) + a));\n        return f;\n    },\n    _renderServerTime24hr: function(c) {\n        var d = new JSBNG__Date();\n        d.setTime(((c + presence.timeSkew)));\n        var a = d.getHours();\n        if (((a < 10))) {\n            a = ((\"0\" + a));\n        }\n    ;\n    ;\n        var b = d.getMinutes();\n        if (((b < 10))) {\n            b = ((\"0\" + b));\n        }\n    ;\n    ;\n        var e = ((((a + \":\")) + b));\n        return e;\n    },\n    setSquelched: function(c) {\n        var a = (new JSBNG__Date()).valueOf();\n        if (c) {\n            var b = ((a + this.jabberSquelchInterval));\n            this._jslog.log(\"squelch\", {\n                now: a,\n                until: b\n            });\n            this._squelchUntil = b;\n            presence.doSync();\n            this.clearHistory();\n        }\n         else if (this._squelchUntil) {\n            this._jslog.log(\"unsquelch\", {\n                now: a,\n                until: this._squelchUntil\n            });\n            this._squelchUntil = null;\n            presence.doSync();\n        }\n        \n    ;\n    ;\n    },\n    isSquelched: function() {\n        return ((this.getSquelchUntil() !== null));\n    },\n    setSquelchedTab: function(a, b) {\n        if (b) {\n            this._jslog.log(\"squelch_tab\", {\n                tab_id: a\n            });\n            this._squelchedIds[a] = true;\n            ((this.tabs[a] && this.tabs[a].squelch()));\n            this.clearHistory(a);\n        }\n         else {\n            this._jslog.log(\"unsquelch_tab\", {\n                tab_id: a\n            });\n            delete this._squelchedIds[a];\n        }\n    ;\n    ;\n    },\n    clearHistory: function(a) {\n        if (a) {\n            ((this.histories[a] && delete this.histories[a]));\n        }\n         else this.histories = {\n        };\n    ;\n    ;\n    },\n    isSquelchedTab: function(a) {\n        return ((a in this._squelchedIds));\n    },\n    getSquelchUntil: function() {\n        if (((this._squelchUntil === null))) {\n            return null;\n        }\n    ;\n    ;\n        var a = (new JSBNG__Date()).valueOf();\n        var b = ((a + ((this.jabberSquelchInterval + 5000))));\n        if (((b < this._squelchUntil))) {\n            this._jslog.warn(\"unsquelch_on_get_bad_until\", {\n                bound: b\n            });\n            this.setSquelched(false);\n            return null;\n        }\n         else if (((a < this._squelchUntil))) {\n            return this._squelchUntil;\n        }\n         else {\n            this.setSquelched(false);\n            return null;\n        }\n        \n    ;\n    ;\n    },\n    _enforceTabLimit: function() {\n        var a = 0;\n        while (((((this.numTabs > this.maxNumTabs)) && ((a < ((this.numTabs - 1))))))) {\n            if (((this.tabList[a].focused || this.tabList[a].numMissed))) {\n                ++a;\n            }\n             else this.closeTab(this.tabList[a].id);\n        ;\n        ;\n        };\n    ;\n    },\n    createMultichatTab: function(e, c, b, f, g, a, d) {\n        if (((typeof this.tabs[e] == \"undefined\"))) {\n            this.createTab(\"thread\", e, b, b, 0, 0);\n        }\n    ;\n    ;\n        this.tabs[e].setHasThread(a);\n        this.tabs[e].addRecipients(c);\n        this.focusTab(e, true, b, b, \"thread\");\n        this.updateMultichatToolbar(e, b, f, g, d);\n    },\n    showMultichatCallout: function(b) {\n        if (this.tabs[b]) {\n            var a = DOM.scry(this.tabs[b].tabHandle, \"a.addToThread\");\n            if (((a.length == 1))) {\n                new AsyncRequest().setData({\n                    thread_id: b\n                }).setRelativeTo(a[0]).setURI(\"/ajax/chat/multichat/callout.php\").setAllowCrossPageTransition(true).send();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    setTabRecipients: function(b, a) {\n        if (this.tabs[b]) {\n            this.tabs[b].setRecipients(a);\n        }\n    ;\n    ;\n    },\n    updateMultichatToolbar: function(f, c, g, h, d) {\n        var e = this.tabs[f];\n        if (e) {\n            var b = DOM.JSBNG__find(e.getTabDOM(), \"div.titlebarLabel\");\n            DOM.setContent(b, g);\n            TooltipLink.setTooltipText(b.firstChild, h);\n            var a = XHPTemplate.getNode(e.getTabDOM(), \"fbDockChatTab\");\n            if (a) {\n                TooltipLink.setTooltipText(a.firstChild, h);\n            }\n        ;\n        ;\n            e.updateName(c, c);\n            if (d) {\n                e.refreshStatusUpdateTime();\n                e.setParticipantStatuses(d);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    createTab: function(h, c, e, b, f, d) {\n        if (!h) {\n            this._jslog.log(\"create_tab_no_type\");\n            h = \"friend\";\n        }\n    ;\n    ;\n        var a = window[this.JSBNG__controllers[h]];\n        var g = new a(this, c, e, b, f, d);\n        this.tabs[c] = g;\n        this.tabList.push(g);\n        this.numTabs++;\n        Arbiter.inform(\"chat/conversation-opened\", {\n            id: c,\n            conversation: g\n        });\n        this._enforceTabLimit();\n        return g;\n    },\n    inNLatestActiveTabs: function(c, b) {\n        var d = keys(this.tabs);\n        d.sort(function(e, f) {\n            return ((this.tabs[e].staleTime - this.tabs[f].staleTime));\n        }.bind(this));\n        for (var a = ((d.length - b)); ((a < d.length)); a++) {\n            if (((d[a] == c))) {\n                return true;\n            }\n        ;\n        ;\n        };\n    ;\n        return false;\n    },\n    isUserIdle: function() {\n        var a = chatOptions.getSetting(\"idle_cutoff\");\n        return ((AvailableList.isUserIdle() && ((!a || !UserActivity.isActive(a)))));\n    }\n};\nfunction ChatDisplay(d, a, c, b, e) {\n    this.parent.construct(this, d, false, a, c, b, e);\n};\n;\nClass.extend(ChatDisplay, \"ChatDisplayInterim\");\nfunction ChatBuddyList() {\n    this.user = presence.user;\n    this.buddyListID = ChatBuddyList.ID++;\n    this.errorMode = false;\n    this.shouldShowLoading = false;\n    this.sortedList = [];\n    this.flMode = false;\n    this.flData = {\n    };\n    this.otherFriendsFlid = \"-1\";\n    this.botsFlid = \"-2\";\n    this.showingErrorMessage = false;\n    this.flSortableGroup = null;\n    this.reorderingLists = false;\n    this.flOpts = {\n    };\n    this.externalFlids = [];\n};\n;\ncopy_properties(ChatBuddyList, {\n    ID: 0,\n    OVERLAY_ONLINE: 0,\n    OVERLAY_IDLE: 1,\n    OVERLAY_OFFLINE: -1,\n    OVERLAY_MOBILE: 2,\n    DEFAULT_OPTS: {\n        fullDisplay: true,\n        excludeIds: {\n        }\n    },\n    MAX_BUDDY_NAME_LENGTH: 20\n});\nClass.mixin(ChatBuddyList, \"Arbiter\", {\n    _lastRenderRev: null,\n    _lastSortRev: null,\n    _showTime: null,\n    init: function(d, c, b, a) {\n        this.root = d;\n        this.flMode = b;\n        this.flData = a;\n        this.shouldShowLoading = c;\n        this._log = EagleEye.createLogger(\"chat-buddylist\", 91937);\n        this._init();\n        Arbiter.subscribe([\"buddylist/availability-changed\",\"buddylist/updated\",], this._render.bind(this));\n        Arbiter.subscribe(\"buddylist/update-error\", this._showLoadError.bind(this));\n        Arbiter.subscribe(\"buddylist/fl-changed\", this._handleFlChange.bind(this));\n    },\n    initError: function(a) {\n        this.root = a;\n        this.errorMode = true;\n        this._init();\n    },\n    _init: function() {\n        this.loaded = false;\n        this._isVisible = false;\n        this.updateDiff = 0;\n        this.rendered = false;\n        this.showingError = false;\n        this.contentDiv = DOM.JSBNG__find(this.root, \"div.content\");\n        this.buddyListError = DOM.JSBNG__find(this.root, \"div.status\");\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"fl_settings\"), this._handleFLMessage.bind(this));\n        Arbiter.subscribe(\"chat/connect\", this._showLoading.bind(this));\n        this.setCompactDisplay(chatOptions.getSetting(\"compact_buddylist\"));\n        Arbiter.subscribe(\"chat/option-changed\", this._updateSetting.bind(this));\n        Arbiter.inform(\"buddylist/initialized\", this, Arbiter.BEHAVIOR_PERSISTENT);\n        this.inform(\"initialized\", this, Arbiter.BEHAVIOR_PERSISTENT);\n    },\n    setCompactDisplay: function(a) {\n        this.isCompactDisplay = a;\n        if (this.isCompactDisplay) {\n            this.itemHeight = 18;\n        }\n         else this.itemHeight = 22;\n    ;\n    ;\n        if (this.rendered) {\n            this._render();\n        }\n    ;\n    ;\n    },\n    _handleFLMessage: function(c, a) {\n        var b = a.obj;\n        if (b.fl_mode) {\n            this._updateNames(b.fl_data);\n        }\n    ;\n    ;\n    },\n    _updateNames: function(b) {\n        for (var a in this.flData) {\n            if (((((typeof b[a] != \"undefined\")) && ((b[a].n != this.flData[a].n))))) {\n                flname = b[a].n;\n                elem = ge(this._getFriendListNameId(a));\n                if (elem) {\n                    DOM.setContent(elem, flname);\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    _flChanged: function(b, a) {\n        return ((((b != this.flMode)) || !are_equal(a, this.flData)));\n    },\n    _onFlChange: function(d, c) {\n        this._dirtyRendering();\n        if (!this.rendered) {\n            this.flMode = d;\n            this.flData = c;\n            return;\n        }\n    ;\n    ;\n        var g = [];\n        var h = [];\n        var f = [];\n        var e = [];\n        if (((this.flMode && ((this.flMode == d))))) {\n            var b = this._groupAvailableListByFl(true);\n            for (var a in c) {\n                if (((typeof this.flData[a] == \"undefined\"))) {\n                    if (c[a].h) {\n                        continue;\n                    }\n                ;\n                ;\n                    g.push(a);\n                    f.push(a);\n                }\n                 else if (((this.flData[a].h != c[a].h))) {\n                    if (c[a].h) {\n                        h.push(a);\n                    }\n                     else {\n                        g.push(a);\n                        if (c[a].o) {\n                            f.push(a);\n                        }\n                    ;\n                    ;\n                    }\n                ;\n                ;\n                }\n                 else if (((this.flData[a].o != c[a].o))) {\n                    if (c[a].o) {\n                        f.push(a);\n                    }\n                     else e.push(a);\n                ;\n                }\n                \n                \n            ;\n            ;\n            };\n        ;\n            for (var a in this.flData) {\n                if (((typeof c[a] == \"undefined\"))) {\n                    h.push(a);\n                }\n            ;\n            ;\n            };\n        ;\n            this.flMode = d;\n            if (((h.length != 0))) {\n                this._removeFlidsFromBuddyList(h, b);\n            }\n        ;\n        ;\n            if (((e.length != 0))) {\n                this._goOfflineToLists(e, true);\n            }\n        ;\n        ;\n            this.flData = c;\n            if (((g.length != 0))) {\n                this._addFlidsToDOM(g, b);\n            }\n        ;\n        ;\n            if (((f.length != 0))) {\n                this._goOnlineToLists(f, true);\n            }\n        ;\n        ;\n        }\n         else if (((this.flMode && ((this.flMode != d))))) {\n            var b = this._groupAvailableListByFl(true);\n            h = keys(this.flData);\n            this.flMode = d;\n            this.flData = c;\n            this._addFlidsToDOM([null,]);\n            this._removeFlidsFromBuddyList(h, b);\n        }\n         else if (((!this.flMode && ((this.flMode != d))))) {\n            for (var a in c) {\n                if (c[a].h) {\n                    continue;\n                }\n            ;\n            ;\n                g.push(a);\n                if (c[a].o) {\n                    f.push(a);\n                }\n            ;\n            ;\n            };\n        ;\n            this.flMode = d;\n            this.flData = c;\n            this._removeFlidsFromDOM([null,]);\n            if (((g.length > 0))) {\n                this._addFlidsToDOM(g);\n            }\n        ;\n        ;\n            if (((f.length > 0))) {\n                this._goOnlineToLists.bind(this, f, true).defer();\n            }\n        ;\n        ;\n        }\n        \n        \n    ;\n    ;\n        this._render();\n    },\n    _addFlidsToDOM: function(e, f) {\n        f = ((f || this._groupAvailableListByFl(true)));\n        var a = this._getRenderedFriendLists();\n        var c = a[0];\n        var h = $(\"fbChatBuddyListParent\");\n        for (var g = 0; ((g < e.length)); g++) {\n            var d = e[g];\n            if (((this.flMode && d))) {\n                var b = DOM.create(\"div\", {\n                    id: this._getFriendListId(d),\n                    className: this._getFriendListItemClasses(d, f)\n                });\n                DOM.setContent(b, HTML(this._renderFriendListHeader(d)));\n                DOM.appendContent(b, HTML(this._renderFriendListContent(d, [])));\n                if (((c == d))) {\n                    DOM.prependContent(h, b);\n                }\n                 else {\n                    var j = a.indexOf(d);\n                    var i = a[((j - 1))];\n                    DOM.insertAfter(ge(this._getFriendListId(i)), b);\n                }\n            ;\n            ;\n                this._addFlSortable(d);\n            }\n             else DOM.prependContent(h, HTML(this._renderFriendListContent(null, [])));\n        ;\n        ;\n        };\n    ;\n        this._addFriendListListeners(e);\n    },\n    _removeFlidsFromDOM: function(b) {\n        for (var c = 0; ((c < b.length)); c++) {\n            var a = b[c];\n            if (a) {\n                if (ge(this._getFriendListId(a))) {\n                    DOM.remove($(this._getFriendListId(a)));\n                    this._removeFlSortable(a);\n                }\n            ;\n            ;\n            }\n             else {\n                DOM.remove($(this._getAvailableMarkerId(a)));\n                DOM.remove($(this._getIdleMarkerId(a)));\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    contentChanged: function() {\n        this.inform(\"content-changed\");\n    },\n    show: function() {\n        if (this._isVisible) {\n            return;\n        }\n    ;\n    ;\n        this._showTime = ((this._showTime || new JSBNG__Date()));\n        AvailableList.update();\n        this._isVisible = true;\n        if (!this.rendered) {\n            this.shouldShowLoading = true;\n            this._firstRender();\n            if (AvailableList.haveFullList) {\n                this._render.bind(this).defer();\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        CSS.show(this.root);\n    },\n    hide: function() {\n        if (!this._isVisible) {\n            return;\n        }\n    ;\n    ;\n        this._showTime = null;\n        this._isVisible = false;\n        this.exitReorderingFlMode();\n        CSS.hide(this.root);\n    },\n    _getUserFlid: function(c, a) {\n        if (((((a === null)) || ((a === undefined))))) {\n            var b = this._getUserFlids(c);\n            a = b[0];\n        }\n    ;\n    ;\n        return a;\n    },\n    _getSortedList: function() {\n        if (((this._lastSortRev != AvailableList.getRev()))) {\n            this.sortedList = this._sort(AvailableList.getAvailableIDs());\n            this._lastSortRev = AvailableList.getRev();\n        }\n    ;\n    ;\n        return this.sortedList;\n    },\n    getSortedListUI: function(a) {\n        if (((!a && this.flMode))) {\n            var b = this._groupAvailableListByFl(true);\n            var c = [];\n            for (var a in b) {\n                c = c.concat(b[a]);\n            ;\n            };\n        ;\n            var d = {\n            };\n            return c.filter(function(e) {\n                return ((!d[e] && (d[e] = true)));\n            });\n        }\n    ;\n    ;\n        return this._getSortedList();\n    },\n    getFriendLists: function() {\n        var a = {\n        };\n        copy_properties(a, this.flData);\n        delete a[this.otherFriendsFlid];\n        delete a[this.botsFlid];\n        return a;\n    },\n    _getRenderedFriendLists: function() {\n        var b = [];\n        for (var a in this.flData) {\n            if (!this.flData[a].h) {\n                b.push(a);\n            }\n        ;\n        ;\n        };\n    ;\n        return b;\n    },\n    _getFriendListsInChat: function() {\n        var a = this._getRenderedFriendLists();\n        a.remove(this.otherFriendsFlid);\n        a.remove(this.botsFlid);\n        return a;\n    },\n    updateUserInfos: function(a) {\n        copy_properties(ChatUserInfos, a);\n    },\n    _sort: function(b) {\n        var a = this._compareFunction.bind(this);\n        b.sort(a);\n        return b;\n    },\n    _compareFunction: function(a, d, b, e) {\n        if (((typeof b == \"undefined\"))) {\n            b = AvailableList.isIdle(a);\n        }\n    ;\n    ;\n        if (((typeof e == \"undefined\"))) {\n            e = AvailableList.isIdle(d);\n        }\n    ;\n    ;\n        if (((b ^ e))) {\n            return ((b ? 1 : -1));\n        }\n    ;\n    ;\n        var c = ChatUserInfos[a].JSBNG__name.toLowerCase();\n        var f = ChatUserInfos[d].JSBNG__name.toLowerCase();\n        return ((((c < f)) ? -1 : 1));\n    },\n    itemOnClick: function(c) {\n        var b = DataStore.get(c, \"id\");\n        var a = DataStore.get(c, \"flid\");\n        presence.pauseSync();\n        Chat.openTab(b, null, null, \"buddylist\");\n        if (!this.isSticky()) {\n            Chat.closeBuddyList();\n        }\n    ;\n    ;\n        this.inform(\"buddylist/buddy-clicked\", {\n            flid: a,\n            id: b\n        });\n        presence.resumeSync();\n    },\n    _renderItem: function(c, a, d) {\n        var i = ChatUserInfos[c];\n        var f = i.JSBNG__name;\n        var h = i.thumbSrc;\n        var e = [\"\\u003Ca\",\" href=\\\"#\\\"\",\" id=\\\"\",this._getBuddyListItemId(c, a),\"\\\"\",\" class=\\\"clearfix friend\",((d ? \" idle\" : \"\")),\"\\\"\",\" title=\\\"\",f,\"\\\"\",\" data-id=\\\"\",parseInt(c, 10),\"\\\"\",\" data-flid=\\\"\",a,\"\\\"\",\"\\u003E\",];\n        var b = !this.isCompactDisplay;\n        var g = this._getFlOpts(a);\n        b &= g.fullDisplay;\n        if (b) {\n            e = e.concat(\"\\u003Cimg src=\\\"\", h, \"\\\" /\\u003E\");\n        }\n    ;\n    ;\n        e = e.concat(\"\\u003Cspan id=\\\"\", this._getBuddyListItemNameId(c, a), \"\\\"\\u003E\", htmlize(f), \"\\u003C/span\\u003E\", \"\\u003C/a\\u003E\");\n        return e.join(\"\");\n    },\n    _groupAvailableListByFl: function(c, a) {\n        if (((!this.flMode || !this.flData))) {\n            return null;\n        }\n    ;\n    ;\n        c = ((c || false));\n        a = ((a || false));\n        var e = {\n        };\n        for (var b in this.flData) {\n            e[b] = [];\n        ;\n        };\n    ;\n        if (a) {\n            return e;\n        }\n    ;\n    ;\n        var d = ((c ? this._getSortedList() : AvailableList.getAvailableIDs()));\n        d.forEach(function(h) {\n            var g = FriendLists.get(h);\n            if (g) {\n                for (var i = 0; ((i < g.length)); ++i) {\n                    var f = g[i];\n                    ((e[f] && e[f].push(h)));\n                };\n            }\n        ;\n        ;\n        });\n        return e;\n    },\n    _listNameInUse: function(b) {\n        for (var a in this.flData) {\n            if (((this.flData[a].n == b))) {\n                return true;\n            }\n        ;\n        ;\n        };\n    ;\n        return false;\n    },\n    createFriendList: function(b) {\n        if (this._listNameInUse(b)) {\n            ErrorDialog.show(_tx(\"An error occurred.\"), _tx(\"You cannot have two lists with the same name. Please create a unique name for this list.\"));\n            return;\n        }\n    ;\n    ;\n        var a = {\n            create: b\n        };\n        this._saveBuddyListSetting(a, function() {\n            for (var c in this.flData) {\n                if (((this.flData[c].n == b))) {\n                    if (!this.flData[c].h) {\n                        this.scrollIntoView($(this._getFriendListId(c)));\n                    }\n                ;\n                ;\n                    Arbiter.inform(\"friend-list/new\", {\n                        flid: c,\n                        fl_name: b\n                    });\n                    break;\n                }\n            ;\n            ;\n            };\n        ;\n        }.bind(this));\n    },\n    handleFlInChat: function(b, a) {\n        if (b) {\n            this._unHideFriendListFromChat(a);\n        }\n         else this._hideFriendListFromChat(a);\n    ;\n    ;\n    },\n    _unHideFriendListFromChat: function(b) {\n        var d = ((this._getFriendListsInChat().length == 0));\n        var c = [b,];\n        var a = {\n            unhide_from_chat: 1,\n            flids: c\n        };\n        this.flData[b].h = 0;\n        this._saveBuddyListSetting(a, function() {\n            this._showEmptyListMomentarily(b);\n            this.scrollIntoView($(this._getFriendListId(b)));\n        }.bind(this));\n        if (d) {\n            this._onFlChange(true, this.flData);\n        }\n         else this._addFlidsToDOM(c);\n    ;\n    ;\n    },\n    _hideFriendListFromChat: function(b) {\n        var d = ((this._getFriendListsInChat().length == 1));\n        var c = [b,];\n        var a = {\n            hide_from_chat: 1,\n            flids: c\n        };\n        this.flData[b].h = 1;\n        this._saveBuddyListSetting(a);\n        if (d) {\n            this._onFlChange(false, this.flData);\n        }\n         else this._removeFlidsFromBuddyList(c);\n    ;\n    ;\n    },\n    _friendListHandleSwitchThrown: function(b) {\n        var a = this.flData[b].o;\n        if (a) {\n            this._goOfflineToLists([b,]);\n        }\n         else this._goOnlineToLists([b,]);\n    ;\n    ;\n    },\n    _friendListHandleSwitchMouseDown: function(b) {\n        var a = JSBNG__Event.listen(JSBNG__document, \"mouseup\", function() {\n            a.remove();\n            this._friendListHandleSwitchThrown(b);\n        }.bind(this));\n    },\n    _friendListHandleMouseOver: function(a) {\n        if (this.reorderingLists) {\n            return;\n        }\n    ;\n    ;\n        CSS.addClass($(this._getFriendListId(a)), \"hover\");\n    },\n    _friendListHandleMouseOut: function(a) {\n        CSS.removeClass($(this._getFriendListId(a)), \"hover\");\n    },\n    _saveBuddyListSetting: function(b, a) {\n        b.user = this.user;\n        a = ((a || bagofholding));\n        new AsyncRequest().setData(b).setURI(\"/ajax/chat/buddy_list_settings.php\").setHandler(this._onBuddyListSettingSave.bind(this, a)).setAllowCrossPageTransition(true).send();\n    },\n    _goOnlineToLists: function(a, b) {\n        b = ((b || false));\n        this._handleFlVisibilityChange(a, 1);\n        this._saveBuddyListSetting({\n            JSBNG__online_to_list: 1,\n            flids: a,\n            read_only: b,\n            notify_ids: Chat.getActiveFriendChats()\n        });\n    },\n    _handleFlVisibilityChange: function(d, f, a) {\n        for (var e = 0; ((e < d.length)); e++) {\n            var c = d[e];\n            var b = ge(this._getFriendListId(c));\n            if (!b) {\n                continue;\n            }\n        ;\n        ;\n            this.flData[c].o = f;\n            if (f) {\n                CSS.addClass(b, \"JSBNG__online\");\n                CSS.removeClass(b, \"offline\");\n                if (((c == this.otherFriendsFlid))) {\n                    this._showEmptyListMomentarily(c);\n                }\n            ;\n            ;\n            }\n             else {\n                CSS.addClass(b, \"offline\");\n                CSS.removeClass(b, \"JSBNG__online\");\n            }\n        ;\n        ;\n            var g = DOM.scry(b, \"div.titletip strong\")[0];\n            ((g && DOM.setContent(g, this._getFriendListTooltipText(c))));\n            ((a && a(c)));\n        };\n    ;\n    },\n    _showEmptyListMomentarily: function(b) {\n        this.shownEmptyFlids = ((this.shownEmptyFlids || {\n        }));\n        this.shownEmptyFlids[b] = 1;\n        var a = ge(this._getFriendListId(b));\n        if (a) {\n            CSS.addClass(a, \"show_empty_list\");\n        }\n    ;\n    ;\n        (function() {\n            delete this.shownEmptyFlids[b];\n            var c = ge(this._getFriendListId(b));\n            if (c) {\n                CSS.removeClass(c, \"show_empty_list\");\n            }\n        ;\n        ;\n        }).bind(this).defer(8000, false);\n    },\n    _goOfflineToLists: function(a, c) {\n        c = ((c || false));\n        var b = this._groupAvailableListByFl();\n        this._handleFlVisibilityChange(a, 0);\n        if (!c) {\n            this._saveBuddyListSetting({\n                offline_to_list: 1,\n                flids: a,\n                notify_ids: Chat.getActiveFriendChats()\n            });\n        }\n    ;\n    ;\n    },\n    _removeFlidsFromBuddyList: function(a, b) {\n        this._removeFlidsFromDOM(a);\n    },\n    _onBuddyListSettingSave: function(b, a) {\n        var d = a.getPayload();\n        if (d) {\n            ((d.userInfos && this.updateUserInfos(d.userInfos)));\n            ((d.availableList && AvailableList.addLegacyAvailableList(d.availableList)));\n            if (d.flData) {\n                var c;\n                if (((typeof d.flMode != \"undefined\"))) {\n                    c = d.flMode;\n                }\n                 else c = true;\n            ;\n            ;\n                this._onFlChange(c, d.flData);\n                this._resetFlidClasses();\n            }\n        ;\n        ;\n            ((b && b()));\n        }\n    ;\n    ;\n    },\n    _resetFlidClasses: function() {\n        if (!this.flMode) {\n            return;\n        }\n    ;\n    ;\n        var c = this._groupAvailableListByFl();\n        for (var b in this.flData) {\n            var a = ge(this._getFriendListId(b));\n            if (a) {\n                CSS.setClass(a, this._getFriendListItemClasses(b, c));\n            }\n        ;\n        ;\n        };\n    ;\n    },\n    _getFriendListItemClasses: function(b, e) {\n        var d = this.flData[b].o;\n        var c = this.flData[b].h;\n        var a = [\"friend_list\",];\n        if (d) {\n            a.push(\"JSBNG__online\");\n        }\n         else a.push(\"offline\");\n    ;\n    ;\n        if (((((!c && this.shownEmptyFlids)) && this.shownEmptyFlids[b]))) {\n            a.push(\"show_empty_list\");\n        }\n    ;\n    ;\n        if (((b == this.otherFriendsFlid))) {\n            a.push(\"compact_friend_list\");\n            a.push(\"other_friends_list\");\n        }\n    ;\n    ;\n        if (((this.reorderingLists && ((((b == this.otherFriendsFlid)) || ((b == this.botsFlid))))))) {\n            a.push(\"suppress\");\n        }\n    ;\n    ;\n        return a.join(\" \");\n    },\n    _renderFriendListHeader: function(c) {\n        var b = this.flData[c].n;\n        var e = this.flData[c].o;\n        var a = \"\";\n        var f = ((typeof this.flData[c].s != \"undefined\"));\n        if (((!f && ((c != this.otherFriendsFlid))))) {\n            var a = ((((((((((\"\\u003Ca href=\\\"/friends/ajax/edit_list.php?list_id=\" + c)) + \"\\\" \")) + \"rel=\\\"dialog-post\\\"\\u003E\")) + _tx(\"edit\"))) + \"\\u003C/a\\u003E\"));\n        }\n    ;\n    ;\n        var d = [\"\\u003Cdiv class=\\\"friendlist_name\\\"\\u003E\",((((\"\\u003Cspan class=\\\"title\\\"\\u003E\\u003Ca href=\\\"#\\\" id=\\\"\" + this._getFriendListNameId(c))) + \"\\\"\\u003E\")),htmlize(b),\"\\u003C/a\\u003E\\u003C/span\\u003E\",\"\\u003Cspan class=\\\"edit_link\\\"\\u003E\",a,\"\\u003C/span\\u003E\",\"\\u003C/div\\u003E\",];\n        if (!f) {\n            d.push(\"\\u003Cdiv class=\\\"switch\\\"\\u003E\\u003Ca class=\\\"online_status\\\" \", \"\\u003E\", \"\\u003Cdiv class=\\\"titletip\\\"\\u003E\\u003Cstrong\\u003E\", this._getFriendListTooltipText(c), \"\\u003C/strong\\u003E\\u003C/div\\u003E\", \"\\u003C/a\\u003E\", \"\\u003C/div\\u003E\");\n        }\n    ;\n    ;\n        return d.join(\"\");\n    },\n    _getFriendListTooltipText: function(a) {\n        return ((this.flData[a].o ? _tx(\"Go Offline\") : _tx(\"Go Online\")));\n    },\n    registerExternalFriendList: function(b) {\n        if (!this.rendered) {\n            this._firstRender();\n        }\n    ;\n    ;\n        var a = ((\"xfl_\" + this.externalFlids.length));\n        this.externalFlids.push(a);\n        this.flOpts[a] = b;\n        return a;\n    },\n    _renderFriendListContent: function(a, i) {\n        var l;\n        var d = ((this.flMode && a));\n        if (d) {\n            l = [\"\\u003Cdiv id=\\\"\",this._getFriendListContainerId(a),\"\\\"\",\"class=\\\"friend_list_container\\\"\\u003E\",];\n        }\n         else l = [];\n    ;\n    ;\n        l.push(\"\\u003Cdiv id=\\\"\", this._getAvailableMarkerId(a), \"\\\" class=\\\"suppress\\\"\\u003E\\u003C/div\\u003E\");\n        var g = [];\n        var b = false, c = false;\n        for (var k = 0; ((k < i.length)); k++) {\n            var e = i[k];\n            var f = this._isIdle(e);\n            var j = [this._renderItem(e, a, f),];\n            if (f) {\n                b = true;\n                g = g.concat(j);\n            }\n             else {\n                c = true;\n                l = l.concat(j);\n            }\n        ;\n        ;\n        };\n    ;\n        var h = ((((b && c)) ? \"\" : \" hide_idle_marker\"));\n        l.push(\"\\u003Cdiv id=\\\"\", this._getIdleMarkerId(a), \"\\\" class=\\\"subheader\", h, \"\\\"\\u003E\\u003C/div\\u003E\");\n        l = l.concat(g);\n        if (d) {\n            l.push(\"\\u003C/div\\u003E\");\n        }\n    ;\n    ;\n        return l.join(\"\");\n    },\n    _isIdle: function(a) {\n        return AvailableList.isIdle(a);\n    },\n    _addFriendListListeners: function(c) {\n        if (!this.flMode) {\n            return;\n        }\n    ;\n    ;\n        c = ((c || this._getRenderedFriendLists()));\n        for (var d = 0; ((d < c.length)); d++) {\n            var b = c[d];\n            if (((typeof this.flData[b].s != \"undefined\"))) {\n                continue;\n            }\n        ;\n        ;\n            var a = $(this._getFriendListId(b));\n            JSBNG__Event.listen(a, \"mouseover\", this._friendListHandleMouseOver.bind(this, b));\n            JSBNG__Event.listen(a, \"mouseout\", this._friendListHandleMouseOut.bind(this, b));\n            var e = DOM.JSBNG__find(a, \"a.online_status\");\n            JSBNG__Event.listen(e, \"mousedown\", this._friendListHandleSwitchMouseDown.bind(this, b));\n        };\n    ;\n    },\n    _renderBuddyContent: function() {\n        var a = ((AvailableList.getCount() ? \"hide_empty_item\" : \"\"));\n        var g = [\"\\u003Cdiv class=\\\"subgroup\\\"\\u003E\",\"\\u003Cdiv id=\\\"fbChatBuddyListParent\\\" class=\\\"list_select\\\"\\u003E\",\"\\u003Cdiv id=\\\"\",this._getBuddyListEmptyItemId(),\"\\\" class=\\\"info_text \",a,\"\\\"\\u003E\",_tx(\"No one is available to chat.\"),\"\\u003C/div\\u003E\",];\n        var c;\n        var d = {\n        };\n        if (this.flMode) {\n            c = keys(this.flData);\n            d = this._groupAvailableListByFl(true);\n        }\n         else c = [null,];\n    ;\n    ;\n        for (var e = 0; ((e < c.length)); ++e) {\n            var b = c[e];\n            var f = [];\n            if (((this.flMode && b))) {\n                if (this.flData[b].h) {\n                    continue;\n                }\n            ;\n            ;\n                g.push(\"\\u003Cdiv id=\\\"\", this._getFriendListId(b), \"\\\"\", \"class=\\\"\", this._getFriendListItemClasses(b, d), \"\\\"\\u003E\", this._renderFriendListHeader(b));\n                f = d[b];\n            }\n             else f = this._getSortedList();\n        ;\n        ;\n            g.push(this._renderFriendListContent(b, f));\n            if (((this.flMode && b))) {\n                g.push(\"\\u003C/div\\u003E\");\n            }\n        ;\n        ;\n        };\n    ;\n        g.concat([\"\\u003C/div\\u003E\",\"\\u003C/div\\u003E\",]);\n        return g.join(\"\");\n    },\n    _render: function() {\n        if (((!this._isVisible || ((this._lastRenderRev == AvailableList.getRev()))))) {\n            return;\n        }\n    ;\n    ;\n        this._lastRenderRev = AvailableList.getRev();\n        this._getSortedList();\n        CSS.conditionClass(this.contentDiv, \"compact\", this.isCompactDisplay);\n        DOM.setContent(this.contentDiv, HTML(this._renderBuddyContent()));\n        if (this.rendered) {\n            this._hideError();\n            this._addFriendListListeners();\n        }\n    ;\n    ;\n        if (this.errorMode) {\n            this._showLoadError();\n        }\n    ;\n    ;\n        if (this.shouldShowLoading) {\n            this._showLoading();\n            this.shouldShowLoading = false;\n        }\n         else if (this._showTime) {\n            var a = ((new JSBNG__Date() - this._showTime));\n            this._showTime = null;\n            this._log({\n                buddy_list_open: a\n            });\n        }\n        \n    ;\n    ;\n    },\n    _firstRender: function() {\n        this._render();\n        this.rendered = true;\n        JSBNG__Event.listen(this.contentDiv, \"click\", function(JSBNG__event) {\n            var a = Parent.byClass(JSBNG__event.getTarget(), \"friend\");\n            ((a && this.itemOnClick(a)));\n        }.bind(this));\n    },\n    updateItemDisplay: function(d) {\n        var a = AvailableList.get(d);\n        if (!a) {\n            return;\n        }\n    ;\n    ;\n        var g = this._getUserFlids(d);\n        for (var c = 0; ((c < g.length)); c++) {\n            var b = g[c];\n            var f = ge(this._getBuddyListItemId(d, b));\n            if (!f) {\n                return;\n            }\n        ;\n        ;\n            var e = ((a == AvailableList.IDLE));\n            f = HTML(this._renderItem(d, b, e)).getRootNode();\n        };\n    ;\n    },\n    _showLoadError: function() {\n        this._showError(_tx(\"Could not load available friends.\"));\n    },\n    _showLoading: function() {\n        this._showError(_tx(\"Loading...\"));\n    },\n    _hideError: function() {\n        this.showingError = false;\n        CSS.removeClass(this.root, \"error\");\n        this.contentChanged();\n    },\n    _showError: function(a) {\n        this._dirtyRendering();\n        this.showingError = true;\n        DOM.setContent(this.buddyListError, HTML(a));\n        CSS.addClass(this.root, \"error\");\n        this.contentChanged();\n    },\n    isSticky: function() {\n        return chatOptions.getSetting(\"sticky_buddylist\");\n    },\n    enterErrorMode: function(a) {\n        this.exitErrorMode();\n        this.exitReorderingFlMode();\n        this.showingErrorMessage = true;\n        var b = $N(\"div\", {\n            id: \"error_fl_alert\"\n        }, [$N(\"span\", {\n            className: \"helper_text\"\n        }, a),$N(\"input\", {\n            type: \"button\",\n            className: \"inputbutton\",\n            value: _tx(\"Okay\"),\n            JSBNG__onclick: this.exitErrorMode.bind(this)\n        }),]);\n        DOM.insertBefore(b, this.contentDiv);\n    },\n    exitErrorMode: function() {\n        if (this.showingErrorMessage) {\n            DOM.remove($(\"error_fl_alert\"));\n            this.showingErrorMessage = false;\n        }\n    ;\n    ;\n        return false;\n    },\n    enterReorderingFlMode: function() {\n        if (this.reorderingLists) {\n            return;\n        }\n    ;\n    ;\n        Bootloader.loadComponents(\"sort\", function() {\n            this.exitErrorMode();\n            this.reorderingLists = true;\n            CSS.addClass(this.root, \"reorder_fl\");\n            var a = this._getRenderedFriendLists();\n            this.flSortableGroup = new SortableGroup();\n            for (var c = 0; ((c < a.length)); c++) {\n                var b = a[c];\n                if (((((b == this.otherFriendsFlid)) || ((b == this.botsFlid))))) {\n                    CSS.addClass(this._getFriendListId(b), \"suppress\");\n                }\n                 else this._addFlSortable(b);\n            ;\n            ;\n            };\n        ;\n            var d = $N(\"div\", {\n                id: \"reorder_fl_alert\"\n            }, [$N(\"span\", {\n                className: \"helper_text\"\n            }, _tx(\"Drag lists to re-order.\")),$N(\"input\", {\n                type: \"button\",\n                className: \"inputbutton\",\n                value: _tx(\"Done Re-Ordering\"),\n                JSBNG__onclick: this.exitReorderingFlMode.bind(this)\n            }),]);\n            DOM.insertBefore(d, this.contentDiv);\n            this.inform(\"reorder-mode/enter\");\n            this.contentChanged();\n        }.bind(this));\n    },\n    exitReorderingFlMode: function() {\n        if (!this.reorderingLists) {\n            return;\n        }\n    ;\n    ;\n        this._reorderFlids();\n        DOM.remove($(\"reorder_fl_alert\"));\n        CSS.removeClass(this.root, \"reorder_fl\");\n        var a = this._getRenderedFriendLists();\n        for (var c = 0; ((c < a.length)); c++) {\n            var b = a[c];\n            if (((((b == this.otherFriendsFlid)) || ((b == this.botsFlid))))) {\n                CSS.removeClass(this._getFriendListId(b), \"suppress\");\n            }\n             else this._removeFlSortable(b);\n        ;\n        ;\n        };\n    ;\n        this.reorderingLists = false;\n        this.flSortableGroup.destroy();\n        this.flSortableGroup = null;\n        this.inform(\"reorder-mode/exit\");\n        this.contentChanged();\n    },\n    _addFlSortable: function(a) {\n        if (((this.flSortableGroup != null))) {\n            this.flSortableGroup.addSortable(a, $(this._getFriendListId(a)));\n        }\n    ;\n    ;\n    },\n    _removeFlSortable: function(a) {\n        if (((this.flSortableGroup != null))) {\n            this.flSortableGroup.removeSortable(a);\n        }\n    ;\n    ;\n    },\n    _reorderFlids: function() {\n        var a = {\n            reorder: 1,\n            flids: this.flSortableGroup.getOrder()\n        };\n        this._saveBuddyListSetting(a);\n    },\n    _getGlobalFlids: function(a) {\n        var b = ((((this.flMode && this.flData)) ? keys(this.flData) : [null,]));\n        return ((a ? b : b.concat(this.externalFlids)));\n    },\n    _getUserFlids: function(d, a, b) {\n        var c = ((((a && a.fl)) ? a.fl : FriendLists.get(d)));\n        if (!b) {\n            c = this._addExternalFlids(d, c);\n        }\n    ;\n    ;\n        return c;\n    },\n    _addExternalFlids: function(d, b) {\n        b = ((b ? $A(b) : []));\n        for (var c = 0; ((c < this.externalFlids.length)); c++) {\n            var a = this.externalFlids[c];\n            var e = this._getFlOpts(a);\n            if (!e.excludeIds[d]) {\n                b.push(a);\n            }\n        ;\n        ;\n        };\n    ;\n        return b;\n    },\n    _getFlOpts: function(a) {\n        return ((this.flOpts[a] || ChatBuddyList.DEFAULT_OPTS));\n    },\n    _getAvailableMarkerId: function(a) {\n        return this._encodeFlid(\"buddy_list_avail_marker\", a);\n    },\n    _getIdleMarkerId: function(a) {\n        return this._encodeFlid(\"buddy_list_idle_marker\", a);\n    },\n    _getBuddyListItemId: function(b, a) {\n        return this._encodeFlid(((\"buddy_list_item_\" + b)), a);\n    },\n    _getBuddyListItemNameId: function(b, a) {\n        return this._encodeFlid(((\"buddy_list_item_name_\" + b)), a);\n    },\n    _getBuddyListEmptyItemId: function() {\n        return \"buddy_list_empty_item\";\n    },\n    _encodeFlid: function(a, b) {\n        return ((((((b ? ((((b + \"_\")) + a)) : a)) + \"_\")) + this.buddyListID));\n    },\n    _getFriendListId: function(a) {\n        return this._encodeFlid(\"friend_list_item\", a);\n    },\n    _getFriendListNameId: function(a) {\n        return this._encodeFlid(\"friend_list_name\", a);\n    },\n    _getFriendListContainerId: function(a) {\n        return this._encodeFlid(\"friend_list_container\", a);\n    },\n    _updateSetting: function(a, b) {\n        this._dirtyRendering();\n        switch (b.JSBNG__name) {\n          case \"compact_buddylist\":\n            this.setCompactDisplay(b.value);\n            break;\n        };\n    ;\n        this._render();\n    },\n    _dirtyRendering: function() {\n        this._lastRenderRev = null;\n    },\n    _handleFlChange: function(a, c) {\n        var d = c.flMode;\n        var b = c.flData;\n        if (this._flChanged(d, b)) {\n            this._onFlChange(d, b);\n        }\n    ;\n    ;\n    },\n    scrollIntoView: function(a) {\n        var b = a.offsetParent;\n        var d = JSBNG__Rect(a);\n        var c = d.boundWithin(JSBNG__Rect(b)).getPositionVector();\n        d.getPositionVector().sub(c).scrollElementBy(b);\n    }\n});\nfunction ChatOrderedList(a) {\n    this._root = a;\n    this._items = {\n    };\n    this._isVisible = false;\n    this._numTopFriends = 5;\n};\n;\nClass.mixin(ChatOrderedList, \"Arbiter\", {\n    init: function(a) {\n        this._template = a;\n        JSBNG__Event.listen(this._root, \"click\", this._onClick.bind(this));\n        OrderedFriendsList.subscribe(\"initialized\", this.update.shield(this));\n        Arbiter.subscribe([\"available-list/initialized\",\"buddylist/availability-changed\",], this.update.shield(this));\n        if (ChatConfig.get(\"blackbird\")) {\n            PresencePrivacy.subscribe(\"privacy-changed\", this.update.shield(this));\n        }\n    ;\n    ;\n        this.inform(\"initialized\", this, Arbiter.BEHAVIOR_PERSISTENT);\n        this._inited = true;\n        this.render();\n    },\n    _getAvailableList: function() {\n        return AvailableList.getAvailableIDs().filter(function(a) {\n            return ((AvailableList.get(a) === AvailableList.ACTIVE));\n        });\n    },\n    _getListItem: function(c) {\n        var d = this._items[c];\n        if (d) {\n            var b = AvailableList.get(c);\n            var a = ((!ChatConfig.get(\"blackbird\") || PresencePrivacy.allows(c)));\n            CSS.conditionClass(d, \"active\", ((b === AvailableList.ACTIVE)));\n            CSS.conditionClass(d, \"idle\", ((b === AvailableList.IDLE)));\n            CSS.conditionClass(d, \"mobile\", ((((b === AvailableList.MOBILE)) && a)));\n            CSS.conditionClass(d, \"invis\", !a);\n        }\n    ;\n    ;\n        return d;\n    },\n    getRoot: function() {\n        return this._root;\n    },\n    getSortedList: function(d) {\n        var l = OrderedFriendsList.getList();\n        if (ChatConfig.get(\"blackbird\")) {\n            l = l.filter(function(r) {\n                return ((PresencePrivacy.get(r) !== PresencePrivacy.BLACKLISTED));\n            });\n        }\n    ;\n    ;\n        var p = ChatConfig.get(\"titan\");\n        if (!p) {\n            l = l.filter(function(r) {\n                return ((AvailableList.get(r) === AvailableList.ACTIVE));\n            });\n        }\n    ;\n    ;\n        var h = [];\n        if (((ChatConfig.get(\"blackbird\") && ((PresencePrivacy.getDefaultPresence() !== PresencePrivacy.ONLINE))))) {\n            var o = l, a = {\n            };\n            var e, f;\n            l = [];\n            for (e = 0; ((e < o.length)); ++e) {\n                f = o[e];\n                if (PresencePrivacy.allows(f)) {\n                    a.id = true;\n                    l.push(f);\n                }\n            ;\n            ;\n            };\n        ;\n            var q = PresencePrivacy.getWhitelist();\n            for (e = 0; ((e < q.length)); ++e) {\n                f = q[e];\n                if (!((f in a))) {\n                    l.push(f);\n                }\n            ;\n            ;\n            };\n        ;\n            for (e = 0; ((e < o.length)); ++e) {\n                f = o[e];\n                if (!PresencePrivacy.allows(f)) {\n                    l.push(f);\n                }\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        if (((Chat.isOnline() && p))) {\n            var k = ChatConfig.get(\"ordered_list.top_friends\", 0);\n            var c = ChatConfig.get(\"ordered_list.available_target\", 0);\n            var n = Math.floor(((this._numTopFriends * c)));\n            var m = [];\n            for (var e = 0, g = l.length; ((((e < g)) && ((n > 0)))); e++) {\n                var f = l[e];\n                var b = ((AvailableList.get(f) === AvailableList.ACTIVE));\n                if (((b || ((e < k))))) {\n                    h.push(f);\n                    ((b && n--));\n                }\n                 else m.push(f);\n            ;\n            ;\n            };\n        ;\n            if (((e < g))) {\n                Array.prototype.push.apply(m, l.slice(e));\n            }\n        ;\n        ;\n            if (((h.length < this._numTopFriends))) {\n                Array.prototype.push.apply(h, m);\n            }\n        ;\n        ;\n        }\n         else Array.prototype.push.apply(h, l);\n    ;\n    ;\n        h = h.slice(0, this._numTopFriends);\n        if (((ChatConfig.get(\"sidebar_online_friends\") && ((h.length === this._numTopFriends))))) {\n            var i = Object.from(h);\n            var j = this._getAvailableList().filter(function(r) {\n                return !((r in i));\n            }).length;\n            ((j && h.splice(-1)));\n        }\n    ;\n    ;\n        h.sort(this._sort.bind(this));\n        return h;\n    },\n    hide: function() {\n        if (!this._isVisible) {\n            return;\n        }\n    ;\n    ;\n        this._isVisible = false;\n        CSS.hide(this._root);\n        this.inform(\"hide\");\n    },\n    _onClick: function(JSBNG__event) {\n        var e = JSBNG__event.getTarget();\n        var b = Parent.byTag(e, \"li\");\n        if (b) {\n            var a = DataStore.get(b, \"id\");\n            if (a) {\n                var d = \"ordered_list\";\n                var c = b;\n                while (b.previousSibling) {\n                    b = b.previousSibling;\n                    if (CSS.hasClass(b, \"separator\")) {\n                        d = \"more_online_friends\";\n                        break;\n                    }\n                ;\n                ;\n                };\n            ;\n                ChatUserInfoManager.get(a, function(f) {\n                    Chat.openTab(a, f.JSBNG__name, \"friend\", d);\n                });\n                Chat.goOnline();\n            }\n             else if (((CSS.hasClass(b, \"separator\") && Parent.byClass(e, \"inner\")))) {\n                this.JSBNG__scrollTo(b);\n            }\n            \n        ;\n        ;\n            return false;\n        }\n    ;\n    ;\n    },\n    setNumTopFriends: function(a) {\n        if (((a !== this._numTopFriends))) {\n            this._numTopFriends = a;\n            this.render();\n        }\n    ;\n    ;\n    },\n    _sort: function(a, d) {\n        if (ChatConfig.get(\"blackbird\")) {\n            var b = this._sortByAllowed(a, d);\n            if (((b !== 0))) {\n                return b;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n        var c = this._sortAlphabetical(a, d);\n        if (((c !== 0))) {\n            return c;\n        }\n    ;\n    ;\n        return OrderedFriendsList.compare(a, d);\n    },\n    _sortByAllowed: function(a, d) {\n        var b = PresencePrivacy.allows(a);\n        var c = PresencePrivacy.allows(d);\n        if (((b !== c))) {\n            return ((b ? -1 : 1));\n        }\n    ;\n    ;\n        return 0;\n    },\n    _sortAlphabetical: function(a, b) {\n        var c = ((((ChatUserInfos[a] || {\n        })).JSBNG__name || \"~\")).toLowerCase();\n        var d = ((((ChatUserInfos[b] || {\n        })).JSBNG__name || \"~\")).toLowerCase();\n        if (((c !== d))) {\n            return ((((c < d)) ? -1 : 1));\n        }\n    ;\n    ;\n        return 0;\n    },\n    _sortMobile: function(a, c) {\n        var b = ((AvailableList.get(a) === AvailableList.MOBILE));\n        var d = ((AvailableList.get(c) === AvailableList.MOBILE));\n        if (((b ^ d))) {\n            return ((d ? -1 : 1));\n        }\n    ;\n    ;\n        return this._sortAlphabetical(a, c);\n    },\n    render: function() {\n        if (((((!this._inited || !this._isVisible)) || !OrderedFriendsList.isReady()))) {\n            return;\n        }\n    ;\n    ;\n        JSBNG__clearTimeout(this._renderTimeout);\n        var i = function(l) {\n            JSBNG__clearTimeout(this._renderTimeout);\n            this._renderTimeout = this.render.bind(this).defer();\n        }.bind(this);\n        var j = this.getSortedList();\n        var e = [];\n        var c;\n        var d;\n        for (var b = 0, g = j.length; ((b < g)); b++) {\n            c = j[b];\n            d = this._getListItem(c);\n            if (d) {\n                e.push(d);\n            }\n             else this._renderListItem(c, i);\n        ;\n        ;\n        };\n    ;\n        if (ChatConfig.get(\"sidebar_online_friends\")) {\n            var a = this._getAvailableList();\n            var k = Object.from(j);\n            a = a.filter(function(l) {\n                return !((l in k));\n            });\n            a.sort(this._sortMobile.bind(this));\n            if (((a.length && e.length))) {\n                e.push(HTML(((((((((((((((((((\"\\u003Cli class=\\\"separator\\\"\\u003E\" + \"\\u003Cdiv class=\\\"outer\\\"\\u003E\")) + \"\\u003Cdiv class=\\\"inner\\\"\\u003E\")) + \"\\u003Cspan class=\\\"text\\\"\\u003E\")) + _tx(\"{MORE ONLINE FRIENDS} ({=count})\", {\n                    \"MORE ONLINE FRIENDS\": _tx(\"MORE ONLINE FRIENDS\"),\n                    \"=count\": a.length\n                }))) + \"\\u003C/span\\u003E\")) + \"\\u003Cdiv class=\\\"dive\\\"\\u003E\\u003Cspan class=\\\"bar\\\"\\u003E\\u003C/span\\u003E\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/div\\u003E\")) + \"\\u003C/li\\u003E\"))));\n            }\n        ;\n        ;\n            for (var f = 0, h = a.length; ((f < h)); f++) {\n                c = a[f];\n                d = this._getListItem(c);\n                if (d) {\n                    e.push(d);\n                }\n                 else this._renderListItem(c, i);\n            ;\n            ;\n            };\n        ;\n        }\n    ;\n    ;\n        if (e.length) {\n            DOM.setContent(this._root, e);\n        }\n    ;\n    ;\n        this.inform(\"render\");\n    },\n    _renderListItem: function(b, a) {\n        ChatUserInfoManager.get(b, function(f) {\n            var c = this._template.render();\n            ChatQuietLinks.silence(c);\n            var e = XHPTemplate.getNode(c, \"profile-photo\");\n            e.setAttribute(\"src\", f.thumbSrc);\n            var d = XHPTemplate.getNode(c, \"JSBNG__name\");\n            DOM.setContent(d, f.JSBNG__name);\n            DataStore.set(c, \"id\", b);\n            this._items[b] = c;\n            ((a && a(c)));\n        }.bind(this));\n    },\n    show: function() {\n        if (this._isVisible) {\n            return;\n        }\n    ;\n    ;\n        this._isVisible = true;\n        CSS.show(this._root);\n        this.render();\n        this.inform(\"show\");\n    },\n    update: function() {\n        this.render();\n    },\n    setScrollContainer: function(a) {\n        if (DOM.contains(a, this._root)) {\n            this._scrollContainer = a;\n        }\n    ;\n    ;\n    },\n    JSBNG__scrollTo: function(c) {\n        if (!this._scrollContainer) {\n            return;\n        }\n    ;\n    ;\n        var e = this._scrollContainer.scrollHeight;\n        var a = this._scrollContainer.clientHeight;\n        var d = this._scrollContainer.scrollTop;\n        var f = Math.min(c.offsetTop, ((e - a)));\n        if (((d !== f))) {\n            var b = ((((Math.abs(((f - d))) / this._scrollContainer.clientHeight)) * 500));\n            animation(this._scrollContainer).to(\"scrollTop\", f).ease(animation.ease.end).duration(b).go();\n        }\n    ;\n    ;\n    }\n});\nfunction ChatOptions(b, a) {\n    this._jslog = JSLogger.create(\"chat_options\");\n    this._jslog.log(\"server\", {\n        vis: b\n    });\n    this.visibility = !!b;\n    this.settings = a;\n};\n;\nChatOptions.prototype = {\n    load: function() {\n        presence.registerStateStorer(this._storeState.bind(this));\n        presence.registerStateLoader(this._loadState.bind(this));\n        Arbiter.subscribe(channel.ON_CONFIG, function(b, a) {\n            var c = a.getConfig(\"visibility\");\n            this._jslog.log(\"vis_chan_config\", {\n                new_vis: c\n            });\n            this.setVisibility(c);\n        }.bind(this));\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"visibility\"), function(a, b) {\n            var c = b.obj;\n            if (((c.window_id === presence.getWindowID()))) {\n                return;\n            }\n        ;\n        ;\n            this._jslog.log(\"vis_chan_message\", {\n                new_vis: c.visibility,\n                window_id: c.window_id\n            });\n            this.setVisibility(c.visibility);\n        }.bind(this));\n        Arbiter.subscribe(PresenceMessage.getArbiterMessageType(\"setting\"), function(a, b) {\n            var c = b.obj;\n            if (((c.window_id === presence.getWindowID()))) {\n                return;\n            }\n        ;\n        ;\n            this.setSetting(c.setting, !!c.value);\n        }.bind(this));\n        Arbiter.inform(\"chat-options/initialized\", this, Arbiter.BEHAVIOR_PERSISTENT);\n    },\n    _storeState: function(a) {\n        a.vis = ((this.visibility ? 1 : 0));\n        a.bls = this.getSetting(\"sticky_buddylist\");\n        a.blc = this.getSetting(\"compact_buddylist\");\n        a.snd = this.getSetting(\"sound\");\n        return a;\n    },\n    _loadState: function(a) {\n        if (((a.vis != this.visibility))) {\n            this._jslog.log(\"vis_load\", {\n                new_vis: a.vis\n            });\n            this.setVisibility(!!a.vis);\n        }\n    ;\n    ;\n        this.setSetting(\"sticky_buddylist\", a.bls);\n        this.setSetting(\"compact_buddylist\", a.blc);\n        this.setSetting(\"sound\", a.snd);\n    },\n    setVisibility: function(a) {\n        if (((a === this.visibility))) {\n            return;\n        }\n    ;\n    ;\n        this.visibility = a;\n        Arbiter.inform(\"chat/visibility-changed\", {\n            sender: this\n        });\n        presence.doSync();\n    },\n    _onVisibilityResponse: function(a) {\n        this._jslog.log(\"vis_send_success\", {\n            new_vis: a\n        });\n        if (a) {\n            this.setVisibility(a);\n        }\n    ;\n    ;\n        if (presence.poppedOut) {\n            presence.popout();\n        }\n    ;\n    ;\n    },\n    _onVisibilityError: function(b) {\n        this._jslog.log(\"vis_send_error\", {\n            old_vis: b\n        });\n        this.setVisibility(b);\n        var a = _tx(\"Chat\");\n        Chat.enterErrorMode(_tx(\"Unable to save your {Chat} settings\", {\n            Chat: a\n        }));\n    },\n    toggleVisibility: function() {\n        this.sendVisibility(!this.visibility);\n    },\n    sendVisibility: function(b) {\n        this._jslog.log(\"vis_send\", {\n            old_vis: this.visibility,\n            new_vis: b\n        });\n        if (((this.visibility == b))) {\n            return;\n        }\n    ;\n    ;\n        var a = {\n            visibility: b,\n            notify_ids: Chat.getActiveFriendChats(),\n            window_id: presence.getWindowID()\n        };\n        if (!b) {\n            this.setVisibility(b);\n        }\n    ;\n    ;\n        new AsyncRequest(chatDisplay.visibilityURL).setHandler(this._onVisibilityResponse.shield(this, b)).setErrorHandler(this._onVisibilityError.shield(this, !b)).setData(a).setAllowCrossPageTransition(true).send();\n        Arbiter.inform(((b ? \"chat/connect\" : \"chat/disconnect\")));\n    },\n    getSetting: function(a) {\n        return this.settings[a];\n    },\n    setSetting: function(a, b) {\n        if (((this.getSetting(a) == b))) {\n            return;\n        }\n    ;\n    ;\n        this.settings[a] = b;\n        Arbiter.inform(\"chat/option-changed\", {\n            JSBNG__name: a,\n            value: b\n        });\n    }\n};\nfunction ChatSidebarDropdown() {\n\n};\n;\nChatSidebarDropdown.prototype = {\n    init: function(a) {\n        this._root = a;\n        Selector.listen(a, \"select\", this._onSelect.bind(this));\n        Selector.listen(a, \"toggle\", this._onToggle.bind(this));\n        Arbiter.subscribe(\"chat/option-changed\", this._onOptionChanged.bind(this));\n        if (ChatConfig.get(\"blackbird\")) {\n            PresencePrivacy.subscribe([\"privacy-default-presence-changed\",], this._onPresencePrivacyChanged.shield(this));\n        }\n         else Arbiter.subscribe([\"chat-options/initialized\",\"chat/visibility-changed\",], this._onVisibilityChanged.shield(this));\n    ;\n    ;\n    },\n    changeSetting: function(b, c) {\n        if (this._pendingChange) {\n            return false;\n        }\n    ;\n    ;\n        this._pendingChange = true;\n        var a = {\n        };\n        a[b] = c;\n        chatOptions.setSetting(b, c);\n        new AsyncRequest(chatDisplay.settingsURL).setHandler(this._onChangeSettingResponse.bind(this, b, c)).setErrorHandler(this._onChangeSettingError.bind(this, b, c)).setFinallyHandler(this._onChangeFinally.bind(this)).setData(a).setAllowCrossPageTransition(true).send();\n    },\n    _conditionEnabled: function(c, a) {\n        var b = Selector.getOption(this._root, c);\n        ((b && Selector.setOptionEnabled(b, a)));\n    },\n    _onChangeSettingResponse: function(a, c, b) {\n        presence.doSync();\n    },\n    _onChangeSettingError: function(a, c, b) {\n        chatOptions.setSetting(a, !c);\n    },\n    _onChangeFinally: function() {\n        this._pendingChange = false;\n    },\n    _onOptionChanged: function(a, b) {\n        var c = b.JSBNG__name;\n        var e = b.value;\n        if (((c === \"sound\"))) {\n            var d = Selector.getOption(this._root, c);\n            if (((e !== Selector.isOptionSelected(d)))) {\n                Selector.setSelected(this._root, c, e);\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _onSelect: function(b) {\n        if (this._pendingChange) {\n            return false;\n        }\n    ;\n    ;\n        var a = Selector.getOptionValue(b.option);\n        switch (a) {\n          case \"popout\":\n            return this.popout();\n          case \"sidebar\":\n            return this.toggleSidebar();\n        };\n    ;\n    },\n    _onToggle: function(a) {\n        if (this._pendingChange) {\n            return false;\n        }\n    ;\n    ;\n        var b = Selector.getOptionValue(a.option);\n        var c = Selector.isOptionSelected(a.option);\n        switch (b) {\n          case \"visibility\":\n            chatOptions.toggleVisibility();\n            break;\n          case \"sound\":\n            this.changeSetting(b, c);\n            break;\n        };\n    ;\n        Selector.toggle(this._root);\n    },\n    _onVisibilityChanged: function() {\n        var a = Chat.isOnline();\n        var b = Selector.getOption(this._root, \"visibility\");\n        if (((a !== Selector.isOptionSelected(b)))) {\n            Selector.setSelected(this._root, \"visibility\", a);\n        }\n    ;\n    ;\n    },\n    _onPresencePrivacyChanged: function() {\n        CSS.conditionClass(this._root, \"defaultPresenceOnline\", ((PresencePrivacy.getDefaultPresence() === PresencePrivacy.ONLINE)));\n    },\n    _setRanking: function(a) {\n        data = {\n            sidebar_ranking: a\n        };\n        new AsyncRequest(chatDisplay.settingsURL).setData(data).send();\n    },\n    popout: function() {\n        presence.popout();\n        Selector.toggle(this._root);\n        return false;\n    },\n    toggleSidebar: function() {\n        Chat.toggleSidebar();\n        Selector.toggle(this._root);\n        return false;\n    }\n};\nfunction ChatTabSlider() {\n    this.handleWidth = 160;\n    this.focusedHandleAdditionalWidth = 100;\n    this.animationTime = 210;\n    this._init();\n};\n;\nChatTabSlider.prototype = {\n    _init: function() {\n        this.org_s = 0;\n        this.numToShow = 0;\n        this.numShift = 1;\n        this.shiftByNumTabs = false;\n        this.timer = null;\n        this.skipAnimation = false;\n        this.chatWidth = null;\n        var a = $(\"fbDockChatTabSlider\");\n        this.chat = ge(\"fbDockChatTabsWrapper\");\n        this.chatTabBar = ge(\"fbDockChatTabs\");\n        this.nextTab = DOM.JSBNG__find(a, \"div.next\");\n        JSBNG__Event.listen(this.nextTab, \"click\", this.next.bind(this));\n        this.prevTab = DOM.JSBNG__find(a, \"div.previous\");\n        JSBNG__Event.listen(this.prevTab, \"click\", this.prev.bind(this));\n        this.nextCounter = DOM.JSBNG__find(this.nextTab, \"span.numTabs\");\n        this.prevCounter = DOM.JSBNG__find(this.prevTab, \"span.numTabs\");\n        this.numMissedNextCounter = DOM.JSBNG__find(this.nextTab, \"span.numMessages\");\n        this.numMissedPrevCounter = DOM.JSBNG__find(this.prevTab, \"span.numMessages\");\n        Toggler.createInstance(this.chatTabBar);\n        this.numNext = 0;\n        this.numPrev = 0;\n        this.prevTabs = {\n        };\n        this.nextTabs = {\n        };\n        presence.registerStateLoader(this._load.bind(this));\n        presence.registerStateStorer(this._store.bind(this));\n        JSBNG__Event.listen(window, \"resize\", this._resize.bind(this));\n    },\n    load: function() {\n        this._load(presence.state);\n        this._resize();\n        Arbiter.inform(\"chat-tab-slider/loaded\", this, Arbiter.BEHAVIOR_PERSISTENT);\n    },\n    _load: function(a) {\n        var b = 0;\n        if (a) {\n            b = ((a.s ? a.s : b));\n        }\n    ;\n    ;\n        this._setPos(b);\n    },\n    _store: function(a) {\n        a.s = this._s;\n        return a;\n    },\n    _calculate: function() {\n        this._setMaxWidth();\n        if (presence.poppedOut) {\n            this.numToShow = chatDisplay.numTabs;\n        }\n         else {\n            this.numToShow = parseInt(((((this.maxWidth - this.focusedHandleAdditionalWidth)) / this.handleWidth)), 10);\n            this.numToShow = ((((this.numToShow > 0)) ? this.numToShow : 1));\n        }\n    ;\n    ;\n        if (this.shiftByNumTabs) {\n            this.numShift = this.numToShow;\n        }\n    ;\n    ;\n        if (((this._s != null))) {\n            this._setPos(this._s);\n        }\n    ;\n    ;\n    },\n    _setMaxWidth: function() {\n        var b = JSBNG__document.body.clientWidth;\n        var a = Parent.byClass(this.chat, \"fbDock\").firstChild;\n        for (; a; a = a.nextSibling) {\n            b -= a.clientWidth;\n        ;\n        };\n    ;\n        if (((window.ChatSidebar && ChatSidebar.isVisible()))) {\n            b -= ChatSidebar.getRoot().clientWidth;\n        }\n    ;\n    ;\n        b += this.chat.clientWidth;\n        this.maxWidth = ((b - 100));\n    },\n    _setPos: function(a) {\n        if (((a < 0))) {\n            a = 0;\n        }\n    ;\n    ;\n        this._s = a;\n        this._e = Math.min(((this._s + this.numToShow)), chatDisplay.numTabs);\n        this._s = Math.max(((this._e - this.numToShow)), 0);\n    },\n    _doSync: function() {\n        var a = ((this.org_s != this._s));\n        this.org_s = 0;\n        if (a) {\n            presence.doSync();\n        }\n    ;\n    ;\n    },\n    _build: function() {\n        if (presence.poppedOut) {\n            return;\n        }\n    ;\n    ;\n        var a = ((((this.numToShow >= chatDisplay.numTabs)) ? true : false));\n        this.setVisibleTabs(a);\n        if (a) {\n            this.resetCounters();\n        }\n         else this.updateCounters();\n    ;\n    ;\n        this.updateMissedCount();\n    },\n    _resize: function() {\n        this.org_s = this._s;\n        this._calculate();\n        this._build();\n        this._doSync();\n        if (((chatDisplay.lastFocused != null))) {\n            this.gotoTab(chatDisplay.lastFocused);\n        }\n    ;\n    ;\n    },\n    addTab: function(a) {\n        this._build();\n    },\n    gotoTab: function(a) {\n        if (!((a in chatDisplay.tabs))) {\n            return;\n        }\n    ;\n    ;\n        var b = chatDisplay.tabList.indexOf(chatDisplay.tabs[a]);\n        if (!this._inRange(b)) {\n            var c = ((((b - this.numToShow)) + 1));\n            this._setPos(c);\n            this._build();\n        }\n    ;\n    ;\n    },\n    close: function() {\n        this._setPos(((((((((this.numPrev > 0)) || ((this.numNext > 0)))) && ((this._s > 0)))) ? ((this._s - 1)) : 0)));\n        this._calculate();\n        this._build();\n    },\n    setVisibleTabs: function(a) {\n        var d = chatDisplay.tabList;\n        for (var b = 0, c = d.length; ((b < c)); ++b) {\n            if (((this._inRange(b, d[b].id) || a))) {\n                d[b].show();\n            }\n             else d[b].hide();\n        ;\n        ;\n        };\n    ;\n    },\n    _inRange: function(c, b) {\n        var d, a = false;\n        if (((c >= this._s))) {\n            d = true;\n            delete this.prevTabs[b];\n        }\n         else this.prevTabs[b] = b;\n    ;\n    ;\n        if (((c < this._e))) {\n            a = true;\n            delete this.nextTabs[b];\n        }\n         else this.nextTabs[b] = b;\n    ;\n    ;\n        return ((d && a));\n    },\n    updateMissedCount: function() {\n        var c = 0;\n        var b = 0;\n        for (var a in this.prevTabs) {\n            c += ((chatDisplay.tabs[a] ? chatDisplay.tabs[a].numMissed : 0));\n        ;\n        };\n    ;\n        this.numMissedPrevCounter.innerHTML = c;\n        CSS.conditionClass(this.numMissedPrevCounter, \"hidden_elem\", !c);\n        for (var a in this.nextTabs) {\n            b += ((chatDisplay.tabs[a] ? chatDisplay.tabs[a].numMissed : 0));\n        ;\n        };\n    ;\n        this.numMissedNextCounter.innerHTML = b;\n        CSS.conditionClass(this.numMissedNextCounter, \"hidden_elem\", !b);\n    },\n    updateCounters: function() {\n        this.numNext = ((chatDisplay.numTabs - this._e));\n        this.numPrev = this._s;\n        if (((this.numNext <= 0))) {\n            this.numNext = 0;\n            CSS.addClass(this.nextTab, \"disabled\");\n        }\n         else CSS.removeClass(this.nextTab, \"disabled\");\n    ;\n    ;\n        if (((this.numPrev <= 0))) {\n            this.numPrev = 0;\n            CSS.addClass(this.prevTab, \"disabled\");\n        }\n         else CSS.removeClass(this.prevTab, \"disabled\");\n    ;\n    ;\n        if (((((this.numPrev > 0)) || ((this.numNext > 0))))) {\n            CSS.show(this.nextTab);\n            CSS.show(this.prevTab);\n        }\n         else {\n            CSS.hide(this.nextTab);\n            CSS.hide(this.prevTab);\n        }\n    ;\n    ;\n        this.nextCounter.innerHTML = this.numNext;\n        this.prevCounter.innerHTML = this.numPrev;\n    },\n    resetCounters: function() {\n        this._setPos(0);\n        this.updateCounters();\n    },\n    shift: function(a) {\n        this.org_s = this._s;\n        chatDisplay.unfocusNoSync();\n        this._shift.bind(this, a).defer();\n    },\n    _shift: function(a) {\n        this._setPos(((((this._s < 0)) ? 0 : ((this._s + a)))));\n        this._slide(a);\n        if (((this.timer || this.skipAnimation))) {\n            this._slideReset();\n            this.skipAnimation = true;\n            var b = JSBNG__setTimeout(function() {\n                this.skipAnimation = false;\n            }.bind(this), 500);\n        }\n         else this.timer = JSBNG__setTimeout(function() {\n            this._slideReset();\n        }.bind(this), this.animationTime);\n    ;\n    ;\n    },\n    _slide: function(a) {\n        this._slideSetup(false);\n        this.setVisibleTabs(true);\n        this.slideInc = ((a * (this.handleWidth)));\n        this.leftPos = ((-(a) * ((this.numNext * (this.slideInc)))));\n        this.chatTabBar.style.left = ((this.leftPos + \"px\"));\n        animation(this.chatTabBar).by(\"left\", this.slideInc).duration(((this.animationTime - 10))).go();\n    },\n    _slideSetup: function(a) {\n        this.chat.style.position = ((a ? \"\" : \"relative\"));\n        this.chat.style.overflow = ((a ? \"visible\" : \"hidden\"));\n        if (!this.chatWidth) {\n            this.chatWidth = this.chatTabBar.clientWidth;\n        }\n    ;\n    ;\n        if (a) {\n            this.chatWidth = null;\n        }\n    ;\n    ;\n        this.chat.style.width = ((a ? \"\" : ((this.chatWidth + \"px\"))));\n        this.chatTabBar.style.width = ((a ? \"\" : ((((chatDisplay.numTabs * this.handleWidth)) + \"px\"))));\n        this.chatTabBar.style.position = ((a ? \"\" : \"absolute\"));\n    },\n    _slideReset: function() {\n        JSBNG__clearTimeout(this.timer);\n        this.timer = null;\n        this._slideSetup(true);\n        this._build();\n        var a = chatDisplay.lastFocused;\n        if (a) {\n            var b = chatDisplay.tabList.indexOf(chatDisplay.tabs[a]);\n            if (this._inRange(b)) {\n                chatDisplay.refocus();\n            }\n             else chatDisplay.lastFocused = null;\n        ;\n        ;\n        }\n    ;\n    ;\n        this._doSync();\n    },\n    next: function() {\n        ((this.numNext && this.shift(this.numShift)));\n        return false;\n    },\n    prev: function() {\n        ((this.numPrev && this.shift(-this.numShift)));\n        return false;\n    }\n};\nvar VideoChatPlugin = function() {\n\n};\nFunction.mixin(VideoChatPlugin, \"Arbiter\", {\n    INSTALL_TYPES: {\n        JAVA: 0,\n        MANUAL: 1\n    },\n    isSupported: function() {\n        var b = ((ua.windows() && ((((((((ua.ie() >= 7)) && !ua.ie64())) || ((ua.firefox() >= 3.6)))) || ((ua.JSBNG__chrome() >= 5))))));\n        var a = ((((ua.osx() > 10.4)) && ((((((ua.firefox() >= 3.6)) || ((ua.JSBNG__chrome() >= 5)))) || ((ua.safari() >= 500))))));\n        return ((b || a));\n    },\n    notifyFromApplet: function(b, a) {\n        Arbiter.inform(String(b), {\n            args: String(a)\n        });\n    },\n    isInstalled: function() {\n        var a = false;\n        if (VideoChatPlugin.isSupported()) {\n            if (VideoChatPlugin.usesActiveX()) {\n                var c = null;\n                try {\n                    c = new ActiveXObject(\"SkypeLimited.SkypeWebPlugin\");\n                    a = !!c;\n                } catch (b) {\n                \n                };\n            ;\n                c = null;\n            }\n             else a = VideoChatPlugin._getInstalledVersion();\n        ;\n        }\n    ;\n    ;\n        return a;\n    },\n    usesActiveX: function() {\n        return ((((ua.ie() && ua.windows())) && !ua.JSBNG__opera()));\n    },\n    setLogger: function(a) {\n        VideoChatPlugin.log = ((a || bagofholding));\n    },\n    embed: function(a) {\n        Bootloader.loadComponents(\"VideoChatPluginCore\", function() {\n            VideoChatPlugin.embed(a);\n        });\n    },\n    remove: bagofholding,\n    _getInstalledVersion: function() {\n        if (!JSBNG__navigator) {\n            return null;\n        }\n    ;\n    ;\n        JSBNG__navigator.plugins.refresh(false);\n        mimeHandler = JSBNG__navigator.mimeTypes[\"application/skypesdk-plugin\"];\n        return ((mimeHandler && mimeHandler.enabledPlugin));\n    }\n});\nvar VideoChatView = {\n    RINGTONE_PATH: \"/sound/bling.mp3\",\n    WINDOW_NAME_COOKIE_KEY: \"vcpwn\",\n    TARGET_ID_COOKIE_KEY: \"vctid\",\n    inIncomingCall: false,\n    inOutgoingCall: false,\n    inManualInstall: false,\n    tokens: [],\n    init: function() {\n        VideoChatView.subscribe(VideoEvents.CALL_INCOMING, VideoChatView._onIncomingCall);\n        VideoChatView.subscribe(VideoEvents.START_CALL_UI, function(a, b) {\n            if (!VideoChatView.inOutgoingCall) {\n                VideoChatView.inOutgoingCall = true;\n                if (VideoChatPlugin.isInstalled()) {\n                    VideoChatView.JSBNG__onOutgoingCall(b.idTarget);\n                }\n                 else VideoChatView._invokeCore(\"promptInstall\", b.idTarget);\n            ;\n            ;\n            }\n        ;\n        ;\n        });\n        if (VideoChatPlugin.isSupported()) {\n            CSS.addClass(JSBNG__document.documentElement, \"videoCallEnabled\");\n        }\n    ;\n    ;\n        JSBNG__onbeforeunloadRegister(function() {\n            if (((((VideoChatView.inIncomingCall || VideoChatView.inOutgoingCall)) && !VideoChatView.inManualInstall))) {\n                return _tx(\"Leaving this page will end your call.\");\n            }\n        ;\n        ;\n        });\n        JSBNG__onleaveRegister(function() {\n            if (((VideoChatView.inIncomingCall || VideoChatView.inOutgoingCall))) {\n                VideoEvents.inform(VideoEvents.CANCEL_CALL, {\n                    cause: \"leave:page\"\n                });\n                VideoChatView.inIncomingCall = false;\n                VideoChatView.inOutgoingCall = false;\n            }\n        ;\n        ;\n        });\n        VideoChatView._checkPriorState();\n    },\n    subscribe: function(b, a) {\n        VideoChatView.tokens.push(VideoEvents.subscribe(b, a));\n    },\n    JSBNG__onProfileButtonClick: function(a) {\n        VideoChatView._invokeCore(\"JSBNG__onProfileButtonClick\", a);\n    },\n    unload: function() {\n        while (VideoChatView.tokens.length) {\n            VideoEvents.unsubscribe(VideoChatView.tokens.pop());\n        ;\n        };\n    ;\n    },\n    mightReloadPostInstall: function() {\n        return ua.windows();\n    },\n    _showDialog: function(b, a) {\n        new Dialog().setAllowCrossPageTransition(true).setTop(((a ? 85 : 125))).setFixed(true).setAsync(new AsyncRequest(b)).show();\n    },\n    _onIncomingCall: function(a, b) {\n        VideoChatView.inIncomingCall = true;\n        VideoChatView._showDialog(URI(\"/ajax/chat/video/incoming_call.php\").setQueryData({\n            idTarget: b.idTarget,\n            callId: b.callId\n        }), true);\n    },\n    JSBNG__onOutgoingCall: function(a) {\n        VideoChatView.inOutgoingCall = true;\n        VideoChatView._showDialog(((\"/ajax/chat/video/outgoing_call.php?idTarget=\" + a)));\n    },\n    _checkPriorState: function() {\n        if (VideoChatView.mightReloadPostInstall()) {\n            var a = getCookie(VideoChatView.WINDOW_NAME_COOKIE_KEY);\n            if (a) {\n                clearCookie(VideoChatView.WINDOW_NAME_COOKIE_KEY);\n                var b = getCookie(VideoChatView.TARGET_ID_COOKIE_KEY);\n                if (b) {\n                    clearCookie(VideoChatView.TARGET_ID_COOKIE_KEY);\n                    if (getCookie(VideoChatView.TARGET_ID_COOKIE_KEY)) {\n                        return;\n                    }\n                ;\n                ;\n                    if (VideoChatPlugin.isInstalled()) {\n                        VideoChatView.JSBNG__onOutgoingCall(b);\n                    }\n                ;\n                ;\n                }\n            ;\n            ;\n            }\n        ;\n        ;\n        }\n    ;\n    ;\n    },\n    _invokeCore: function(b) {\n        var a = Array.prototype.slice.call(arguments, 1);\n        Bootloader.loadComponents(\"VideoChatViewCore\", function() {\n            VideoChatView.initCore();\n            VideoChatView[b].apply(VideoChatView, a);\n        });\n    }\n};\nvar VideoChat = {\n    init: function() {\n        VideoEvents.subscribe(VideoEvents.START_CALL_UI, function() {\n            return VideoChat.JSBNG__onStartCallUI();\n        });\n        VideoEvents.subscribe(VideoEvents.START_CALL, function(a, b) {\n            VideoChat._invokeCore(\"JSBNG__onStartCall\", b.idTarget);\n        });\n        VideoChatView.init();\n        Arbiter.inform(\"video-chat/initialized\", this, Arbiter.BEHAVIOR_STATE);\n    },\n    handleMessage: function(b, a, c) {\n        VideoChat._invokeCore(\"handleMessage\", b, a, c);\n    },\n    JSBNG__onStartCallUI: bagofholding,\n    _invokeCore: function(b) {\n        var a = Array.prototype.slice.call(arguments, 1);\n        Bootloader.loadComponents(\"VideoChatCore\", function() {\n            VideoChat.initCore();\n            VideoChat[b].apply(VideoChat, a);\n        });\n    }\n};");
// 15166
fpc.call(JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_28[13], o20,o22);
// undefined
o20 = null;
// 20740
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o1,o3);
// undefined
o1 = null;
// undefined
o3 = null;
// 20759
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o27,o28);
// undefined
o27 = null;
// undefined
o28 = null;
// 20892
o2.valueOf = f925563445_1175;
// undefined
o2 = null;
// 20899
o25.valueOf = f925563445_1175;
// undefined
o25 = null;
// 20778
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o29,o30);
// undefined
o29 = null;
// undefined
o30 = null;
// 21288
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_157[0](o22);
// 22080
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o35,o36);
// undefined
o35 = null;
// undefined
o36 = null;
// 22095
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o37,o38);
// undefined
o37 = null;
// undefined
o38 = null;
// 22218
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o32,o39);
// undefined
o32 = null;
// undefined
o39 = null;
// 22233
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o40,o41);
// undefined
o40 = null;
// undefined
o41 = null;
// 22248
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o42,o43);
// undefined
o42 = null;
// undefined
o43 = null;
// 22263
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o44,o45);
// undefined
o44 = null;
// undefined
o45 = null;
// 22278
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o46,o47);
// undefined
o46 = null;
// undefined
o47 = null;
// 22293
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o48,o49);
// undefined
o48 = null;
// undefined
o49 = null;
// 22308
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o50,o51);
// undefined
o50 = null;
// undefined
o51 = null;
// 22323
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o52,o53);
// undefined
o52 = null;
// undefined
o53 = null;
// 22338
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o54,o55);
// undefined
o54 = null;
// undefined
o55 = null;
// 22353
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o56,o57);
// undefined
o56 = null;
// undefined
o57 = null;
// 22368
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o58,o59);
// undefined
o58 = null;
// undefined
o59 = null;
// 22383
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o60,o61);
// undefined
o60 = null;
// undefined
o61 = null;
// 22398
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o62,o63);
// undefined
o62 = null;
// undefined
o63 = null;
// 22413
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o64,o65);
// undefined
o64 = null;
// undefined
o65 = null;
// 22633
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 22701
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 22789
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 22818
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 22847
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 23181
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 23262
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 23312
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 23341
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 23373
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o4,o33);
// undefined
o4 = null;
// undefined
o33 = null;
// 23392
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o34,o66);
// undefined
o34 = null;
// undefined
o66 = null;
// 23411
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o67,o68);
// undefined
o67 = null;
// undefined
o68 = null;
// 23444
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o69,o70);
// undefined
o69 = null;
// undefined
o70 = null;
// 23463
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o71,o72);
// undefined
o71 = null;
// undefined
o72 = null;
// 23482
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o73,o74);
// undefined
o73 = null;
// undefined
o74 = null;
// 23501
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o24,o75);
// undefined
o24 = null;
// undefined
o75 = null;
// 23520
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o76,o77);
// undefined
o76 = null;
// undefined
o77 = null;
// 23539
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o78,o79);
// undefined
o78 = null;
// undefined
o79 = null;
// 23558
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o80,o81);
// undefined
o80 = null;
// undefined
o81 = null;
// 23577
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o82,o83);
// undefined
o82 = null;
// undefined
o83 = null;
// 23596
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o84,o85);
// undefined
o84 = null;
// undefined
o85 = null;
// 23615
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o86,o87);
// undefined
o86 = null;
// undefined
o87 = null;
// 23634
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o88,o89);
// undefined
o88 = null;
// undefined
o89 = null;
// 23653
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o90,o91);
// undefined
o90 = null;
// undefined
o91 = null;
// 23672
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o92,o93);
// undefined
o92 = null;
// undefined
o93 = null;
// 23691
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o94,o95);
// undefined
o94 = null;
// undefined
o95 = null;
// 23710
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o96,o97);
// undefined
o96 = null;
// undefined
o97 = null;
// 23729
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o98,o99);
// undefined
o98 = null;
// undefined
o99 = null;
// 23748
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o100,o101);
// undefined
o100 = null;
// undefined
o101 = null;
// 23767
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o102,o103);
// undefined
o102 = null;
// undefined
o103 = null;
// 23786
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o104,o105);
// undefined
o104 = null;
// undefined
o105 = null;
// 23805
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o106,o107);
// undefined
o106 = null;
// undefined
o107 = null;
// 23824
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o108,o109);
// undefined
o108 = null;
// undefined
o109 = null;
// 23843
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o110,o111);
// undefined
o110 = null;
// undefined
o111 = null;
// 23862
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o112,o113);
// undefined
o112 = null;
// undefined
o113 = null;
// 23881
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o114,o115);
// undefined
o114 = null;
// undefined
o115 = null;
// 23900
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o116,o117);
// undefined
o116 = null;
// undefined
o117 = null;
// 23919
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o118,o119);
// undefined
o118 = null;
// undefined
o119 = null;
// 23938
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o120,o121);
// undefined
o120 = null;
// undefined
o121 = null;
// 23957
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o122,o123);
// undefined
o122 = null;
// undefined
o123 = null;
// 23976
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o124,o125);
// undefined
o124 = null;
// undefined
o125 = null;
// 23995
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o126,o127);
// undefined
o126 = null;
// undefined
o127 = null;
// 24014
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o128,o129);
// undefined
o128 = null;
// undefined
o129 = null;
// 24033
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o130,o131);
// undefined
o130 = null;
// undefined
o131 = null;
// 24052
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o132,o133);
// undefined
o132 = null;
// undefined
o133 = null;
// 24071
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o134,o135);
// undefined
o134 = null;
// undefined
o135 = null;
// 24090
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o136,o137);
// undefined
o136 = null;
// undefined
o137 = null;
// 24109
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o138,o139);
// undefined
o138 = null;
// undefined
o139 = null;
// 24128
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o140,o141);
// undefined
o140 = null;
// undefined
o141 = null;
// 24147
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o142,o143);
// undefined
o142 = null;
// undefined
o143 = null;
// 24166
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o144,o145);
// undefined
o144 = null;
// undefined
o145 = null;
// 24185
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o146,o147);
// undefined
o146 = null;
// undefined
o147 = null;
// 24204
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o148,o149);
// undefined
o148 = null;
// undefined
o149 = null;
// 24223
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o150,o151);
// undefined
o150 = null;
// undefined
o151 = null;
// 24242
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o152,o153);
// undefined
o152 = null;
// undefined
o153 = null;
// 24261
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o154,o155);
// undefined
o154 = null;
// undefined
o155 = null;
// 24280
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o156,o157);
// undefined
o156 = null;
// undefined
o157 = null;
// 24299
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o158,o159);
// undefined
o158 = null;
// undefined
o159 = null;
// 24318
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o160,o161);
// undefined
o160 = null;
// undefined
o161 = null;
// 24337
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o162,o163);
// undefined
o162 = null;
// undefined
o163 = null;
// 24356
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o164,o165);
// undefined
o164 = null;
// undefined
o165 = null;
// 24375
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o166,o167);
// undefined
o166 = null;
// undefined
o167 = null;
// 24394
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o168,o169);
// undefined
o168 = null;
// undefined
o169 = null;
// 24413
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o170,o171);
// undefined
o170 = null;
// undefined
o171 = null;
// 24432
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o172,o173);
// undefined
o172 = null;
// undefined
o173 = null;
// 24451
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o174,o175);
// undefined
o174 = null;
// undefined
o175 = null;
// 24470
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o176,o177);
// undefined
o176 = null;
// undefined
o177 = null;
// 24489
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o178,o179);
// undefined
o178 = null;
// undefined
o179 = null;
// 24508
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o180,o181);
// undefined
o180 = null;
// undefined
o181 = null;
// 24527
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o182,o183);
// undefined
o182 = null;
// undefined
o183 = null;
// 24546
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o184,o185);
// undefined
o184 = null;
// undefined
o185 = null;
// 24565
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o186,o187);
// undefined
o186 = null;
// undefined
o187 = null;
// 24584
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o188,o189);
// undefined
o188 = null;
// undefined
o189 = null;
// 24603
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o190,o191);
// undefined
o190 = null;
// undefined
o191 = null;
// 24622
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o192,o193);
// undefined
o192 = null;
// undefined
o193 = null;
// 24641
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o194,o195);
// undefined
o194 = null;
// undefined
o195 = null;
// 24660
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o196,o197);
// undefined
o196 = null;
// undefined
o197 = null;
// 24679
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o198,o199);
// undefined
o198 = null;
// undefined
o199 = null;
// 24698
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o200,o201);
// undefined
o200 = null;
// undefined
o201 = null;
// 24717
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o202,o203);
// undefined
o202 = null;
// undefined
o203 = null;
// 24736
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o204,o205);
// undefined
o204 = null;
// undefined
o205 = null;
// 24755
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o206,o207);
// undefined
o206 = null;
// undefined
o207 = null;
// 24774
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o208,o209);
// undefined
o208 = null;
// undefined
o209 = null;
// 24793
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o210,o211);
// undefined
o210 = null;
// undefined
o211 = null;
// 24795
JSBNG_Replay.s082fcf515016ee1031a177a6c4d1bf6ed1d26724_88[0]();
// 24813
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o212,o213);
// undefined
o212 = null;
// undefined
o213 = null;
// 24828
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o214,o215);
// undefined
o214 = null;
// undefined
o215 = null;
// 24843
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o216,o217);
// undefined
o216 = null;
// undefined
o217 = null;
// 24858
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o218,o219);
// undefined
o218 = null;
// undefined
o219 = null;
// 24873
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o220,o221);
// undefined
o220 = null;
// undefined
o221 = null;
// 24888
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o222,o223);
// undefined
o222 = null;
// undefined
o223 = null;
// 24913
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o224,o225);
// undefined
o224 = null;
// undefined
o225 = null;
// 24928
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o226,o227);
// undefined
o226 = null;
// undefined
o227 = null;
// 24947
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o26,o228);
// undefined
o26 = null;
// undefined
o228 = null;
// 24966
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o23,o229);
// undefined
o23 = null;
// undefined
o229 = null;
// 24985
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o230,o231);
// undefined
o230 = null;
// undefined
o231 = null;
// 25000
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o232,o233);
// undefined
o232 = null;
// undefined
o233 = null;
// 25015
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o234,o235);
// undefined
o234 = null;
// undefined
o235 = null;
// 25034
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o31,o236);
// undefined
o31 = null;
// undefined
o236 = null;
// 25049
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o237,o238);
// undefined
o237 = null;
// undefined
o238 = null;
// 25064
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o239,o240);
// undefined
o239 = null;
// undefined
o240 = null;
// 25080
JSBNG_Replay.s8a49429a6603de1543c369412d20f364f6ef46c7_158[0](o22);
// undefined
o22 = null;
// 25115
fpc.call(JSBNG_Replay.s6e7388bce8bd61779ec50008bb318803a134ae12_11[2], o241,o242);
// undefined
o241 = null;
// undefined
o242 = null;
// 25118
cb(); return null; }
finalize(); })();
